# region common
l_on = {
    "ru": "вкл",
    "en": "on",
    "es": "en",
    "fr": "en",
    "zh": "开启",
    "ar": "تشغيل",
}
l_off = {
    "ru": "выкл",
    "en": "off",
    "es": "de",
    "fr": "de",
    "zh": "关掉",
    "ar": "إيقاف",
}
l_yes = {
    "ru": "да",
    "en": "yes",
    "es": "sí",
    "fr": "oui",
    "zh": "是的",
    "ar": "نعم",
}
l_no = {
    "ru": "нет",
    "en": "no",
    "es": "no",
    "fr": "non",
    "zh": "没有",
    "ar": "لا",
}
l_yes_percent = {
    "ru": "👩🏽‍💻 Да, 100%",
    "en": "👩🏽‍💻 Yes, 100%",
    "es": "👩🏽‍💻 Sí, 100%",
    "fr": "👩🏽‍💻 Oui, 100%",
    "zh": "👩🏽‍💻 是的，100%",
    "ar": "👩🏽‍💻 نعم، 100%",
}
l_no_percent = {
    "ru": "👩🏽‍💻 Нет, 0%",
    "en": "👩🏽‍💻 No, 0%",
    "es": "👩🏽‍💻 No, 0%",
    "fr": "👩🏽‍💻 Non, 0%",
    "zh": "👩🏽‍💻 不，0%",
    "ar": "👩🏽‍💻 لا، 0%",
}
l_all_ans = {
    "ru": "все",
    "en": "all",
    "es": "todo",
    "fr": "tout",
    "zh": "所有",
    "ar": "كل شيء",
}
l_menu = {
    "ru": "🔙 Menu",
    "en": "🔙 Menu",
    "es": "🔙 Menú",
    "fr": "🔙 Menu",
    "zh": "🔙 菜单",
    "ar": "🔙 القائمة",
}
l_back = {
    "ru": "🔙 Назад",
    "en": "🔙 Back",
    "es": "🔙 Atrás",
    "fr": "🔙 Retour",
    "zh": "🔙 返回",
    "ar": "🔙 العودة",
}
l_forever = {
    "ru": "навсегда",
    "en": "forever",
    "es": "para siempre",
    "fr": "pour toujours",
    "zh": "永远",
    "ar": "إلى الأبد",
}
l_members = {
    "ru": "участ.",
    "en": "participant.",
    "es": "participante.",
    "fr": "part.",
    "zh": "参与。",
    "ar": "مشارك.",
}
l_add = {
    "ru": "✅ Добавить",
    "en": "✅ Add",
    "es": "✅ Agregar",
    "fr": "✅ Ajouter",
    "zh": "✅ 添加",
    "ar": "✅ إضافة",
}
l_untill = {
    "ru": "до",
    "en": "until",
    "es": "hasta",
    "fr": "jusqu'à",
    "zh": "到",
    "ar": "إلى",
}
l_remove = {
    "ru": "🚫 Удалить",
    "en": "🚫 Delete",
    "es": "🚫 Eliminar",
    "fr": "🚫 Supprimer",
    "zh": "🚫 删除",
    "ar": "🚫 حذف",
}
l_try_again = {
    "ru": "👩🏽‍💻 <b>Ошибка</b> или попробуй позже",
    "en": "👩🏽‍💻 <b>Error</b> or try again later",
    "es": "👩🏽‍💻 <b>Error</b> o inténtalo más tarde",
    "fr": "👩🏽‍💻 <b>Erreur</b> ou réessayez plus tard",
    "zh": "👩🏽‍💻 <b>错误</b> 或稍后再试",
    "ar": "👩🏽‍💻 <b>خطأ</b> أو حاول لاحقًا",
}
l_hand_request = {
    "ru": "👩🏽‍💻 <i><b>Обработка</b> запроса..\n#длительность 1мин</i>",
    "en": "👩🏽‍💻 <i><b>Processing</b> request..\n#duration 1min</i>",
    "es": "👩🏽‍💻 <i><b>Procesando</b> la solicitud..\n#duración 1min</i>",
    "fr": "👩🏽‍💻 <i><b>Traitement</b> de la demande..\n#durée 1min</i>",
    "zh": "👩🏽‍💻 <i><b>处理</b> 请求..\n#持续时间 1分钟</i>",
    "ar": "👩🏽‍💻 <i><b>معالجة</b> الطلب..\n#المدة 1دقيقة</i>",
}
l_please_subscribe = {
    "ru": "👩🏽‍💻 Оформи ежемесячную 💨Подписку",
    "en": "👩🏽‍💻 Subscribe to the monthly 💨Subscription",
    "es": "👩🏽‍💻 Suscríbete mensualmente a la 💨Suscripción",
    "fr": "👩🏽‍💻 Abonnez-vous à un abonnement mensuel 💨",
    "zh": "👩🏽‍💻 订阅每月💨订阅",
    "ar": "👩🏽‍💻 قم بإنشاء اشتراك شهري 💨",
}
l_please_subscribe_need = {
    "ru": "👩🏽‍💻 <b>Необходимо</b> 💨Подписка",
    "en": "👩🏽‍💻 <b>Required</b> 💨Subscription",
    "es": "👩🏽‍💻 <b>Necesario</b> 💨Suscripción",
    "fr": "👩🏽‍💻 <b>Nécessaire</b> 💨Abonnement",
    "zh": "👩🏽‍💻 <b>必要</b> 💨订阅",
    "ar": "👩🏽‍💻 <b>مطلوب</b> 💨اشتراك",
}
l_subscribe_spoiler = {
    "ru": "оформи 💨Подписку",
    "en": "Subscribe 💨",
    "es": "suscríbete 💨",
    "fr": "abonne-toi 💨",
    "zh": "оформ💨订阅",
    "ar": "اشترك 💨",
}
l_subscribe_channel_for_post = {
    "ru": "👩🏽‍💻 <b>Подпишись</b> на @{0}, чтобы продолжить",
    "en": "👩🏽‍💻 <b>Subscribe</b> to @{0} to continue",
    "es": "👩🏽‍💻 <b>Suscríbete</b> a @{0} para continuar",
    "fr": "👩🏽‍💻 <b>Abonnez-vous</b> à @{0} pour continuer",
    "zh": "👩🏽‍💻 <b>订阅</b> @{0} 以继续",
    "ar": "👩🏽‍💻 <b>اشترك</b> في @{0} للمتابعة",
}
l_sound = {
    "ru": "Звук",
    "en": "Sound",
    "es": "Sonido",
    "fr": "Son",
    "zh": "声音",
    "ar": "صوت",
}
l_date = {
    "ru": "Дата",
    "en": "Date",
    "es": "Fecha",
    "fr": "Date",
    "zh": "日期",
    "ar": "تاريخ",
}
l_timer = {
    "ru": "Таймер",
    "en": "Timer",
    "es": "Temporizador",
    "fr": "Minuteur",
    "zh": "计时器",
    "ar": "مؤقت",
}
l_media = {
    "ru": "Медиа",
    "en": "Media",
    "es": "Medios",
    "fr": "Média",
    "zh": "媒体",
    "ar": "وسائط",
}
l_week = {
    "ru": "неделя",
    "en": "week",
    "es": "semana",
    "fr": "semaine",
    "zh": "周",
    "ar": "أسبوع",
}
l_subscribers = {
    "ru": "подписчики",
    "en": "subscribers",
    "es": "suscriptores",
    "fr": "abonnés",
    "zh": "订阅者",
    "ar": "المشتركين",
}
l_sec = {
    "ru": "сек",
    "en": "sec",
    "es": "seg",
    "fr": "sec",
    "zh": "秒",
    "ar": "ثانية",
}
l_min = {
    "ru": "мин",
    "en": "min",
    "es": "min",
    "fr": "min",
    "zh": "分钟",
    "ar": "دقيقة",
}
l_hours = {
    "ru": "часов",
    "en": "hours",
    "es": "horas",
    "fr": "heures",
    "zh": "小时",
    "ar": "ساعات",
}
l_days = {
    "ru": "дней",
    "en": "days",
    "es": "días",
    "fr": "jours",
    "zh": "天数",
    "ar": "أيام",
}
l_length = {
    "ru": "Длина",
    "en": "Length",
    "es": "Longitud",
    "fr": "Longueur",
    "zh": "长度",
    "ar": "الطول",
}
l_post = {
    "ru": "пост",
    "en": "post",
    "es": "publicación",
    "fr": "post",
    "zh": "帖子",
    "ar": "منشور",
}
l_post_upper = {
    "ru": "Пост",
    "en": "Post",
    "es": "Publicación",
    "fr": "Post",
    "zh": "帖子",
    "ar": "منشور",
}
l_from_channel = {
    "ru": "из канала",
    "en": "from the channel",
    "es": "del canal",
    "fr": "du canal",
    "zh": "来自频道",
    "ar": "من القناة",
}
l_choose_direction = {
    "ru": "👇🏽 <b>Выбери</b> направление",
    "en": "👇🏽 <b>Select</b> a direction",
    "es": "👇🏽 <b>Elige</b> la dirección",
    "fr": "👇🏽 <b>Choisis</b> une direction",
    "zh": "👇🏽 <b>选择</b> 方向",
    "ar": "👇🏽 <b>اختر</b> الاتجاه",
}
l_choose_direction_app = {
    "ru": "👇🏽 <b>Для</b> создания мини-приложения открой веб-версию через [🫧 Menu] слева или жми на кнопку [👩🏽‍💻 Приложения]: далее вставляй токен и настраивай свое приложение",
    "en": "👇🏽 <b>To</b> create a mini-app, open the web version via [🫧 Menu] on the left or click the [👩🏽‍💻 Applications] button: then paste the token and configure your app",
    "es": "👇🏽 <b>Para</b> crear una mini-aplicación, abre la versión web a través de [🫧 Menu] a la izquierda o pulsa el botón [👩🏽‍💻 Aplicaciones]: luego pega el token y configura tu aplicación",
    "fr": "👇🏽 <b>Pour</b> créer une mini-application, ouvre la version web via [🫧 Menu] à gauche ou clique sur le bouton [👩🏽‍💻 Applications] : ensuite colle le token et configure ton application",
    "zh": "👇🏽 <b>要</b>创建迷你应用，请通过左侧的 [🫧 Menu] 打开网页版或点击 [👩🏽‍💻 应用] 按钮：然后粘贴令牌并配置你的应用",
    "ar": "👇🏽 <b>لـ</b>إنشاء تطبيق مصغر، افتح النسخة الويب عبر [🫧 Menu] على اليسار أو اضغط على زر [👩🏽‍💻 التطبيقات]: ثم الصق الرمز وقم بإعداد تطبيقك",
}
l_about = {
    "ru": "<b>👩🏽‍💻 Ferey проекты</b>:\n\n<blockquote>▪️проекты: <a href='https://t.me/FereyDemoBot?start=about'>Demo App</a>\n▪️конструктор: <a href='https://t.me/FereyBotBot?start=about'>Bot App</a>\n▪️приватные посты: <a href='https://t.me/FereyPostBot?start=about'>Post App</a>\n▪️публичные медиа: <a href='https://t.me/FereyMediaBot?start=about'>Media App</a>\n▪️администрирование: <a href='https://t.me/FereyChannelBot?start=about'>Channel App</a>\n▪️модерация: <a href='https://t.me/FereyGroupBot?start=about'>Group App</a>\n▪️поиск: <a href='https://t.me/FereyFindBot?start=about'>Find App</a>\n▪️инструменты: <a href='https://t.me/FereyToolsBot?start=about'>Tools App</a>\n▪️стикеры/эмоджи: <a href='https://t.me/FereyStickerBot?start=about'>Sticker App</a>\n▪️нейро: <a href='https://t.me/FereyAIBot?start=about'>AI App</a>\n▪️автоматизация: <a href='https://t.me/FereyUserBot?start=about'>User App</a>\n▪️блокчейн NFT/FT: <a href='https://t.me/FereyTONestBot?start=about'>TONest App</a>\n▪️кодекс/фест/лига: <a href='https://t.me/FereyCodexBot?start=about'>Codex App</a></blockquote>\n\n👩🏽‍💻 /content",
    "en": "<b>👩🏽‍💻 Ferey projects</b>:\n\n<blockquote>▪️projects: <a href='https://t.me/FereyDemoBot?start=about'>Demo App</a>\n▪️constructor: <a href='https://t.me/FereyBotBot?start=about'>Bot App</a>\n▪️private posts: <a href='https://t.me/FereyPostBot?start=about'>Post App</a>\n▪️public media: <a href='https://t.me/FereyMediaBot?start=about'>Media App</a>\n▪️administration: <a href='https://t.me/FereyChannelBot?start=about'>Channel App</a>\n▪️moderation: <a href='https://t.me/FereyGroupBot?start=about'>Group App</a>\n▪️search: <a href='https://t.me/FereyFindBot?start=about'>Find App</a>\n▪️tools: <a href='https://t.me/FereyToolsBot?start=about'>Tools App</a>\n▪️stickers/emojis: <a href='https://t.me/FereyStickerBot?start=about'>Sticker App</a>\n▪️neuro: <a href='https://t.me/FereyAIBot?start=about'>AI App</a>\n▪️automation: <a href='https://t.me/FereyUserBot?start=about'>User App</a>\n▪️blockchain NFT/FT: <a href='https://t.me/FereyTONestBot?start=about'>TONest App</a>\n▪️code/fest/league: <a href='https://t.me/FereyCodexBot?start=about'>Codex App</a></blockquote>\n\n👩🏽‍💻 /content",
    "es": "<b>👩🏽‍💻 Proyectos Ferey</b>:\n\n<blockquote>▪️proyectos: <a href='https://t.me/FereyDemoBot?start=about'>Demo App</a>\n▪️constructor: <a href='https://t.me/FereyBotBot?start=about'>Bot App</a>\n▪️publicaciones privadas: <a href='https://t.me/FereyPostBot?start=about'>Post App</a>\n▪️medios públicos: <a href='https://t.me/FereyMediaBot?start=about'>Media App</a>\n▪️administración: <a href='https://t.me/FereyChannelBot?start=about'>Channel App</a>\n▪️moderación: <a href='https://t.me/FereyGroupBot?start=about'>Group App</a>\n▪️búsqueda: <a href='https://t.me/FereyFindBot?start=about'>Find App</a>\n▪️herramientas: <a href='https://t.me/FereyToolsBot?start=about'>Tools App</a>\n▪️stickers/emojis: <a href='https://t.me/FereyStickerBot?start=about'>Sticker App</a>\n▪️neuro: <a href='https://t.me/FereyAIBot?start=about'>AI App</a>\n▪️automatización: <a href='https://t.me/FereyUserBot?start=about'>User App</a>\n▪️blockchain NFT/FT: <a href='https://t.me/FereyTONestBot?start=about'>TONest App</a>\n▪️código/fest/liga: <a href='https://t.me/FereyCodexBot?start=about'>Codex App</a></blockquote>\n\n👩🏽‍💻 /content",
    "fr": "<b>👩🏽‍💻 Projets Ferey</b>:\n\n<blockquote>▪️projets : <a href='https://t.me/FereyDemoBot?start=about'>Demo App</a>\n▪️constructeur : <a href='https://t.me/FereyBotBot?start=about'>Bot App</a>\n▪️posts privés : <a href='https://t.me/FereyPostBot?start=about'>Post App</a>\n▪️médias publics : <a href='https://t.me/FereyMediaBot?start=about'>Media App</a>\n▪️administration : <a href='https://t.me/FereyChannelBot?start=about'>Channel App</a>\n▪️modération : <a href='https://t.me/FereyGroupBot?start=about'>Group App</a>\n▪️recherche : <a href='https://t.me/FereyFindBot?start=about'>Find App</a>\n▪️outils : <a href='https://t.me/FereyToolsBot?start=about'>Tools App</a>\n▪️stickers/émoticônes : <a href='https://t.me/FereyStickerBot?start=about'>Sticker App</a>\n▪️neuro : <a href='https://t.me/FereyAIBot?start=about'>AI App</a>\n▪️automatisation : <a href='https://t.me/FereyUserBot?start=about'>User App</a>\n▪️blockchain NFT/FT : <a href='https://t.me/FereyTONestBot?start=about'>TONest App</a>\n▪️code/fête/ligue : <a href='https://t.me/FereyCodexBot?start=about'>Codex App</a></blockquote>\n\n👩🏽‍💻 /content",
    "zh": "<b>👩🏽‍💻 Ferey 项目</b>:\n\n<blockquote>▪️项目: <a href='https://t.me/FereyDemoBot?start=about'>Demo App</a>\n▪️构建器: <a href='https://t.me/FereyBotBot?start=about'>Bot App</a>\n▪️私人帖子: <a href='https://t.me/FereyPostBot?start=about'>Post App</a>\n▪️公共媒体: <a href='https://t.me/FereyMediaBot?start=about'>Media App</a>\n▪️管理: <a href='https://t.me/FereyChannelBot?start=about'>Channel App</a>\n▪️审核: <a href='https://t.me/FereyGroupBot?start=about'>Group App</a>\n▪️搜索: <a href='https://t.me/FereyFindBot?start=about'>Find App</a>\n▪️工具: <a href='https://t.me/FereyToolsBot?start=about'>Tools App</a>\n▪️贴纸/表情: <a href='https://t.me/FereyStickerBot?start=about'>Sticker App</a>\n▪️神经: <a href='https://t.me/FereyAIBot?start=about'>AI App</a>\n▪️自动化: <a href='https://t.me/FereyUserBot?start=about'>User App</a>\n▪️区块链 NFT/FT: <a href='https://t.me/FereyTONestBot?start=about'>TONest App</a>\n▪️法典/节/联盟: <a href='https://t.me/FereyCodexBot?start=about'>Codex App</a></blockquote>\n\n👩🏽‍💻 /content",
    "ar": "<b>👩🏽‍💻 مشاريع Ferey</b>:\n\n<blockquote>▪️المشاريع: <a href='https://t.me/FereyDemoBot?start=about'>تطبيق العرض</a>\n▪️المنشئ: <a href='https://t.me/FereyBotBot?start=about'>تطبيق البوت</a>\n▪️المشاركات الخاصة: <a href='https://t.me/FereyPostBot?start=about'>تطبيق المنشور</a>\n▪️الوسائط العامة: <a href='https://t.me/FereyMediaBot?start=about'>تطبيق الوسائط</a>\n▪️الإدارة: <a href='https://t.me/FereyChannelBot?start=about'>تطبيق القناة</a>\n▪️الاعتدال: <a href='https://t.me/FereyGroupBot?start=about'>تطبيق المجموعة</a>\n▪️البحث: <a href='https://t.me/FereyFindBot?start=about'>تطبيق البحث</a>\n▪️الأدوات: <a href='https://t.me/FereyToolsBot?start=about'>تطبيق الأدوات</a>\n▪️الملصقات/الإيموجي: <a href='https://t.me/FereyStickerBot?start=about'>تطبيق الملصقات</a>\n▪️الذكاء الاصطناعي: <a href='https://t.me/FereyAIBot?start=about'>تطبيق الذكاء الاصطناعي</a>\n▪️الأتمتة: <a href='https://t.me/FereyUserBot?start=about'>تطبيق المستخدم</a>\n▪️بلوكشين NFT/FT: <a href='https://t.me/FereyTONestBot?start=about'>تطبيق TONest</a>\n▪️المدونة/المهرجان/الرابطة: <a href='https://t.me/FereyCodexBot?start=about'>تطبيق المدونة</a></blockquote>\n\n👩🏽‍💻 /content",
}
l_subscribe_btn = {
    "ru": "👩🏽‍💻 Я подписался",
    "en": "👩🏽‍💻 I subscribed",
    "es": "👩🏽‍💻 Me he suscrito",
    "fr": "👩🏽‍💻 Je me suis abonné",
    "zh": "👩🏽‍💻 我已订阅",
    "ar": "👩🏽‍💻 لقد اشتركت",
}
l_subscribe_all = {
    "ru": "¹ Все приложения и проекты",
    "en": "¹ All applications and projects",
    "es": "¹ Todas las aplicaciones y proyectos",
    "fr": "¹ Toutes les applications et projets",
    "zh": "¹ 所有应用程序和项目",
    "ar": "¹ جميع التطبيقات والمشاريع",
}
l_subscribe_already = {
    "ru": "👩🏽‍💻 У вас уже есть активная 💨Подписка",
    "en": "👩🏽‍💻 You already have an active 💨Subscription",
    "es": "👩🏽‍💻 Ya tienes una 💨Suscripción activa",
    "fr": "👩🏽‍💻 Vous avez déjà un abonnement actif 💨",
    "zh": "👩🏽‍💻 您已经有一个活跃的💨订阅",
    "ar": "👩🏽‍💻 لديك اشتراك نشط بالفعل 💨",
}
l_donate = {
    "ru": "Донат",
    "en": "Donate",
    "es": "Donación",
    "fr": "Donner",
    "zh": "捐赠",
    "ar": "تبرع",
}
l_progress = {
    "ru": "Прогресс",
    "en": "Progress",
    "es": "Progreso",
    "fr": "Progrès",
    "zh": "进展",
    "ar": "التقدم",
}
l_marketplace = {
    "ru": "Маркетплейс",
    "en": "Marketplace",
    "es": "Marketplace",
    "fr": "Marché",
    "zh": "市场平台",
    "ar": "سوق",
}
l_subscription = {
    "ru": "Подписка",
    "en": "Subscription",
    "es": "Suscripción",
    "fr": "Abonnement",
    "zh": "订阅",
    "ar": "اشتراك",
}
l_material = {
    "ru": "Материал",
    "en": "Material",
    "es": "Material",
    "fr": "Matériel",
    "zh": "材料",
    "ar": "المادة",
}
l_subscribe_success = {
    "ru": "👩🏽‍💻 <b>Успешный</b> донат!",
    "en": "👩🏽‍💻 <b>Successful</b> donation!",
    "es": "👩🏽‍💻 <b>¡Donación exitosa!</b>",
    "fr": "👩🏽‍💻 <b>Don</b> réussi !",
    "zh": "👩🏽‍💻 <b>成功的</b> 捐赠！",
    "ar": "👩🏽‍💻 <b>تبرع ناجح</b>!",
}
l_subscribe_balance = {
    "ru": "👩🏽‍💻 Текущий /balance {0}{1}",
    "en": "👩🏽‍💻 Current /balance {0}{1}",
    "es": "👩🏽‍💻 Actual /balance {0}{1}",
    "fr": "👩🏽‍💻 Actuel /balance {0}{1}",
    "zh": "👩🏽‍💻 当前 /balance {0}{1}",
    "ar": "👩🏽‍💻 الرصيد الحالي /balance {0}{1}",
}
l_subscribe_deposit = {
    "ru": "² Донат на баланс",
    "en": "² Donation to balance",
    "es": "² Donación al saldo",
    "fr": "² Don sur le solde",
    "zh": "² 充值到余额",
    "ar": "² تبرع إلى الرصيد",
}
l_sub_to_private_channel = {
    "ru": "подписка на канал",
    "en": "subscription to the channel",
    "es": "suscripción al canal",
    "fr": "abonnement à la chaîne",
    "zh": "频道订阅",
    "ar": "الاشتراك في القناة",
}
l_language_get = {
    "ru": "🌏 <b>Выбери</b> один из доступных языков",
    "en": "🌏 <b>Select</b> one of the available languages",
    "es": "🌏 <b>Elige</b> uno de los idiomas disponibles",
    "fr": "🌏 <b>Choisis</b> une des langues disponibles",
    "zh": "🌏 <b>选择</b> 可用语言之一",
    "ar": "🌏 <b>اختر</b> واحدة من اللغات المتاحة",
}
l_language_set = {
    "ru": "{0} Текущий язык: {1}\n\n👩🏽‍💻 Жми /start",
    "en": "{0} Current language: {1}\n\n👩🏽‍💻 Click /start",
    "es": "{0} Idioma actual: {1}\n\n👩🏽‍💻 Haz clic en /start",
    "fr": "{0} Langue actuelle : {1}\n\n👩🏽‍💻 Appuie sur /start",
    "zh": "{0} 当前语言: {1}\n\n👩🏽‍💻 点击 /start",
    "ar": "{0} اللغة الحالية: {1}\n\n👩🏽‍💻 اضغط /start",
}
l_ferey_like = {
    "ru": "💔 Лайк",
    "en": "💔 Like",
    "es": "💔 Me gusta",
    "fr": "💔 J'aime",
    "zh": "💔 点赞",
    "ar": "💔 أعجبني",
}
l_subscribe_main = {
    "ru": "👩🏽‍💻 <b>Оформи</b> ежемесячную подписку:\n\n",
    "en": "👩🏽‍💻 <b>Subscribe</b> to a monthly plan:",
    "es": "👩🏽‍💻 <b>Suscríbete</b> a la suscripción mensual:",
    "fr": "👩🏽‍💻 <b>Abonnez-vous</b> à un abonnement mensuel :",
    "zh": "👩🏽‍💻 <b>订阅</b> 每月订阅：",
    "ar": "👩🏽‍💻 <b>اشترك</b> في الاشتراك الشهري:",
}
l_paysupport = {
    "ru": "👩🏽‍💻 <b>Возврат</b> средств согласно <a href='https://telegram.org/tos/bot-developers#6-2-4-rewards-for-stars'>условиям использования</a> возможен не позднее 21 дня командой /refund для разовых (нерекуррентных) операций",
    "en": "👩🏽‍💻 <b>Refund</b> of funds according to <a href='https://telegram.org/tos/bot-developers#6-2-4-rewards-for-stars'>terms of use</a> is possible no later than 21 days by the /refund team for one-time (non-recurring) operations.",
    "es": "👩🏽‍💻 <b>Reembolso</b> de fondos de acuerdo con <a href='https://telegram.org/tos/bot-developers#6-2-4-rewards-for-stars'>los términos de uso</a> es posible hasta 21 días por parte del equipo /refund para operaciones únicas (no recurrentes)",
    "fr": "👩🏽‍💻 <b>Remboursement</b> des fonds conformément aux <a href='https://telegram.org/tos/bot-developers#6-2-4-rewards-for-stars'>conditions d'utilisation</a> possible au plus tard 21 jours par l'équipe /refund pour les opérations uniques (non récurrentes)",
    "zh": "👩🏽‍💻 <b>退款</b> 根据 <a href='https://telegram.org/tos/bot-developers#6-2-4-rewards-for-stars'>使用条款</a>，团队 /refund 可在不超过 21 天内处理一次性（非定期）操作。",
    "ar": "👩🏽‍💻 <b>استرداد</b> الأموال وفقًا لـ <a href='https://telegram.org/tos/bot-developers#6-2-4-rewards-for-stars'>شروط الاستخدام</a> ممكن في موعد لا يتجاوز 21 يومًا من قبل الفريق /refund للعمليات الفردية (غير المتكررة)",
}
l_refund_need_id = {
    "ru": "👩🏽‍💻 <b>Необходимо</b> прислать ID-операции (более 100 символов), хранящийся в настройках телеграм аккаунта, с которого была произведена оплата в разделе [★ Мои звезды]",
    "en": "👩🏽‍💻 <b>It is necessary</b> to send the operation ID (more than 100 characters), stored in the settings of the Telegram account from which the payment was made in the section [★ My Stars]",
    "es": "👩🏽‍💻 <b>Es necesario</b> enviar el ID de la operación (más de 100 caracteres), que se encuentra en la configuración de la cuenta de Telegram desde la que se realizó el pago en la sección [★ Mis estrellas]",
    "fr": "👩🏽‍💻 <b>Il est nécessaire</b> d'envoyer l'ID de l'opération (plus de 100 caractères), qui se trouve dans les paramètres du compte Telegram à partir duquel le paiement a été effectué dans la section [★ Mes étoiles]",
    "zh": "👩🏽‍💻 <b>需要</b> 发送操作ID（超过100个字符），该ID存储在进行支付的Telegram账户的设置中，位于[★ 我的星星]部分。",
    "ar": "👩🏽‍💻 <b>يجب</b> إرسال معرف العملية (أكثر من 100 حرف) المخزن في إعدادات حساب التليجرام الذي تم منه الدفع في قسم [★ نجومي]",
}
l_refund_title = {
    "ru": "Возврат",
    "en": "Return",
    "es": "Devolución",
    "fr": "Retour",
    "zh": "返回",
    "ar": "عودة",
}
l_refund_already_done = {
    "ru": "👩🏽‍💻 <b>Возврат</b> уже был произведен ранее",
    "en": "👩🏽‍💻 <b>Return</b> has already been made earlier",
    "es": "👩🏽‍💻 <b>El reembolso</b> ya se ha realizado anteriormente",
    "fr": "👩🏽‍💻 <b>Le retour</b> a déjà été effectué auparavant",
    "zh": "👩🏽‍💻 <b>退款</b> 已经在之前进行过",
    "ar": "👩🏽‍💻 <b>تم إجراء الإرجاع سابقًا</b>",
}
l_refund_success = {
    "ru": "👩🏽‍💻 <b>Возврат</b> произведен успешно",
    "en": "👩🏽‍💻 <b>Return</b> completed successfully",
    "es": "👩🏽‍💻 <b>Devolución</b> realizada con éxito",
    "fr": "👩🏽‍💻 <b>Retour</b> effectué avec succès",
    "zh": "👩🏽‍💻 <b>退货</b> 成功完成",
    "ar": "👩🏽‍💻 <b>تمت عملية الإرجاع بنجاح</b>",
}
l_refund_incorrect = {
    "ru": "👩🏽‍💻 <b>Некорректный</b> ID-операции",
    "en": "👩🏽‍💻 <b>Incorrect</b> operation ID",
    "es": "👩🏽‍💻 <b>ID de operación <b>incorrecto</b></b>",
    "fr": "👩🏽‍💻 <b>ID d'opération incorrect</b>",
    "zh": "👩🏽‍💻 <b>不正确</b> 的操作ID",
    "ar": "👩🏽‍💻 <b>معرف غير صحيح</b> ID-العملية",
}
l_refund_error = {
    "ru": "👩🏽‍💻 <b>Ошибка</b> возврата (возврат не возможен после 21 дня)",
    "en": "👩🏽‍💻 <b>Return Error</b> (return not possible after 21 days)",
    "es": "👩🏽‍💻 <b>Error</b> de devolución (la devolución no es posible después de 21 días)",
    "fr": "👩🏽‍💻 <b>Erreur</b> de retour (le retour n'est pas possible après 21 jours)",
    "zh": "👩🏽‍💻 <b>错误</b> 退货（21天后无法退货）",
    "ar": "👩🏽‍💻 <b>خطأ</b> في الإرجاع (لا يمكن الإرجاع بعد 21 يومًا)",
}
l_payment_6_months = {
    "ru": "6 месяцев",
    "en": "6 months",
    "es": "6 meses",
    "fr": "6 mois",
    "zh": "6个月",
    "ar": "6 أشهر",
}
l_payment_1_months = {
    "ru": "1 месяц",
    "en": "1 month",
    "es": "1 mes",
    "fr": "1 mois",
    "zh": "1个月",
    "ar": "1 شهر",
}
l_payment_success = {
    "ru": "👩🏽‍💻 <b>Успешная</b> отправка:",
    "en": "👩🏽‍💻 <b>Successful</b> submission:",
    "es": "👩🏽‍💻 <b>Envío</b> exitoso:",
    "fr": "👩🏽‍💻 <b>Envoi</b> réussi :",
    "zh": "👩🏽‍💻 <b>成功</b> 发送：",
    "ar": "👩🏽‍💻 <b>إرسال</b> ناجح:",
}
l_payment_hashtag = {
    "ru": "#оплата",
    "en": "#payment",
    "es": "#pago",
    "fr": "#paiement",
    "zh": "#支付",
    "ar": "#الدفع",
}
l_payment = {
    "ru": "Оплата",
    "en": "Payment",
    "es": "Pago",
    "fr": "Paiement",
    "zh": "支付",
    "ar": "الدفع",
}
l_payment_check_token = {
    "ru": "👩🏽‍💻 <b>Проверьте</b> свой токен для получения платажей",
    "en": "👩🏽‍💻 <b>Check</b> your token for receiving payments",
    "es": "👩🏽‍💻 <b>Verifique</b> su token para recibir pagos",
    "fr": "👩🏽‍💻 <b>Vérifiez</b> votre jeton pour recevoir des paiements",
    "zh": "👩🏽‍💻 <b>检查</b> 您的付款令牌",
    "ar": "👩🏽‍💻 <b>تحقق</b> من رمزك للحصول على المدفوعات",
}
l_payment_check_token_chn = {
    "ru": "👩🏽‍💻 <b>Проверьте</b> свой токен для получения платажей (бот для приема платежей также должен быть Администратором канала)",
    "en": "👩🏽‍💻 <b>Check</b> your token for receiving payments (the payment bot must also be an Administrator of the channel)",
    "es": "👩🏽‍💻 <b>Verifique</b> su token para recibir pagos (el bot para recibir pagos también debe ser Administrador del canal)",
    "fr": "👩🏽‍💻 <b>Vérifiez</b> votre jeton pour recevoir des paiements (le bot de réception des paiements doit également être Administrateur du canal)",
    "zh": "👩🏽‍💻 <b>检查</b> 您的支付令牌（接收支付的机器人也必须是频道管理员）",
    "ar": "👩🏽‍💻 <b>تحقق</b> من رمزك لاستلام المدفوعات (يجب أن يكون البوت لاستلام المدفوعات أيضًا مسؤولًا عن القناة)",
}
l_media_content_successfully_changed = {
    "ru": "👩🏽‍💻 <b>Медиа</b>-контент успешно изменен",
    "en": "👩🏽‍💻 <b>Media</b> content has been successfully changed",
    "es": "👩🏽‍💻 <b>El</b> contenido multimedia se ha modificado con éxito",
    "fr": "👩🏽‍💻 <b>Le</b> contenu multimédia a été modifié avec succès",
    "zh": "👩🏽‍💻 <b>媒体</b>内容已成功更改",
    "ar": "👩🏽‍💻 <b>تم تعديل</b> المحتوى الإعلامي بنجاح",
}
l_waiting = {
    "ru": "Ожидание",
    "en": "Waiting",
    "es": "Esperando",
    "fr": "Attente",
    "zh": "等待",
    "ar": "انتظار",
}
l_don_desc = {
    "ru": "★ Поддержка и развитие",
    "en": "★ Support and development",
    "es": "★ Soporte y desarrollo",
    "fr": "★ Support et développement",
    "zh": "★ 支持与发展",
    "ar": "★ الدعم والتطوير",
}
l_bot_mention_in_story = {
    "ru": "Отметка в сториз",
    "en": "Story mention",
    "es": "Marca en las historias",
    "fr": "Marque dans les stories",
    "zh": "故事中的标记",
    "ar": "علامة في القصص",
}
l_boost_parse = {
    "ru": "👩🏽‍💻 <b>Boost</b> список",
    "en": "👩🏽‍💻 <b>Boost</b> list",
    "es": "👩🏽‍💻 <b>Impulsa</b> lista",
    "fr": "👩🏽‍💻 <b>Boost</b> liste",
    "zh": "👩🏽‍💻 <b>提升</b> 列表",
    "ar": "👩🏽‍💻 <b>تعزيز</b> القائمة",
}
l_admin_closed_group_reject = {
    "ru": "👩🏽‍💻 Администратор закрытой группы не принял заявки на вступление",
    "en": "👩🏽‍💻 The administrator of the closed group did not accept the membership requests.",
    "es": "👩🏽‍💻 El administrador del grupo cerrado no aceptó las solicitudes de ingreso",
    "fr": "👩🏽‍💻 L'administrateur du groupe privé n'a pas accepté les demandes d'adhésion",
    "zh": "👩🏽‍💻 私密群组的管理员没有接受入群申请",
    "ar": "👩🏽‍💻 مدير المجموعة المغلقة لم يقبل طلبات الانضمام",
}
l_permissions_add_members = {
    "ru": "🚶 Зайди в «Разрешения» группы и включи <i>участникам группы</i> возможность: [Добавление участников]",
    "en": "🚶 Go to the group's \"Permissions\" and enable <i>group members</i> the ability: [Add members]",
    "es": "🚶 Entra en \"Permisos\" del grupo y activa la opción para <i>miembros del grupo</i>: [Agregar miembros]",
    "fr": "🚶 Va dans «Permissions» du groupe et active la possibilité pour <i>les membres du groupe</i> : [Ajouter des membres]",
    "zh": "🚶 进入小组的“权限”并启用 <i>小组成员</i> 的权限: [添加成员]",
    "ar": "🚶 ادخل إلى \"الأذونات\" الخاصة بالمجموعة وقم بتمكين <i>أعضاء المجموعة</i> من إمكانية: [إضافة أعضاء]",
}
l_insert_group_link = {
    "ru": "🚶 Вставь ссылку на группу, а не канал",
    "en": "🚶 Insert a link to the group, not the channel",
    "es": "🚶 Inserta el enlace al grupo, no al canal",
    "fr": "🚶 Insère le lien vers le groupe, pas le canal",
    "zh": "🚶 请插入小组的链接，而不是频道",
    "ar": "🚶 أدخل رابط المجموعة، وليس القناة",
}
l_start_group_check = {
    "ru": "🚶 Начинаем проверку группы..\n#длительность 2мин",
    "en": "🚶 Starting group check..  \n#duration 2min",
    "es": "🚶 Comenzamos la verificación del grupo..  \n#duración 2min",
    "fr": "🚶 Nous commençons la vérification du groupe..  \n#durée 2min",
    "zh": "🚶 开始检查小组..\n#持续时间 2分钟",
    "ar": "🚶 نبدأ فحص المجموعة..  \n#المدة 2دقائق",
}
l_check_group_members = {
    "ru": "🚶 Проверяем участников группы..\n#длительность 1мин",
    "en": "🚶 Checking group participants..  \n#duration 1min",
    "es": "🚶 Verificando a los participantes del grupo..  \n#duración 1min",
    "fr": "🚶 Vérifions les participants du groupe..  \n#durée 1min",
    "zh": "🚶 正在检查小组成员..\n#持续时间 1分钟",
    "ar": "🚶 نتحقق من المشاركين في المجموعة..  \n#المدة 1دقيقة",
}
l_admin_rights_required = {
    "ru": "🔺 Требуются права админа",
    "en": "🔺 Admin rights required",
    "es": "🔺 Se requieren derechos de administrador",
    "fr": "🔺 Des droits d'administrateur sont requis",
    "zh": "🔺 需要管理员权限",
    "ar": "🔺 تحتاج إلى حقوق المسؤول",
}
l_triggers = {
    "ru": "Триггеры",
    "en": "Triggers",
    "es": "Disparadores",
    "fr": "Déclencheurs",
    "zh": "触发器",
    "ar": "المحفزات",
}
l_actions2 = {
    "ru": "Действия",
    "en": "Actions",
    "es": "Acciones",
    "fr": "Actions",
    "zh": "行动",
    "ar": "إجراءات",
}
l_messages = {
    "ru": "Сообщения",
    "en": "Messages",
    "es": "Mensajes",
    "fr": "Messages",
    "zh": "消息",
    "ar": "رسائل",
}
l_languages = {
    "ru": "Языки",
    "en": "Languages",
    "es": "Idiomas",
    "fr": "Langues",
    "zh": "语言",
    "ar": "اللغات",
}
l_buttons = {
    "ru": "Кнопки",
    "en": "Buttons",
    "es": "Botones",
    "fr": "Boutons",
    "zh": "按钮",
    "ar": "أزرار",
}
l_medias = {
    "ru": "Медиа",
    "en": "Media",
    "es": "Medios",
    "fr": "Média",
    "zh": "媒体",
    "ar": "وسائط",
}
l_users = {
    "ru": "Пользователи",
    "en": "Users",
    "es": "Usuarios",
    "fr": "Utilisateurs",
    "zh": "用户",
    "ar": "المستخدمون",
}
l_cmember_parse = {
    "ru": "👥 <b>Cписок</b> подписчиков: <u>{0}</u>\n\n[✅ <i>Назначение администраторов</i>] - включение опции позволяет получить подписчиков до добавления @{1}-приложения\n\n👩🏽‍💻 <b>Оформи</b> <a href='{2}'>💨Подписку</a> для получения имен пользователей",
    "en": "👥 <b>Subscriber</b> list: <u>{0}</u>\n\n[✅ <i>Assigning administrators</i>] - enabling this option allows you to get subscribers before adding the @{1} app\n\n👩🏽‍💻 <b>Set up</b> <a href='{2}'>💨Subscription</a> to receive usernames",
    "es": "👥 <b>Lista</b> de suscriptores: <u>{0}</u>\n\n[✅ <i>Asignación de administradores</i>] - habilitar la opción permite obtener suscriptores antes de agregar la aplicación @{1}\n\n👩🏽‍💻 <b>Realiza</b> <a href='{2}'>💨Suscripción</a> para recibir nombres de usuario",
    "fr": "👥 <b>Liste</b> des abonnés : <u>{0}</u>\n\n[✅ <i>Désignation des administrateurs</i>] - activer cette option permet d'obtenir des abonnés avant d'ajouter l'application @{1}\n\n👩🏽‍💻 <b>Créez</b> <a href='{2}'>💨l'abonnement</a> pour obtenir les noms d'utilisateur",
    "zh": "👥 <b>订阅者</b> 列表: <u>{0}</u>\n\n[✅ <i>管理员指定</i>] - 启用此选项可以在添加 @{1} 应用程序之前获取订阅者\n\n👩🏽‍💻 <b>创建</b> <a href='{2}'>💨订阅</a> 以获取用户名",
    "ar": "👥 <b>قائمة</b> المشتركين: <u>{0}</u>\n\n[✅ <i>تعيين المشرفين</i>] - تفعيل الخيار يسمح بالحصول على المشتركين قبل إضافة @{1}-التطبيق\n\n👩🏽‍💻 <b>قم بإنشاء</b> <a href='{2}'>💨اشتراك</a> للحصول على أسماء المستخدمين",
}
l_parse_rights = {
    "ru": "👥 <b>В настройках</b> [Администраторы] вкл опцию для @{0}-приложения:\n[✅ Назначение администраторов]\n🕚Подожди 1min\n👩🏽‍💻 Выполни команду /parse\n\n⚙️ <b>Команды</b> /cmd",
    "en": "👥 <b>In the settings</b> [Administrators] enable the option for the @{0} application:  \n[✅ Assign Administrators]  \n🕚Wait 1min  \n👩🏽‍💻 Execute the command /parse  \n\n⚙️ <b>Commands</b> /cmd",
    "es": "👥 <b>En la configuración</b> [Administradores] activa la opción para la aplicación @{0}:\n[✅ Asignación de administradores]\n🕚Espera 1min\n👩🏽‍💻 Ejecuta el comando /parse\n\n⚙️ <b>Comandos</b> /cmd",
    "fr": "👥 <b>Dans les paramètres</b> [Administrateurs] active l'option pour l'application @{0} :\n[✅ Attribution des administrateurs]\n🕚Attends 1min\n👩🏽‍💻 Exécute la commande /parse\n\n⚙️ <b>Commandes</b> /cmd",
    "zh": "👥 <b>在设置中</b> [管理员] 启用 @{0} 应用程序的选项：  \n[✅ 指定管理员]  \n🕚 等待 1分钟  \n👩🏽‍💻 执行命令 /parse  \n\n⚙️ <b>命令</b> /cmd",
    "ar": "👥 <b>في الإعدادات</b> [المسؤولون] قم بتفعيل الخيار لتطبيق @{0}:\n[✅ تعيين المسؤولين]\n🕚انتظر 1min\n👩🏽‍💻 نفذ الأمر /parse\n\n⚙️ <b>الأوامر</b> /cmd",
}
l_info_anonymous_for = {
    "ru": "Аноним для",
    "en": "Anonymous for",
    "es": "Anónimo para",
    "fr": "Anonyme pour",
    "zh": "匿名为",
    "ar": "مجهول لـ",
}
l_info_oppforpart = {
    "ru": "Возможности участников",
    "en": "Participants' capabilities",
    "es": "Oportunidades de los participantes",
    "fr": "Fonctionnalités des participants",
    "zh": "参与者的能力",
    "ar": "إمكانيات المشاركين",
}
# endregion


# region post
l_post_media = {
    "ru": "✏️ 1. <b>Прикрепи медиа</b> контент для поста: <i>фото/гиф/видео/аудио/документ/стикер</i> или запиши <i>голосовое/телескоп</i>",
    "en": "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or record <i>voice/telescope</i>",
    "es": "✏️ 1. <b>Adjunta contenido</b> multimedia para la publicación: <i>foto/gif/video/audio/documento/sticker</i> o graba <i>un mensaje de voz/telescopio</i>",
    "fr": "✏️ 1. <b>Ajoute un contenu</b> média pour le post : <i>photo/gif/vidéo/audio/document/sticker</i> ou enregistre <i>un message vocal/téléscope</i>",
    "zh": "✏️ 1. <b>附加媒体</b> 内容到帖子：<i>照片/动图/视频/音频/文档/贴纸</i> 或录制 <i>语音/望远镜</i>",
    "ar": "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/GIF/فيديو/صوت/وثيقة/ملصق</i> أو سجل <i>صوتي/تلسكوبي</i>",
}
l_post_media_wait = {
    "ru": "👩🏽‍💻 <b>Обработка</b> {0}..\n#длительность {1}мин",
    "en": "👩🏽‍💻 <b>Processing</b> {0}..  \n#duration {1}min",
    "es": "👩🏽‍💻 <b>Procesando</b> {0}..\n#duración {1}min",
    "fr": "👩🏽‍💻 <b>Traitement</b> {0}..  \n#durée {1}min",
    "zh": "👩🏽‍💻 <b>处理</b> {0}..\n#持续时间 {1}分钟",
    "ar": "👩🏽‍💻 <b>معالجة</b> {0}..  \n#المدة {1}دقائق",
}
l_post_media_toobig = {
    "ru": "👩🏽‍💻 Файл больше 20 Мб, загрузи меньший обьем",
    "en": "👩🏽‍💻 The file is larger than 20 MB, please upload a smaller size.",
    "es": "👩🏽‍💻 El archivo es mayor de 20 MB, sube uno de menor tamaño.",
    "fr": "👩🏽‍💻 Le fichier dépasse 20 Mo, télécharge un fichier de plus petite taille.",
    "zh": "👩🏽‍💻 文件超过20MB，请上传更小的文件",
    "ar": "👩🏽‍💻 الملف أكبر من 20 ميغابايت، يرجى تحميل حجم أصغر",
}
l_post_media_chat_not_found = {
    "ru": "👩🏽‍💻 Необходимо /start-запустить @{0}-приложение перед выполнением операции",
    "en": "👩🏽‍💻 You need to /start the @{0} application before performing the operation.",
    "es": "👩🏽‍💻 Es necesario /start-iniciar la aplicación @{0} antes de realizar la operación",
    "fr": "👩🏽‍💻 Il est nécessaire de /start-lancer l'application @{0} avant d'effectuer l'opération.",
    "zh": "👩🏽‍💻 在执行操作之前，需要启动 @{0} 应用程序 /start",
    "ar": "👩🏽‍💻 يجب /start-تشغيل تطبيق @{0} قبل تنفيذ العملية",
}
l_post_media_need_token = {
    "ru": "👩🏽‍💻 Необходимо создать @tg-бота для приема платежей и добавить его токен в настройках приложения",
    "en": "👩🏽‍💻 It is necessary to create a @tg-bot for receiving payments and add its token in the application settings.",
    "es": "👩🏽‍💻 Es necesario crear un @tg-bot para recibir pagos y agregar su token en la configuración de la aplicación",
    "fr": "👩🏽‍💻 Il est nécessaire de créer un @tg-bot pour recevoir des paiements et d'ajouter son token dans les paramètres de l'application",
    "zh": "👩🏽‍💻 需要创建一个 @tg-机器人来接收付款，并在应用程序设置中添加它的令牌",
    "ar": "👩🏽‍💻 يجب إنشاء @tg-بوت لاستقبال المدفوعات وإضافة رمزه في إعدادات التطبيق",
}
l_post_sticker_toobig = {
    "ru": "👩🏽‍💻 Загрузи меньший обьем",
    "en": "👩🏽‍💻 Upload a smaller size",
    "es": "👩🏽‍💻 Carga un volumen menor",
    "fr": "👩🏽‍💻 Télécharge un volume plus petit",
    "zh": "👩🏽‍💻 上传更小的容量",
    "ar": "👩🏽‍💻 قم بتحميل حجم أصغر",
}
l_media_isvideonote = {
    "ru": "👩🏽‍💻 <b>Использовать</b> это квадратное видео как <b>телескоп</b> <i>(круглая видео-заметка)</i>?",
    "en": "👩🏽‍💻 <b>Use</b> this square video as a <b>telescope</b> <i>(circular video note)</i>?",
    "es": "👩🏽‍💻 <b>¿Usar</b> este video cuadrado como <b>telescopio</b> <i>(nota de video redonda)</i>?",
    "fr": "👩🏽‍💻 <b>Utiliser</b> cette vidéo carrée comme <b>télescope</b> <i>(note vidéo ronde)</i> ?",
    "zh": "👩🏽‍💻 <b>使用</b> 这个方形视频作为 <b>望远镜</b> <i>(圆形视频备注)</i>？",
    "ar": "👩🏽‍💻 <b>استخدم</b> هذا الفيديو المربع كـ <b>تلسكوب</b> <i>(ملاحظة فيديو دائرية)</i>?",
}
l_post_text = {
    "ru": "✏️ <b>Введи текст</b> (<i>не забудь использовать форматирование</i>)",
    "en": "✏️ <b>Enter text</b> (<i>don't forget to use formatting</i>)",
    "es": "✏️ <b>Introduce el texto</b> (<i>no olvides usar el formato</i>)",
    "fr": "✏️ <b>Entrez le texte</b> (<i>n'oubliez pas d'utiliser le formatage</i>)",
    "zh": "✏️ <b>输入文本</b> (<i>别忘了使用格式</i>)",
    "ar": "✏️ <b>أدخل النص</b> (<i>لا تنسَ استخدام التنسيق</i>)",
}
l_post_text_limit = {
    "ru": "❗️ <b>Количество символов</b> текста (<i>включая форматирование</i>): <u>{0}</u> больше 1024",
    "en": "❗️ <b>Number of characters</b> in the text (<i>including formatting</i>): <u>{0}</u> more than 1024",
    "es": "❗️ <b>Cantidad de caracteres</b> del texto (<i>incluyendo el formato</i>): <u>{0}</u> más de 1024",
    "fr": "❗️ <b>Nombre de caractères</b> du texte (<i>y compris le formatage</i>): <u>{0}</u> supérieur à 1024",
    "zh": "❗️ <b>字符</b> 数量 (<i>包括格式</i>): <u>{0}</u> 超过 1024",
    "ar": "❗️ <b>عدد الأحرف</b> في النص (<i>بما في ذلك التنسيق</i>): <u>{0}</u> أكبر من 1024",
}
l_post_tgph = {
    "ru": "✏️ *2. Использовать загруженный <b>media</b>-контент в виде <u>предпросмотра</u> внизу поста (работает только с <i>jpg|png|gif|mp4</i>-файлами до 5Mb)?\n\n<blockquote>или жми «➡️️/Next», чтобы пропустить этот шаг</blockquote>",
    "en": "✏️ *2. Use the uploaded <b>media</b> content as a <u>preview</u> at the bottom of the post (works only with <i>jpg|png|gif|mp4</i> files up to 5Mb)?\n\n<blockquote>or press \"➡️️/Next\" to skip this step</blockquote>",
    "es": "✏️ *2. ¿Usar el contenido <b>media</b> cargado como <u>vista previa</u> en la parte inferior de la publicación (solo funciona con archivos <i>jpg|png|gif|mp4</i> de hasta 5Mb)?\n\n<blockquote>o presiona «➡️️/Siguiente» para omitir este paso</blockquote>",
    "fr": "✏️ *2. Utiliser le contenu <b>media</b> téléchargé sous forme d'<u>aperçu</u> en bas du post (fonctionne uniquement avec des fichiers <i>jpg|png|gif|mp4</i> jusqu'à 5Mo) ?\n\n<blockquote>ou appuie sur «➡️️/Suivant» pour passer cette étape</blockquote>",
    "zh": "✏️ *2. 在帖子底部以<u>预览</u>的形式使用上传的<b>媒体</b>内容（仅适用于大小不超过5Mb的<i>jpg|png|gif|mp4</i>文件）？\n\n<blockquote>或者点击“➡️️/下一步”以跳过此步骤</blockquote>",
    "ar": "✏️ *2. استخدام المحتوى <b>الوسائط</b> الذي تم تحميله كـ <u>معاينة</u> في أسفل المنشور (يعمل فقط مع ملفات <i>jpg|png|gif|mp4</i> حتى 5Mb)؟\n\n<blockquote>أو اضغط على \"➡️️/التالي\" لتخطي هذه الخطوة</blockquote>",
}
l_post_tgph_yes = {
    "ru": "✅ Да",
    "en": "✅ Yes",
    "es": "✅ Sí",
    "fr": "✅ Oui",
    "zh": "✅ 是",
    "ar": "✅ نعم",
}
l_post_tgph_no = {
    "ru": "☑️ Нет",
    "en": "☑️ No",
    "es": "☑️ No",
    "fr": "☑️ Non",
    "zh": "☑️ 没有",
    "ar": "☑️ لا",
}
l_post_button = {
    "ru": "✏️ 3. <b>Введи названия</b> для кнопок и <b>ссылки</b> в формате (одну или несколько; кликни на образец ниже, чтобы скопировать):\n\n<code>[🐳 Link | {0}]\n\n[❤️ Like][🔗 | https://t.me/share/url?url={0}&text=™️]</code>\n\n<blockquote>или жми «➡️️/Next», чтобы пропустить этот шаг</blockquote>",
    "en": "✏️ 3. <b>Enter the names</b> for the buttons and <b>link</b> in the format (one or several; click on the sample below to copy):\n\n<code>[🐳 Link | {0}]\n\n[❤️ Like][🔗 | https://t.me/share/url?url={0}&text=™️]</code>\n\n<blockquote>or press \"➡️️/Next\" to skip this step</blockquote>",
    "es": "✏️ 3. <b>Introduce los nombres</b> para los botones y <b>enlace</b> en el formato (uno o varios; haz clic en el ejemplo a continuación para copiar):\n\n<code>[🐳 Enlace | {0}]\n\n[❤️ Me gusta][🔗 | https://t.me/share/url?url={0}&text=™️]</code>\n\n<blockquote>o presiona «➡️️/Siguiente» para omitir este paso</blockquote>",
    "fr": "✏️ 3. <b>Entrez les noms</b> pour les boutons et <b>le lien</b> au format (un ou plusieurs ; cliquez sur l'exemple ci-dessous pour copier) :\n\n<code>[🐳 Lien | {0}]\n\n[❤️ J'aime][🔗 | https://t.me/share/url?url={0}&text=™️]</code>\n\n<blockquote>ou appuyez sur «➡️️/Suivant» pour passer cette étape</blockquote>",
    "zh": "✏️ 3. <b>输入按钮和</b> <b>链接的名称</b>，格式为（一个或多个；点击下面的示例以复制）：\n\n<code>[🐳 链接 | {0}]\n\n[❤️ 喜欢][🔗 | https://t.me/share/url?url={0}&text=™️]</code>\n\n<blockquote>或者点击“➡️️/下一步”以跳过此步骤</blockquote>",
    "ar": "✏️ 3. <b>أدخل الأسماء</b> للأزرار و <b>الرابط</b> بالتنسيق (واحد أو أكثر؛ انقر على النموذج أدناه لنسخه):\n\n<code>[🐳 Link | {0}]\n\n[❤️ Like][🔗 | https://t.me/share/url?url={0}&text=™️]</code>\n\n<blockquote>أو اضغط على \"➡️️/التالي\" لتخطي هذه الخطوة</blockquote>",
}
l_post_button_chn = {
    "ru": "✏️ 3. <b>Введи названия</b> для кнопок и <b>ссылки</b> в формате (одну или несколько; кликни на образец ниже, чтобы скопировать):\n\n<code>[🐳 Boost | https://t.me/{0}?boost]\n\n[❤️ Like][🔗 | https://t.me/share/url?url={1}&text=™️]</code>\n\n<blockquote>или жми «➡️️/Next», чтобы пропустить этот шаг</blockquote>",
    "en": "✏️ 3. <b>Enter the names</b> for the buttons and <b>links</b> in the format (one or more; click on the sample below to copy):\n\n<code>[🐳 Boost | https://t.me/{0}?boost]\n\n[❤️ Like][🔗 | https://t.me/share/url?url={1}&text=™️]</code>\n\n<blockquote>or press \"➡️️/Next\" to skip this step</blockquote>",
    "es": "✏️ 3. <b>Introduce los nombres</b> para los botones y <b>enlaces</b> en el formato (uno o varios; haz clic en el ejemplo a continuación para copiar):\n\n<code>[🐳 Boost | https://t.me/{0}?boost]\n\n[❤️ Like][🔗 | https://t.me/share/url?url={1}&text=™️]</code>\n\n<blockquote>o presiona «➡️️/Siguiente» para omitir este paso</blockquote>",
    "fr": "✏️ 3. <b>Entrez les noms</b> pour les boutons et <b>le lien</b> au format (un ou plusieurs ; cliquez sur l'exemple ci-dessous pour copier) :\n\n<code>[🐳 Boost | https://t.me/{0}?boost]\n\n[❤️ Like][🔗 | https://t.me/share/url?url={1}&text=™️]</code>\n\n<blockquote>ou appuyez sur «➡️️/Suivant» pour passer cette étape</blockquote>",
    "zh": "✏️ 3. <b>输入按钮和</b> <b>链接的名称</b>，格式为（一个或多个；点击下面的示例以复制）：\n\n<code>[🐳 Boost | https://t.me/{0}?boost]\n\n[❤️ Like][🔗 | https://t.me/share/url?url={1}&text=™️]</code>\n\n<blockquote>或者点击“➡️️/下一步”以跳过此步骤</blockquote>",
    "ar": "✏️ 3. <b>أدخل أسماء</b> للأزرار و <b>الرابط</b> بالتنسيق (واحد أو أكثر؛ انقر على النموذج أدناه لنسخه):\n\n<code>[🐳 Boost | https://t.me/{0}?boost]\n\n[❤️ Like][🔗 | https://t.me/share/url?url={1}&text=™️]</code>\n\n<blockquote>أو اضغط على \"➡️️/التالي\" لتخطي هذه الخطوة</blockquote>",
}
l_post_button_urlinvalid = {
    "ru": "🔗 Ссылка {0} не действительна",
    "en": "🔗 The link {0} is not valid",
    "es": "🔗 El enlace {0} no es válido",
    "fr": "🔗 Le lien {0} n'est pas valide",
    "zh": "🔗 链接 {0} 无效",
    "ar": "🔗 الرابط {0} غير صالح",
}
l_post_date = {
    "ru": "✏️ <b>Выбери дату</b> на календаре\n\n<blockquote>или жми «➡️️/Next», чтобы не указывать дату</blockquote>",
    "en": "✏️ <b>Select a date</b> on the calendar\n\n<blockquote>or press \"➡️️/Next\" to skip the date</blockquote>",
    "es": "✏️ <b>Elige una fecha</b> en el calendario\n\n<blockquote>o presiona «➡️️/Siguiente» para no especificar una fecha</blockquote>",
    "fr": "✏️ <b>Choisis une date</b> sur le calendrier\n\n<blockquote>ou appuie sur «➡️️/Suivant» pour ne pas indiquer de date</blockquote>",
    "zh": "✏️ <b>选择日期</b> 在日历上\n\n<blockquote>或者点击“➡️️/下一步”，以便不指定日期</blockquote>",
    "ar": "✏️ <b>اختر تاريخًا</b> من التقويم\n\n<blockquote>أو اضغط على \"➡️️/التالي\" لتجنب تحديد التاريخ</blockquote>",
}
l_post_timer = {
    "ru": "✏️ <b>Выбери дату</b> на календаре для <b>авто-удаления</b> поста\n\n<blockquote>или жми «➡️️/Next», чтобы не указывать дату</blockquote>",
    "en": "✏️ <b>Select a date</b> on the calendar for <b>auto-deletion</b> of the post\n\n<blockquote>or click \"➡️️/Next\" to skip specifying a date</blockquote>",
    "es": "✏️ <b>Elige una fecha</b> en el calendario para <b>eliminación automática</b> de la publicación\n\n<blockquote>o presiona «➡️️/Siguiente» para no especificar una fecha</blockquote>",
    "fr": "✏️ <b>Choisissez une date</b> sur le calendrier pour <b>la suppression automatique</b> du post\n\n<blockquote>ou appuyez sur «➡️️/Suivant» pour ne pas indiquer de date</blockquote>",
    "zh": "✏️ <b>选择日期</b> 在日历上用于 <b>自动删除</b> 帖子\n\n<blockquote>或者点击“➡️️/下一步”，以便不指定日期</blockquote>",
    "ar": "✏️ <b>اختر تاريخًا</b> في التقويم لـ <b>الحذف التلقائي</b> للمنشور\n\n<blockquote>أو اضغط على «➡️️/التالي» لعدم تحديد تاريخ</blockquote>",
}
l_post_window = {
    "ru": "✏️ *<b>Введи</b> текст для <i>диалогового окна</i> при нажатии на <u>кнопки</u> <b>поста</b>\n\n<blockquote>или жми «➡️️/Next», чтобы пропустить этот шаг</blockquote>",
    "en": "✏️ *<b>Enter</b> text for the <i>dialog window</i> when clicking on the <u>buttons</u> of the <b>post</b>\n\n<blockquote>or press \"➡️️/Next\" to skip this step</blockquote>",
    "es": "✏️ *<b>Introduce</b> el texto para <i>la ventana de diálogo</i> al hacer clic en <u>el botón</u> <b>de la publicación</b>\n\n<blockquote>o presiona «➡️️/Siguiente» para omitir este paso</blockquote>",
    "fr": "✏️ *<b>Entrez</b> le texte pour <i>la boîte de dialogue</i> en appuyant sur <u>le bouton</u> <b>du post</b>\n\n<blockquote>ou appuyez sur «➡️️/Suivant» pour passer cette étape</blockquote>",
    "zh": "✏️ *<b>输入</b> 在点击 <u>按钮</u> <b>帖子</b> 时的 <i>对话框</i> 文本\n\n<blockquote>或者点击“➡️️/下一步”以跳过此步骤</blockquote>",
    "ar": "✏️ *<b>أدخل</b> نصًا لـ <i>نافذة الحوار</i> عند الضغط على <u>زر</u> <b>المنشور</b>\n\n<blockquote>أو اضغط على «➡️️/التالي» لتخطي هذه الخطوة</blockquote>",
}
l_post_window_limit = {
    "ru": "❗️ <b>Количество символов</b> диалогового окна: <u>{0}</u> больше допустимых 200",
    "en": "❗️ <b>Number of characters</b> in the dialog window: <u>{0}</u> exceeds the allowed 200",
    "es": "❗️ <b>Cantidad de caracteres</b> de la ventana de diálogo: <u>{0}</u> más que los 200 permitidos",
    "fr": "❗️ <b>Nombre de caractères</b> de la fenêtre de dialogue : <u>{0}</u> dépasse le maximum autorisé de 200",
    "zh": "❗️ <b>对话框的字符数</b>：<u>{0}</u> 超过了允许的 200",
    "ar": "❗️ <b>عدد الأحرف</b> في نافذة الحوار: <u>{0}</u> أكبر من الحد المسموح به 200",
}
l_post_finish = {
    "ru": "✅ <b>Пост готов</b>\n\n<i>Нажми «➡️️/Next», чтобы подтвердить, а затем на кнопку: [🔗 Публикация]</i>",
    "en": "✅ <b>Post ready</b>\n\n<i>Click \"➡️️/Next\" to confirm, and then on the button: [🔗 Publish]</i>",
    "es": "✅ <b>Publicación lista</b>\n\n<i>Haz clic en «➡️️/Siguiente» para confirmar, y luego en el botón: [🔗 Publicar]</i>",
    "fr": "✅ <b>Post prêt</b>\n\n<i>Appuie sur «➡️️/Suivant» pour confirmer, puis sur le bouton : [🔗 Publication]</i>",
    "zh": "✅ <b>帖子已准备好</b>\n\n<i>点击“➡️️/下一步”以确认，然后点击按钮：[🔗 发布]</i>",
    "ar": "✅ <b>المنشور جاهز</b>\n\n<i>اضغط على \"➡️️/التالي\" للتأكيد، ثم على الزر: [🔗 نشر]</i>",
}
l_switch_pm_text = {
    "ru": "🔗 Создать пост с кнопкой",
    "en": "🔗 Create a post with a button",
    "es": "🔗 Crear una publicación con un botón",
    "fr": "🔗 Créer un post avec un bouton",
    "zh": "🔗 创建带按钮的帖子",
    "ar": "🔗 إنشاء منشور مع زر",
}
l_post_new = {
    "ru": "⛰ Создать",
    "en": "⛰ Create",
    "es": "⛰ Crear",
    "fr": "⛰ Créer",
    "zh": "⛰ 创建",
    "ar": "⛰ إنشاء",
}
l_post_delete = {
    "ru": "🚫 Удалить",
    "en": "🚫 Delete",
    "es": "🚫 Eliminar",
    "fr": "🚫 Supprimer",
    "zh": "🚫 删除",
    "ar": "🚫 حذف",
}
l_post_change = {
    "ru": "♻️ Изменить",
    "en": "♻️ Change",
    "es": "♻️ Cambiar",
    "fr": "♻️ Modifier",
    "zh": "♻️ 更改",
    "ar": "♻️ تغيير",
}
l_post_creation = {
    "ru": "<b>Дата создания</b>",
    "en": "<b>Creation date</b>",
    "es": "<b>Fecha de creación</b>",
    "fr": "<b>Date de création</b>",
    "zh": "<b>创建日期</b>",
    "ar": "<b>تاريخ الإنشاء</b>",
}
l_post_publish = {
    "ru": "🔗 Публикация",
    "en": "🔗 Publication",
    "es": "🔗 Publicación",
    "fr": "🔗 Publication",
    "zh": "🔗 发布",
    "ar": "🔗 نشر",
}
l_post_pub = {
    "ru": "👩🏽‍💻 Пост опубликован",
    "en": "👩🏽‍💻 Post published",
    "es": "👩🏽‍💻 Publicación publicada",
    "fr": "👩🏽‍💻 Publication publiée",
    "zh": "👩🏽‍💻 帖子已发布",
    "ar": "👩🏽‍💻 تم نشر المنشور",
}
l_post_error = {
    "ru": "👩🏽‍💻 Ошибка опубликации",
    "en": "👩🏽‍💻 Publication error",
    "es": "👩🏽‍💻 Error de publicación",
    "fr": "👩🏽‍💻 Erreur de publication",
    "zh": "👩🏽‍💻 发布错误",
    "ar": "👩🏽‍💻 خطأ في النشر",
}
l_post_btn_answer = {
    "ru": "✅ <b>Пользователь</b> <b>{0}</b> (username={1}, id={2}) <i>нажал</i> на [<b>{3}</b>] в посте #<u>{4}</u>",
    "en": "✅ <b>User</b> <b>{0}</b> (username={1}, id={2}) <i>clicked</i> on [<b>{3}</b>] in post #<u>{4}</u>",
    "es": "✅ <b>Usuario</b> <b>{0}</b> (nombre de usuario={1}, id={2}) <i>hizo clic</i> en [<b>{3}</b>] en la publicación #<u>{4}</u>",
    "fr": "✅ <b>Utilisateur</b> <b>{0}</b> (nom d'utilisateur={1}, id={2}) <i>a cliqué</i> sur [<b>{3}</b>] dans le post #<u>{4}</u>",
    "zh": "✅ <b>用户</b> <b>{0}</b> (用户名={1}, id={2}) <i>点击了</i> [<b>{3}</b>] 在帖子 #<u>{4}</u>",
    "ar": "✅ <b>المستخدم</b> <b>{0}</b> (اسم المستخدم={1}, id={2}) <i>ضغط</i> على [<b>{3}</b>] في المنشور #<u>{4}</u>",
}
l_post_datetime = {
    "ru": "<b>Дата</b>",
    "en": "<b>Date</b>",
    "es": "<b>Fecha</b>",
    "fr": "<b>Date</b>",
    "zh": "<b>日期</b>",
    "ar": "<b>التاريخ</b>",
}
l_post_preview = {
    "ru": "<b>Превью</b>",
    "en": "<b>Preview</b>",
    "es": "<b>Vista previa</b>",
    "fr": "<b>Aperçu</b>",
    "zh": "<b>预览</b>",
    "ar": "<b>معاينة</b>",
}
l_post_buttons = {
    "ru": "<b>Кнопки</b>",
    "en": "<b>Buttons</b>",
    "es": "<b>Botones</b>",
    "fr": "<b>Boutons</b>",
    "zh": "<b>按钮</b>",
    "ar": "<b>الأزرار</b>",
}
l_post_pins = {
    "ru": "<b>Закреп</b>",
    "en": "<b>Pin</b>",
    "es": "<b>Fijar</b>",
    "fr": "<b>Épingle</b>",
    "zh": "<b>固定</b>",
    "ar": "<b>تثبيت</b>",
}
l_btn = {
    "ru": "кнопки",
    "en": "buttons",
    "es": "botones",
    "fr": "boutons",
    "zh": "按钮",
    "ar": "الأزرار",
}
l_default = {
    "ru": "по умолчанию",
    "en": "by default",
    "es": "por defecto",
    "fr": "par défaut",
    "zh": "默认",
    "ar": "افتراضي",
}
l_silence = {
    "ru": "тихо",
    "en": "quiet",
    "es": "silencio",
    "fr": "silencieusement",
    "zh": "安静",
    "ar": "هادئ",
}
l_pin = {
    "ru": "закреп",
    "en": "pin",
    "es": "fijar",
    "fr": "fixer",
    "zh": "固定",
    "ar": "تثبيت",
}
l_preview = {
    "ru": "превью",
    "en": "preview",
    "es": "vista previa",
    "fr": "aperçu",
    "zh": "预览",
    "ar": "معاينة",
}
l_spoiler = {
    "ru": "спойлер",
    "en": "spoiler",
    "es": "spoiler",
    "fr": "spoiler",
    "zh": "剧透",
    "ar": "مفسد",
}
l_podcast = {
    "ru": "подкаст",
    "en": "podcast",
    "es": "podcast",
    "fr": "podcast",
    "zh": "播客",
    "ar": "بودكاست",
}
l_album = {
    "ru": "альбом",
    "en": "album",
    "es": "álbum",
    "fr": "album",
    "zh": "相册",
    "ar": "ألبوم",
}
l_gallery = {
    "ru": "галерея",
    "en": "gallery",
    "es": "galería",
    "fr": "galerie",
    "zh": "画廊",
    "ar": "معرض",
}
l_format = {
    "ru": "формат",
    "en": "format",
    "es": "formato",
    "fr": "format",
    "zh": "格式",
    "ar": "تنسيق",
}
l_reaction = {
    "ru": "реакция",
    "en": "reaction",
    "es": "reacción",
    "fr": "réaction",
    "zh": "反应",
    "ar": "رد فعل",
}
l_effect = {
    "ru": "эффект",
    "en": "effect",
    "es": "efecto",
    "fr": "effet",
    "zh": "效果",
    "ar": "أثر",
}
l_blog = {
    "ru": "блог",
    "en": "blog",
    "es": "blog",
    "fr": "blog",
    "zh": "博客",
    "ar": "مدونة",
}
l_web = {
    "ru": "веб",
    "en": "web",
    "es": "web",
    "fr": "web",
    "zh": "网页",
    "ar": "ويب",
}
l_notice = {
    "ru": "нотис",
    "en": "notice",
    "es": "aviso",
    "fr": "avis",
    "zh": "通知",
    "ar": "إشعار",
}
l_window = {
    "ru": "окно",
    "en": "window",
    "es": "ventana",
    "fr": "fenêtre",
    "zh": "窗口",
    "ar": "نافذة",
}
l_remoji = {
    "ru": "Эмоджи",
    "en": "Emoji",
    "es": "Emojis",
    "fr": "Émoji",
    "zh": "表情符号",
    "ar": "إيموجي",
}
l_theme = {
    "ru": "Тема",
    "en": "Subject",
    "es": "Tema",
    "fr": "Sujet",
    "zh": "主题",
    "ar": "الموضوع",
}
l_destruct = {
    "ru": "Самоуничтожение контента",
    "en": "Self-destruction of content",
    "es": "Autodestrucción de contenido",
    "fr": "Auto-destruction du contenu",
    "zh": "自我毁灭内容",
    "ar": "تدمير المحتوى",
}
l_tag = {
    "ru": "@tag",
    "en": "@tag",
    "es": "@tag",
    "fr": "@tag",
    "zh": "@tag",
    "ar": "@tag",
}
l_via = {
    "ru": "@via",
    "en": "@via",
    "es": "@via",
    "fr": "@via",
    "zh": "@via",
    "ar": "@عبر",
}
l_buttons_text = {
    "ru": "👩🏽‍💻 Режим [✅ кнопки] доступен, если создана хотя бы 1 кнопка при создании поста",
    "en": "👩🏽‍💻 The [✅ button] mode is available if at least 1 button is created when the post is created.",
    "es": "👩🏽‍💻 El modo [✅ botón] está disponible si se ha creado al menos 1 botón al crear la publicación.",
    "fr": "👩🏽‍💻 Le mode [✅ bouton] est disponible si au moins 1 bouton a été créé lors de la création du post.",
    "zh": "👩🏽‍💻 模式 [✅ 按钮] 可用，如果在创建帖子时至少创建了 1 个按钮",
    "ar": "👩🏽‍💻 وضع [✅ الزر] متاح إذا تم إنشاء زر واحد على الأقل عند إنشاء المنشور",
}
l_preview_text = {
    "ru": "👩🏽‍💻 Режим [✅ превью] используется с jpg|png|gif|mp4-файлами до 5Mb",
    "en": "👩🏽‍💻 The [✅ preview] mode is used with jpg|png|gif|mp4 files up to 5Mb",
    "es": "👩🏽‍💻 El modo [✅ vista previa] se utiliza con archivos jpg|png|gif|mp4 de hasta 5Mb",
    "fr": "👩🏽‍💻 Le mode [✅ aperçu] est utilisé avec des fichiers jpg|png|gif|mp4 jusqu'à 5 Mo",
    "zh": "👩🏽‍💻 模式 [✅ 预览] 用于大小不超过 5Mb 的 jpg|png|gif|mp4 文件",
    "ar": "👩🏽‍💻 وضع [✅ المعاينة] يُستخدم مع ملفات jpg|png|gif|mp4 حتى 5Mb",
}
l_gallery_text = {
    "ru": "👩🏽‍💻 Режим [✅ галерея] доступен для 2 и более медиа файлов",
    "en": "👩🏽‍💻 The [✅ gallery] mode is available for 2 or more media files",
    "es": "👩🏽‍💻 El modo [✅ galería] está disponible para 2 o más archivos multimedia",
    "fr": "👩🏽‍💻 Le mode [✅ galerie] est disponible pour 2 fichiers multimédias ou plus",
    "zh": "👩🏽‍💻 模式 [✅ 画廊] 可用于 2 个或更多媒体文件",
    "ar": "👩🏽‍💻 وضع [✅ المعرض] متاح لملفين وسائط أو أكثر",
}
l_spoiler_text = {
    "ru": "👩🏽‍💻 Режим [✅ спойлер] доступен для photo/gif/video контента",
    "en": "👩🏽‍💻 The [✅ spoiler] mode is available for photo/gif/video content",
    "es": "👩🏽‍💻 El modo [✅ spoiler] está disponible para contenido de photo/gif/video",
    "fr": "👩🏽‍💻 Le mode [✅ spoiler] est disponible pour le contenu photo/gif/vidéo",
    "zh": "👩🏽‍💻 模式 [✅ 剧透] 可用于 photo/gif/video 内容",
    "ar": "👩🏽‍💻 وضع [✅ سبويلر] متاح لمحتوى photo/gif/video",
}
l_podcast_call = {
    "ru": "👩🏽‍💻 Режим [✅ подкаст] доступен для audio/voice/video контента или youtube-ссылок в тексте",
    "en": "👩🏽‍💻 The [✅ podcast] mode is available for audio/voice/video content or youtube links in the text.",
    "es": "👩🏽‍💻 El modo [✅ podcast] está disponible para contenido de audio/voz/video o enlaces de youtube en el texto",
    "fr": "👩🏽‍💻 Le mode [✅ podcast] est disponible pour le contenu audio/voix/vidéo ou les liens youtube dans le texte",
    "zh": "👩🏽‍💻 模式 [✅ 播客] 可用于音频/语音/视频内容或文本中的 YouTube 链接",
    "ar": "👩🏽‍💻 وضع [✅ بودكاست] متاح لمحتوى الصوت/الصوت/الفيديو أو روابط يوتيوب في النص",
}
l_window_text = {
    "ru": "👩🏽‍💻 Режим [окно] доступен для постов с кнопками без ссылок",
    "en": "👩🏽‍💻 The [window] mode is available for posts with buttons without links",
    "es": "👩🏽‍💻 El modo [ventana] está disponible para publicaciones con botones sin enlaces",
    "fr": "👩🏽‍💻 Le mode [fenêtre] est disponible pour les publications avec des boutons sans liens",
    "zh": "👩🏽‍💻 模式 [窗口] 可用于没有链接的按钮帖子",
    "ar": "👩🏽‍💻 وضع [نافذة] متاح للمنشورات التي تحتوي على أزرار بدون روابط",
}
l_tag_text = {
    "ru": "👩🏽‍💻 Режим [✅ @tag] доступен для текста без режима @via-бот",
    "en": "👩🏽‍💻 The [✅ @tag] mode is available for text without the @via-bot mode",
    "es": "👩🏽‍💻 El modo [✅ @tag] está disponible para texto sin el modo @via-bot",
    "fr": "👩🏽‍💻 Le mode [✅ @tag] est disponible pour le texte sans le mode @via-bot",
    "zh": "👩🏽‍💻 模式 [✅ @tag] 可用于没有 @via-机器人模式的文本",
    "ar": "👩🏽‍💻 وضع [✅ @tag] متاح للنص بدون وضع @via-بوت",
}
l_destruct_text = {
    "ru": "👩🏽‍💻 Режим [✅ Самоуничтожение] доступен для фото/видео/голосовое/телескоп-контента без режима @via-бот",
    "en": "👩🏽‍💻 The [✅ Self-Destruct] mode is available for photo/video/voice/telescope content without the @via-bot mode.",
    "es": "👩🏽‍💻 El modo [✅ Autodestrucción] está disponible para contenido de foto/video/voz/telescopio sin el modo @via-bot",
    "fr": "👩🏽‍💻 Le mode [✅ Auto-destruction] est disponible pour le contenu photo/vidéo/voix/téléscope sans le mode @via-bot",
    "zh": "👩🏽‍💻 模式 [✅ 自毁] 可用于没有 @via-机器人模式的照片/视频/语音/望远镜内容",
    "ar": "👩🏽‍💻 وضع [✅ التدمير الذاتي] متاح لمحتوى الصور/الفيديو/الصوت/التلسكوب بدون وضع @via-بوت",
}
l_post_has_restricted = {
    "ru": "👩🏽‍💻 <b>Ошибка</b> отправки видео-заметки/голосового для premium-аккаунта! В настройках <b>[Конфиденциальность]</b> добавь @{0} в <i>исключения</i> для <b>[Голосовые сообщения]</b>, чтобы отобразить видео-заметку/голосовое",
    "en": "👩🏽‍💻 <b>Error</b> sending video note/voice message for premium account! In the <b>[Privacy]</b> settings, add @{0} to <i>exceptions</i> for <b>[Voice Messages]</b> to display the video note/voice message.",
    "es": "👩🏽‍💻 <b>Error</b> al enviar la nota de video/voz para la cuenta premium! En la configuración <b>[Privacidad]</b> añade @{0} a <i>excepciones</i> para <b>[Mensajes de voz]</b>, para mostrar la nota de video/voz.",
    "fr": "👩🏽‍💻 <b>Erreur</b> d'envoi de la vidéo-notes/message vocal pour le compte premium ! Dans les paramètres <b>[Confidentialité]</b>, ajoute @{0} dans <i>exceptions</i> pour <b>[Messages vocaux]</b> afin d'afficher la vidéo-notes/message vocal.",
    "zh": "👩🏽‍💻 <b>发送视频备注/语音的错误</b>，适用于premium账户！在设置中 <b>[隐私]</b> 将 @{0} 添加到 <i>例外</i> 中，以便显示视频备注/语音。",
    "ar": "👩🏽‍💻 <b>خطأ</b> في إرسال ملاحظة فيديو/صوت لحساب premium! في الإعدادات <b>[الخصوصية]</b> أضف @{0} إلى <i>الاستثناءات</i> لـ <b>[الرسائل الصوتية]</b> لعرض ملاحظة الفيديو/الصوت",
}
l_post_tz = {
    "ru": "📍 <b>Часовой пояс</b> геопозиции установлен\n\n🕐 <b>Текущее</b> время: <u>{0}</u> ({1}{2} по Гринвичу)",
    "en": "📍 <b>Time zone</b> of the geolocation is set\n\n🕐 <b>Current</b> time: <u>{0}</u> ({1}{2} GMT)",
    "es": "📍 <b>Zona horaria</b> de la geolocalización establecida\n\n🕐 <b>Hora</b> actual: <u>{0}</u> ({1}{2} GMT)",
    "fr": "📍 <b>Fuseau horaire</b> de la géolocalisation défini\n\n🕐 <b>Heure</b> actuelle : <u>{0}</u> ({1}{2} GMT)",
    "zh": "📍 <b>时区</b> 地理位置已设置\n\n🕐 <b>当前</b> 时间: <u>{0}</u> ({1}{2} 格林威治时间)",
    "ar": "📍 <b>توقيت</b> الموقع الجغرافي تم تعيينه\n\n🕐 <b>الوقت الحالي</b>: <u>{0}</u> ({1}{2} بتوقيت غرينتش)",
}
l_post_time_future = {
    "ru": "🕒 <b>Укажи</b> дату и время в будущем",
    "en": "🕒 <b>Specify</b> a date and time in the future",
    "es": "🕒 <b>Indica</b> la fecha y la hora en el futuro",
    "fr": "🕒 <b>Indiquez</b> une date et une heure dans le futur",
    "zh": "🕒 <b>请</b> 指定未来的日期和时间",
    "ar": "🕒 <b>حدد</b> التاريخ والوقت في المستقبل",
}
l_me = {
    "ru": "👤 Себе",
    "en": "👤 Yourself",
    "es": "👤 A ti mismo",
    "fr": "👤 Soi-même",
    "zh": "👤 自己",
    "ar": "👤 لنفسك",
}
l_all = {
    "ru": "👥 Всем",
    "en": "👥 Everyone",
    "es": "👥 A todos",
    "fr": "👥 Tout le monde",
    "zh": "👥 大家好",
    "ar": "👥 الجميع",
}
l_usr = {
    "ru": "👩🏽‍💻 Юзер",
    "en": "👩🏽‍💻 User",
    "es": "👩🏽‍💻 Usuario",
    "fr": "👩🏽‍💻 Utilisateur",
    "zh": "👩🏽‍💻 用户",
    "ar": "👩🏽‍💻 مستخدم",
}
l_username = {
    "ru": "👩🏽‍💻 @username",
    "en": "👩🏽‍💻 @username",
    "es": "👩🏽‍💻 @username",
    "fr": "👩🏽‍💻 @username",
    "zh": "👩🏽‍💻 @username",
    "ar": "👩🏽‍💻 @username",
}
l_bot = {
    "ru": "👩🏽‍💻 Приложение",
    "en": "👩🏽‍💻 Application",
    "es": "👩🏽‍💻 Aplicación",
    "fr": "👩🏽‍💻 Application",
    "zh": "👩🏽‍💻 应用程序",
    "ar": "👩🏽‍💻 التطبيق",
}
l_channel = {
    "ru": "👩🏽‍💻 Канал",
    "en": "👩🏽‍💻 Channel",
    "es": "👩🏽‍💻 Canal",
    "fr": "👩🏽‍💻 Chaîne",
    "zh": "👩🏽‍💻 渠道",
    "ar": "👩🏽‍💻 القناة",
}
l_chn = {
    "ru": "канал",
    "en": "channel",
    "es": "canal",
    "fr": "canal",
    "zh": "频道",
    "ar": "قناة",
}
l_group = {
    "ru": "👩🏽‍💻 Группа",
    "en": "👩🏽‍💻 Group",
    "es": "👩🏽‍💻 Grupo",
    "fr": "👩🏽‍💻 Groupe",
    "zh": "👩🏽‍💻 小组",
    "ar": "👩🏽‍💻 مجموعة",
}
l_user = {
    "ru": "👩🏽‍💻 Пользователи",
    "en": "👩🏽‍💻 Users",
    "es": "👩🏽‍💻 Usuarios",
    "fr": "👩🏽‍💻 Utilisateurs",
    "zh": "👩🏽‍💻 用户",
    "ar": "👩🏽‍💻 المستخدمون",
}
l_ids = {
    "ru": "🙌🏽 По id",
    "en": "🙌🏽 By id",
    "es": "🙌🏽 Por id",
    "fr": "🙌🏽 Par id",
    "zh": "🙌🏽 按 id",
    "ar": "🙌🏽 حسب المعرف",
}
l_recipient = {
    "ru": "👩🏽‍💻 <b>Выбери</b> получателя",
    "en": "👩🏽‍💻 <b>Select</b> recipient",
    "es": "👩🏽‍💻 <b>Elige</b> el destinatario",
    "fr": "👩🏽‍💻 <b>Choisissez</b> le destinataire",
    "zh": "👩🏽‍💻 <b>选择</b> 收件人",
    "ar": "👩🏽‍💻 <b>اختر</b> المستلم",
}
l_enter = {
    "ru": "👩🏽‍💻 <b>Введи</b> Ids получателей через <i>пробелы/раздели</i>",
    "en": "👩🏽‍💻 <b>Enter</b> the recipients' Ids separated by <i>spaces/slashes</i>",
    "es": "👩🏽‍💻 <b>Introduce</b> los Ids de los destinatarios a través de <i>espacios/separa</i>",
    "fr": "👩🏽‍💻 <b>Entrez</b> les Ids des destinataires séparés par <i>des espaces/virgules</i>",
    "zh": "👩🏽‍💻 <b>输入</b> 收件人的 Ids 通过 <i>空格/分隔</i>",
    "ar": "👩🏽‍💻 <b>أدخل</b> معرفات المستلمين عبر <i>المسافات/الفواصل</i>",
}
l_enter_username = {
    "ru": "👩🏽‍💻 <b>Введи</b> @username получателя",
    "en": "👩🏽‍💻 <b>Enter</b> @username of the recipient",
    "es": "👩🏽‍💻 <b>Introduce</b> @username del destinatario",
    "fr": "👩🏽‍💻 <b>Entrez</b> @username du destinataire",
    "zh": "👩🏽‍💻 <b>输入</b> @username 收件人",
    "ar": "👩🏽‍💻 <b>أدخل</b> @username المستلم",
}
l_post_time_zone = {
    "ru": "📍 <b>Часовой пояс</b> геопозиции установлен\n\n🕐 <b>Текущее</b> время: <u>{0}</u> ({1}{2} по Гринвичу)",
    "en": "📍 <b>Time zone</b> of the geolocation is set\n\n🕐 <b>Current</b> time: <u>{0}</u> ({1}{2} GMT)",
    "es": "📍 <b>Zona horaria</b> de la geolocalización establecida\n\n🕐 <b>Hora</b> actual: <u>{0}</u> ({1}{2} GMT)",
    "fr": "📍 <b>Fuseau horaire</b> de la géolocalisation défini\n\n🕐 <b>Heure</b> actuelle : <u>{0}</u> ({1}{2} GMT)",
    "zh": "📍 <b>时区</b> 地理位置已设置\n\n🕐 <b>当前</b> 时间: <u>{0}</u> ({1}{2} 格林威治时间)",
    "ar": "📍 <b>منطقة زمنية</b> الموقع الجغرافي تم تعيينها\n\n🕐 <b>الوقت الحالي</b>: <u>{0}</u> ({1}{2} بتوقيت غرينتش)",
}
l_broadcast_plan = {
    "ru": "👩🏽‍💻 <b>Готово!</b> Рассылка запланирована",
    "en": "👩🏽‍💻 <b>Done!</b> The mailing is scheduled",
    "es": "👩🏽‍💻 <b>¡Listo!</b> El envío está programado",
    "fr": "👩🏽‍💻 <b>Prêt!</b> L'envoi est planifié",
    "zh": "👩🏽‍💻 <b>完成！</b> 邮件已计划发送",
    "ar": "👩🏽‍💻 <b>تم!</b> تم جدولة الإرسال",
}
l_broadcast_plan_bot = {
    "ru": "👩🏽‍💻 <b>Готово!</b> Рассылка запланирована в @{0}",
    "en": "👩🏽‍💻 <b>Done!</b> The mailing is scheduled for @{0}",
    "es": "👩🏽‍💻 <b>¡Listo!</b> El envío está programado para @{0}",
    "fr": "👩🏽‍💻 <b>Prêt!</b> L'envoi est prévu pour @{0}",
    "zh": "👩🏽‍💻 <b>完成！</b> 邮件将在 @{0} 发送",
    "ar": "👩🏽‍💻 <b>تم!</b> تم جدولة الإرسال في @{0}",
}
l_broadcast_plan_ent = {
    "ru": "👩🏽‍💻 <b>Готово!</b> Публикация запланирована: {0}",
    "en": "👩🏽‍💻 <b>Done!</b> Publication scheduled: {0}",
    "es": "👩🏽‍💻 <b>¡Listo!</b> Publicación programada: {0}",
    "fr": "👩🏽‍💻 <b>Prêt!</b> Publication prévue : {0}",
    "zh": "👩🏽‍💻 <b>完成！</b> 发布已计划：{0}",
    "ar": "👩🏽‍💻 <b>جاهز!</b> تم جدولة النشر: {0}",
}
l_broadcast_start = {
    "ru": "📧 <b>Старт</b> рассылки..\n#длительность {0} мин",
    "en": "📧 <b>Start</b> of the mailing..\n#duration {0} min",
    "es": "📧 <b>Inicio</b> del envío..\n#duración {0} min",
    "fr": "📧 <b>Démarrer</b> l'envoi..\n#durée {0} min",
    "zh": "📧 <b>开始</b> 发送..\n#持续时间 {0} 分钟",
    "ar": "📧 <b>بدء</b> الإرسال..\n#المدة {0} دقيقة",
}
l_broadcast_process = {
    "ru": "📧 <b>Рассылка</b>..{0}%",
    "en": "📧 <b>Newsletter</b>..{0}%",
    "es": "📧 <b>Boletín</b>..{0}%",
    "fr": "📧 <b>Newsletter</b>..{0}%",
    "zh": "📧 <b>邮件发送</b>..{0}%",
    "ar": "📧 <b>النشرة</b>..{0}%",
}
l_broadcast_finish = {
    "ru": "🏁 <b>Рассылка</b> завершена\n\n📧 <b>Количество</b> пользователей, получивших сообщение: <u>{0}</u>",
    "en": "🏁 <b>Newsletter</b> completed\n\n📧 <b>Number</b> of users who received the message: <u>{0}</u>",
    "es": "🏁 <b>Envío</b> completado\n\n📧 <b>Cantidad</b> de usuarios que recibieron el mensaje: <u>{0}</u>",
    "fr": "🏁 <b>Envoi</b> terminé\n\n📧 <b>Nombre</b> d'utilisateurs ayant reçu le message : <u>{0}</u>",
    "zh": "🏁 <b>发送</b> 完成\n\n📧 <b>收到消息的</b> 用户数量: <u>{0}</u>",
    "ar": "🏁 <b>تم الانتهاء من الإرسال</b>\n\n📧 <b>عدد</b> المستخدمين الذين تلقوا الرسالة: <u>{0}</u>",
}
l_post_del_timer = {
    "ru": "👩🏽‍💻 <b>Пост</b> #{0} удален по таймеру в {1}",
    "en": "👩🏽‍💻 <b>Post</b> #{0} deleted by timer at {1}",
    "es": "👩🏽‍💻 <b>Publicación</b> #{0} eliminada por el temporizador en {1}",
    "fr": "👩🏽‍💻 <b>Post</b> #{0} supprimé par le minuteur à {1}",
    "zh": "👩🏽‍💻 <b>帖子</b> #{0} 已根据计时器在 {1} 删除",
    "ar": "👩🏽‍💻 <b>المنشور</b> #{0} تم حذفه بواسطة المؤقت في {1}",
}
l_generate_calendar_time = {
    "ru": "🕒 <b>Отправь время</b> поста на {0} в формате {1}. Текущее время: <u>{2}</u> ({3} по Гринвичу)\n\n📍 Отправь <b>геопозицию</b>, чтобы <i>автоматически</i> определить часовой пояс",
    "en": "🕒 <b>Send the time</b> of the post on {0} in the format {1}. Current time: <u>{2}</u> ({3} GMT)\n\n📍 Send <b>geolocation</b> to <i>automatically</i> determine the time zone",
    "es": "🕒 <b>Envía la hora</b> de la publicación en {0} en el formato {1}. Hora actual: <u>{2}</u> ({3} GMT)\n\n📍 Envía <b>geolocalización</b> para <i>determinar automáticamente</i> la zona horaria",
    "fr": "🕒 <b>Envoyez l'heure</b> du post à {0} au format {1}. Heure actuelle : <u>{2}</u> ({3} à Greenwich)\n\n📍 Envoyez <b>la géolocalisation</b> pour <i>déterminer automatiquement</i> le fuseau horaire",
    "zh": "🕒 <b>发送帖子时间</b>到 {0}，格式为 {1}。当前时间：<u>{2}</u> （格林威治时间 {3}）\n\n📍 发送 <b>地理位置</b>，以便 <i>自动</i> 确定时区",
    "ar": "🕒 <b>أرسل وقت</b> المنشور في {0} بتنسيق {1}. الوقت الحالي: <u>{2}</u> ({3} بتوقيت غرينتش)\n\n📍 أرسل <b>الموقع الجغرافي</b> لتحديد المنطقة الزمنية <i>بشكل تلقائي</i>",
}
l_time_timer = {
    "ru": "🕒 <b>Отправь время</b> <i>авто-удаления</i> поста на {0} в формате {1}. Текущее время: <u>{2}</u> ({3} по Гринвичу)\n\n📍 Отправь <b>геопозицию</b>, чтобы <i>автоматически</i> определить часовой пояс",
    "en": "🕒 <b>Send the time</b> <i>auto-deletion</i> of the post at {0} in the format {1}. Current time: <u>{2}</u> ({3} GMT)\n\n📍 Send <b>geolocation</b> to <i>automatically</i> determine the time zone",
    "es": "🕒 <b>Envía la hora</b> <i>de eliminación automática</i> de la publicación a {0} en el formato {1}. Hora actual: <u>{2}</u> ({3} GMT)\n\n📍 Envía <b>geolocalización</b> para <i>determinar automáticamente</i> la zona horaria",
    "fr": "🕒 <b>Envoyez l'heure</b> <i>d'auto-suppression</i> du post à {0} au format {1}. Heure actuelle : <u>{2}</u> ({3} GMT)\n\n📍 Envoyez <b>la géolocalisation</b> pour <i>déterminer automatiquement</i> le fuseau horaire",
    "zh": "🕒 <b>发送时间</b> <i>自动删除</i> 帖子在 {0} 的格式 {1}。当前时间：<u>{2}</u> ({3} 格林威治时间)\n\n📍 发送 <b>地理位置</b>，以便 <i>自动</i> 确定时区",
    "ar": "🕒 <b>أرسل وقت</b> <i>الحذف التلقائي</i> للمنشور في {0} بتنسيق {1}. الوقت الحالي: <u>{2}</u> ({3} بتوقيت غرينتش)\n\n📍 أرسل <b>الموقع الجغرافي</b> لتحديد <i>التوقيت</i> تلقائيًا",
}
l_month_1 = {
    "ru": "Янв",
    "en": "Jan",
    "es": "Ene",
    "fr": "Janv",
    "zh": "一月",
    "ar": "يناير",
}
l_month_2 = {
    "ru": "Фев",
    "en": "Feb",
    "es": "Feb",
    "fr": "Fév",
    "zh": "二月",
    "ar": "فبراير",
}
l_month_3 = {
    "ru": "Мар",
    "en": "Mar",
    "es": "Mar",
    "fr": "Mars",
    "zh": "马",
    "ar": "مار",
}
l_month_4 = {
    "ru": "Апр",
    "en": "Apr",
    "es": "Abr",
    "fr": "Avr",
    "zh": "四月",
    "ar": "أبريل",
}
l_month_5 = {
    "ru": "Май",
    "en": "May",
    "es": "Mayo",
    "fr": "Mai",
    "zh": "五月",
    "ar": "مايو",
}
l_month_6 = {
    "ru": "Июн",
    "en": "Jun",
    "es": "Jun",
    "fr": "Juin",
    "zh": "六月",
    "ar": "يونيو",
}
l_month_7 = {
    "ru": "Июл",
    "en": "Jul",
    "es": "Jul",
    "fr": "Juil",
    "zh": "七月",
    "ar": "يوليو",
}
l_month_8 = {
    "ru": "Авг",
    "en": "Aug",
    "es": "Ago",
    "fr": "Août",
    "zh": "八月",
    "ar": "أغسطس",
}
l_month_9 = {
    "ru": "Сен",
    "en": "Sep",
    "es": "Sep",
    "fr": "Sep",
    "zh": "九月",
    "ar": "سبتمبر",
}
l_month_10 = {
    "ru": "Окт",
    "en": "Oct",
    "es": "Oct",
    "fr": "Oct",
    "zh": "十月",
    "ar": "أكتوبر",
}
l_month_11 = {
    "ru": "Ноя",
    "en": "November",
    "es": "Noviembre",
    "fr": "Novembre",
    "zh": "十一月",
    "ar": "نوفمبر",
}
l_month_12 = {
    "ru": "Дек",
    "en": "Dec",
    "es": "Dic",
    "fr": "Décembre",
    "zh": "装饰",
    "ar": "ديك",
}
l_weekday_1 = {
    "ru": "пн",
    "en": "mon",
    "es": "lun",
    "fr": "lun",
    "zh": "周一",
    "ar": "الإثنين",
}
l_weekday_2 = {
    "ru": "вт",
    "en": "Tue",
    "es": "mar",
    "fr": "mar",
    "zh": "周二",
    "ar": "الثلاثاء",
}
l_weekday_3 = {
    "ru": "ср",
    "en": "sr",
    "es": "sr",
    "fr": "sr",
    "zh": "sr",
    "ar": "س.ر",
}
l_weekday_4 = {
    "ru": "чт",
    "en": "th",
    "es": "ch",
    "fr": "chт",
    "zh": "读",
    "ar": "قراءة",
}
l_weekday_5 = {
    "ru": "пт",
    "en": "Fri",
    "es": "pt",
    "fr": "ven.",
    "zh": "周五",
    "ar": "الجمعة",
}
l_weekday_6 = {
    "ru": "сб",
    "en": "sb",
    "es": "sb",
    "fr": "sb",
    "zh": "周六",
    "ar": "س.ب",
}
l_weekday_7 = {
    "ru": "вс",
    "en": "all",
    "es": "todo",
    "fr": "tous",
    "zh": "所有",
    "ar": "في",
}
l_inline_demo = {
    "ru": "демо проектов",
    "en": "demo projects",
    "es": "demostración de proyectos",
    "fr": "démonstration de projets",
    "zh": "演示项目",
    "ar": "عرض المشاريع",
}
l_inline_bot = {
    "ru": "нейро-конструктор",
    "en": "neuro-constructor",
    "es": "neuro-constructor",
    "fr": "neuro-constructeur",
    "zh": "神经构建器",
    "ar": "مُنشئ الأعصاب",
}
l_inline_post = {
    "ru": "приватный постинг",
    "en": "private posting",
    "es": "publicación privada",
    "fr": "publication privée",
    "zh": "私密发布",
    "ar": "نشر خاص",
}
l_inline_media = {
    "ru": "публичные медиа",
    "en": "public media",
    "es": "medios públicos",
    "fr": "médias publics",
    "zh": "公共媒体",
    "ar": "وسائل الإعلام العامة",
}
l_inline_channel = {
    "ru": "администрирование каналов",
    "en": "channel administration",
    "es": "administración de canales",
    "fr": "administration des canaux",
    "zh": "频道管理",
    "ar": "إدارة القنوات",
}
l_inline_group = {
    "ru": "модерация групп",
    "en": "group moderation",
    "es": "moderación de grupos",
    "fr": "modération des groupes",
    "zh": "群组审核",
    "ar": "إدارة المجموعات",
}
l_inline_find = {
    "ru": "премиум поиск",
    "en": "premium search",
    "es": "búsqueda premium",
    "fr": "recherche premium",
    "zh": "高级搜索",
    "ar": "بحث متميز",
}
l_inline_ai = {
    "ru": "нейро-генерация контента",
    "en": "neuro-content generation",
    "es": "neuro-generación de contenido",
    "fr": "génération de contenu par neuro-génération",
    "zh": "神经内容生成",
    "ar": "توليد المحتوى العصبي",
}
l_inline_ads = {
    "ru": "телеграм реклама",
    "en": "telegram advertising",
    "es": "publicidad en telegram",
    "fr": "publicité Telegram",
    "zh": "电报广告",
    "ar": "إعلانات تيليجرام",
}
l_inline_vpn = {
    "ru": "vpn настройки",
    "en": "vpn settings",
    "es": "configuración de vpn",
    "fr": "paramètres vpn",
    "zh": "vpn 设置",
    "ar": "إعدادات vpn",
}
l_inline_sticker = {
    "ru": "стикеры/эмоджи",
    "en": "stickers/emojis",
    "es": "stickers/emoji",
    "fr": "autocollants/émoticônes",
    "zh": "贴纸/表情符号",
    "ar": "ملصقات/رموز تعبيرية",
}
l_inline_target = {
    "ru": "телеграмм таргет",
    "en": "telegram target",
    "es": "telegram target",
    "fr": "cible de télégramme",
    "zh": "电报目标",
    "ar": "تارغت تلغرام",
}
l_inline_user = {
    "ru": "автоматизация аккаунтов",
    "en": "account automation",
    "es": "automatización de cuentas",
    "fr": "automatisation des comptes",
    "zh": "账户自动化",
    "ar": "أتمتة الحسابات",
}
l_inline_tools = {
    "ru": "телеграм инструменты",
    "en": "telegram tools",
    "es": "herramientas de telegram",
    "fr": "outils Telegram",
    "zh": "电报工具",
    "ar": "أدوات تيليجرام",
}
l_inline_work = {
    "ru": "вакансии проекта",
    "en": "project vacancies",
    "es": "vacantes del proyecto",
    "fr": "offres du projet",
    "zh": "项目职位",
    "ar": "وظائف المشروع",
}
l_inline_tonest = {
    "ru": "блокчейн инструменты",
    "en": "blockchain tools",
    "es": "herramientas de blockchain",
    "fr": "outils de blockchain",
    "zh": "区块链工具",
    "ar": "أدوات البلوكشين",
}
l_inline_codex = {
    "ru": "кодекс/фест/лига",
    "en": "code/fest/league",
    "es": "código/fest/liga",
    "fr": "code/fête/ligue",
    "zh": "法典/节日/联盟",
    "ar": "رمز/مهرجان/رابطة",
}
l_inline_support = {
    "ru": "служба заботы",
    "en": "care service",
    "es": "servicio de atención",
    "fr": "service de soins",
    "zh": "关怀服务",
    "ar": "خدمة الرعاية",
}
l_post_is_paid = {
    "ru": "👩🏽‍💻 <b>Пользователь</b>:   успешно оплатил пост: {1}",
    "en": "👩🏽‍💻 <b>User</b>: successfully paid for the post: {1}",
    "es": "👩🏽‍💻 <b>Usuario</b>:   ha pagado con éxito la publicación: {1}",
    "fr": "👩🏽‍💻 <b>Utilisateur</b>: a réussi à payer le post : {1}",
    "zh": "👩🏽‍💻 <b>用户</b>:   成功支付了帖子: {1}",
    "ar": "👩🏽‍💻 <b>المستخدم</b>:   دفع المنشور بنجاح: {1}",
}
l_text = {
    "ru": "Текст",
    "en": "Text",
    "es": "Texto",
    "fr": "Texte",
    "zh": "文本",
    "ar": "نص",
}
l_photo = {
    "ru": "Фото",
    "en": "Photo",
    "es": "Foto",
    "fr": "Photo",
    "zh": "照片",
    "ar": "صورة",
}
l_gif = {
    "ru": "Гиф",
    "en": "Gif",
    "es": "Gif",
    "fr": "Gif",
    "zh": "动图",
    "ar": "غيف",
}
l_video = {
    "ru": "Видео",
    "en": "Video",
    "es": "Vídeo",
    "fr": "Vidéo",
    "zh": "视频",
    "ar": "فيديو",
}
l_telescope = {
    "ru": "Телескоп",
    "en": "Telescope",
    "es": "Telescopio",
    "fr": "Télescope",
    "zh": "望远镜",
    "ar": "تلسكوب",
}
l_audio = {
    "ru": "Аудио",
    "en": "Audio",
    "es": "Audio",
    "fr": "Audio",
    "zh": "音频",
    "ar": "صوت",
}
l_voice = {
    "ru": "Голосовое",
    "en": "Voice",
    "es": "Voz de voz",
    "fr": "Vocal",
    "zh": "语音",
    "ar": "صوتي",
}
l_sticker = {
    "ru": "Стикер",
    "en": "Sticker",
    "es": "Sticker",
    "fr": "Autocollant",
    "zh": "贴纸",
    "ar": "ملصق",
}
l_document = {
    "ru": "Документ",
    "en": "Document",
    "es": "Documento",
    "fr": "Document",
    "zh": "文档",
    "ar": "وثيقة",
}
l_voice_restricted = {
    "ru": "👩🏽‍💻 <b>Режим</b> отправки голосовых/телескопов заблокирован в настройках [Конфиденциальности]: будет использован режим [Авто-замена] для аудио/видео форматов",
    "en": "👩🏽‍💻 <b>Sending</b> mode for voice/telescopes is blocked in the [Privacy] settings: the [Auto-replace] mode will be used for audio/video formats",
    "es": "👩🏽‍💻 <b>Modo</b> de envío de mensajes de voz/telescopios está bloqueado en la configuración de [Privacidad]: se utilizará el modo [Auto-reemplazo] para formatos de audio/video.",
    "fr": "👩🏽‍💻 <b>Le mode</b> d'envoi de messages vocaux/téléscopes est bloqué dans les paramètres [Confidentialité] : le mode [Auto-remplacement] sera utilisé pour les formats audio/vidéo.",
    "zh": "👩🏽‍💻 <b>发送</b> 语音/望远镜的模式在 [隐私] 设置中被禁用：将使用 [自动替换] 模式处理音频/视频格式",
    "ar": "👩🏽‍💻 <b>وضع</b> إرسال الرسائل الصوتية/التلسكوبية محجوز في إعدادات [الخصوصية]: سيتم استخدام وضع [التبديل التلقائي] لصيغ الصوت/الفيديو",
}

l_desc = {
    "ru": "Описание",
    "en": "Description",
    "es": "Descripción",
    "fr": "Description",
    "zh": "描述",
    "ar": "وصف",
}
l_members2 = {
    "ru": "Участники",
    "en": "Members",
    "es": "Miembros",
    "fr": "Membres",
    "zh": "成员",
    "ar": "الأعضاء",
}
l_days2 = {
    "ru": "Дни публикации",
    "en": "Publication days",
    "es": "Días de publicación",
    "fr": "Jours de publication",
    "zh": "发布天数",
    "ar": "أيام النشر",
}
l_bio = {
    "ru": "Био",
    "en": "Bio",
    "es": "Biografía",
    "fr": "Biographie",
    "zh": "个人简介",
    "ar": "نبذة",
}
l_scam = {
    "ru": "Скам",
    "en": "Scam",
    "es": "Estafa",
    "fr": "Arnaque",
    "zh": "骗局",
    "ar": "احتيال",
}
l_fake = {
    "ru": "Фейк",
    "en": "Fake",
    "es": "Falso",
    "fr": "Faux",
    "zh": "假",
    "ar": "مزيف",
}

# endregion


# region FereyDemoBot
l_demo_btn1 = {
    "ru": "👩🏽‍💻 Проекты",
    "en": "👩🏽‍💻 Projects",
    "es": "👩🏽‍💻 Proyectos",
    "fr": "👩🏽‍💻 Projets",
    "zh": "👩🏽‍💻 项目",
    "ar": "👩🏽‍💻 المشاريع",
}
l_demo_btn2 = {
    "ru": "💨 Подписка",
    "en": "💨 Subscription",
    "es": "💨 Suscripción",
    "fr": "💨 Abonnement",
    "zh": "💨 订阅",
    "ar": "💨 الاشتراك",
}
l_demo_welcome = {
    "ru": "🌱 <b>{0}</b>, добро пожаловать в <i>@tg-приложение</i> <b>Ferey</b>-проекта:\n\n<blockquote>▪️<b>информация</b> о проектах\n▪️<b>телеграф</b>-/blog</blockquote>",
    "en": "🌱 <b>{0}</b>, welcome to the <i>@tg-app</i> <b>Ferey</b> project:\n\n<blockquote>▪️<b>information</b> about projects\n▪️<b>telegraph</b>-/blog</blockquote>",
    "es": "🌱 <b>{0}</b>, bienvenido a la <i>@tg-aplicación</i> del proyecto <b>Ferey</b>:\n\n<blockquote>▪️<b>información</b> sobre proyectos\n▪️<b>telegraph</b>-/blog</blockquote>",
    "fr": "🌱 <b>{0}</b>, bienvenue dans la <i>@tg-application</i> du projet <b>Ferey</b>:\n\n<blockquote>▪️<b>information</b> sur les projets\n▪️<b>telegraph</b>-/blog</blockquote>",
    "zh": "🌱 <b>{0}</b>, 欢迎来到 <i>@tg-应用</i> <b>Ferey</b> 项目:\n\n<blockquote>▪️<b>项目信息</b>\n▪️<b>telegraph</b>-/blog</blockquote>",
    "ar": "🌱 <b>{0}</b>, مرحبًا بك في <i>@tg-تطبيق</i> مشروع <b>Ferey</b>:\n\n<blockquote>▪️<b>معلومات</b> عن المشاريع\n▪️<b>telegraph</b>-/blog</blockquote>",
}
l_subscribe_demo = {
    "ru": "👩🏽‍💻 <b>Оформи</b> ежемесячную подписку:\n\n¹ [<b>Все приложения</b> и проекты (-<u>22</u>%)]",
    "en": "👩🏽‍💻 <b>Subscribe</b> to a monthly plan:\n\n¹ [<b>All apps</b> and projects (-<u>22</u>%)]",
    "es": "👩🏽‍💻 <b>Suscríbete</b> a la suscripción mensual:\n\n¹ [<b>Todas las aplicaciones</b> y proyectos (-<u>22</u>%)]",
    "fr": "👩🏽‍💻 <b>Abonnez-vous</b> à un abonnement mensuel :\n\n¹ [<b>Toutes les applications</b> et projets (-<u>22</u>%) ]",
    "zh": "👩🏽‍💻 <b>订阅</b> 每月订阅：\n\n¹ [<b>所有应用程序</b> 和项目 (-<u>22</u>%) ]",
    "ar": "👩🏽‍💻 <b>اشترك</b> في الاشتراك الشهري:\n\n¹ [<b>جميع التطبيقات</b> والمشاريع (-<u>22</u>%)]",
}
l_kind_1 = {
    "ru": "<b>👩🏽‍💻@FereyDemoBot</b>\n\n<blockquote>▪️<b>информация</b> о проектах\n▪️<b>telegraph</b>-/blog</blockquote>",
    "en": "<b>👩🏽‍💻@FereyDemoBot</b>\n\n<blockquote>▪️<b>information</b> about projects\n▪️<b>telegraph</b>-/blog</blockquote>",
    "es": "<b>👩🏽‍💻@FereyDemoBot</b>\n\n<blockquote>▪️<b>información</b> sobre proyectos\n▪️<b>telegraph</b>-/blog</blockquote>",
    "fr": "<b>👩🏽‍💻@FereyDemoBot</b>\n\n<blockquote>▪️<b>informations</b> sur les projets\n▪️<b>télégraphe</b>-/blog</blockquote>",
    "zh": "<b>👩🏽‍💻@FereyDemoBot</b>\n\n<blockquote>▪️<b>项目信息</b>\n▪️<b>telegraph</b>-/blog</blockquote>",
    "ar": "<b>👩🏽‍💻@FereyDemoBot</b>\n\n<blockquote>▪️<b>معلومات</b> عن المشاريع\n▪️<b>telegraph</b>-/blog</blockquote>",
}
l_kind_2 = {
    "ru": "<b>👩🏽‍💻@FereyBotBot</b> - нейро-конструктор приложений\n\n<blockquote>▪️<b>сбор/бан/аналитика</b> подписчиков\n▪️авто-<b>перевод/оповещения</b>\n▪️<b>интеграции</b> и платежи\n▪️нейро-<b>генерация/клон</b> приложений\n▪️<b>веб-мини/нейро</b>-постинг</blockquote>",
    "en": "<b>👩🏽‍💻@FereyBotBot</b> - neuro-app constructor\n\n<blockquote>▪️<b>collection/banning/analytics</b> of subscribers\n▪️auto-<b>translation/notifications</b>\n▪️<b>integrations</b> and payments\n▪️neuro-<b>generation/cloning</b> of applications\n▪️<b>web-mini/neuro</b>-posting</blockquote>",
    "es": "<b>👩🏽‍💻@FereyBotBot</b> - neuro-constructor de aplicaciones\n\n<blockquote>▪️<b>recolección/banco/análisis</b> de suscriptores\n▪️auto-<b>traducción/notificaciones</b>\n▪️<b>integraciones</b> y pagos\n▪️neuro-<b>generación/clonación</b> de aplicaciones\n▪️<b>web-mini/neuro</b>-publicación</blockquote>",
    "fr": "<b>👩🏽‍💻@FereyBotBot</b> - neuro-constructeur d'applications\n\n<blockquote>▪️<b>collecte/bannissement/analyse</b> des abonnés\n▪️auto-<b>traduction/notifications</b>\n▪️<b>intégrations</b> et paiements\n▪️neuro-<b>génération/clonage</b> d'applications\n▪️<b>web-mini/neuro</b>-publication</blockquote>",
    "zh": "<b>👩🏽‍💻@FereyBotBot</b> - 神经应用构建器\n\n<blockquote>▪️<b>订阅者</b> 收集/封禁/分析\n▪️自动<b>翻译/通知</b>\n▪️<b>集成</b> 和支付\n▪️神经<b>生成/克隆</b> 应用\n▪️<b>网页迷你/神经</b> 发布</blockquote>",
    "ar": "<b>👩🏽‍💻@FereyBotBot</b> - مُنشئ تطبيقات عصبية\n\n<blockquote>▪️<b>جمع/حظر/تحليلات</b> المشتركين  \n▪️ترجمة/إشعارات<b> تلقائية</b>  \n▪️<b>تكاملات</b> ومدفوعات  \n▪️توليد/استنساخ<b> عصبي</b> للتطبيقات  \n▪️<b>نشر/عصبي</b> ويب-ميني</blockquote>",
}
l_kind_3 = {
    "ru": "<b>👩🏽‍💻@FereyChannelBot</b> - администрирование каналов\n\n<blockquote>▪️<b>сбор/бан/аналитика</b> подписчиков\n▪️<b>авто-декор/подкасты</b> поста\n▪️кнопочный <b>счетчик</b>\n▪️<b>веб-мини/нейро</b>-постинг</blockquote>",
    "en": "<b>👩🏽‍💻@FereyChannelBot</b> - channel administration\n\n<blockquote>▪️<b>collection/banning/analytics</b> of subscribers\n▪️<b>auto-decor/podcasts</b> of posts\n▪️button <b>counter</b>\n▪️<b>web-mini/neuro</b>-posting</blockquote>",
    "es": "<b>👩🏽‍💻@FereyChannelBot</b> - administración de canales\n\n<blockquote>▪️<b>recolección/baneo/análisis</b> de suscriptores\n▪️<b>auto-decoración/podcasts</b> de publicaciones\n▪️contador <b>botón</b>\n▪️<b>web-mini/neuro</b>-publicación</blockquote>",
    "fr": "<b>👩🏽‍💻@FereyChannelBot</b> - administration des chaînes\n\n<blockquote>▪️<b>collecte/bannissement/analyse</b> des abonnés\n▪️<b>auto-décor/podcasts</b> des publications\n▪️compteur <b>bouton</b>\n▪️<b>web-mini/neuro</b>-publication</blockquote>",
    "zh": "<b>👩🏽‍💻@FereyChannelBot</b> - 频道管理\n\n<blockquote>▪️<b>订阅者</b> 收集/封禁/分析\n▪️<b>自动装饰/播客</b> 帖子\n▪️按钮 <b>计数器</b>\n▪️<b>网络迷你/神经</b>-发布</blockquote>",
    "ar": "<b>👩🏽‍💻@FereyChannelBot</b> - إدارة القنوات\n\n<blockquote>▪️<b>جمع/حظر/تحليلات</b> المشتركين\n▪️<b>تزيين تلقائي/بودكاست</b> المنشور\n▪️عداد <b>زر</b>\n▪️<b>ويب ميني/نيورو</b>-نشر</blockquote>",
}
l_kind_4 = {
    "ru": "<b>👩🏽‍💻@FereyGroupBot</b> - модерация групп\n\n<blockquote>▪️<b>защита</b> группы от шпионов\n▪️ограничение прав до <b>подписки</b>\n▪️<b>голосование</b>/бан-ограничения\n▪️аналитика и <b>вовлеченность</b>\n▪️<b>авто-ответы</b> и стоп-слова\n▪️кнопочный <b>счетчик</b>\n▪️<b>веб-мини/нейро</b>-постинг</blockquote>",
    "en": "<b>👩🏽‍💻@FereyGroupBot</b> - group moderation\n\n<blockquote>▪️<b>protection</b> of the group from spies\n▪️limiting rights to <b>subscription</b>\n▪️<b>voting</b>/ban restrictions\n▪️analytics and <b>engagement</b>\n▪️<b>auto-responses</b> and stop words\n▪️button <b>counter</b>\n▪️<b>web-mini/neuro</b> posting</blockquote>",
    "es": "<b>👩🏽‍💻@FereyGroupBot</b> - moderación de grupos\n\n<blockquote>▪️<b>protección</b> del grupo contra espías\n▪️limitación de derechos hasta <b>suscripción</b>\n▪️<b>votación</b>/restricciones de baneo\n▪️análisis y <b>compromiso</b>\n▪️<b>respuestas automáticas</b> y palabras clave\n▪️contador <b>botón</b>\n▪️<b>web-mini/neuro</b>-publicación</blockquote>",
    "fr": "<b>👩🏽‍💻@FereyGroupBot</b> - modération des groupes\n\n<blockquote>▪️<b>protection</b> du groupe contre les espions\n▪️restriction des droits jusqu'à <b>l'abonnement</b>\n▪️<b>vote</b>/restrictions de bannissement\n▪️analyse et <b>engagement</b>\n▪️<b>réponses automatiques</b> et mots interdits\n▪️compteur <b>par bouton</b>\n▪️<b>web-mini/neuro</b>-publishing</blockquote>",
    "zh": "<b>👩🏽‍💻@FereyGroupBot</b> - 群组管理\n\n<blockquote>▪️<b>保护</b> 群组免受间谍侵害\n▪️将权限限制为 <b>订阅</b>\n▪️<b>投票</b>/禁令限制\n▪️分析和 <b>参与度</b>\n▪️<b>自动回复</b> 和禁用词\n▪️按钮 <b>计数器</b>\n▪️<b>网页迷你/神经</b> 发布</blockquote>",
    "ar": "<b>👩🏽‍💻@FereyGroupBot</b> - إدارة المجموعات\n\n<blockquote>▪️<b>حماية</b> المجموعة من الجواسيس\n▪️تقييد الحقوق إلى <b>الاشتراك</b>\n▪️<b>التصويت</b>/قيود الحظر\n▪️التحليلات و<b>المشاركة</b>\n▪️<b>الردود التلقائية</b> وكلمات التوقف\n▪️عداد <b>زر</b>\n▪️<b>نشر الويب/الذكاء</b> الاصطناعي</blockquote>",
}
l_kind_5 = {
    "ru": "<b>👩🏽‍💻@FereyUserBot</b> - автоматизация аккаунтов\n\n<blockquote>▪️<b>авто</b>-перевод/транскрибация\n▪️<b>нейро-генерация</b> приложения\n▪️<b>мониторинг</b> гео/слов\n▪️<b>авто-формат</b> и подкасты\n▪️<b>веб-мини/нейро</b>-постинг</blockquote>",
    "en": "<b>👩🏽‍💻@FereyUserBot</b> - account automation\n\n<blockquote>▪️<b>auto</b>-translation/transcription\n▪️<b>neural generation</b> of applications\n▪️<b>monitoring</b> geo/words\n▪️<b>auto-format</b> and podcasts\n▪️<b>web-mini/neural</b>-posting</blockquote>",
    "es": "<b>👩🏽‍💻@FereyUserBot</b> - automatización de cuentas\n\n<blockquote>▪️<b>auto</b>-traducción/transcripción\n▪️<b>neuro-generación</b> de aplicaciones\n▪️<b>monitoreo</b> de geo/palabras\n▪️<b>auto-formato</b> y podcasts\n▪️<b>web-mini/neuro</b>-publicación</blockquote>",
    "fr": "<b>👩🏽‍💻@FereyUserBot</b> - automatisation des comptes\n\n<blockquote>▪️<b>auto</b>-traduction/transcription\n▪️<b>génération</b> neuro de l'application\n▪️<b>surveillance</b> géo/mots\n▪️<b>auto-format</b> et podcasts\n▪️<b>web-mini/neuro</b>-publishing</blockquote>",
    "zh": "<b>👩🏽‍💻@FereyUserBot</b> - 账户自动化\n\n<blockquote>▪️<b>自动</b>翻译/转录\n▪️<b>神经生成</b>应用程序\n▪️<b>监控</b>地理/词汇\n▪️<b>自动格式</b>和播客\n▪️<b>网络迷你/神经</b>发布</blockquote>",
    "ar": "<b>👩🏽‍💻@FereyUserBot</b> - أتمتة الحسابات\n\n<blockquote>▪️<b>الترجمة</b> التلقائية/التفريغ\n▪️<b>التوليد</b> العصبي للتطبيقات\n▪️<b>مراقبة</b> الجغرافيا/الكلمات\n▪️<b>التنسيق</b> التلقائي والبودكاست\n▪️<b>النشر</b> المصغر/العصبي</blockquote>",
}
l_kind_6 = {
    "ru": "<b>👩🏽‍💻@FereyPostBot</b> - приватные посты\n\n<blockquote>▪️<b>кнопочный</b> счетчик\n▪️инлайн-<b>телескопы</b>\n▪️<b>клик</b>\n▪️<b>шёпот</b>-сообщения</blockquote>",
    "en": "<b>👩🏽‍💻@FereyPostBot</b> - private posts\n\n<blockquote>▪️<b>button</b> counter\n▪️inline-<b>telescopes</b>\n▪️<b>click</b>\n▪️<b>whisper</b> messages</blockquote>",
    "es": "<b>👩🏽‍💻@FereyPostBot</b> - publicaciones privadas\n\n<blockquote>▪️<b>contador</b> de botones\n▪️in-line <b>telescopios</b>\n▪️<b>clic</b>\n▪️<b>susurro</b> - mensajes</blockquote>",
    "fr": "<b>👩🏽‍💻@FereyPostBot</b> - publications privées\n\n<blockquote>▪️compteur <b>à boutons</b>\n▪️<b>télescopes</b> en ligne\n▪️<b>clic</b>\n▪️messages <b>chuchotés</b></blockquote>",
    "zh": "<b>👩🏽‍💻@FereyPostBot</b> - 私密帖子\n\n<blockquote>▪️<b>按钮</b>计数器\n▪️在线<b>望远镜</b>\n▪️<b>点击</b>\n▪️<b>耳语</b>消息</blockquote>",
    "ar": "<b>👩🏽‍💻@FereyPostBot</b> - منشورات خاصة\n\n<blockquote>▪️<b>عداد</b> زري\n▪️<الب>تلسكوبات</b> داخلية\n▪️<b>نقرة</b>\n▪️<b>همس</b> - رسائل</blockquote>",
}
l_kind_7 = {
    "ru": "<b>👩🏽‍💻@FereyMediaBot</b> - публичные медиа-креативы\n\n<blockquote>▪️<b>стикеры</b> из текста и фото\n▪️<b>аудио-тренды</b>\n▪️<b>видео-заметки</b>\n▪️инлайн-<b>телескопы</b>\n▪️<b>кнопочные</b> #нейро-титры</blockquote>",
    "en": "<b>👩🏽‍💻@FereyMediaBot</b> - public media creatives\n\n<blockquote>▪️<b>stickers</b> from text and photos\n▪️<b>audio trends</b>\n▪️<b>video notes</b>\n▪️inline-<b>telescopes</b>\n▪️<b>button</b> #neuro-captions</blockquote>",
    "es": "<b>👩🏽‍💻@FereyMediaBot</b> - creativos de medios públicos\n\n<blockquote>▪️<b>stickers</b> de texto y foto\n▪️<b>tendencias de audio</b>\n▪️<b>notas de video</b>\n▪️in-line <b>telescopios</b>\n▪️<b>botones</b> #neuro-subtítulos</blockquote>",
    "fr": "<b>👩🏽‍💻@FereyMediaBot</b> - créations médiatiques publiques\n\n<blockquote>▪️<b>autocollants</b> à partir de texte et de photos\n▪️<b>tendances audio</b>\n▪️<b>notes vidéo</b>\n▪️in-line <b>télescopes</b>\n▪️<b>boutons</b> #neuro-sous-titres</blockquote>",
    "zh": "<b>👩🏽‍💻@FereyMediaBot</b> - 公共媒体创意\n\n<blockquote>▪️<b>贴纸</b> 从文本和照片\n▪️<b>音频趋势</b>\n▪️<b>视频笔记</b>\n▪️在线<b>望远镜</b>\n▪️<b>按钮式</b> #神经字幕</blockquote>",
    "ar": "<b>👩🏽‍💻@FereyMediaBot</b> - وسائل الإعلام العامة\n\n<blockquote>▪️<b>ملصقات</b> من النص والصور\n▪️<b>اتجاهات الصوت</b>\n▪️<b>ملاحظات الفيديو</b>\n▪️<inline-<b>تلسكوبات</b>\n▪️<b>أزرار</b> #ترجمات-عصبية</blockquote>",
}
l_kind_8 = {
    "ru": "<b>👩🏽‍💻@FereyFindBot</b> - премиум поиск\n\n<blockquote>▪️<b>top</b> каналы/группы\n▪️<b>vip</b> пользователи/приложения\n▪️<b>geo</b> парсинг\n▪️<b>smm</b> пассивный маркетинг</blockquote>",
    "en": "<b>👩🏽‍💻@FereyFindBot</b> - premium search\n\n<blockquote>▪️<b>top</b> channels/groups\n▪️<b>vip</b> users/apps\n▪️<b>geo</b> parsing\n▪️<b>smm</b> passive marketing</blockquote>",
    "es": "<b>👩🏽‍💻@FereyFindBot</b> - búsqueda premium\n\n<blockquote>▪️<b>canales</b>/grupos <br>\n▪️<b>usuarios</b>/aplicaciones <b>vip</b> <br>\n▪️<b>geo</b> análisis <br>\n▪️<b>smm</b> marketing pasivo</blockquote>",
    "fr": "<b>👩🏽‍💻@FereyFindBot</b> - recherche premium\n\n<blockquote>▪️<b>top</b> canaux/groupes\n▪️<b>vip</b> utilisateurs/applications\n▪️<b>geo</b> parsing\n▪️<b>smm</b> marketing passif</blockquote>",
    "zh": "<b>👩🏽‍💻@FereyFindBot</b> - 高级搜索\n\n<blockquote>▪️<b>顶级</b> 频道/群组\n▪️<b>VIP</b> 用户/应用\n▪️<b>地理</b> 解析\n▪️<b>SMM</b> 被动营销</blockquote>",
    "ar": "<b>👩🏽‍💻@FereyFindBot</b> - بحث متميز\n\n<blockquote>▪️<b>أفضل</b> القنوات/المجموعات\n▪️<b>مستخدمين</b> / تطبيقات <b>VIP</b>\n▪️<b>جيو</b> تحليل\n▪️<b>إس إم إم</b> تسويق غير نشط</blockquote>",
}
l_kind_9 = {
    "ru": "<b>👩🏽‍💻 @FereyAIBot</b> - нейро-генерация контента\n\n<blockquote>▪️<b>текст/изображение</b>\n▪️<b>нейро-анализ</b> @tg-tech-канала\n▪️<b>распознавание</b> речи\n▪️<b>очистка ⁰истории</b> /start</blockquote>",
    "en": "<b>👩🏽‍💻 @FereyAIBot</b> - neuro-content generation\n\n<blockquote>▪️<b>text/image</b>\n▪️<b>neuro-analysis</b> @tg-tech-channel\n▪️<b>speech</b> recognition\n▪️<b>history</b> cleaning /start</blockquote>",
    "es": "<b>👩🏽‍💻 @FereyAIBot</b> - neuro-generación de contenido\n\n<blockquote>▪️<b>texto/imágen</b>\n▪️<b>neuro-análisis</b> del canal @tg-tech\n▪️<b>reconocimiento</b> de voz\n▪️<b>limpieza ⁰historia</b> /start</blockquote>",
    "fr": "<b>👩🏽‍💻 @FereyAIBot</b> - génération de contenu par neuro\n\n<blockquote>▪️<b>texte/image</b>\n▪️<b>neuro-analyse</b> du canal @tg-tech\n▪️<b>reconnaissance</b> vocale\n▪️<b>nettoyage de l'historique</b> /start</blockquote>",
    "zh": "<b>👩🏽‍💻 @FereyAIBot</b> - 神经内容生成\n\n<blockquote>▪️<b>文本/图像</b>\n▪️<b>神经分析</b> @tg-tech-频道\n▪️<b>语音识别</b>\n▪️<b>清除历史</b> /start</blockquote>",
    "ar": "<b>👩🏽‍💻 @FereyAIBot</b> - توليد المحتوى العصبي\n\n<blockquote>▪️<b>نص/صورة</b>\n▪️<b>تحليل عصبي</b> @tg-tech-قناة\n▪️<b>التعرف على</b> الكلام\n▪️<b>تنظيف ⁰السجل</b> /start</blockquote>",
}
l_kind_10 = {
    "ru": "<b>👩🏽‍💻 @FereyToolsBot</b> - телеграм инструменты\n\n<blockquote>▪️<b>преобразование</b> контента\n▪️<b>/json</b> информация о сообщ\n▪️<b>удаление</b> фона\n▪️<b>/id</b> группы/канала/приложения\n▪️конвертация в <b>телескопы</b>\n▪️<b>/telegraph</b> фото/видео-ссылка\n▪️пустое сообщение <b>0-длины</b></blockquote>",
    "en": "<b>👩🏽‍💻 @FereyToolsBot</b> - Telegram tools\n\n<blockquote>▪️<b>content</b> transformation\n▪️<b>/json</b> message info\n▪️<b>background</b> removal\n▪️<b>/id</b> group/channel/app\n▪️conversion to <b>telescopes</b>\n▪️<b>/telegraph</b> photo/video link\n▪️empty message <b>0-length</b></blockquote>",
    "es": "<b>👩🏽‍💻 @FereyToolsBot</b> - herramientas de telegram\n\n<blockquote>▪️<b>transformación</b> de contenido\n▪️<b>/json</b> información sobre el mensaje\n▪️<b>eliminación</b> de fondo\n▪️<b>/id</b> grupo/canal/aplicación\n▪️conversión a <b>telescopios</b>\n▪️<b>/telegraph</b> enlace de foto/video\n▪️mensaje vacío <b>de 0 longitud</b></blockquote>",
    "fr": "<b>👩🏽‍💻 @FereyToolsBot</b> - outils Telegram\n\n<blockquote>▪️<b>transformation</b> de contenu\n▪️<b>/json</b> informations sur le message\n▪️<b>suppression</b> de l'arrière-plan\n▪️<b>/id</b> du groupe/canal/application\n▪️conversion en <b>télescopes</b>\n▪️<b>/telegraph</b> lien photo/vidéo\n▪️message vide <b>de longueur 0</b></blockquote>",
    "zh": "<b>👩🏽‍💻 @FereyToolsBot</b> - Telegram 工具\n\n<blockquote>▪️<b>内容转换</b>\n▪️<b>/json</b> 消息信息\n▪️<b>去除</b> 背景\n▪️<b>/id</b> 群组/频道/应用\n▪️转换为 <b>望远镜</b>\n▪️<b>/telegraph</b> 照片/视频链接\n▪️空消息 <b>0-长度</b></blockquote>",
    "ar": "<b>👩🏽‍💻 @FereyToolsBot</b> - أدوات تيليجرام\n\n<blockquote>▪️<b>تحويل</b> المحتوى  \n▪️<b>/json</b> معلومات عن الرسالة  \n▪️<b>إزالة</b> الخلفية  \n▪️<b>/id</b> المجموعة/القناة/التطبيق  \n▪️التحويل إلى <b>تلسكوبات</b>  \n▪️<b>/telegraph</b> رابط صورة/فيديو  \n▪️رسالة فارغة <b>طولها 0</b></blockquote>",
}
l_kind_11 = {
    "ru": "<b>👩🏽‍💻 @FereyStickerBot</b> - стикеры/эмоджи наборы\n\n<blockquote>▪️️стикеры static/video/animated\n▪️️эмоджи static/video/animated\n▪️️преобразование photo в video-стикер/эмоджи</blockquote>",
    "en": "<b>👩🏽‍💻 @FereyStickerBot</b> - sticker/emoji packs\n\n<blockquote>▪️️stickers static/video/animated\n▪️️emojis static/video/animated\n▪️️conversion of photo to video sticker/emoji</blockquote>",
    "es": "<b>👩🏽‍💻 @FereyStickerBot</b> - paquetes de stickers/emojis\n\n<blockquote>▪️️stickers estáticos/video/animados\n▪️️emojis estáticos/video/animados\n▪️️conversión de foto a sticker/video-emojis</blockquote>",
    "fr": "<b>👩🏽‍💻 @FereyStickerBot</b> - ensembles de stickers/émoticônes\n\n<blockquote>▪️️stickers statiques/vidéo/animés\n▪️️émoticônes statiques/vidéo/animées\n▪️️conversion de photo en sticker/émoticône vidéo</blockquote>",
    "zh": "<b>👩🏽‍💻 @FereyStickerBot</b> - 贴纸/表情符号套件\n\n<blockquote>▪️️静态/视频/动画贴纸\n▪️️静态/视频/动画表情符号\n▪️️将照片转换为视频贴纸/表情符号</blockquote>",
    "ar": "<b>👩🏽‍💻 @FereyStickerBot</b> - مجموعات الملصقات/الإيموجي\n\n<blockquote>▪️️ملصقات ثابتة/فيديو/متحركة\n▪️️إيموجي ثابتة/فيديو/متحركة\n▪️️تحويل الصورة إلى ملصق/إيموجي فيديو</blockquote>",
}
l_kind_12 = {
    "ru": "<b>👩🏽‍💻 @FereyTONestBot</b> - блокчейн проекты\n\n<blockquote>▪️️соло/альбом NFT\n▪️️монеты (токены) FT\n▪️️нейро-парсинг смарт-контрактов</blockquote>",
    "en": "<b>👩🏽‍💻 @FereyTONestBot</b> - blockchain projects\n\n<blockquote>▪️️solo/album NFT\n▪️️coins (tokens) FT\n▪️️neural parsing of smart contracts</blockquote>",
    "es": "<b>👩🏽‍💻 @FereyTONestBot</b> - proyectos de blockchain\n\n<blockquote>▪️️solo/álbum NFT\n▪️️monedas (tokens) FT\n▪️️neuro-parsing de contratos inteligentes</blockquote>",
    "fr": "<b>👩🏽‍💻 @FereyTONestBot</b> - projets blockchain\n\n<blockquote>▪️️solo/album NFT\n▪️️monnaies (tokens) FT\n▪️️neuro-parsing de contrats intelligents</blockquote>",
    "zh": "<b>👩🏽‍💻 @FereyTONestBot</b> - 区块链项目\n\n<blockquote>▪️️单曲/NFT专辑\n▪️️货币（代币）FT\n▪️️智能合约的神经解析</blockquote>",
    "ar": "<b>👩🏽‍💻 @FereyTONestBot</b> - مشاريع البلوكشين\n\n<blockquote>▪️️سولو/ألبوم NFT\n▪️️عملات (رموز) FT\n▪️️تحليل ذكي لعقود السمارت</blockquote>",
}
l_kind_13 = {
    "ru": "<b>👩🏽‍💻 @FereyCodexBot</b> - кодекс\n\n<blockquote>▪️️кодекс\n▪️️фест\n▪️️лига</blockquote>",
    "en": "<b>👩🏽‍💻 @FereyCodexBot</b> - codex\n\n<blockquote>▪️️codex\n▪️️fest\n▪️️league</blockquote>",
    "es": "<b>👩🏽‍💻 @FereyCodexBot</b> - código\n\n<blockquote>▪️️código\n▪️️festival\n▪️️liga</blockquote>",
    "fr": "<b>👩🏽‍💻 @FereyCodexBot</b> - code\n\n<blockquote>▪️️code\n▪️️fest\n▪️️ligue</blockquote>",
    "zh": "<b>👩🏽‍💻 @FereyCodexBot</b> - 代码\n\n<blockquote>▪️️代码\n▪️️节\n▪️️联盟</blockquote>",
    "ar": "<b>👩🏽‍💻 @FereyCodexBot</b> - المدونة\n\n<blockquote>▪️️المدونة\n▪️️المهرجان\n▪️️الرابطة</blockquote>",
}
# endregion


# region FereyToolsBot
l_tools_btn1 = {
    "ru": "👩🏽‍💻 Инструменты",
    "en": "👩🏽‍💻 Tools",
    "es": "👩🏽‍💻 Herramientas",
    "fr": "👩🏽‍💻 Outils",
    "zh": "👩🏽‍💻 工具",
    "ar": "👩🏽‍💻 الأدوات",
}
l_tools_btn2 = {
    "ru": "💨 Подписка",
    "en": "💨 Subscription",
    "es": "💨 Suscripción",
    "fr": "💨 Abonnement",
    "zh": "💨 订阅",
    "ar": "💨 الاشتراك",
}
l_tools_welcome = {
    "ru": "🌱 <b>{0}</b>, добро пожаловать в <i>@tg-приложение</i> <b>Telegram</b>-инструментов:\n\n<blockquote>▪️<b>преобразование</b> контента\n▪️<b>/json</b> информация о сообщ\n▪️<b>удаление</b> фона\n▪️<b>/id</b> группы/канала/приложения\n▪️конвертация в <b>телескопы</b>\n▪️пустое сообщение <b>0-длины</b>\n▪️скачивание <b>tg-сториз</b>, <b>x/ig/tt/yt</b>-видео</blockquote>",
    "en": "🌱 <b>{0}</b>, welcome to the <i>@tg-app</i> <b>Telegram</b> tools:\n\n<blockquote>▪️<b>content</b> transformation\n▪️<b>/json</b> message info\n▪️<b>background</b> removal\n▪️<b>/id</b> group/channel/app\n▪️conversion to <b>telescopes</b>\n▪️empty message <b>0-length</b>\n▪️downloading <b>tg-stories</b>, <b>x/ig/tt/yt</b> videos</blockquote>",
    "es": "🌱 <b>{0}</b>, bienvenido a <i>@tg-aplicación</i> <b>Telegram</b>-herramientas:\n\n<blockquote>▪️<b>transformación</b> de contenido\n▪️<b>/json</b> información sobre el mensaje\n▪️<b>eliminación</b> de fondo\n▪️<b>/id</b> de grupo/canal/aplicación\n▪️conversión a <b>telescopios</b>\n▪️mensaje vacío <b>de 0-longitud</b>\n▪️descarga de <b>tg-stories</b>, <b>x/ig/tt/yt</b>-videos</blockquote>",
    "fr": "🌱 <b>{0}</b>, bienvenue dans <i>@tg-application</i> <b>Telegram</b>-outils :\n\n<blockquote>▪️<b>transformation</b> de contenu\n▪️<b>/json</b> informations sur le message\n▪️<b>suppression</b> de l'arrière-plan\n▪️<b>/id</b> du groupe/canal/application\n▪️conversion en <b>télescopes</b>\n▪️message vide <b>de longueur 0</b>\n▪️téléchargement de <b>tg-stories</b>, <b>x/ig/tt/yt</b>-vidéos</blockquote>",
    "zh": "🌱 <b>{0}</b>, 欢迎来到 <i>@tg-应用</i> <b>Telegram</b> 工具：\n\n<blockquote>▪️<b>内容转换</b>\n▪️<b>/json</b> 消息信息\n▪️<b>去除</b> 背景\n▪️<b>/id</b> 群组/频道/应用\n▪️转换为 <b>望远镜</b>\n▪️空消息 <b>0-长度</b>\n▪️下载 <b>tg-故事</b>，<b>x/ig/tt/yt</b> 视频</blockquote>",
    "ar": "🌱 <b>{0}</b>، مرحبًا بك في <i>@tg-تطبيق</i> أدوات <b>Telegram</b>:\n\n<blockquote>▪️<b>تحويل</b> المحتوى  \n▪️<b>/json</b> معلومات عن الرسالة  \n▪️<b>إزالة</b> الخلفية  \n▪️<b>/id</b> المجموعة/القناة/التطبيق  \n▪️التحويل إلى <b>تيليسكوب</b>  \n▪️رسالة فارغة <b>طولها 0</b>  \n▪️تحميل <b>tg-قصص</b>، <b>x/ig/tt/yt</b>-فيديو</blockquote>",
}
l_subscribe_tools = {
    "ru": "👩🏽‍💻 <b>Оформи</b> ежемесячную подписку:\n\n<a href='{0}'>¹ [<b>Все приложения</b> и проекты (-<u>22</u>%)]</a>\n\n<a href='{1}'>² Донат {2}</a>\n<a href='{3}'>​</a>",
    "en": "👩🏽‍💻 <b>Subscribe</b> to a monthly plan:\n\n<a href='{0}'>¹ [<b>All apps</b> and projects (-<u>22</u>%)]</a>\n\n<a href='{1}'>² Donate {2}</a>\n<a href='{3}'>​</a>",
    "es": "👩🏽‍💻 <b>Suscríbete</b> a la suscripción mensual:\n\n<a href='{0}'>¹ [<b>Todas las aplicaciones</b> y proyectos (-<u>22</u>%)]</a>\n\n<a href='{1}'>² Donar {2}</a>\n<a href='{3}'>​</a>",
    "fr": "👩🏽‍💻 <b>Abonnez-vous</b> à un abonnement mensuel :\n\n<a href='{0}'>¹ [<b>Toutes les applications</b> et projets (-<u>22</u>%)]</a>\n\n<a href='{1}'>² Don {2}</a>\n<a href='{3}'>​</a>",
    "zh": "👩🏽‍💻 <b>订阅</b> 每月订阅：\n\n<a href='{0}'>¹ [<b>所有应用程序</b> 和项目 (-<u>22</u>%)]</a>\n\n<a href='{1}'>² 捐赠 {2}</a>\n<a href='{3}'>​</a>",
    "ar": "👩🏽‍💻 <b>اشترك</b> في الاشتراك الشهري:\n\n<a href='{0}'>¹ [<b>جميع التطبيقات</b> والمشاريع (-<u>22</u>%)]</a>\n\n<a href='{1}'>² تبرع {2}</a>\n<a href='{3}'>​</a>",
}
l_image_text = {
    "ru": "👩🏽‍💻 <b>Выбери</b> инструменты для преобразования <i>изображения</i> в",
    "en": "👩🏽‍💻 <b>Select</b> tools to convert <i>image</i> to",
    "es": "👩🏽‍💻 <b>Elige</b> herramientas para convertir <i>imagen</i> en",
    "fr": "👩🏽‍💻 <b>Choisis</b> des outils pour convertir <i>l'image</i> en",
    "zh": "👩🏽‍💻 <b>选择</b> 将<i>图像</i>转换为",
    "ar": "👩🏽‍💻 <b>اختر</b> الأدوات لتحويل <i>الصورة</i> إلى",
}
l_image_jpg = {
    "ru": "🏞️ jpg",
    "en": "🏞️ jpg",
    "es": "🏞️ jpg",
    "fr": "🏞️ jpg",
    "zh": "🏞️ jpg",
    "ar": "🏞️ jpg",
}
l_image_png = {
    "ru": "🌁 png",
    "en": "🌁 png",
    "es": "🌁 png",
    "fr": "🌁 png",
    "zh": "🌁 png",
    "ar": "🌁 png",
}
l_image_mp4 = {
    "ru": "🎥 mp4",
    "en": "🎥 mp4",
    "es": "🎥 mp4",
    "fr": "🎥 mp4",
    "zh": "🎥 mp4",
    "ar": "🎥 mp4",
}
l_image_album = {
    "ru": "9️⃣ альбом⁹",
    "en": "9️⃣ album⁹",
    "es": "9️⃣ álbum⁹",
    "fr": "9️⃣ album⁹",
    "zh": "9️⃣ 专辑⁹",
    "ar": "٩️⃣ ألبوم⁹",
}
l_image_collage = {
    "ru": "1️⃣ коллаж¹",
    "en": "1️⃣ collage¹",
    "es": "1️⃣ collage¹",
    "fr": "1️⃣ collage¹",
    "zh": "1️⃣ 拼贴¹",
    "ar": "1️⃣ كولاج¹",
}
l_image_ico = {
    "ru": "🖼️ ico",
    "en": "🖼️ ico",
    "es": "🖼️ ico",
    "fr": "🖼️ ico",
    "zh": "🖼️ ico",
    "ar": "🖼️ ico",
}
l_image_sticker = {
    "ru": "🌌 стикер",
    "en": "🌌 sticker",
    "es": "🌌 sticker",
    "fr": "🌌 autocollant",
    "zh": "🌌 贴纸",
    "ar": "🌌 ملصق",
}
l_image_rbg = {
    "ru": "🙌🏽 удалить фон",
    "en": "🙌🏽 remove background",
    "es": "🙌🏽 eliminar fondo",
    "fr": "🙌🏽 supprimer l'arrière-plan",
    "zh": "🙌🏽 删除背景",
    "ar": "🙌🏽 إزالة الخلفية",
}
l_image_slice = {
    "ru": "🔪 Срез",
    "en": "🔪 Slice",
    "es": "🔪 Corte",
    "fr": "🔪 Tranche",
    "zh": "🔪 切片",
    "ar": "🔪 قطع",
}
l_image_slice_mini = {
    "ru": "🔪 срез",
    "en": "🔪 slice",
    "es": "🔪 corte",
    "fr": "🔪 tranche",
    "zh": "🔪 切片",
    "ar": "🔪 قطع",
}
l_image_descpic = {
    "ru": "⿴ Bot Desc Pic",
    "en": "⿴ Bot Desc Pic",
    "es": "⿴ Descripción del Bot Pic",
    "fr": "⿴ Description du bot Pic",
    "zh": "⿴ 机器人描述图片",
    "ar": "⿴ وصف البوت صورة",
}
l_image_watermark = {
    "ru": "🪼 Водяной знак",
    "en": "🪼 Watermark",
    "es": "🪼 Marca de agua",
    "fr": "🪼 Filigrane",
    "zh": "🪼 水印",
    "ar": "🪼 علامة مائية",
}
l_image_jpg_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> фото для преобразования в jpg",
    "en": "👩🏽‍💻 <b>Attach</b> a photo to convert to jpg",
    "es": "👩🏽‍💻 <b>Adjunta</b> una foto para convertirla a jpg",
    "fr": "👩🏽‍💻 <b>Joins</b> une photo à convertir en jpg",
    "zh": "👩🏽‍💻 <b>附加</b> 照片以转换为 jpg",
    "ar": "👩🏽‍💻 <b>أرفق</b> صورة للتحويل إلى jpg",
}
l_image_png_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> фото для преобразования в png",
    "en": "👩🏽‍💻 <b>Attach</b> a photo to convert to png",
    "es": "👩🏽‍💻 <b>Adjunta</b> una foto para convertirla a png",
    "fr": "👩🏽‍💻 <b>Joins</b> une photo pour la convertir en png",
    "zh": "👩🏽‍💻 <b>附加</b> 照片以转换为 png",
    "ar": "👩🏽‍💻 <b>أرفق</b> صورة للتحويل إلى png",
}
l_image_mp4_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> фото для преобразования в mp4 (Telegram-аватарку)",
    "en": "👩🏽‍💻 <b>Attach</b> a photo to convert to mp4 (Telegram avatar)",
    "es": "👩🏽‍💻 <b>Adjunta</b> una foto para convertirla a mp4 (avatar de Telegram)",
    "fr": "👩🏽‍💻 <b>Joins</b> une photo pour la convertir en mp4 (avatar Telegram)",
    "zh": "👩🏽‍💻 <b>附加</b> 照片以转换为 mp4（Telegram 头像）",
    "ar": "👩🏽‍💻 <b>أرفق</b> صورة لتحويلها إلى mp4 (صورة ملف تعريف Telegram)",
}
l_image_ico_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> фото для преобразования в ico-иконку (320x320)",
    "en": "👩🏽‍💻 <b>Attach</b> a photo to convert to an ico icon (320x320)",
    "es": "👩🏽‍💻 <b>Adjunta</b> una foto para convertirla en un ícono ico (320x320)",
    "fr": "👩🏽‍💻 <b>Joins</b> une photo pour la convertir en icône ico (320x320)",
    "zh": "👩🏽‍💻 <b>附加</b> 照片以转换为 ico 图标 (320x320)",
    "ar": "👩🏽‍💻 <b>أرفق</b> صورة لتحويلها إلى أيقونة ico (320x320)",
}
l_image_sticker_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> фото для преобразования в стикер",
    "en": "👩🏽‍💻 <b>Attach</b> a photo to convert it into a sticker",
    "es": "👩🏽‍💻 <b>Adjunta</b> una foto para convertirla en un sticker",
    "fr": "👩🏽‍💻 <b>Joins</b> une photo pour la convertir en autocollant",
    "zh": "👩🏽‍💻 <b>附加</b> 照片以转换为贴纸",
    "ar": "👩🏽‍💻 <b>أرفق</b> صورة للتحويل إلى ملصق",
}
l_image_album_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> фото для преобразования в альбом из 9 частей",
    "en": "👩🏽‍💻 <b>Attach</b> a photo to convert it into an album of 9 parts",
    "es": "👩🏽‍💻 <b>Adjunta</b> una foto para convertirla en un álbum de 9 partes",
    "fr": "👩🏽‍💻 <b>Joins</b> une photo pour la convertir en un album de 9 parties",
    "zh": "👩🏽‍💻 <b>附加</b> 照片以转换为 9 部分的相册",
    "ar": "👩🏽‍💻 <b>أرفق</b> صورة لتحويلها إلى ألبوم مكون من 9 أجزاء",
}
l_image_collage_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> альбом для преобразования в 1-единый коллаж",
    "en": "👩🏽‍💻 <b>Attach</b> an album for conversion into a single collage",
    "es": "👩🏽‍💻 <b>Adjunta</b> un álbum para convertir en un único collage",
    "fr": "👩🏽‍💻 <b>Attache</b> un album pour le transformer en un seul collage",
    "zh": "👩🏽‍💻 <b>附加</b> 要转换为一个统一拼贴的相册",
    "ar": "👩🏽‍💻 <b>أرفق</b> ألبومًا للتحويل إلى كولاج موحد واحد",
}
l_image_rbg_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> фото для удаления фона",
    "en": "👩🏽‍💻 <b>Attach</b> a photo to remove the background",
    "es": "👩🏽‍💻 <b>Adjunta</b> una foto para eliminar el fondo",
    "fr": "👩🏽‍💻 <b>Joins</b> une photo pour supprimer l'arrière-plan",
    "zh": "👩🏽‍💻 <b>附加</b> 照片以删除背景",
    "ar": "👩🏽‍💻 <b>أرفق</b> صورة لإزالة الخلفية",
}
l_image_slice_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> фото для преобразования в узкую полоску фото (срез)",
    "en": "👩🏽‍💻 <b>Attach</b> a photo to convert it into a narrow strip of photo (crop)",
    "es": "👩🏽‍💻 <b>Adjunta</b> una foto para convertirla en una franja estrecha de foto (recorte)",
    "fr": "👩🏽‍💻 <b>Joins</b> une photo pour la convertir en une bande étroite de photo (découpe)",
    "zh": "👩🏽‍💻 <b>附加</b> 照片以转换为窄条照片（切片）",
    "ar": "👩🏽‍💻 <b>أرفق</b> صورة لتحويلها إلى شريط ضيق من الصورة (قص)",
}
l_image_descpic_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> фото для преобразования в формат, необходимый для установки Description Picture для своего приложения в @BotFather (640x360)",
    "en": "👩🏽‍💻 <b>Attach</b> a photo for conversion to the format required to set the Description Picture for your app in @BotFather (640x360)",
    "es": "👩🏽‍💻 <b>Adjunta</b> una foto para convertirla al formato necesario para establecer la Descripción de la Imagen para tu aplicación en @BotFather (640x360)",
    "fr": "👩🏽‍💻 <b>Joins</b> une photo pour la convertir au format nécessaire pour définir l'image de description de votre application dans @BotFather (640x360)",
    "zh": "👩🏽‍💻 <b>附加</b> 照片以转换为在 @BotFather 中为您的应用程序设置描述图片所需的格式 (640x360)",
    "ar": "👩🏽‍💻 <b>أرفق</b> صورة للتحويل إلى التنسيق المطلوب لتعيين صورة الوصف لتطبيقك في @BotFather (640x360)",
}
l_image_watermark_attach = {
    "ru": "👩🏽‍💻 <b>Отправь</b> фото с подписью для текста водяного знака до 32 символов",
    "en": "👩🏽‍💻 <b>Send</b> a photo with a caption for the watermark text up to 32 characters",
    "es": "👩🏽‍💻 <b>Envía</b> una foto con un pie de foto para el texto de la marca de agua de hasta 32 caracteres",
    "fr": "👩🏽‍💻 <b>Envoyez</b> une photo avec une légende pour le texte du filigrane jusqu'à 32 caractères",
    "zh": "👩🏽‍💻 <b>发送</b> 带有水印文本的照片，最多 32 个字符",
    "ar": "👩🏽‍💻 <b>أرسل</b> صورة مع نص لعلامة مائية يصل إلى 32 حرفًا",
}
l_image_watermark_error = {
    "ru": "👩🏽‍💻 <b>Необходимо</b> отправить файл вместе с подписью",
    "en": "👩🏽‍💻 <b>It is necessary</b> to send the file along with the signature",
    "es": "👩🏽‍💻 <b>Es necesario</b> enviar el archivo junto con la firma",
    "fr": "👩🏽‍💻 <b>Il est nécessaire</b> d'envoyer le fichier avec la signature",
    "zh": "👩🏽‍💻 <b>需要</b> 将文件与签名一起发送",
    "ar": "👩🏽‍💻 <b>يجب</b> إرسال الملف مع التوقيع",
}
l_gif_text = {
    "ru": "👩🏽‍💻 <b>Выбери</b> инструменты для преобразования <i>гиф</i> в",
    "en": "👩🏽‍💻 <b>Select</b> tools to convert <i>gif</i> to",
    "es": "👩🏽‍💻 <b>Elige</b> herramientas para convertir <i>gif</i> en",
    "fr": "👩🏽‍💻 <b>Choisis</b> des outils pour convertir <i>gif</i> en",
    "zh": "👩🏽‍💻 <b>选择</b> 将<i>gif</i>转换为",
    "ar": "👩🏽‍💻 <b>اختر</b> الأدوات لتحويل <i>GIF</i> إلى",
}
l_gif_mp4 = {
    "ru": "🎥 mp4",
    "en": "🎥 mp4",
    "es": "🎥 mp4",
    "fr": "🎥 mp4",
    "zh": "🎥 mp4",
    "ar": "🎥 mp4",
}
l_gif_thumb = {
    "ru": "🖼️ ico",
    "en": "🖼️ ico",
    "es": "🖼️ ico",
    "fr": "🖼️ ico",
    "zh": "🖼️ ico",
    "ar": "🖼️ ico",
}
l_gif_descgif = {
    "ru": "⿴ Bot Desc Gif",
    "en": "⿴ Bot Desc Gif",
    "es": "⿴ Descripción del Bot Gif",
    "fr": "⿴ Description du bot Gif",
    "zh": "⿴ 机器人描述 动图",
    "ar": "⿴ وصف البوت جيف",
}
l_gif_mp4_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> гиф для преобразования в mp4",
    "en": "👩🏽‍💻 <b>Attach</b> a gif to convert to mp4",
    "es": "👩🏽‍💻 <b>Adjunta</b> un gif para convertir a mp4",
    "fr": "👩🏽‍💻 <b>Attache</b> un gif pour le convertir en mp4",
    "zh": "👩🏽‍💻 <b>附加</b> gif 以转换为 mp4",
    "ar": "👩🏽‍💻 <b>أرفق</b> صورة متحركة لتحويلها إلى mp4",
}
l_gif_thumb_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> гиф для преобразования в ico-иконку (320x320)",
    "en": "👩🏽‍💻 <b>Attach</b> a gif to convert it to an ico icon (320x320)",
    "es": "👩🏽‍💻 <b>Adjunta</b> un gif para convertirlo en un ícono ico (320x320)",
    "fr": "👩🏽‍💻 <b>Joins</b> un gif à convertir en icône ico (320x320)",
    "zh": "👩🏽‍💻 <b>附加</b> gif 以转换为 ico 图标 (320x320)",
    "ar": "👩🏽‍💻 <b>أرفق</b> صورة متحركة لتحويلها إلى أيقونة ico (320x320)",
}
l_gif_descgif_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> гиф для преобразования в формат, необходимый для установки Description Gif для своего приложения в @BotFather (640x360). После формирования GIF нажимаем на нее через <u>мобильное</u> приложение (ожидая загрузки), далее Поделиться - приложение Telegram - @BotFather",
    "en": "👩🏽‍💻 <b>Attach</b> a gif for conversion to the format required to set the Description Gif for your app in @BotFather (640x360). After the GIF is created, click on it through the <u>mobile</u> app (waiting for it to load), then Share - Telegram app - @BotFather",
    "es": "👩🏽‍💻 <b>Adjunta</b> un gif para convertirlo al formato necesario para establecer la Descripción Gif para tu aplicación en @BotFather (640x360). Después de formar el GIF, haz clic en él a través de la <u>aplicación</u> móvil (esperando la carga), luego Compartir - aplicación Telegram - @BotFather",
    "fr": "👩🏽‍💻 <b>Attache</b> un gif pour le convertir au format nécessaire pour définir le Description Gif de votre application dans @BotFather (640x360). Après avoir créé le GIF, cliquez dessus via l'application <u>mobile</u> (en attendant le chargement), puis Partager - application Telegram - @BotFather",
    "zh": "👩🏽‍💻 <b>附加</b> GIF 以转换为 @BotFather 中应用程序所需的描述 GIF 格式 (640x360)。生成 GIF 后，通过 <u>移动</u> 应用程序点击它（等待加载），然后选择分享 - Telegram 应用 - @BotFather",
    "ar": "👩🏽‍💻 <b>أرفق</b> صورة متحركة لتحويلها إلى التنسيق المطلوب لتثبيت وصف الصورة المتحركة لتطبيقك في @BotFather (640x360). بعد إنشاء الصورة المتحركة، انقر عليها عبر <u>التطبيق</u> المحمول (في انتظار التحميل)، ثم شارك - تطبيق تيليجرام - @BotFather",
}
l_video_text = {
    "ru": "👩🏽‍💻 <b>Выбери</b> инструменты для преобразования <i>видео</i> в",
    "en": "👩🏽‍💻 <b>Select</b> tools to convert <i>video</i> to",
    "es": "👩🏽‍💻 <b>Elige</b> herramientas para convertir <i>video</i> en",
    "fr": "👩🏽‍💻 <b>Choisis</b> des outils pour convertir <i>des vidéos</i> en",
    "zh": "👩🏽‍💻 <b>选择</b> 将 <i>视频</i> 转换为",
    "ar": "👩🏽‍💻 <b>اختر</b> الأدوات لتحويل <i>الفيديو</i> إلى",
}
l_video_mp3 = {
    "ru": "▶️ mp3",
    "en": "▶️ mp3",
    "es": "▶️ mp3",
    "fr": "▶️ mp3",
    "zh": "▶️ mp3",
    "ar": "▶️ mp3",
}
l_video_mp4 = {
    "ru": "🎥 mp4",
    "en": "🎥 mp4",
    "es": "🎥 mp4",
    "fr": "🎥 mp4",
    "zh": "🎥 mp4",
    "ar": "🎥 mp4",
}
l_video_album = {
    "ru": "9️⃣ альбом⁹",
    "en": "9️⃣ album⁹",
    "es": "9️⃣ álbum⁹",
    "fr": "9️⃣ album⁹",
    "zh": "9️⃣ 专辑⁹",
    "ar": "٩️⃣ ألبوم⁹",
}
l_video_slide = {
    "ru": "1️⃣ слайд¹",
    "en": "1️⃣ slide¹",
    "es": "1️⃣ diapositiva¹",
    "fr": "1️⃣ diapositive¹",
    "zh": "1️⃣ 幻灯片¹",
    "ar": "1️⃣ شريحة¹",
}
l_video_thumb = {
    "ru": "🖼️ ico",
    "en": "🖼️ ico",
    "es": "🖼️ ico",
    "fr": "🖼️ ico",
    "zh": "🖼️ ico",
    "ar": "🖼️ ico",
}
l_video_gif = {
    "ru": "📽️ gif",
    "en": "📽️ gif",
    "es": "📽️ gif",
    "fr": "📽️ gif",
    "zh": "📽️ gif",
    "ar": "📽️ جيف",
}
l_video_sticker = {
    "ru": "🌌 стикер",
    "en": "🌌 sticker",
    "es": "🌌 sticker",
    "fr": "🌌 autocollant",
    "zh": "🌌 贴纸",
    "ar": "🌌 ملصق",
}
l_video_videonote = {
    "ru": "⚫️ телескоп",
    "en": "⚫️ telescope",
    "es": "⚫️ telescopio",
    "fr": "⚫️ télescope",
    "zh": "⚫️ 望远镜",
    "ar": "⚫️ تلسكوب",
}
l_video_slice = {
    "ru": "🔪 Срез",
    "en": "🔪 Slice",
    "es": "🔪 Corte",
    "fr": "🔪 Trancher",
    "zh": "🔪 切片",
    "ar": "🔪 قطع",
}
l_video_slice_mini = {
    "ru": "🔪 срез",
    "en": "🔪 slice",
    "es": "🔪 corte",
    "fr": "🔪 tranche",
    "zh": "🔪 切片",
    "ar": "🔪 قطع",
}
l_video_transcribe = {
    "ru": "🗣️ транскрибация",
    "en": "🗣️ transcription",
    "es": "🗣️ transcripción",
    "fr": "🗣️ transcription",
    "zh": "🗣️ 转录",
    "ar": "🗣️ النسخ",
}
l_video_mp3_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> видео для преобразования в mp3-аудио",
    "en": "👩🏽‍💻 <b>Attach</b> a video for conversion to mp3 audio",
    "es": "👩🏽‍💻 <b>Adjunta</b> un video para convertirlo a audio mp3",
    "fr": "👩🏽‍💻 <b>Joins</b> une vidéo pour la convertir en audio mp3",
    "zh": "👩🏽‍💻 <b>附加</b> 视频以转换为 mp3 音频",
    "ar": "👩🏽‍💻 <b>أرفق</b> فيديو لتحويله إلى صوت mp3",
}
l_video_mp4_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> видео для преобразования в mp4",
    "en": "👩🏽‍💻 <b>Attach</b> a video for conversion to mp4",
    "es": "👩🏽‍💻 <b>Adjunta</b> un video para convertirlo a mp4",
    "fr": "👩🏽‍💻 <b>Joins</b> une vidéo à convertir en mp4",
    "zh": "👩🏽‍💻 <b>附加</b> 视频以转换为 mp4",
    "ar": "👩🏽‍💻 <b>أرفق</b> فيديو للتحويل إلى mp4",
}
l_video_gif_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> видео для преобразования в гиф",
    "en": "👩🏽‍💻 <b>Attach</b> a video to convert to gif",
    "es": "👩🏽‍💻 <b>Adjunta</b> un video para convertirlo en gif",
    "fr": "👩🏽‍💻 <b>Joins</b> une vidéo à convertir en gif",
    "zh": "👩🏽‍💻 <b>附加</b> 视频以转换为 GIF",
    "ar": "👩🏽‍💻 <b>أرفق</b> فيديو للتحويل إلى صورة متحركة",
}
l_video_thumb_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> видео для преобразования в ico-иконку (320x320)",
    "en": "👩🏽‍💻 <b>Attach</b> a video to convert to an ico icon (320x320)",
    "es": "👩🏽‍💻 <b>Adjunta</b> un video para convertirlo en un ícono ico (320x320)",
    "fr": "👩🏽‍💻 <b>Joins</b> une vidéo pour la convertir en icône ico (320x320)",
    "zh": "👩🏽‍💻 <b>附加</b> 视频以转换为 ico 图标 (320x320)",
    "ar": "👩🏽‍💻 <b>أرفق</b> فيديو لتحويله إلى أيقونة ico (320x320)",
}
l_video_sticker_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> фото/видео для преобразования в видео-стикер",
    "en": "👩🏽‍💻 <b>Attach</b> a photo/video to convert it into a video sticker",
    "es": "👩🏽‍💻 <b>Adjunta</b> una foto/video para convertirlo en un video-sticker",
    "fr": "👩🏽‍💻 <b>Joins</b> une photo/vidéo pour la convertir en vidéo-sticker",
    "zh": "👩🏽‍💻 <b>附加</b> 照片/视频以转换为视频贴纸",
    "ar": "👩🏽‍💻 <b>أرفق</b> صورة/فيديو لتحويله إلى ملصق فيديو",
}
l_video_album_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> видео для преобразования в альбом из 9 частей",
    "en": "👩🏽‍💻 <b>Attach</b> a video to convert it into an album of 9 parts",
    "es": "👩🏽‍💻 <b>Adjunta</b> un video para convertirlo en un álbum de 9 partes",
    "fr": "👩🏽‍💻 <b>Joins</b> une vidéo pour la convertir en un album de 9 parties",
    "zh": "👩🏽‍💻 <b>附加</b> 视频以转换为 9 部分的相册",
    "ar": "👩🏽‍💻 <b>أرفق</b> فيديو للتحويل إلى ألبوم مكون من 9 أجزاء",
}
l_video_slide_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> альбом из нескольких видео до 1мин для преобразования в слайдшоу",
    "en": "👩🏽‍💻 <b>Attach</b> an album of several videos up to 1 minute for conversion to a slideshow",
    "es": "👩🏽‍💻 <b>Adjunta</b> un álbum de varios videos de hasta 1 minuto para convertirlo en un slideshow",
    "fr": "👩🏽‍💻 <b>Joins</b> un album de plusieurs vidéos de 1 minute pour la conversion en diaporama",
    "zh": "👩🏽‍💻 <b>附加</b> 一个不超过1分钟的视频专辑以转换为幻灯片。",
    "ar": "👩🏽‍💻 <b>أرفق</b> ألبومًا من عدة مقاطع فيديو تصل مدتها إلى دقيقة واحدة لتحويلها إلى عرض شرائح",
}
l_video_videonote_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> видео для преобразования в телескоп (круглую видео-заметку)",
    "en": "👩🏽‍💻 <b>Attach</b> a video for conversion to a telescope (circular video note)",
    "es": "👩🏽‍💻 <b>Adjunta</b> un video para convertirlo en un telescopio (una nota de video redonda)",
    "fr": "👩🏽‍💻 <b>Joindre</b> une vidéo pour la conversion en télescope (note vidéo ronde)",
    "zh": "👩🏽‍💻 <b>附加</b> 视频以转换为望远镜（圆形视频备注）",
    "ar": "👩🏽‍💻 <b>أرفق</b> فيديو للتحويل إلى تلسكوب (ملاحظة فيديو دائرية)",
}
l_video_slice_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> видео для преобразования в узкую видео-полоску (срез)",
    "en": "👩🏽‍💻 <b>Attach</b> a video to convert it into a narrow video strip (slice)",
    "es": "👩🏽‍💻 <b>Adjunta</b> un video para convertirlo en una franja de video estrecha (corte)",
    "fr": "👩🏽‍💻 <b>Attache</b> une vidéo pour la convertir en une bande vidéo étroite (coupure)",
    "zh": "👩🏽‍💻 <b>附加</b> 视频以转换为窄视频条（切片）",
    "ar": "👩🏽‍💻 <b>أرفق</b> فيديو لتحويله إلى شريط فيديو ضيق (قطع)",
}
l_video_transcribe_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> круглую видео-заметку для извлечения текста",
    "en": "👩🏽‍💻 <b>Attach</b> a round video note for text extraction",
    "es": "👩🏽‍💻 <b>Adjunta</b> una nota de video circular para extraer texto",
    "fr": "👩🏽‍💻 <b>Attache</b> une note vidéo ronde pour extraire le texte",
    "zh": "👩🏽‍💻 <b>附加</b> 圆形视频笔记以提取文本",
    "ar": "👩🏽‍💻 <b>أرفق</b> ملاحظة فيديو دائرية لاستخراج النص",
}
l_audio_text = {
    "ru": "👩🏽‍💻 <b>Выбери</b> инструменты для преобразования <i>audio</i> в",
    "en": "👩🏽‍💻 <b>Select</b> tools to convert <i>audio</i> to",
    "es": "👩🏽‍💻 <b>Elige</b> herramientas para convertir <i>audio</i> en",
    "fr": "👩🏽‍💻 <b>Choisis</b> des outils pour convertir <i>audio</i> en",
    "zh": "👩🏽‍💻 <b>选择</b> 将 <i>音频</i> 转换为",
    "ar": "👩🏽‍💻 <b>اختر</b> الأدوات لتحويل <i>audio</i> إلى",
}
l_audio_mp3 = {
    "ru": "▶️ mp3-аудио",
    "en": "▶️ mp3 audio",
    "es": "▶️ audio mp3",
    "fr": "▶️ audio mp3",
    "zh": "▶️ mp3音频",
    "ar": "▶️ mp3-صوت",
}
l_audio_ogg = {
    "ru": "🎤 ogg-голосовое",
    "en": "🎤 ogg-voice",
    "es": "🎤 voz ogg",
    "fr": "🎤 voix ogg",
    "zh": "🎤 ogg-语音",
    "ar": "🎤 ogg-صوتي",
}
l_audio_vinyl = {
    "ru": "⚫️ винил-пластинка",
    "en": "⚫️ vinyl record",
    "es": "⚫️ disco de vinilo",
    "fr": "⚫️ disque vinyle",
    "zh": "⚫️ 黑胶唱片",
    "ar": "⚫️ أسطوانة فونوغراف",
}
l_audio_transcribe = {
    "ru": "🗣️ транскрибация",
    "en": "🗣️ transcription",
    "es": "🗣️ transcripción",
    "fr": "🗣️ transcription",
    "zh": "🗣️ 转录",
    "ar": "🗣️ النسخ",
}
l_audio_mp3_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> голосовое для преобразования в mp3",
    "en": "👩🏽‍💻 <b>Attach</b> a voice message to convert to mp3",
    "es": "👩🏽‍💻 <b>Adjunta</b> un audio para convertirlo a mp3",
    "fr": "👩🏽‍💻 <b>Joins</b> un enregistrement vocal pour le convertir en mp3",
    "zh": "👩🏽‍💻 <b>附加</b> 语音以转换为 mp3",
    "ar": "👩🏽‍💻 <b>أرفق</b> صوتًا للتحويل إلى mp3",
}
l_audio_ogg_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> аудио для преобразования в голосовое",
    "en": "👩🏽‍💻 <b>Attach</b> audio for conversion to voice",
    "es": "👩🏽‍💻 <b>Adjunta</b> el audio para convertirlo en voz",
    "fr": "👩🏽‍💻 <b>Joins</b> un audio pour le convertir en voix",
    "zh": "👩🏽‍💻 <b>附加</b> 音频以转换为语音",
    "ar": "👩🏽‍💻 <b>أرفق</b> الصوت للتحويل إلى صوت",
}
l_audio_vinyl_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> аудио для преобразования в телескоп в виде виниловой пластинки",
    "en": "👩🏽‍💻 <b>Attach</b> the audio for conversion to a telescope in the form of a vinyl record",
    "es": "👩🏽‍💻 <b>Adjunta</b> el audio para convertirlo en un telescopio en forma de disco de vinilo",
    "fr": "👩🏽‍💻 <b>Joins</b> un audio à convertir en télescope sous forme de disque vinyle",
    "zh": "👩🏽‍💻 <b>附加</b> 音频以转换为黑胶唱片的望远镜",
    "ar": "👩🏽‍💻 <b>أرفق</b> الصوت للتحويل إلى تلسكوب على شكل أسطوانة فونو",
}
l_audio_transcribe_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> голосовое для преобразования в текст",
    "en": "👩🏽‍💻 <b>Attach</b> a voice message for conversion to text",
    "es": "👩🏽‍💻 <b>Adjunta</b> un audio para convertirlo en texto",
    "fr": "👩🏽‍💻 <b>Joins</b> un message vocal pour le convertir en texte",
    "zh": "👩🏽‍💻 <b>附加</b> 语音以转换为文本",
    "ar": "👩🏽‍💻 <b>أرفق</b> صوتًا للتحويل إلى نص",
}
l_audio_recognize = {
    "ru": "👩🏽‍💻 <b>Ошибка</b> распознавания речи",
    "en": "👩🏽‍💻 <b>Speech recognition</b> error",
    "es": "👩🏽‍💻 <b>Error</b> de reconocimiento de voz",
    "fr": "👩🏽‍💻 <b>Erreur</b> de reconnaissance vocale",
    "zh": "👩🏽‍💻 <b>语音识别错误</b>",
    "ar": "👩🏽‍💻 <b>خطأ</b> في التعرف على الصوت",
}
l_text_text = {
    "ru": "👩🏽‍💻 <b>Выбери</b> инструменты для преобразования <i>текста</i> в",
    "en": "👩🏽‍💻 <b>Select</b> tools for converting <i>text</i> to",
    "es": "👩🏽‍💻 <b>Elige</b> herramientas para convertir <i>texto</i> en",
    "fr": "👩🏽‍💻 <b>Choisis</b> des outils pour convertir <i>le texte</i> en",
    "zh": "👩🏽‍💻 <b>选择</b> 将 <i>文本</i> 转换为",
    "ar": "👩🏽‍💻 <b>اختر</b> الأدوات لتحويل <i>النص</i> إلى",
}
l_text_ocr = {
    "ru": "🔣 ocr",
    "en": "🔣 ocr",
    "es": "🔣 ocr",
    "fr": "🔣 ocr",
    "zh": "🔣 ocr",
    "ar": "🔣 ocr",
}
l_text_bin = {
    "ru": "🔢 bin",
    "en": "🔢 bin",
    "es": "🔢 bin",
    "fr": "🔢 bin",
    "zh": "🔢 bin",
    "ar": "🔢 بن",
}
l_text_hex = {
    "ru": "🔠 hex",
    "en": "🔠 hex",
    "es": "🔠 hex",
    "fr": "🔠 hex",
    "zh": "🔠 十六进制",
    "ar": "🔠 سداسي",
}
l_text_null = {
    "ru": "0️⃣ null",
    "en": "0️⃣ null",
    "es": "0️⃣ nulo",
    "fr": "0️⃣ null",
    "zh": "0️⃣ null",
    "ar": "0️⃣ null",
}
l_text_mp3 = {
    "ru": "▶️ mp3-аудио",
    "en": "▶️ mp3 audio",
    "es": "▶️ audio mp3",
    "fr": "▶️ audio mp3",
    "zh": "▶️ mp3音频",
    "ar": "▶️ ملف mp3 الصوتي",
}
l_text_url = {
    "ru": "️🧾 url-encode",
    "en": "️🧾 url-encode",
    "es": "️🧾 url-encode",
    "fr": "️🧾 url-encode",
    "zh": "️🧾 url-encode",
    "ar": "️🧾 ترميز عنوان URL",
}
l_text_ocr_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> файл для оптического распознавания текста",
    "en": "👩🏽‍💻 <b>Attach</b> a file for optical character recognition",
    "es": "👩🏽‍💻 <b>Adjunta</b> un archivo para el reconocimiento óptico de caracteres",
    "fr": "👩🏽‍💻 <b>Joindre</b> un fichier pour la reconnaissance optique de caractères",
    "zh": "👩🏽‍💻 <b>附加</b> 文件以进行光学字符识别",
    "ar": "👩🏽‍💻 <b>أرفق</b> ملفًا للتعرف الضوئي على النص",
}
l_text_bin_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> текст для преобразования в байтовый вид",
    "en": "👩🏽‍💻 <b>Attach</b> the text to be converted to byte format",
    "es": "👩🏽‍💻 <b>Adjunta</b> el texto para convertirlo en formato de bytes",
    "fr": "👩🏽‍💻 <b>Attache</b> le texte à convertir en format binaire",
    "zh": "👩🏽‍💻 <b>附加</b> 要转换为字节格式的文本",
    "ar": "👩🏽‍💻 <b>أرفق</b> النص للتحويل إلى شكل بايت",
}
l_text_hex_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> текст для преобразования в hex-символы (шестнадцатиричное представление байт)",
    "en": "👩🏽‍💻 <b>Attach</b> the text to be converted to hex symbols (hexadecimal representation of bytes)",
    "es": "👩🏽‍💻 <b>Adjunta</b> el texto para convertirlo en símbolos hexadecimales (representación hexadecimal de bytes)",
    "fr": "👩🏽‍💻 <b>Attache</b> le texte à convertir en symboles hexadécimaux (représentation hexadécimale des octets)",
    "zh": "👩🏽‍💻 <b>附加</b> 要转换为十六进制符号的文本（字节的十六进制表示）",
    "ar": "👩🏽‍💻 <b>أرفق</b> نصًا للتحويل إلى رموز hex (التمثيل السداسي عشر للبايتات)",
}
l_text_mp3_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> текст для преобразования в голосовое",
    "en": "👩🏽‍💻 <b>Attach</b> the text to be converted to speech",
    "es": "👩🏽‍💻 <b>Adjunta</b> el texto para convertirlo en voz",
    "fr": "👩🏽‍💻 <b>Joins</b> le texte à convertir en voix",
    "zh": "👩🏽‍💻 <b>附加</b> 要转换为语音的文本",
    "ar": "👩🏽‍💻 <b>أرفق</b> النص لتحويله إلى صوت",
}
l_text_url_attach = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> текст для url-encode-преобразования (процентное и шестнадцатиричное кодирование как правило https-ссылок)",
    "en": "👩🏽‍💻 <b>Attach</b> the text for URL-encode conversion (percent and hexadecimal encoding of HTTPS links)",
    "es": "👩🏽‍💻 <b>Adjunta</b> el texto para la conversión a url-encode (la codificación porcentual y hexadecimal de enlaces https generalmente)",
    "fr": "👩🏽‍💻 <b>Attache</b> le texte pour la conversion en url-encode (le codage en pourcentage et en hexadécimal des liens https)",
    "zh": "👩🏽‍💻 <b>附加</b> 要进行 URL 编码转换的文本（百分比和十六进制编码通常用于 HTTPS 链接）",
    "ar": "👩🏽‍💻 <b>أرفق</b> نصًا لتحويله إلى ترميز url (عادةً ما يكون الترميز النسبى والسداسى عشر لروابط https)",
}
l_text_text1024 = {
    "ru": "💭 Текст 1024 символа",
    "en": "💭 Text 1024 characters",
    "es": "💭 Texto de 1024 caracteres",
    "fr": "💭 Texte de 1024 caractères",
    "zh": "💭 文本 1024 个字符",
    "ar": "💭 نص 1024 حرف",
}
l_text_text4096 = {
    "ru": "🗯️ Текст 4096 символа",
    "en": "🗯️ Text 4096 characters",
    "es": "🗯️ Texto de 4096 caracteres",
    "fr": "🗯️ Texte de 4096 caractères",
    "zh": "🗯️ 文本 4096 个字符",
    "ar": "🗯️ نص 4096 حرف",
}
l_convert_error = {
    "ru": "👩🏽‍💻 <b>Ошибка</b> преобразования контента (попробуй позже или загрузи другой файл)",
    "en": "👩🏽‍💻 <b>Error</b> converting content (try again later or upload a different file)",
    "es": "👩🏽‍💻 <b>Error</b> al convertir el contenido (intenta más tarde o carga otro archivo)",
    "fr": "👩🏽‍💻 <b>Erreur</b> de conversion du contenu (réessayez plus tard ou téléchargez un autre fichier)",
    "zh": "👩🏽‍💻 <b>内容转换错误</b>（稍后再试或上传其他文件）",
    "ar": "👩🏽‍💻 <b>خطأ</b> في تحويل المحتوى (حاول لاحقًا أو قم بتحميل ملف آخر)",
}
l_convert_more_one = {
    "ru": "👩🏽‍💻 <b>Загрузи</b> более 1го файла как альбом",
    "en": "👩🏽‍💻 <b>Upload</b> more than 1 file as an album",
    "es": "👩🏽‍💻 <b>Sube</b> más de 1 archivo como álbum",
    "fr": "👩🏽‍💻 <b>Télécharge</b> plus d'un fichier en tant qu'album",
    "zh": "👩🏽‍💻 <b>上传</b> 超过 1 个文件作为相册",
    "ar": "👩🏽‍💻 <b>قم بتحميل</b> أكثر من ملف واحد كألبوم",
}
l_telegraph_text = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> .jpg/.png/.gif/.mp4 - контент, чтобы создать ссылку",
    "en": "👩🏽‍💻 <b>Attach</b> .jpg/.png/.gif/.mp4 content to create a link",
    "es": "👩🏽‍💻 <b>Adjunta</b> contenido .jpg/.png/.gif/.mp4 para crear un enlace",
    "fr": "👩🏽‍💻 <b>Joins</b> .jpg/.png/.gif/.mp4 - contenu pour créer un lien",
    "zh": "👩🏽‍💻 <b>附加</b> .jpg/.png/.gif/.mp4 - 内容以创建链接",
    "ar": "👩🏽‍💻 <b>أرفق</b> محتوى .jpg/.png/.gif/.mp4 لإنشاء رابط",
}
l_telegraph_error = {
    "ru": "👩🏽‍💻 <b>Ошибка</b> получения ссылки (попробуй позже или загрузи другой файл)",
    "en": "👩🏽‍💻 <b>Error</b> retrieving the link (try again later or upload a different file)",
    "es": "👩🏽‍💻 <b>Error</b> al obtener el enlace (intenta más tarde o carga otro archivo)",
    "fr": "👩🏽‍💻 <b>Erreur</b> lors de l'obtention du lien (réessayez plus tard ou téléchargez un autre fichier)",
    "zh": "👩🏽‍💻 <b>获取链接时出错</b>（稍后再试或上传其他文件）",
    "ar": "👩🏽‍💻 <b>خطأ</b> في الحصول على الرابط (حاول لاحقًا أو قم بتحميل ملف آخر)",
}
l_json_text = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> любое сообщение или сделай пересылку",
    "en": "👩🏽‍💻 <b>Attach</b> any message or forward it",
    "es": "👩🏽‍💻 <b>Adjunta</b> cualquier mensaje o reenvía",
    "fr": "👩🏽‍💻 <b>Joins</b> n'importe quel message ou fais un transfert",
    "zh": "👩🏽‍💻 <b>附加</b> 任何消息或转发",
    "ar": "👩🏽‍💻 <b>أرفق</b> أي رسالة أو قم بإعادة توجيهها",
}
l_sticker_circle_on = {
    "ru": "✅ Закруглить",
    "en": "✅ Round",
    "es": "✅ Redondear",
    "fr": "✅ Arrondir",
    "zh": "✅ 圆角",
    "ar": "✅ تقويس",
}
l_sticker_circle_off = {
    "ru": "☑️ Закруглить",
    "en": "☑️ Round",
    "es": "☑️ Redondear",
    "fr": "☑️ Arrondir",
    "zh": "☑️ 圆角",
    "ar": "☑️ تقويس",
}
l_sticker_rbg_on = {
    "ru": "✅ Удалить фон",
    "en": "✅ Remove background",
    "es": "✅ Eliminar fondo",
    "fr": "✅ Supprimer l'arrière-plan",
    "zh": "✅ 删除背景",
    "ar": "✅ إزالة الخلفية",
}
l_sticker_rbg_off = {
    "ru": "☑️ Удалить фон",
    "en": "☑️ Remove background",
    "es": "☑️ Eliminar fondo",
    "fr": "☑️ Supprimer l'arrière-plan",
    "zh": "☑️ 删除背景",
    "ar": "☑️ إزالة الخلفية",
}
l_tools_need_link_story = {
    "ru": "👩🏽‍💻 Вставь ссылку на @-tg-историю или x/ig/tt/yt-видео",
    "en": "👩🏽‍💻 Insert a link to the @-tg-story or x/ig/tt/yt-video",
    "es": "👩🏽‍💻 Inserta el enlace a la historia de @-tg- o a un video de x/ig/tt/yt",
    "fr": "👩🏽‍💻 Insérez le lien vers l'histoire @-tg- ou la vidéo x/ig/tt/yt",
    "zh": "👩🏽‍💻 插入 @-tg-故事或 x/ig/tt/yt-视频的链接",
    "ar": "👩🏽‍💻 أدخل رابطًا إلى قصة @-tg- أو فيديو x/ig/tt/yt",
}
l_tools_no_stories = {
    "ru": "👩🏽‍💻 Доступных для скачивания историй нет",
    "en": "👩🏽‍💻 There are no stories available for download",
    "es": "👩🏽‍💻 No hay historias disponibles para descargar",
    "fr": "👩🏽‍💻 Il n'y a pas d'histoires disponibles à télécharger",
    "zh": "👩🏽‍💻 没有可下载的故事",
    "ar": "👩🏽‍💻 لا توجد قصص متاحة للتنزيل",
}
l_tools_has_restricted = {
    "ru": "👩🏽‍💻 <b>Ошибка</b> отправки видео-заметки/голосового для premium-аккаунта! В настройках <b>[Конфиденциальность]</b> добавь @{0} в <i>исключения</i> для <b>[Голосовые сообщения]</b>, чтобы отобразить видео-заметку/голосовое",
    "en": "👩🏽‍💻 <b>Error</b> sending video note/voice message for premium account! In the settings <b>[Privacy]</b> add @{0} to <i>exceptions</i> for <b>[Voice Messages]</b> to display the video note/voice message.",
    "es": "👩🏽‍💻 <b>Error</b> al enviar la nota de video/voz para la cuenta premium! En la configuración <b>[Privacidad]</b> añade @{0} a <i>excepciones</i> para <b>[Mensajes de voz]</b>, para mostrar la nota de video/voz.",
    "fr": "👩🏽‍💻 <b>Erreur</b> d'envoi de la vidéo-notes/message vocal pour le compte premium ! Dans les paramètres <b>[Confidentialité]</b>, ajoute @{0} dans <i>exceptions</i> pour <b>[Messages vocaux]</b> afin d'afficher la vidéo-notes/message vocal.",
    "zh": "👩🏽‍💻 <b>发送视频备注/语音的错误</b>，适用于premium账户！在设置中 <b>[隐私]</b> 将 @{0} 添加到 <i>例外</i> 中，以便显示视频备注/语音。",
    "ar": "👩🏽‍💻 <b>خطأ</b> في إرسال ملاحظة فيديو/صوت لحساب premium! في الإعدادات <b>[الخصوصية]</b> أضف @{0} إلى <i>الاستثناءات</i> لـ <b>[الرسائل الصوتية]</b> لعرض ملاحظة الفيديو/الصوت",
}
l_tools_acc_age = {
    "ru": "<b>Возраст аккаунта</b>: {0}",
    "en": "<b>Account Age</b>: {0}",
    "es": "<b>Edad de la cuenta</b>: {0}",
    "fr": "<b>Âge du compte</b>: {0}",
    "zh": "<b>账户年龄</b>: {0}",
    "ar": "<b>عمر الحساب</b>: {0}",
}
l_tools_set_owner = {
    "ru": "👩🏽‍💻 <b>ID</b>-создателя набора ({0}):\n\n<blockquote><code>{1}</code></blockquote>",
    "en": "👩🏽‍💻 <b>Set Creator ID</b> ({0}):\n\n<blockquote><code>{1}</code></blockquote>",
    "es": "👩🏽‍💻 <b>ID</b> del creador del conjunto ({0}):\n\n<blockquote><code>{1}</code></blockquote>",
    "fr": "👩🏽‍💻 <b>ID</b> du créateur de l'ensemble ({0}) :\n\n<blockquote><code>{1}</code></blockquote>",
    "zh": "👩🏽‍💻 <b>创建者ID</b>（{0}）：\n\n<blockquote><code>{1}</code></blockquote>",
    "ar": "👩🏽‍💻 <b>معرف</b>-المنشئ المجموعة ({0}):\n\n<blockquote><code>{1}</code></blockquote>",
}
# endregion


# region FereyAIBot
l_ai_btn1 = {
    "ru": "👩🏽‍💻 Нейросети",
    "en": "👩🏽‍💻 Neural Networks",
    "es": "👩🏽‍💻 Redes neuronales",
    "fr": "👩🏽‍💻 Réseaux de neurones",
    "zh": "👩🏽‍💻 神经网络",
    "ar": "👩🏽‍💻 الشبكات العصبية",
}
l_ai_btn2 = {
    "ru": "💨 Подписка",
    "en": "💨 Subscription",
    "es": "💨 Suscripción",
    "fr": "💨 Abonnement",
    "zh": "💨 订阅",
    "ar": "💨 الاشتراك",
}
l_ai_welcome = {
    "ru": "🌱 <b>{0}</b>, добро пожаловать в <i>@tg-приложение</i> для #нейро-генерации контента:\n\n<blockquote>▪️<b>текст/изображение</b>\n▪️<b>#нейро-анализ</b> @tg-каналов\n▪️<b>распознавание</b> речи\n▪️<b>генерация</b> голоса\n▪️<b>очистка ⁰истории</b> /start</blockquote>",
    "en": "🌱 <b>{0}</b>, welcome to the <i>@tg-app</i> for #neuro-content generation:\n\n<blockquote>▪️<b>text/image</b>\n▪️<b>#neuro-analysis</b> of @tg-channels\n▪️<b>speech</b> recognition\n▪️<b>voice</b> generation\n▪️<b>history</b> cleaning /start</blockquote>",
    "es": "🌱 <b>{0}</b>, bienvenido a <i>@tg-aplicación</i> para #neuro-generación de contenido:\n\n<blockquote>▪️<b>texto/imágen</b>\n▪️<b>#neuro-análisis</b> de @tg-canales\n▪️<b>reconocimiento</b> de voz\n▪️<b>generación</b> de voz\n▪️<b>limpieza de ⁰historia</b> /start</blockquote>",
    "fr": "🌱 <b>{0}</b>, bienvenue dans <i>@tg-application</i> pour la #génération-neuro de contenu :\n\n<blockquote>▪️<b>texte/image</b>\n▪️<b>#analyse-neuro</b> des canaux @tg\n▪️<b>reconnaissance</b> vocale\n▪️<b>génération</b> de voix\n▪️<b>nettoyage de l'historique</b> /start</blockquote>",
    "zh": "🌱 <b>{0}</b>, 欢迎来到 <i>@tg-应用程序</i> 用于 #神经生成内容：\n\n<blockquote>▪️<b>文本/图像</b>\n▪️<b>#神经分析</b> @tg-频道\n▪️<b>语音识别</b>\n▪️<b>语音生成</b>\n▪️<b>清除历史</b> /start</blockquote>",
    "ar": "🌱 <b>{0}</b>، مرحبًا بك في <i>@tg-تطبيق</i> لـ #توليد المحتوى العصبي:\n\n<blockquote>▪️<b>نص/صورة</b>\n▪️<b>#تحليل-عصبي</b> لقنوات @tg\n▪️<b>التعرف</b> على الكلام\n▪️<b>توليد</b> الصوت\n▪️<b>تنظيف ⁰السجل</b> /start</blockquote>",
}
l_gen_txt = {
    "ru": "📘 Текст{0}",
    "en": "📘 Text{0}",
    "es": "📘 Texto{0}",
    "fr": "📘 Texte{0}",
    "zh": "📘 文本{0}",
    "ar": "📘 نص{0}",
}
l_gen_voice = {
    "ru": "🗣️ Голос",
    "en": "🗣️ Voice",
    "es": "🗣️ Voz",
    "fr": "🗣️ Voix",
    "zh": "🗣️ 声音",
    "ar": "🗣️ صوت",
}
l_gen_img = {
    "ru": "🌌 Образ",
    "en": "🌌 Image",
    "es": "🌌 Imagen",
    "fr": "🌌 Image",
    "zh": "🌌 形象",
    "ar": "🌌 صورة",
}
l_gen_tlg = {
    "ru": "👩🏽‍💻 @tg-канал",
    "en": "👩🏽‍💻 @tg-channel",
    "es": "👩🏽‍💻 @canal-tg",
    "fr": "👩🏽‍💻 @tg-canal",
    "zh": "👩🏽‍💻 @tg-频道",
    "ar": "👩🏽‍💻 @tg-قناة",
}
l_generate_main = {
    "ru": "👩🏽‍💻 <b>Выбери режим</b>",
    "en": "👩🏽‍💻 <b>Select mode</b>",
    "es": "👩🏽‍💻 <b>Elige un modo</b>",
    "fr": "👩🏽‍💻 <b>Choisissez un mode</b>",
    "zh": "👩🏽‍💻 <b>选择模式</b>",
    "ar": "👩🏽‍💻 <b>اختر الوضع</b>",
}
l_generate_prompt = {
    "ru": "👩🏽‍💻 <b>Введи</b> запрос для <b>{0}</b> 👇🏼..",
    "en": "👩🏽‍💻 <b>Enter</b> a request for <b>{0}</b> 👇🏼..",
    "es": "👩🏽‍💻 <b>Introduce</b> la consulta para <b>{0}</b> 👇🏼..",
    "fr": "👩🏽‍💻 <b>Entrez</b> une requête pour <b>{0}</b> 👇🏼..",
    "zh": "👩🏽‍💻 <b>输入</b> 查询以 <b>{0}</b> 👇🏼..",
    "ar": "👩🏽‍💻 <b>أدخل</b> الطلب لـ <b>{0}</b> 👇🏼..",
}
l_generate_chn = {
    "ru": "👩🏽‍💻 <b>Вставь</b> ссылку на @tg-канал для анализа финансовых показателей",
    "en": "👩🏽‍💻 <b>Insert</b> the link to the @tg-channel for financial performance analysis",
    "es": "👩🏽‍💻 <b>Inserta</b> el enlace al canal @tg para el análisis de indicadores financieros",
    "fr": "👩🏽‍💻 <b>Insère</b> le lien vers le canal @tg pour l'analyse des indicateurs financiers",
    "zh": "👩🏽‍💻 <b>插入</b> 分析财务指标的 @tg-频道链接",
    "ar": "👩🏽‍💻 <b>أدخل</b> رابط قناة @tg لتحليل المؤشرات المالية",
}
l_generate_wait = {
    "ru": "👩🏽‍💻 <b>Выбери режим</b> или <b>дождись</b> окончания генерации..",
    "en": "👩🏽‍💻 <b>Select a mode</b> or <b>wait</b> for the generation to finish..",
    "es": "👩🏽‍💻 <b>Elige un modo</b> o <b>espera</b> a que termine la generación..",
    "fr": "👩🏽‍💻 <b>Choisis un mode</b> ou <b>attends</b> la fin de la génération..",
    "zh": "👩🏽‍💻 <b>选择模式</b> 或者 <b>等待</b> 生成结束..",
    "ar": "👩🏽‍💻 <b>اختر الوضع</b> أو <b>انتظر</b> انتهاء التوليد..",
}
l_generate_subcribe = {
    "ru": "👩🏽‍💻 Подожди {0} сек или оформи 💨Подписку",
    "en": "👩🏽‍💻 Wait {0} seconds or subscribe 💨",
    "es": "👩🏽‍💻 Espera {0} seg o suscríbete 💨",
    "fr": "👩🏽‍💻 Attends {0} sec ou souscris à 💨l'Abonnement",
    "zh": "👩🏽‍💻 等待 {0} 秒或订阅 💨订阅",
    "ar": "👩🏽‍💻 انتظر {0} ثانية أو اشترك 💨",
}
l_generate_subcribe2 = {
    "ru": "👩🏽‍💻 <b>Подожди</b> <i>{0}сек или <a href='{1}'>оформи 💨Подписку</a></i>",
    "en": "👩🏽‍💻 <b>Wait</b> <i>{0}sec or <a href='{1}'>subscribe 💨</a></i>",
    "es": "👩🏽‍💻 <b>Espera</b> <i>{0}seg o <a href='{1}'>suscríbete 💨</a></i>",
    "fr": "👩🏽‍💻 <b>Attends</b> <i>{0}sec ou <a href='{1}'>abonne-toi 💨</a></i>",
    "zh": "👩🏽‍💻 <b>等一下</b> <i>{0}秒或<a href='{1}'>订阅💨</a></i>",
    "ar": "👩🏽‍💻 <b>انتظر</b> <i>{0}ثانية أو <a href='{1}'>اشترك 💨</a></i>",
}
l_neuro_generation_limit_content = {
    "ru": "👩🏽‍💻 <b>Достигнут</b> суточный лимит ({0}) на <i>нейро-генерацию</i> контента",
    "en": "👩🏽‍💻 <b>Daily</b> limit reached ({0}) on <i>neuro-generation</i> content",
    "es": "👩🏽‍💻 <b>Límite</b> diario alcanzado ({0}) en contenido de <i>neuro-generación</i>",
    "fr": "👩🏽‍💻 <b>Limite</b> quotidienne atteinte ({0}) sur le contenu de <i>neuro-génération</i>",
    "zh": "👩🏽‍💻 <b>每日限制达到</b> ({0}) <i>的神经生成内容</i>",
    "ar": "👩🏽‍💻 تم الوصول إلى الحد اليومي ({0}) على محتوى توليد الأعصاب",
}
l_generate_subcribe_channel = {
    "ru": "👩🏽‍💻 Оформи 💨Подписку, чтобы узнать финансовый потенциал твоего @tg-канала",
    "en": "👩🏽‍💻 Subscribe 💨 to discover the financial potential of your @tg-channel",
    "es": "👩🏽‍💻 Suscríbete 💨 para conocer el potencial financiero de tu canal @tg.",
    "fr": "👩🏽‍💻 Abonnez-vous 💨 pour découvrir le potentiel financier de votre @tg-canal",
    "zh": "👩🏽‍💻 订阅 💨以了解你 @tg-频道的财务潜力",
    "ar": "👩🏽‍💻 اشترك 💨لتعرف على الإمكانيات المالية لقناتك @tg-канала",
}
l_generate_error = {
    "ru": "👩🏽‍💻 <b>Ошибка</b> генерации, повтори запрос позже",
    "en": "👩🏽‍💻 <b>Error</b> generating, please try again later",
    "es": "👩🏽‍💻 <b>Error</b> de generación, repite la solicitud más tarde",
    "fr": "👩🏽‍💻 <b>Erreur</b> de génération, veuillez réessayer plus tard",
    "zh": "👩🏽‍💻 <b>生成错误</b>，请稍后重试",
    "ar": "👩🏽‍💻 <b>خطأ</b> في التوليد، يرجى إعادة الطلب لاحقًا",
}
l_generate_error_clear = {
    "ru": "Ошибка генерации",
    "en": "Generation error",
    "es": "Error de generación",
    "fr": "Erreur de génération",
    "zh": "生成错误",
    "ar": "خطأ في التوليد",
}
l_process_error = {
    "ru": "👩🏽‍💻 <b>Ошибка</b> преобразования",
    "en": "👩🏽‍💻 <b>Conversion Error</b>",
    "es": "👩🏽‍💻 <b>Error</b> de conversión",
    "fr": "👩🏽‍💻 <b>Erreur</b> de conversion",
    "zh": "👩🏽‍💻 <b>转换错误</b>",
    "ar": "👩🏽‍💻 <b>خطأ</b> في التحويل",
}
l_generate_errchn = {
    "ru": "👩🏽‍💻 <b>Ошибка</b> доступа к каналу (попробуй позже или сделай канал публичным)",
    "en": "👩🏽‍💻 <b>Access</b> error to the channel (try again later or make the channel public)",
    "es": "👩🏽‍💻 <b>Error</b> de acceso al canal (intenta más tarde o haz el canal público)",
    "fr": "👩🏽‍💻 <b>Erreur</b> d'accès au canal (réessaye plus tard ou rends le canal public)",
    "zh": "👩🏽‍💻 <b>访问</b> 渠道时出错（稍后再试或将频道设为公开）",
    "ar": "👩🏽‍💻 <b>خطأ</b> في الوصول إلى القناة (حاول لاحقًا أو اجعل القناة عامة)",
}
l_ai_request = {
    "ru": "👩🏽‍💻 <i><b>Обработка</b> запроса..\n#длительность 0 мин</i>",
    "en": "👩🏽‍💻 <i><b>Processing</b> request..\n#duration 0 min</i>",
    "es": "👩🏽‍💻 <i><b>Procesando</b> la solicitud..\n#duración 0 min</i>",
    "fr": "👩🏽‍💻 <i><b>Traitement</b> de la demande..\n#durée 0 min</i>",
    "zh": "👩🏽‍💻 <i><b>处理</b> 请求..\n#持续时间 0 分钟</i>",
    "ar": "👩🏽‍💻 <i><b>معالجة</b> الطلب..\n#المدة 0 دقيقة</i>",
}
# endregion


# region FereyBotBot
l_bot_btn1 = {
    "ru": "👩🏽‍💻 Приложения",
    "en": "👩🏽‍💻 Applications",
    "es": "👩🏽‍💻 Aplicaciones",
    "fr": "👩🏽‍💻 Applications",
    "zh": "👩🏽‍💻 应用程序",
    "ar": "👩🏽‍💻 التطبيقات",
}
l_bot_btn2 = {
    "ru": "💨 Подписка",
    "en": "💨 Subscription",
    "es": "💨 Suscripción",
    "fr": "💨 Abonnement",
    "zh": "💨 订阅",
    "ar": "💨 الاشتراك",
}
l_bot_welcome = {
    "ru": "🌱 <b>{0}</b>, добро пожаловать в #нейро-конструктор <b>@tg</b>-приложений:\n\n<blockquote>▪️монетизация и интеграции\n▪️нейро-локализация/оповещения\n▪️маркетплейс и геймификация\n▪️нейро-генерация приложений\n▪️веб-мини/нейро-постинг</blockquote>",
    "en": "🌱 <b>{0}</b>, welcome to the #neuro-constructor <b>@tg</b> applications:\n\n<blockquote>▪️monetization and integrations\n▪️neuro-translation/notifications\n▪️marketplace and gamification\n▪️neuro-generation of applications\n▪️web-mini/neuro-posting</blockquote>",
    "es": "🌱 <b>{0}</b>, bienvenido al #neuro-constructor de aplicaciones <b>@tg</b>:\n\n<blockquote>▪️monetización e integraciones\n▪️neuro-traducción/notificaciones\n▪️marketplace y gamificación\n▪️neuro-generación de aplicaciones\n▪️web-mini/neuro-publicación</blockquote>",
    "fr": "🌱 <b>{0}</b>, bienvenue dans le #neuro-constructeur <b>@tg</b>-d'applications :\n\n<blockquote>▪️monétisation et intégrations\n▪️neuro-traduction/notifications\n▪️marketplace et gamification\n▪️neuro-génération d'applications\n▪️web-mini/neuro-posting</blockquote>",
    "zh": "🌱 <b>{0}</b>, 欢迎来到 #神经构建器 <b>@tg</b> 应用程序：\n\n<blockquote>▪️货币化和集成\n▪️神经翻译/通知\n▪️市场和游戏化\n▪️神经应用生成\n▪️网页迷你/神经发布</blockquote>",
    "ar": "🌱 <b>{0}</b>، مرحبًا بك في #مُنشئ-الذكاء <b>@tg</b>-التطبيقات:\n\n<blockquote>▪️تحقيق الدخل والتكاملات\n▪️الترجمة/الإشعارات الذكية\n▪️سوق الألعاب والت gamification\n▪️توليد التطبيقات الذكية\n▪️ويب-ميني/نشر ذكي</blockquote>",
}
l_wait_for_translate_bot = {
    "ru": "👩🏽‍💻 <b>Перевод</b> {0}-приложения на <i>{1}</i>-язык\n\n#длительность 0мин",
    "en": "👩🏽‍💻 <b>Translation</b> of the {0} application into <i>{1}</i> language\n\n#duration 0min",
    "es": "👩🏽‍💻 <b>Traducción</b> de la aplicación {0} al idioma <i>{1}</i>\n\n#duración 0min",
    "fr": "👩🏽‍💻 <b>Traduction</b> de l'application {0} en <i>{1}</i>\n\n#durée 0min",
    "zh": "👩🏽‍💻 <b>翻译</b> {0} 应用程序到 <i>{1}</i> 语言\n\n#持续时间 0分钟",
    "ar": "👩🏽‍💻 <b>ترجمة</b> {0} - التطبيق إلى <i>{1}</i> - اللغة\n\n#المدة 0دقيقة",
}
l_template_is_ready = {
    "ru": "👩🏽‍💻 <b>Шаблон</b> для @{0} готов!",
    "en": "👩🏽‍💻 <b>Template</b> for @{0} is ready!",
    "es": "👩🏽‍💻 <b>¡La plantilla</b> para @{0} está lista!",
    "fr": "👩🏽‍💻 <b>Modèle</b> pour @{0} prêt !",
    "zh": "👩🏽‍💻 <b>模板</b> 为 @{0} 准备好了!",
    "ar": "👩🏽‍💻 <b>القالب</b> لـ @{0} جاهز!",
}
l_payment_successful = {
    "ru": "👩🏽‍💻 <b>Пользователь</b> {0} 💰Внес оплату в размере {1} {2}",
    "en": "👩🏽‍💻 <b>User</b> {0} 💰Made a payment of {1} {2}",
    "es": "👩🏽‍💻 <b>Usuario</b> {0} 💰Hizo un pago de {1} {2}",
    "fr": "👩🏽‍💻 <b>Utilisateur</b> {0} 💰A effectué un paiement de {1} {2}",
    "zh": "👩🏽‍💻 <b>用户</b> {0} 💰已支付 {1} {2}",
    "ar": "👩🏽‍💻 <b>المستخدم</b> {0} 💰قام بدفع مبلغ قدره {1} {2}",
}
l_create_view_web = {
    "ru": "👩🏽‍💻 <b>Скрытая</b> ссылка на веб-страницу: <a href='{0}'>@{1}/web</a>\n\n👩🏽‍💻 <b>Подлинная</b> телеграм-ссылка: <code>{0}</code>",
    "en": "👩🏽‍💻 <b>Hidden</b> link to the web page: <a href='{0}'>@{1}/web</a>\n\n👩🏽‍💻 <b>Authentic</b> Telegram link: <code>{0}</code>",
    "es": "👩🏽‍💻 <b>Enlace</b> oculto a la página web: <a href='{0}'>@{1}/web</a>\n\n👩🏽‍💻 <b>Enlace</b> auténtico de Telegram: <code>{0}</code>",
    "fr": "👩🏽‍💻 <b>Lien</b> caché vers la page web : <a href='{0}'>@{1}/web</a>\n\n👩🏽‍💻 <b>Lien</b> Telegram authentique : <code>{0}</code>",
    "zh": "👩🏽‍💻 <b>隐藏的</b> 网页链接: <a href='{0}'>@{1}/web</a>\n\n👩🏽‍💻 <b>真实的</b> 电报链接: <code>{0}</code>",
    "ar": "👩🏽‍💻 <b>رابط</b> مخفي لصفحة الويب: <a href='{0}'>@{1}/web</a>\n\n👩🏽‍💻 <b>رابط</b> تيليجرام الأصلي: <code>{0}</code>",
}
l_admin_answer = {
    "ru": "👩🏽‍💻 <b>Администратор</b>: {0} to {1}:\n\n{2}",
    "en": "👩🏽‍💻 <b>Administrator</b>: {0} to {1}:\n\n{2}",
    "es": "👩🏽‍💻 <b>Administrador</b>: {0} a {1}:\n\n{2}",
    "fr": "👩🏽‍💻 <b>Administrateur</b>: {0} à {1} :\n\n{2}",
    "zh": "👩🏽‍💻 <b>管理员</b>: {0} 到 {1}:\n\n{2}",
    "ar": "👩🏽‍💻 <b>مدير</b>: {0} إلى {1}:\n\n{2}",
}
l_bot_need_start = {
    "ru": "👩🏽‍💻 <b>Необходимо</b>: /start-запустить @{0}-приложение перед началом работы",
    "en": "👩🏽‍💻 <b>Required</b>: /start to launch the @{0} application before starting work",
    "es": "👩🏽‍💻 <b>Necesario</b>: /start-lanzar @{0}-aplicación antes de comenzar a trabajar",
    "fr": "👩🏽‍💻 <b>Nécessaire</b>: /start-lancer l'application @{0} avant de commencer à travailler",
    "zh": "👩🏽‍💻 <b>必要</b>: /start-启动 @{0}-应用程序在开始工作之前",
    "ar": "👩🏽‍💻 <b>مطلوب</b>: /start-تشغيل @{0}-التطبيق قبل البدء في العمل",
}
l_bot_need_start_add = {
    "ru": "👩🏽‍💻 <b>Необходимо</b>: /start-запустить @{0}-бота, токен которого был добавлен, а также добавить бота в канал как администратора",
    "en": "👩🏽‍💻 <b>Required</b>: /start to launch the @{0} bot, whose token has been added, and also add the bot to the channel as an administrator",
    "es": "👩🏽‍💻 <b>Necesario</b>: /start-para iniciar el bot @{0}, cuyo token ha sido agregado, y también agregar el bot al canal como administrador",
    "fr": "👩🏽‍💻 <b>Nécessaire</b>: /start-lancer le bot @{0}, dont le token a été ajouté, et ajouter le bot au canal en tant qu'administrateur",
    "zh": "👩🏽‍💻 <b>必要</b>: /start-启动 @{0} - 机器人，已添加其令牌，并将机器人添加为频道管理员",
    "ar": "👩🏽‍💻 <b>مطلوب</b>: /start-تشغيل @{0}-البوت، الذي تم إضافة رمزه، بالإضافة إلى إضافة البوت إلى القناة كمدير",
}
l_bot_need_restart_extra_bot = {
    "ru": "👩🏽‍💻 <b>Необходимо</b>: /start-запустить @{0}-приложение (токен которого был добавлен) для принятия оплат",
    "en": "👩🏽‍💻 <b>Required</b>: /start to launch the @{0} application (whose token has been added) to accept payments",
    "es": "👩🏽‍💻 <b>Necesario</b>: /start-lanzar @{0}-aplicación (cuyo token ha sido añadido) para aceptar pagos",
    "fr": "👩🏽‍💻 <b>Nécessaire</b>: /start-lancer l'application @{0} (dont le token a été ajouté) pour accepter les paiements",
    "zh": "👩🏽‍💻 <b>必要</b>: /start-启动 @{0}-应用程序（其令牌已添加）以接受付款",
    "ar": "👩🏽‍💻 <b>مطلوب</b>: /start-تشغيل @{0}-التطبيق (الذي تمت إضافة رمزه) لقبول المدفوعات",
}
l_bot_user_balls = {
    "ru": "👩🏽‍💻 <b>Баллы:</b> {0}",
    "en": "👩🏽‍💻 <b>Points:</b> {0}",
    "es": "👩🏽‍💻 <b>Puntos:</b> {0}",
    "fr": "👩🏽‍💻 <b>Points :</b> {0}",
    "zh": "👩🏽‍💻 <b>分数：</b> {0}",
    "ar": "👩🏽‍💻 <b>النقاط:</b> {0}",
}
l_bot_in_chn_added = {
    "ru": "👩🏽‍💻 <b>@{0}</b> успешно добавлен в канал <b>{1}</b> [id=<code>{2}</code>] и видит его подписчиков",
    "en": "👩🏽‍💻 <b>@{0}</b> has been successfully added to the channel <b>{1}</b> [id=<code>{2}</code>] and can see its subscribers",
    "es": "👩🏽‍💻 <b>@{0}</b> se ha añadido con éxito al canal <b>{1}</b> [id=<code>{2}</code>] y ve a sus suscriptores",
    "fr": "👩🏽‍💻 <b>@{0}</b> a été ajouté avec succès au canal <b>{1}</b> [id=<code>{2}</code>] et voit ses abonnés",
    "zh": "👩🏽‍💻 <b>@{0}</b> 成功添加到频道 <b>{1}</b> [id=<code>{2}</code>] 并且可以看到它的订阅者",
    "ar": "👩🏽‍💻 <b>@{0}</b> تم إضافته بنجاح إلى القناة <b>{1}</b> [id=<code>{2}</code>] ويرى مشتركيها",
}
l_bot_in_chn_deleted = {
    "ru": "👩🏽‍💻 <b>@{0}</b> покинул канал: <b>{1}</b> [id=<code>{2}</code>] поскольку не является его администратором",
    "en": "👩🏽‍💻 <b>@{0}</b> left the channel: <b>{1}</b> [id=<code>{2}</code>] because they are not its administrator",
    "es": "👩🏽‍💻 <b>@{0}</b> ha abandonado el canal: <b>{1}</b> [id=<code>{2}</code>] ya que no es su administrador",
    "fr": "👩🏽‍💻 <b>@{0}</b> a quitté le canal : <b>{1}</b> [id=<code>{2}</code>] car il n'est pas son administrateur",
    "zh": "👩🏽‍💻 <b>@{0}</b> 离开了频道: <b>{1}</b> [id=<code>{2}</code>] 因为他不是管理员",
    "ar": "👩🏽‍💻 <b>@{0}</b> غادر القناة: <b>{1}</b> [id=<code>{2}</code>] لأنه ليس مشرفًا عليها",
}
l_bot_in_grp_added = {
    "ru": "👩🏽‍💻 <b>@{0}</b> успешно добавлен в группу: <b>{1}</b> [id=<code>{2}</code>] и видит ее участников",
    "en": "👩🏽‍💻 <b>@{0}</b> successfully added to the group: <b>{1}</b> [id=<code>{2}</code>] and sees its members",
    "es": "👩🏽‍💻 <b>@{0}</b> se ha añadido con éxito al grupo: <b>{1}</b> [id=<code>{2}</code>] y ve a sus miembros",
    "fr": "👩🏽‍💻 <b>@{0}</b> a été ajouté avec succès au groupe : <b>{1}</b> [id=<code>{2}</code>] et voit ses membres",
    "zh": "👩🏽‍💻 <b>@{0}</b> 成功添加到组：<b>{1}</b> [id=<code>{2}</code>] 并查看其成员",
    "ar": "👩🏽‍💻 <b>@{0}</b> تم إضافته بنجاح إلى المجموعة: <b>{1}</b> [id=<code>{2}</code>] ويرى أعضائها",
}
l_bot_in_grp_deleted = {
    "ru": "👩🏽‍💻 <b>@{0}</b> покинул группу: <b>{1}</b> [id=<code>{2}</code>] поскольку не является ее администратором",
    "en": "👩🏽‍💻 <b>@{0}</b> left the group: <b>{1}</b> [id=<code>{2}</code>] as they are not its administrator",
    "es": "👩🏽‍💻 <b>@{0}</b> ha abandonado el grupo: <b>{1}</b> [id=<code>{2}</code>] ya que no es su administrador",
    "fr": "👩🏽‍💻 <b>@{0}</b> a quitté le groupe : <b>{1}</b> [id=<code>{2}</code>] car il n'est pas son administrateur",
    "zh": "👩🏽‍💻 <b>@{0}</b> 已退出群组：<b>{1}</b> [id=<code>{2}</code>] 因为他不是管理员",
    "ar": "👩🏽‍💻 <b>@{0}</b> غادر المجموعة: <b>{1}</b> [id=<code>{2}</code>] لأنه ليس مشرفًا عليها",
}
l_bot_pub_with_payment = {
    "ru": "★ Оплата публикации",
    "en": "★ Payment for publication",
    "es": "★ Pago de publicación",
    "fr": "★ Paiement de la publication",
    "zh": "★ 发布付款",
    "ar": "★ دفع النشر",
}
l_bot_sub_with_payment = {
    "ru": "★ Оплата подписки",
    "en": "★ Subscription payment",
    "es": "★ Pago de la suscripción",
    "fr": "★ Paiement de l'abonnement",
    "zh": "★ 订阅付款",
    "ar": "★ دفع الاشتراك",
}
l_bot_msg_open = {
    "ru": "ᯅ Публикация",
    "en": "ᯅ Publication",
    "es": "ᯅ Publicación",
    "fr": "ᯅ Publication",
    "zh": "ᯅ 发布",
    "ar": "ᯅ النشر",
}
l_bot_off_handler_done = {
    "ru": "👩🏽‍💻 <b>@{0}</b>-@tg-приложение выключено",
    "en": "👩🏽‍💻 <b>@{0}</b>-@tg-app is turned off",
    "es": "👩🏽‍💻 <b>@{0}</b>-la aplicación @tg está desactivada",
    "fr": "👩🏽‍💻 <b>@{0}</b>-l'application @tg est désactivée",
    "zh": "👩🏽‍💻 <b>@{0}</b>-@tg应用已关闭",
    "ar": "👩🏽‍💻 <b>@{0}</b>-تطبيق تيليجرام مغلق",
}
l_parse_text = {
    "ru": "👩🏽‍💻 <b>Готово!</b> Парсинг пользователей (<u>{0}</u>) @{1}-приложения\n\n<blockquote>👩🏽‍💻 <b>Команды</b>:\n/cmd - все команды\n/parse     <i>все пользователи приложения</i>\n<code>/parse utm</code>   <i>utm-рефералы</i>\n<code>/parse ban</code>    <i>ban-пользователи</i>\n<code>/parse old</code>    <i>старые id-пользователи</i>\n<code>/parse admin</code>    <i>admin-пользователи</i>\n<code>/parse promo</code>    <i>promo-пользователи</i>\n<code>/parse premium</code>    <i>premium-пользователи</i>\n<code>/parse 1</code>    <i>кто лайкнул пост #1</i></blockquote>",
    "en": "👩🏽‍💻 <b>Done!</b> Parsing users (<u>{0}</u>) of the @{1} app\n\n<blockquote>👩🏽‍💻 <b>Commands</b>:\n/cmd - all commands\n/parse     <i>all app users</i>\n<code>/parse utm</code>   <i>utm-referrals</i>\n<code>/parse ban</code>    <i>ban-users</i>\n<code>/parse old</code>    <i>old id-users</i>\n<code>/parse admin</code>    <i>admin-users</i>\n<code>/parse promo</code>    <i>promo-users</i>\n<code>/parse premium</code>    <i>premium-users</i>\n<code>/parse 1</code>    <i>who liked post #1</i></blockquote>",
    "es": "👩🏽‍💻 <b>¡Listo!</b> Análisis de usuarios (<u>{0}</u>) de la aplicación @{1}\n\n<blockquote>👩🏽‍💻 <b>Comandos</b>:\n/cmd - todos los comandos\n/parse     <i>todos los usuarios de la aplicación</i>\n<code>/parse utm</code>   <i>utm-referidos</i>\n<code>/parse ban</code>    <i>usuarios baneados</i>\n<code>/parse old</code>    <i>usuarios con id antiguos</i>\n<code>/parse admin</code>    <i>usuarios administradores</i>\n<code>/parse promo</code>    <i>usuarios promocionales</i>\n<code>/parse premium</code>    <i>usuarios premium</i>\n<code>/parse 1</code>    <i>quién le dio like a la publicación #1</i></blockquote>",
    "fr": "👩🏽‍💻 <b>Prêt!</b> Analyse des utilisateurs (<u>{0}</u>) de l'application @{1}\n\n<blockquote>👩🏽‍💻 <b>Commandes</b>:\n/cmd - toutes les commandes\n/parse     <i>tous les utilisateurs de l'application</i>\n<code>/parse utm</code>   <i>utm-référents</i>\n<code>/parse ban</code>    <i>utilisateurs bannis</i>\n<code>/parse old</code>    <i>anciens utilisateurs id</i>\n<code>/parse admin</code>    <i>utilisateurs admin</i>\n<code>/parse promo</code>    <i>utilisateurs promo</i>\n<code>/parse premium</code>    <i>utilisateurs premium</i>\n<code>/parse 1</code>    <i>qui a aimé le post #1</i></blockquote>",
    "zh": "👩🏽‍💻 <b>完成！</b> 解析用户 (<u>{0}</u>) @{1} 应用程序\n\n<blockquote>👩🏽‍💻 <b>命令</b>:\n/cmd - 所有命令\n/parse     <i>所有应用程序用户</i>\n<code>/parse utm</code>   <i>utm-推荐人</i>\n<code>/parse ban</code>    <i>ban-用户</i>\n<code>/parse old</code>    <i>旧的 id-用户</i>\n<code>/parse admin</code>    <i>admin-用户</i>\n<code>/parse promo</code>    <i>promo-用户</i>\n<code>/parse premium</code>    <i>premium-用户</i>\n<code>/parse 1</code>    <i>谁点赞了帖子 #1</i></blockquote>",
    "ar": "👩🏽‍💻 <b>تم!</b> تحليل المستخدمين (<u>{0}</u>) @{1}-التطبيق\n\n<blockquote>👩🏽‍💻 <b>الأوامر</b>:\n/cmd - جميع الأوامر\n/parse     <i>جميع مستخدمي التطبيق</i>\n<code>/parse utm</code>   <i>إحالات utm</i>\n<code>/parse ban</code>    <i>مستخدمو الحظر</i>\n<code>/parse old</code>    <i>المستخدمون ذوو المعرفات القديمة</i>\n<code>/parse admin</code>    <i>مستخدمو الإدارة</i>\n<code>/parse promo</code>    <i>مستخدمو الترويج</i>\n<code>/parse premium</code>    <i>مستخدمو البريميوم</i>\n<code>/parse 1</code>    <i>من أعجب بالمنشور #1</i></blockquote>",
}
l_bot_business_self = {
    "ru": "👩🏽‍💻 Такое сообщение нельзя послать себе, только другим",
    "en": "👩🏽‍💻 You cannot send this message to yourself, only to others.",
    "es": "👩🏽‍💻 No se puede enviar este mensaje a uno mismo, solo a otros",
    "fr": "👩🏽‍💻 Ce type de message ne peut pas être envoyé à soi-même, seulement aux autres",
    "zh": "👩🏽‍💻 这样的消息不能发送给自己，只能发送给其他人",
    "ar": "👩🏽‍💻 لا يمكن إرسال هذه الرسالة لنفسك، فقط للآخرين",
}
l_bot_business_settings = {
    "ru": "👩🏽‍💻 <b>Необходимо</b> включить [Управление историями] в настройках [Телеграм для бизнеса]",
    "en": "👩🏽‍💻 <b>It is necessary</b> to enable [Story Management] in the settings of [Telegram for Business]",
    "es": "👩🏽‍💻 <b>Es necesario</b> activar [Gestión de historias] en la configuración de [Telegram para negocios]",
    "fr": "👩🏽‍💻 <b>Il est nécessaire</b> d'activer [Gestion des histoires] dans les paramètres [Telegram pour les entreprises]",
    "zh": "👩🏽‍💻 <b>需要</b> 在 [商业 Telegram] 的设置中启用 [故事管理]",
    "ar": "👩🏽‍💻 <b>يجب</b> تفعيل [إدارة القصص] في إعدادات [تليجرام للأعمال]",
}
l_bot_req_gen_photo = {
    "ru": "👩🏽‍💻 <b>Запрос</b> на генерацию фото-селфи",
    "en": "👩🏽‍💻 <b>Request</b> for photo generation",
    "es": "👩🏽‍💻 <b>Solicitud</b> de generación de foto",
    "fr": "👩🏽‍💻 <b>Demande</b> de génération de photo",
    "zh": "👩🏽‍💻 <b>请求</b> 生成照片",
    "ar": "👩🏽‍💻 <b>طلب</b> لإنشاء صورة",
}
l_bot_req_gen_voice = {
    "ru": "👩🏽‍💻 <b>Запрос</b> на запись голосового",
    "en": "👩🏽‍💻 <b>Request</b> to record a voice",
    "es": "👩🏽‍💻 <b>Solicitud</b> para grabar un mensaje de voz",
    "fr": "👩🏽‍💻 <b>Demande</b> d'enregistrement vocal",
    "zh": "👩🏽‍💻 <b>语音录制请求</b>",
    "ar": "👩🏽‍💻 <b>طلب</b> لتسجيل الصوت",
}
l_bot_req_gen_photo_prepare = {
    "ru": "👩🏽‍💻 <b>Отправка</b> фото..\n<blockquote>#длительность 1мин</blockquote>",
    "en": "👩🏽‍💻 <b>Sending</b> photo..\n<blockquote>#duration 1min</blockquote>",
    "es": "👩🏽‍💻 <b>Enviando</b> foto..\n<blockquote>#duración 1min</blockquote>",
    "fr": "👩🏽‍💻 <b>Envoi</b> de la photo..\n<blockquote>#durée 1min</blockquote>",
    "zh": "👩🏽‍💻 <b>发送</b> 照片..\n<blockquote>#持续时间 1分钟</blockquote>",
    "ar": "👩🏽‍💻 <b>إرسال</b> الصورة..\n<blockquote>#المدة 1دقيقة</blockquote>",
}
l_bot_req_gen_voice_prepare = {
    "ru": "👩🏽‍💻 <b>Запись</b> голосового..\n<blockquote>#длительность 1мин</blockquote>",
    "en": "👩🏽‍💻 <b>Voice</b> recording..\n<blockquote>#duration 1min</blockquote>",
    "es": "👩🏽‍💻 <b>Grabación</b> de voz..\n<blockquote>#duración 1min</blockquote>",
    "fr": "👩🏽‍💻 <b>Enregistrement</b> vocal..\n<blockquote>#durée 1min</blockquote>",
    "zh": "👩🏽‍💻 <b>录音</b> 声音..\n<blockquote>#时长 1分钟</blockquote>",
    "ar": "👩🏽‍💻 <b>تسجيل</b> صوتي..\n<blockquote>#المدة 1دقيقة</blockquote>",
}
l_cdeleteanswer = {
    "ru": "🚫 <b>Приложение</b> успешно откреплено [<b>{0}</b>]",
    "en": "🚫 <b>Application</b> successfully unpinned [<b>{0}</b>]",
    "es": "🚫 <b>La aplicación</b> se ha desvinculado correctamente [<b>{0}</b>]",
    "fr": "🚫 <b>Application</b> détaché avec succès [<b>{0}</b>]",
    "zh": "🚫 <b>应用程序</b> 已成功解除固定 [<b>{0}</b>]",
    "ar": "🚫 <b>التطبيق</b> تم فصله بنجاح [<b>{0}</b>]",
}
l_transfer_success = {
    "ru": "👩🏽‍💻 <b>Права</b> владения на @{0}-@tg-приложением успешно переданы @{1}-аккаунту!\n\n👩🏽‍💻 Теперь для передачи прав/настройки можно использовать @botFather-бота",
    "en": "👩🏽‍💻 <b>Ownership</b> rights for the @{0}-@tg application have been successfully transferred to the @{1} account!\n\n👩🏽‍💻 You can now use the @botFather bot to transfer rights/settings.",
    "es": "👩🏽‍💻 <b>Los</b> derechos de propiedad de la aplicación @{0}-@tg se han transferido con éxito a la cuenta @{1}!\n\n👩🏽‍💻 Ahora puedes usar el bot @botFather para transferir derechos/configuraciones.",
    "fr": "👩🏽‍💻 <b>Les droits</b> de propriété sur l'application @{0}-@tg ont été transférés avec succès au compte @{1} !\n\n👩🏽‍💻 Vous pouvez maintenant utiliser le bot @botFather pour transférer des droits/configurer.",
    "zh": "👩🏽‍💻 <b>所有权</b> 已成功转移至 @{1} 的 @{0}-@tg 应用程序！\n\n👩🏽‍💻 现在可以使用 @botFather 机器人来传递权限/设置",
    "ar": "👩🏽‍💻 <b>حقوق</b> الملكية على @{0}-تطبيق @tg تم نقلها بنجاح إلى حساب @{1}!\n\n👩🏽‍💻 الآن يمكن استخدام بوت @botFather لنقل الحقوق/الإعدادات",
}
l_bot_transfer_to = {
    "ru": "👩🏽‍💻 @{0}-@tg-приложение - успешно передано пользователю: <code>{1}</code>",
    "en": "👩🏽‍💻 @{0}-@tg-application - successfully sent to the user: <code>{1}</code>",
    "es": "👩🏽‍💻 @{0}-@tg-aplicación - se ha enviado con éxito al usuario: <code>{1}</code>",
    "fr": "👩🏽‍💻 @{0}-@tg-application - a été transmis avec succès à l'utilisateur : <code>{1}</code>",
    "zh": "👩🏽‍💻 @{0}-@tg-应用程序 - 成功传递给用户：<code>{1}</code>",
    "ar": "👩🏽‍💻 @{0}-تطبيق tg - تم تسليمه بنجاح للمستخدم: <code>{1}</code>",
}
l_bot_transfer_from = {
    "ru": "👩🏽‍💻 @{0}-@tg-приложение - успешно получено от пользователя: <code>{1}</code>",
    "en": "👩🏽‍💻 @{0}-@tg-application - successfully received from user: <code>{1}</code>",
    "es": "👩🏽‍💻 @{0}-@tg-aplicación - recibida con éxito del usuario: <code>{1}</code>",
    "fr": "👩🏽‍💻 @{0}-@tg-application - reçu avec succès de l'utilisateur : <code>{1}</code>",
    "zh": "👩🏽‍💻 @{0}-@tg-应用程序 - 成功从用户处获取: <code>{1}</code>",
    "ar": "👩🏽‍💻 @{0}-تطبيق tg - تم استلامه بنجاح من المستخدم: <code>{1}</code>",
}
l_telegraph_title = {
    "ru": "📰 Telegra.ph блог",
    "en": "📰 Telegra.ph blog",
    "es": "📰 Telegra.ph blog",
    "fr": "📰 Blog Telegra.ph",
    "zh": "📰 Telegra.ph 博客",
    "ar": "📰 مدونة Telegra.ph",
}
l_telegraph_blog = {
    "ru": "<figure><img src='{0}'/><figcaption>Фото профиля: @{1}</figcaption></figure><blockquote>Landing блог</blockquote>👩🏽‍💻 <b>@tg-приложение:</b> {2}<br>[<b>id</b>={3}]<br><b>Био:</b> {4}<br><aside>Канал</aside><a href='https://t.me/{5}'>@{5}</a>",
    "en": "<figure><img src='{0}'/><figcaption>Profile photo: @{1}</figcaption></figure><blockquote>Landing blog</blockquote>👩🏽‍💻 <b>@tg-app:</b> {2}<br>[<b>id</b>={3}]<br><b>Bio:</b> {4}<br><aside>Channel</aside><a href='https://t.me/{5}'>@{5}</a>",
    "es": "<figure><img src='{0}'/><figcaption>Foto de perfil: @{1}</figcaption></figure><blockquote>Blog de aterrizaje</blockquote>👩🏽‍💻 <b>Aplicación de tg:</b> {2}<br>[<b>id</b>={3}]<br><b>Bio:</b> {4}<br><aside>Canal</aside><a href='https://t.me/{5}'>@{5}</a>",
    "fr": "<figure><img src='{0}'/><figcaption>Photo de profil : @{1}</figcaption></figure><blockquote>Blog de destination</blockquote>👩🏽‍💻 <b>Application @tg :</b> {2}<br>[<b>id</b>={3}]<br><b>Bio :</b> {4}<br><aside>Canal</aside><a href='https://t.me/{5}'>@{5}</a>",
    "zh": "<figure><img src='{0}'/><figcaption>个人资料照片: @{1}</figcaption></figure><blockquote>着陆博客</blockquote>👩🏽‍💻 <b>@tg-应用:</b> {2}<br>[<b>id</b>={3}]<br><b>简介:</b> {4}<br><aside>频道</aside><a href='https://t.me/{5}'>@{5}</a>",
    "ar": "<figure><img src='{0}'/><figcaption>صورة الملف الشخصي: @{1}</figcaption></figure><blockquote>مدونة الهبوط</blockquote>👩🏽‍💻 <b>@تطبيق-تيغ:</b> {2}<br>[<b>id</b>={3}]<br><b>السيرة الذاتية:</b> {4}<br><aside>القناة</aside><a href='https://t.me/{5}'>@{5}</a>",
}
l_no_permission_table = {
    "ru": "👩🏽‍💻 <b>Нет прав</b> для записи в данную таблицу: {0}\n\n👩🏽‍💻 <b>Необходимо</b> заново добавить корректную ссылку на таблицу в @{1}-приложении",
    "en": "👩🏽‍💻 <b>No permissions</b> to write to this table: {0}\n\n👩🏽‍💻 <b>It is necessary</b> to re-add the correct link to the table in the @{1} application",
    "es": "👩🏽‍💻 <b>No tienes permisos</b> para escribir en esta tabla: {0}\n\n👩🏽‍💻 <b>Es necesario</b> volver a agregar el enlace correcto a la tabla en la aplicación @{1}",
    "fr": "👩🏽‍💻 <b>Pas de droits</b> pour écrire dans ce tableau : {0}\n\n👩🏽‍💻 <b>Il est nécessaire</b> de réajouter un lien correct vers le tableau dans l'application @{1}",
    "zh": "👩🏽‍💻 <b>没有权限</b> 写入此表格: {0}\n\n👩🏽‍💻 <b>需要</b> 在 @{1} 应用中重新添加正确的表格链接",
    "ar": "👩🏽‍💻 <b>لا توجد صلاحيات</b> للكتابة في هذه الجدول: {0}\n\n👩🏽‍💻 <b>يجب</b> إعادة إضافة الرابط الصحيح إلى الجدول في تطبيق @{1}",
}
l_web_version = {
    "ru": "👩🏽‍💻 <b>Веб</b>-версия:",
    "en": "👩🏽‍💻 <b>Web</b> version:",
    "es": "👩🏽‍💻 <b>Versión</b> web:",
    "fr": "👩🏽‍💻 <b>Version</b> web :",
    "zh": "👩🏽‍💻 <b>网页</b>版本：",
    "ar": "👩🏽‍💻 <b>الويب</b>-نسخة:",
}
l_bot_del_done_usr = {
    "ru": "👩🏽‍💻 <b>Удаление</b> завершено: {0} (-{1})",
    "en": "👩🏽‍💻 <b>Deletion</b> completed: {0} (-{1})",
    "es": "👩🏽‍💻 <b>Eliminación</b> completada: {0} (-{1})",
    "fr": "👩🏽‍💻 <b>Suppression</b> terminée : {0} (-{1})",
    "zh": "👩🏽‍💻 <b>删除</b> 完成：{0} (-{1})",
    "ar": "👩🏽‍💻 <b>تم الانتهاء من الحذف</b>: {0} (-{1})",
}
l_bot_clr_done_usr = {
    "ru": "👩🏽‍💻 <b>Очистка</b> завершена: {0} (-{1})",
    "en": "👩🏽‍💻 <b>Cleanup</b> completed: {0} (-{1})",
    "es": "👩🏽‍💻 <b>Limpieza</b> completada: {0} (-{1})",
    "fr": "👩🏽‍💻 <b>Nettoyage</b> terminé : {0} (-{1})",
    "zh": "👩🏽‍💻 <b>清理</b> 完成: {0} (-{1})",
    "ar": "👩🏽‍💻 <b>تم الانتهاء من التنظيف</b>: {0} (-{1})",
}
l_bot_attach_csv_user_ids = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> csv-таблицу со столбцом с идентификаторами пользователей. В названии csv-файла должен быть ID-приложения (который можно взять из токена бота до знака «:»)",
    "en": "👩🏽‍💻 <b>Attach</b> a csv file with a column of user IDs. The name of the csv file must include the app ID (which can be taken from the bot token before the \":\" sign)",
    "es": "👩🏽‍💻 <b>Adjunta</b> una tabla csv con una columna de identificadores de usuarios. El nombre del archivo csv debe contener el ID de la aplicación (que se puede obtener del token del bot antes del signo «:»)",
    "fr": "👩🏽‍💻 <b>Joins</b> un tableau csv avec une colonne contenant les identifiants des utilisateurs. Le nom du fichier csv doit contenir l'ID de l'application (qui peut être extrait du token du bot avant le caractère «:»)",
    "zh": "👩🏽‍💻 <b>附加</b> 一个包含用户标识符列的csv表格。csv文件的名称中必须包含应用程序ID（可以从机器人令牌中在“:”之前获取）",
    "ar": "👩🏽‍💻 <b>أرفق</b> جدول csv مع عمود يحتوي على معرفات المستخدمين. يجب أن يحتوي اسم ملف csv على معرف التطبيق (الذي يمكن الحصول عليه من رمز البوت قبل علامة “:”)",
}
l_bot_attach_csv_user_ids_start = {
    "ru": "👩🏽‍💻 <b>Старт</b> обновления списка пользователей ({0})..",
    "en": "👩🏽‍💻 <b>Start</b> updating the user list ({0})..",
    "es": "👩🏽‍💻 <b>Inicio</b> de la actualización de la lista de usuarios ({0})..",
    "fr": "👩🏽‍💻 <b>Démarrer</b> la mise à jour de la liste des utilisateurs ({0})..",
    "zh": "👩🏽‍💻 <b>开始</b> 更新用户列表 ({0})..",
    "ar": "👩🏽‍💻 <b>بدء</b> تحديث قائمة المستخدمين ({0})..",
}
l_bot_attach_csv_user_ids_finish = {
    "ru": "👩🏽‍💻 <b>Финиш</b> обновления списка пользователей ({0})..",
    "en": "👩🏽‍💻 <b>Finish</b> updating the user list ({0})..",
    "es": "👩🏽‍💻 <b>Fin</b> de la actualización de la lista de usuarios ({0})..",
    "fr": "👩🏽‍💻 <b>Fin</b> de la mise à jour de la liste des utilisateurs ({0})..",
    "zh": "👩🏽‍💻 <b>完成</b> 用户列表更新 ({0})..",
    "ar": "👩🏽‍💻 <b>إنهاء</b> تحديث قائمة المستخدمين ({0})..",
}
l_bot_donate_gift = {
    "ru": "🧸 Благотворительный подарок",
    "en": "🧸 Charitable gift",
    "es": "🧸 Regalo benéfico",
    "fr": "🧸 Cadeau de charité",
    "zh": "🧸 慈善礼物",
    "ar": "🧸 هدية خيرية",
}
l_show_admin_panel_md = {
    "ru": "<b>👩🏽‍💻 Создание и редактирование блога</b>\n\n👩🏽‍💻 Выполнен вход в режиме <b>Администратор</b>: можно создавать и редактировать блоги, но не удалять их\n\n<blockquote>¹ Авторизация (в течение 10сек) по ссылке в браузере:\n<code>{0}</code>\n\n² Перейди (в течение 10сек) по нужной ссылке для редактирования публикации (жми, чтобы скопировать):</blockquote>\n\n",
    "en": "<b>👩🏽‍💻 Creating and editing a blog</b>\n\n👩🏽‍💻 Logged in as <b>Administrator</b>: you can create and edit blogs, but not delete them\n\n<blockquote>¹ Authorization (within 10 seconds) via the link in the browser:\n<code>{0}</code>\n\n² Go (within 10 seconds) to the necessary link to edit the post (click to copy):</blockquote>",
    "es": "<b>👩🏽‍💻 Creación y edición de blogs</b>\n\n👩🏽‍💻 Has iniciado sesión como <b>Administrador</b>: puedes crear y editar blogs, pero no eliminarlos\n\n<blockquote>¹ Autorización (dentro de 10 segundos) a través del enlace en el navegador:\n<code>{0}</code>\n\n² Ve (dentro de 10 segundos) al enlace necesario para editar la publicación (haz clic para copiar):</blockquote>",
    "fr": "<b>👩🏽‍💻 Création et édition de blog</b>\n\n👩🏽‍💻 Connexion en mode <b>Administrateur</b> : vous pouvez créer et éditer des blogs, mais pas les supprimer\n\n<blockquote>¹ Authentification (dans les 10 secondes) via le lien dans le navigateur :\n<code>{0}</code>\n\n² Allez (dans les 10 secondes) sur le lien nécessaire pour éditer la publication (cliquez pour copier) :</blockquote>",
    "zh": "<b>👩🏽‍💻 创建和编辑博客</b>\n\n👩🏽‍💻 已以 <b>管理员</b> 身份登录：可以创建和编辑博客，但不能删除它们\n\n<blockquote>¹ 在浏览器中通过链接进行授权（在10秒内）：\n<code>{0}</code>\n\n² 在10秒内点击所需链接以编辑发布（点击以复制）：</blockquote>",
    "ar": "<b>👩🏽‍💻 إنشاء وتحرير المدونة</b>\n\n👩🏽‍💻 تم تسجيل الدخول كـ <b>مدير</b>: يمكنك إنشاء وتحرير المدونات، ولكن لا يمكنك حذفها\n\n<blockquote>¹ تسجيل الدخول (خلال 10 ثواني) عبر الرابط في المتصفح:\n<code>{0}</code>\n\n² انتقل (خلال 10 ثواني) إلى الرابط المطلوب لتحرير المنشور (اضغط لنسخ):</blockquote>",
}
l_show_admin_panel_html = {
    "ru": "<b>👩🏽‍💻 Создание и редактирование блога</b>\n\n👩🏽‍💻 Вы зашли как <b>Администратор</b> и можете создавать и редактировать блоги, но не удалять их\n\n<blockquote>1. Авторизация по ссылке в браузере:\n{0}\n\n2. Перейди (в течение 10сек) по нужной ссылке для редактирования публикации (жми, чтобы скопировать):</blockquote>\n\n",
    "en": "<b>👩🏽‍💻 Creating and Editing a Blog</b>\n\n👩🏽‍💻 You are logged in as <b>Administrator</b> and can create and edit blogs, but cannot delete them.\n\n<blockquote>1. Authorization via the link in the browser:\n{0}\n\n2. Go (within 10 seconds) to the necessary link to edit the post (click to copy):</blockquote>",
    "es": "<b>👩🏽‍💻 Creación y edición de blogs</b>\n\n👩🏽‍💻 Has ingresado como <b>Administrador</b> y puedes crear y editar blogs, pero no eliminarlos\n\n<blockquote>1. Autenticación a través del enlace en el navegador:\n{0}\n\n2. Ve (dentro de 10 segundos) al enlace necesario para editar la publicación (haz clic para copiar):</blockquote>",
    "fr": "<b>👩🏽‍💻 Création et édition de blog</b>\n\n👩🏽‍💻 Vous êtes connecté en tant que <b>Administrateur</b> et pouvez créer et éditer des blogs, mais pas les supprimer\n\n<blockquote>1. Authentification via le lien dans le navigateur :\n{0}\n\n2. Allez (dans les 10 secondes) sur le lien nécessaire pour éditer la publication (cliquez pour copier) :</blockquote>",
    "zh": "<b>👩🏽‍💻 创建和编辑博客</b>\n\n👩🏽‍💻 您以 <b>管理员</b> 身份登录，可以创建和编辑博客，但不能删除它们\n\n<blockquote>1. 通过浏览器中的链接进行授权：\n{0}\n\n2. 在10秒内点击所需链接以编辑发布内容（点击以复制）：</blockquote>",
    "ar": "<b>👩🏽‍💻 إنشاء وتحرير المدونة</b>\n\n👩🏽‍💻 لقد قمت بتسجيل الدخول كـ <b>مدير</b> ويمكنك إنشاء وتحرير المدونات، ولكن لا يمكنك حذفها\n\n<blockquote>1. تسجيل الدخول عبر الرابط في المتصفح:\n{0}\n\n2. انتقل (خلال 10 ثوانٍ) إلى الرابط المطلوب لتحرير المنشور (اضغط لنسخ):</blockquote>",
}
l_show_admin_panel_create = {
    "ru": "🆕 Создать",
    "en": "🆕 Create",
    "es": "🆕 Crear",
    "fr": "🆕 Créer",
    "zh": "🆕 创建",
    "ar": "🆕 إنشاء",
}
l_show_admin_panel_auth = {
    "ru": "👩🏽‍💻 Авторизация",
    "en": "👩🏽‍💻 Authorization",
    "es": "👩🏽‍💻 Autorización",
    "fr": "👩🏽‍💻 Authentification",
    "zh": "👩🏽‍💻 授权",
    "ar": "👩🏽‍💻 تسجيل الدخول",
}
l_promos = {
    "ru": "Promo-пользователи",
    "en": "Promo users",
    "es": "Usuarios promocionales",
    "fr": "Promo-utilisateurs",
    "zh": "促销用户",
    "ar": "المستخدمون الترويجيون",
}
l_utms = {
    "ru": "UTM-пользователи",
    "en": "UTM users",
    "es": "Usuarios UTM",
    "fr": "Utilisateurs UTM",
    "zh": "UTM用户",
    "ar": "مستخدمي UTM",
}
l_premiums = {
    "ru": "Premium-пользователи",
    "en": "Premium users",
    "es": "Usuarios premium",
    "fr": "Utilisateurs Premium",
    "zh": "高级用户",
    "ar": "المستخدمون المميزون",
}
l_bans = {
    "ru": "Бан-пользователи",
    "en": "Banned users",
    "es": "Bane-usuarios",
    "fr": "Bannir les utilisateurs",
    "zh": "封禁用户",
    "ar": "حظر المستخدمين",
}
l_auto_translate = {
    "ru": "Авто-перевод",
    "en": "Auto-translation",
    "es": "Auto-traducción",
    "fr": "Auto-traduction",
    "zh": "自动翻译",
    "ar": "الترجمة التلقائية",
}
l_auto_answer = {
    "ru": "Авто-ответ",
    "en": "Auto-reply",
    "es": "Auto-respuesta",
    "fr": "Réponse automatique",
    "zh": "自动回复",
    "ar": "الرد التلقائي",
}
l_auto_post = {
    "ru": "Авто-постинг",
    "en": "Auto-posting",
    "es": "Auto-publicación",
    "fr": "Auto-publishing",
    "zh": "自动发布",
    "ar": "النشر التلقائي",
}
l_all_trg = {
    "ru": ": все триггеры",
    "en": ": all triggers",
    "es": ": todos los triggers",
    "fr": ": tous les déclencheurs",
    "zh": ": 所有触发器",
    "ar": ": جميع المحفزات",
}
l_one_trg = {
    "ru": ": 1 триггер",
    "en": ": 1 trigger",
    "es": ": 1 desencadenante",
    "fr": ": 1 déclencheur",
    "zh": ": 1 个触发器",
    "ar": ": 1 مشغل",
}
l_order_act = {
    "ru": ": по порядку",
    "en": ": in order",
    "es": ": en orden",
    "fr": ": dans l'ordre",
    "zh": ": 按顺序",
    "ar": ": بالترتيب",
}
l_rand_act = {
    "ru": ": вразброс",
    "en": ": scattered",
    "es": ": al azar",
    "fr": ": au hasard",
    "zh": ": 随意",
    "ar": ": عشوائي",
}
l_trigger = {
    "ru": "Триггер",
    "en": "Trigger",
    "es": "Disparador",
    "fr": "Déclencheur",
    "zh": "触发器",
    "ar": "المشغل",
}
l_action = {
    "ru": "Действие",
    "en": "Action",
    "es": "Acción",
    "fr": "Action",
    "zh": "行动",
    "ar": "إجراء",
}
l_message = {
    "ru": "Сообщение",
    "en": "Message",
    "es": "Mensaje",
    "fr": "Message",
    "zh": "消息",
    "ar": "رسالة",
}
l_trg_add = {
    "ru": "+ Добавить Триггер",
    "en": "+ Add Trigger",
    "es": "+ Agregar Trigger",
    "fr": "+ Ajouter un déclencheur",
    "zh": "+ 添加触发器",
    "ar": "+ إضافة مشغل",
}
l_trg_cmd = {
    "ru": "+ команда",
    "en": "+ team",
    "es": "+ equipo",
    "fr": "+ équipe",
    "zh": "+ 团队",
    "ar": "+ الفريق",
}
l_trg_txt = {
    "ru": "+ сообщение",
    "en": "+ message",
    "es": "+ mensaje",
    "fr": "+ message",
    "zh": "+ 消息",
    "ar": "+ رسالة",
}
l_trg_bpm = {
    "ru": "+ бизнес лс",
    "en": "+ business ls",
    "es": "+ negocio l.s.",
    "fr": "+ entreprise lс",
    "zh": "+ 商业私信",
    "ar": "+ الأعمال الخاصة",
}
l_trg_btn = {
    "ru": "+ кнопка",
    "en": "+ button",
    "es": "+ botón",
    "fr": "+ bouton",
    "zh": "+ 按钮",
    "ar": "+ زر",
}
l_trg_rct = {
    "ru": "+ реакция",
    "en": "+ reaction",
    "es": "+ reacción",
    "fr": "+ réaction",
    "zh": "+ 反应",
    "ar": "+ رد فعل",
}
l_trg_var = {
    "ru": "+ переменная",
    "en": "+ variable",
    "es": "+ variable",
    "fr": "+ variable",
    "zh": "+ 变量",
    "ar": "+ متغير",
}
l_trg_lst = {
    "ru": "+ список",
    "en": "+ list",
    "es": "+ lista",
    "fr": "+ liste",
    "zh": "+ 列表",
    "ar": "+ قائمة",
}
l_act_add = {
    "ru": "+ Добавить Действие",
    "en": "+ Add Action",
    "es": "+ Agregar Acción",
    "fr": "+ Ajouter une action",
    "zh": "+ 添加操作",
    "ar": "+ إضافة إجراء",
}
l_act_dly = {
    "ru": "+ задержка",
    "en": "+ delay",
    "es": "+ retraso",
    "fr": "+ retard",
    "zh": "+ 延迟",
    "ar": "+ تأخير",
}
l_act_wait = {
    "ru": "+ ожидание",
    "en": "+ waiting",
    "es": "+ espera",
    "fr": "+ attente",
    "zh": "+ 等待",
    "ar": "+ الانتظار",
}
l_act_wait_title = {
    "ru": "Ожидание",
    "en": "Waiting",
    "es": "Esperando",
    "fr": "Attente",
    "zh": "等待",
    "ar": "انتظار",
}
l_act_req = {
    "ru": "+ запрос",
    "en": "+ request",
    "es": "+ solicitud",
    "fr": "+ demande",
    "zh": "+ 请求",
    "ar": "+ طلب",
}
l_act_unpin = {
    "ru": "+ открепить все",
    "en": "+ unpin all",
    "es": "+ desanclar todo",
    "fr": "+ détacher tout",
    "zh": "+ 取消所有",
    "ar": "+ إلغاء تثبيت الكل",
}
l_act_unpin_title = {
    "ru": "Открепить все сообщения",
    "en": "Unpin all messages",
    "es": "Desvincular todos los mensajes",
    "fr": "Détacher tous les messages",
    "zh": "解除所有消息固定",
    "ar": "إلغاء تثبيت جميع الرسائل",
}
l_act_delkb = {
    "ru": "+ удалить нижнюю клавиатуру",
    "en": "+ remove the bottom keyboard",
    "es": "+ eliminar el teclado inferior",
    "fr": "+ supprimer le clavier inférieur",
    "zh": "+ 删除下方键盘",
    "ar": "+ حذف لوحة المفاتيح السفلية",
}
l_act_delkb_title = {
    "ru": "Удалить нижнюю клавиатуру↓",
    "en": "Remove the bottom keyboard↓",
    "es": "Eliminar el teclado inferior↓",
    "fr": "Supprimer le clavier inférieur↓",
    "zh": "删除下方键盘↓",
    "ar": "إزالة لوحة المفاتيح السفلية↓",
}
l_msg_text = {
    "ru": ": текст",
    "en": ": text",
    "es": ": texto",
    "fr": ": texte",
    "zh": ": 文本",
    "ar": ": نص",
}
l_msg_photo = {
    "ru": ": фото",
    "en": ": photo",
    "es": ": foto",
    "fr": ": photo",
    "zh": ": 图片",
    "ar": ": صورة",
}
l_msg_gif = {
    "ru": ": гиф",
    "en": ": gif",
    "es": ": gif",
    "fr": ": gif",
    "zh": ": 动图",
    "ar": ": صورة متحركة",
}
l_msg_video = {
    "ru": ": видео",
    "en": ": video",
    "es": ": video",
    "fr": ": vidéo",
    "zh": ": 视频",
    "ar": ": فيديو",
}
l_msg_video_note = {
    "ru": ": телескоп",
    "en": ": telescope",
    "es": ": telescopio",
    "fr": ": télescope",
    "zh": ": 望远镜",
    "ar": ": تلسكوب",
}
l_msg_audio = {
    "ru": ": аудио",
    "en": ": audio",
    "es": ": audio",
    "fr": ": audio",
    "zh": ": 音频",
    "ar": ": صوت",
}
l_msg_voice = {
    "ru": ": голосовое",
    "en": ": voice",
    "es": ": voz",
    "fr": ": vocal",
    "zh": ": 语音",
    "ar": ": صوتي",
}
l_msg_document = {
    "ru": ": документ",
    "en": ": document",
    "es": ": documento",
    "fr": ": document",
    "zh": ": 文档",
    "ar": ": مستند",
}
l_msg_sticker = {
    "ru": ": стикер",
    "en": ": sticker",
    "es": ": sticker",
    "fr": ": autocollant",
    "zh": ": 贴纸",
    "ar": ": ملصق",
}
l_msg_quiz = {
    "ru": ": опрос",
    "en": ": survey",
    "es": ": encuesta",
    "fr": ": sondage",
    "zh": ": 调查",
    "ar": ": استطلاع",
}
l_msg_dice = {
    "ru": ": игра",
    "en": ": game",
    "es": ": juego",
    "fr": ": jeu",
    "zh": ": 游戏",
    "ar": ": لعبة",
}
l_msg_web = {
    "ru": ": веб",
    "en": ": web",
    "es": ": web",
    "fr": ": web",
    "zh": ": 网络",
    "ar": ": الويب",
}
l_btn_button_in = {
    "ru": "✅ Кнопка ↑",
    "en": "✅ Button ↑",
    "es": "✅ Botón ↑",
    "fr": "✅ Bouton ↑",
    "zh": "✅ 按钮 ↑",
    "ar": "✅ زر ↑",
}
l_btn_link = {
    "ru": "🔗 Ссылка",
    "en": "🔗 Link",
    "es": "🔗 Enlace",
    "fr": "🔗 Lien",
    "zh": "🔗 链接",
    "ar": "🔗 رابط",
}
l_btn_search = {
    "ru": "🔎 Поиск",
    "en": "🔎 Search",
    "es": "🔎 Búsqueda",
    "fr": "🔎 Recherche",
    "zh": "🔎 搜索",
    "ar": "🔎 البحث",
}
l_btn_like = {
    "ru": "❤️ Лайк",
    "en": "❤️ Like",
    "es": "❤️ Me gusta",
    "fr": "❤️ J'aime",
    "zh": "❤️ 点赞",
    "ar": "❤️ إعجاب",
}
l_btn_web = {
    "ru": "🌐 Веб",
    "en": "🌐 Web",
    "es": "🌐 Web",
    "fr": "🌐 Web",
    "zh": "🌐 网络",
    "ar": "🌐 ويب",
}
l_btn_story = {
    "ru": "🫥 Сториз",
    "en": "🫥 Stories",
    "es": "🫥 Historias",
    "fr": "🫥 Stories",
    "zh": "🫥 故事",
    "ar": "🫥 القصص",
}
l_btn_copy = {
    "ru": "📋 Копировать",
    "en": "📋 Copy",
    "es": "📋 Copiar",
    "fr": "📋 Copier",
    "zh": "📋 复制",
    "ar": "📋 نسخ",
}
l_btn_pay = {
    "ru": "⭐️ Оплата",
    "en": "⭐️ Payment",
    "es": "⭐️ Pago",
    "fr": "⭐️ Paiement",
    "zh": "⭐️ 付款",
    "ar": "⭐️ الدفع",
}
l_btn_share = {
    "ru": "↗️ Поделиться",
    "en": "↗️ Share",
    "es": "↗️ Compartir",
    "fr": "↗️ Partager",
    "zh": "↗️ 分享",
    "ar": "↗️ شارك",
}
l_btn_button_kb = {
    "ru": "✅ Кнопка ↓",
    "en": "✅ Button ↓",
    "es": "✅ Botón ↓",
    "fr": "✅ Bouton ↓",
    "zh": "✅ 按钮 ↓",
    "ar": "✅ زر ↓",
}
l_btn_contact = {
    "ru": "📞 Сотовый",
    "en": "📞 Mobile",
    "es": "📞 Móvil",
    "fr": "📞 Mobile",
    "zh": "📞 手机",
    "ar": "📞 الهاتف المحمول",
}
l_btn_geo = {
    "ru": "📍 Гео",
    "en": "📍 Geo",
    "es": "📍 Geo",
    "fr": "📍 Geo",
    "zh": "📍 地理",
    "ar": "📍 جغرافيا",
}
l_btn_blog = {
    "ru": "📰 Блог",
    "en": "📰 Blog",
    "es": "📰 Blog",
    "fr": "📰 Blog",
    "zh": "📰 博客",
    "ar": "📰 مدونة",
}
l_btn_name = {
    "ru": "Имя:",
    "en": "Name:",
    "es": "Nombre:",
    "fr": "Nom :",
    "zh": "姓名：",
    "ar": "الاسم:",
}
l_btn_type = {
    "ru": "Тип:",
    "en": "Type:",
    "es": "Tipo:",
    "fr": "Type :",
    "zh": "类型：",
    "ar": "نوع:",
}
l_all_json = {
    "ru": ": *",
    "en": ": *",
    "es": ": *",
    "fr": ": *",
    "zh": ": *",
    "ar": ": *",
}
l_one_json = {
    "ru": ": 1",
    "en": ": 1",
    "es": ": 1",
    "fr": ": 1",
    "zh": ": 1",
    "ar": ": 1",
}
l_add_trg_json = {
    "ru": "+ Триггер",
    "en": "+ Trigger",
    "es": "+ Activador",
    "fr": "+ Déclencheur",
    "zh": "+ 触发器",
    "ar": "+ مشغل",
}
l_add_act_json = {
    "ru": "+ Действие",
    "en": "+ Action",
    "es": "+ Acción",
    "fr": "+ Action",
    "zh": "+ 行动",
    "ar": "+ إجراء",
}
l_add_msg_json = {
    "ru": "+ Сообщение",
    "en": "+ Message",
    "es": "+ Mensaje",
    "fr": "+ Message",
    "zh": "+ 消息",
    "ar": "+ رسالة",
}
l_bot_collection_name = {
    "ru": "SBT-коллекция @{0}",
    "en": "SBT collection @{0}",
    "es": "Colección SBT @{0}",
    "fr": "SBT-collection @{0}",
    "zh": "SBT-集合 @{0}",
    "ar": "مجموعة SBT @{0}",
}
l_bot_collection_desc = {
    "ru": "Уникальные sbt-награды за выдающиеся достижения в исследовании @tg-приложения",
    "en": "Unique sbt awards for outstanding achievements in the research of the @tg application",
    "es": "Premios sbt únicos por logros destacados en la investigación de la aplicación @tg",
    "fr": "Récompenses sbt uniques pour des réalisations exceptionnelles dans la recherche de l'application @tg",
    "zh": "独特的sbt奖项，表彰在@tg应用程序研究中的杰出成就",
    "ar": "جوائز sbt الفريدة للإنجازات المتميزة في بحث تطبيق @tg",
}
l_bot_collection_address = {
    "ru": "👩🏽‍💻 <b>Адрес</b> коллекции:",
    "en": "👩🏽‍💻 <b>Collection</b> address:",
    "es": "👩🏽‍💻 <b>Dirección</b> de la colección:",
    "fr": "👩🏽‍💻 <b>Adresse</b> de la collection :",
    "zh": "👩🏽‍💻 <b>集合</b> 地址：",
    "ar": "👩🏽‍💻 <b>عنوان</b> المجموعة:",
}
l_bot_sbt_desc = {
    "ru": "SBT верифицирован в @{0}: @tg-приложение изучено на {1}%",
    "en": "SBT verified at @{0}: @tg-app studied at {1}%",
    "es": "SBT verificado en @{0}: la aplicación @tg ha sido estudiada en {1}%",
    "fr": "SBT vérifié à @{0} : l'application @tg a été examinée à {1}%",
    "zh": "SBT已在@{0}验证：@tg应用程序已研究{1}%。",
    "ar": "تم التحقق من SBT في @{0}: تم دراسة تطبيق @tg بنسبة {1}%",
}
l_bot_detach = {
    "ru": "👩🏽‍💻 Открепить nft от",
    "en": "👩🏽‍💻 Unpin nft from",
    "es": "👩🏽‍💻 Desvincular nft de",
    "fr": "👩🏽‍💻 Détacher le nft de",
    "zh": "👩🏽‍💻 从中解除 nft 绑定",
    "ar": "👩🏽‍💻 إلغاء تثبيت nft من",
}
l_bot_ya_legenda = {
    "ru": "Я легенда",
    "en": "I am legend",
    "es": "Soy leyenda",
    "fr": "Je suis une légende",
    "zh": "我是一位传奇",
    "ar": "أنا أسطورة",
}
l_bot_odin_den = {
    "ru": "Один день",
    "en": "One day",
    "es": "Un día",
    "fr": "Un jour",
    "zh": "一天",
    "ar": "يوم واحد",
}
l_bot_ancharted = {
    "ru": "Анчартед",
    "en": "Uncharted",
    "es": "Uncharted",
    "fr": "Uncharted",
    "zh": "未解之谜",
    "ar": "أونشارتد",
}
l_bot_odisseya = {
    "ru": "Одиссея",
    "en": "Odyssey",
    "es": "Odisea",
    "fr": "Odyssée",
    "zh": "奥德赛",
    "ar": "أوديسا",
}
l_bot_shag_v_pered = {
    "ru": "Шаг в перед",
    "en": "Step forward",
    "es": "Paso adelante",
    "fr": "Pas en avant",
    "zh": "向前一步",
    "ar": "خطوة إلى الأمام",
}
l_bot_gran_budushego = {
    "ru": "Грань будушего",
    "en": "Edge of the future",
    "es": "Límite del futuro",
    "fr": "La frontière de l'avenir",
    "zh": "未来的边缘",
    "ar": "حدود المستقبل",
}
l_bot_nazad_v_budushee = {
    "ru": "Назад в будущее",
    "en": "Back to the Future",
    "es": "Regreso al futuro",
    "fr": "Retour vers le futur",
    "zh": "回到未来",
    "ar": "عودة إلى المستقبل",
}
l_bot_interstellar = {
    "ru": "Интерстеллар",
    "en": "Interstellar",
    "es": "Interestelar",
    "fr": "Interstellar",
    "zh": "星际穿越",
    "ar": "بين النجوم",
}
l_bot_gravitaciya = {
    "ru": "Гравитация",
    "en": "Gravity",
    "es": "Gravedad",
    "fr": "Gravité",
    "zh": "重力",
    "ar": "الجاذبية",
}
l_bot_vspomnit_vse = {
    "ru": "Вспомнить все",
    "en": "Remember Everything",
    "es": "Recordar todo",
    "fr": "Se souvenir de tout",
    "zh": "回忆一切",
    "ar": "تذكر كل شيء",
}
l_bot_la_la_lend = {
    "ru": "Ла-ла Ленд",
    "en": "La La Land",
    "es": "La La Land",
    "fr": "La La Land",
    "zh": "拉拉地球",
    "ar": "لا لا لاند",
}
l_bot_tihoe_mesto = {
    "ru": "Тихое место",
    "en": "A Quiet Place",
    "es": "Lugar silencioso",
    "fr": "Un endroit silencieux",
    "zh": "安静的地方",
    "ar": "مكان هادئ",
}
l_bot_oblachnyy_atlas = {
    "ru": "Облачный атлас",
    "en": "Cloud Atlas",
    "es": "Nube Atlas",
    "fr": "Nuage de points",
    "zh": "云图",
    "ar": "سحابة الأطلس",
}
l_bot_zvezdnyy_put = {
    "ru": "Звездный путь",
    "en": "Star Trek",
    "es": "Viaje estelar",
    "fr": "Voyage dans les étoiles",
    "zh": "星际旅行",
    "ar": "مسار النجوم",
}
l_bot_moana = {
    "ru": "Моана",
    "en": "Moana",
    "es": "Moana",
    "fr": "Moana",
    "zh": "莫阿娜",
    "ar": "موانا",
}
l_bot_vverh = {
    "ru": "Вверх",
    "en": "Up",
    "es": "Arriba",
    "fr": "Haut",
    "zh": "向上",
    "ar": "إلى الأعلى",
}
l_bot_menyu = {
    "ru": "Меню",
    "en": "Menu",
    "es": "Menú",
    "fr": "Menu",
    "zh": "菜单",
    "ar": "قائمة الطعام",
}
l_bot_intro = {
    "ru": "Интро",
    "en": "Intro",
    "es": "Intro",
    "fr": "Intro",
    "zh": "介绍",
    "ar": "مقدمة",
}
l_bot_sumerki = {
    "ru": "Сумерки",
    "en": "Twilight",
    "es": "Crepúsculo",
    "fr": "Crépuscule",
    "zh": "黄昏",
    "ar": "الغسق",
}
l_bot_maynkraft = {
    "ru": "Майнкрафт",
    "en": "Minecraft",
    "es": "Minecraft",
    "fr": "Minecraft",
    "zh": "我的世界",
    "ar": "ماينكرافت",
}
l_bot_slushai_serdce = {
    "ru": "Слушай сердце",
    "en": "Listen to your heart",
    "es": "Escucha al corazón",
    "fr": "Écoute le cœur",
    "zh": "听从心灵",
    "ar": "اسمع القلب",
}
l_bot_khrabroe_serdce = {
    "ru": "Храброе сердце",
    "en": "Braveheart",
    "es": "Corazón valiente",
    "fr": "Cœur vaillant",
    "zh": "勇敢的心",
    "ar": "قلب شجاع",
}
l_bot_iz_moego_okna = {
    "ru": "Из моего окна",
    "en": "From my window",
    "es": "Desde mi ventana",
    "fr": "De ma fenêtre",
    "zh": "从我的窗户",
    "ar": "من نافذتي",
}
l_bot_voobrazharium = {
    "ru": "Воображариум",
    "en": "Imaginarium",
    "es": "Imaginarium",
    "fr": "Imaginarium",
    "zh": "想象力空间",
    "ar": "خياليات",
}
l_bot_voobrazi_drakonov = {
    "ru": "Вообрази драконов",
    "en": "Imagine dragons",
    "es": "Imagina dragones",
    "fr": "Imagine des dragons",
    "zh": "想象一下龙",
    "ar": "تخيل التنين",
}
l_bot_skayfol = {
    "ru": "Скайфол",
    "en": "Skyfall",
    "es": "Skyfall",
    "fr": "Skyfall",
    "zh": "天幕危机",
    "ar": "سكايفول",
}
l_bot_vozvraschenie_domoy = {
    "ru": "Возвращение домой",
    "en": "Returning Home",
    "es": "Regreso a casa",
    "fr": "Retour à la maison",
    "zh": "回家",
    "ar": "العودة إلى الوطن",
}
l_bot_nebo_polnoe_zvezd = {
    "ru": "Небо, полное звезд",
    "en": "The sky full of stars",
    "es": "Cielo lleno de estrellas",
    "fr": "Ciel plein d'étoiles",
    "zh": "星空满天",
    "ar": "سماء مليئة بالنجوم",
}
l_bot_7_lepestok = {
    "ru": "7 лепесток",
    "en": "7 petal",
    "es": "7 pétalo",
    "fr": "7 pétale",
    "zh": "7 花瓣",
    "ar": "7 بتلة",
}
l_bot_7_simfoniya = {
    "ru": "7 симфония",
    "en": "7th symphony",
    "es": "7 sinfonía",
    "fr": "7ème symphonie",
    "zh": "7 交响曲",
    "ar": "7 السيمفونية",
}
l_bot_7_zhizney = {
    "ru": "7 жизней",
    "en": "7 lives",
    "es": "7 vidas",
    "fr": "7 vies",
    "zh": "7条命",
    "ar": "7 أرواح",
}
l_bot_f1 = {
    "ru": "F1",
    "en": "F1",
    "es": "F1",
    "fr": "F1",
    "zh": "F1",
    "ar": "F1",
}
l_bot_proekt_h = {
    "ru": "Проект Х",
    "en": "Project X",
    "es": "Proyecto X",
    "fr": "Projet X",
    "zh": "项目X",
    "ar": "مشروع X",
}
l_bot_snova_17 = {
    "ru": "Снова 17",
    "en": "Again 17",
    "es": "De nuevo 17",
    "fr": "Encore 17",
    "zh": "再次 17",
    "ar": "مرة أخرى 17",
}
l_bot_legenda_17 = {
    "ru": "Легенда 17",
    "en": "Legend 17",
    "es": "Leyenda 17",
    "fr": "Légende 17",
    "zh": "传奇 17",
    "ar": "أسطورة 17",
}
l_bot_za_kadrom = {
    "ru": "За кадром",
    "en": "Behind the scenes",
    "es": "Detrás de cámaras",
    "fr": "Hors champ",
    "zh": "幕后",
    "ar": "خلف الكواليس",
}
l_bot_eta_istoriya = {
    "ru": "Эта история",
    "en": "This story",
    "es": "Esta historia",
    "fr": "Cette histoire",
    "zh": "这个故事",
    "ar": "هذه القصة",
}
l_bot_moy_mir = {
    "ru": "Мой мир",
    "en": "My world",
    "es": "Mi mundo",
    "fr": "Mon monde",
    "zh": "我的世界",
    "ar": "عالمي",
}
l_bot_moy_dom = {
    "ru": "Мой дом",
    "en": "My house",
    "es": "Mi casa",
    "fr": "Ma maison",
    "zh": "我的家",
    "ar": "منزلي",
}
l_bot_navigatsiya = {
    "ru": "Навигация",
    "en": "Navigation",
    "es": "Navegación",
    "fr": "Navigation",
    "zh": "导航",
    "ar": "الملاحة",
}
l_bot_mne_nravitsya = {
    "ru": "Мне нравится",
    "en": "I like",
    "es": "Me gusta",
    "fr": "J'aime",
    "zh": "我喜欢",
    "ar": "أحب",
}
l_bot_progress_cmd = {
    "ru": "👩🏽‍💻 <b>Найдена</b> /-команда в @{0}-приложении:\n\n<blockquote>{1}</blockquote>",
    "en": "👩🏽‍💻 <b>Found</b> /-team in @{0}-application:\n\n<blockquote>{1}</blockquote>",
    "es": "👩🏽‍💻 <b>Encontrado</b> /-equipo en la aplicación @{0}:\n\n<blockquote>{1}</blockquote>",
    "fr": "👩🏽‍💻 <b>Équipe</b> trouvée dans l'application @{0} :\n\n<blockquote>{1}</blockquote>",
    "zh": "👩🏽‍💻 <b>找到</b> /-团队在 @{0}-应用程序中：\n\n<blockquote>{1}</blockquote>",
    "ar": "👩🏽‍💻 <b>تم العثور على</b> /-فريق في تطبيق @{0}:\n\n<blockquote>{1}</blockquote>",
}
l_bot_progress_cmd_default = {
    "ru": "👩🏽‍💻 <b>Владелец</b> @{0}-приложения еще не создал экстра команд, поэтому для прохождения задания можно использовать команду по умолчанию:\n\n<blockquote>/cmd_911</blockquote>",
    "en": "👩🏽‍💻 <b>Owner</b> of the @{0} app has not created extra teams yet, so you can use the default team to complete the task:\n\n<blockquote>/cmd_911</blockquote>",
    "es": "👩🏽‍💻 <b>Propietario</b> de la aplicación @{0} aún no ha creado equipos adicionales, por lo que se puede usar el equipo predeterminado para completar la tarea:\n\n<blockquote>/cmd_911</blockquote>",
    "fr": "👩🏽‍💻 <b>Propriétaire</b> de l'application @{0} n'a pas encore créé d'équipes supplémentaires, donc pour accomplir la tâche, vous pouvez utiliser l'équipe par défaut :\n\n<blockquote>/cmd_911</blockquote>",
    "zh": "👩🏽‍💻 <b>拥有者</b> @{0} 应用程序尚未创建额外的团队，因此可以使用默认团队来完成任务：\n\n<blockquote>/cmd_911</blockquote>",
    "ar": "👩🏽‍💻 <b>مالك</b> تطبيق @{0} لم ينشئ فرقًا إضافية بعد، لذلك يمكنك استخدام الفريق الافتراضي لإكمال المهمة:\n\n<blockquote>/cmd_911</blockquote>",
}
l_bot_progress_cmd_done = {
    "ru": "👩🏽‍💻 <b>Команда</b> по умолчанию (/{cmd}) выполнена",
    "en": "👩🏽‍💻 <b>Default team</b> (/{cmd}) executed",
    "es": "👩🏽‍💻 <b>Equipo</b> predeterminado (/{cmd}) ejecutado",
    "fr": "👩🏽‍💻 <b>Équipe</b> par défaut (/{cmd}) exécutée",
    "zh": "👩🏽‍💻 <b>默认团队</b> (/{cmd}) 已执行",
    "ar": "👩🏽‍💻 <b>الفريق</b> الافتراضي (/{cmd}) تم التنفيذ",
}
l_bot_progress_promo = {
    "ru": "👩🏽‍💻 <b>Владелец</b> @{0}-приложения установил промокод, поэтому для прохождения задания необходимо его узнать и ввести",
    "en": "👩🏽‍💻 <b>Owner</b> of the @{0} app has set a promo code, so to complete the task, you need to find out and enter it.",
    "es": "👩🏽‍💻 <b>Propietario</b> de la aplicación @{0} ha establecido un código promocional, por lo que es necesario conocerlo e ingresarlo para completar la tarea.",
    "fr": "👩🏽‍💻 <b>Propriétaire</b> de l'application @{0} a installé un code promo, donc pour compléter la tâche, il est nécessaire de le connaître et de l'entrer.",
    "zh": "👩🏽‍💻 <b>拥有者</b> @{0} 应用程序已设置促销代码，因此完成任务需要了解并输入它。",
    "ar": "👩🏽‍💻 <b>مالك</b> تطبيق @{0} قام بتعيين رمز ترويجي، لذا يجب معرفة وإدخال هذا الرمز لإكمال المهمة.",
}
l_bot_progress_promo_default = {
    "ru": "👩🏽‍💻 <b>Владелец</b> @{0}-приложения еще не создал промокод, поэтому для прохождения задания можно использовать промокод по умолчанию:\n\n<blockquote><code>#911</code></blockquote>",
    "en": "👩🏽‍💻 <b>Owner</b> of the @{0} app has not created a promo code yet, so you can use the default promo code to complete the task:\n\n<blockquote><code>#911</code></blockquote>",
    "es": "👩🏽‍💻 <b>Propietario</b> de la aplicación @{0} aún no ha creado un código promocional, por lo que se puede utilizar el código promocional predeterminado para completar la tarea:\n\n<blockquote><code>#911</code></blockquote>",
    "fr": "👩🏽‍💻 <b>Propriétaire</b> de l'application @{0} n'a pas encore créé de code promo, donc pour compléter la tâche, vous pouvez utiliser le code promo par défaut :\n\n<blockquote><code>#911</code></blockquote>",
    "zh": "👩🏽‍💻 <b>拥有者</b> @{0} 的应用程序尚未创建促销代码，因此可以使用默认促销代码来完成任务：\n\n<blockquote><code>#911</code></blockquote>",
    "ar": "👩🏽‍💻 <b>مالك</b> تطبيق @{0} لم ينشئ رمز ترويجي بعد، لذلك يمكنك استخدام رمز الترويج الافتراضي لإكمال المهمة:\n\n<blockquote><code>#911</code></blockquote>",
}
l_bot_progress_promo_done = {
    "ru": "👩🏽‍💻 <b>Промокод</b> <code>{0}</code> успешно распознан",
    "en": "👩🏽‍💻 <b>Promo code</b> <code>{0}</code> successfully recognized",
    "es": "👩🏽‍💻 <b>Código promocional</b> <code>{0}</code> reconocido con éxito",
    "fr": "👩🏽‍💻 <b>Code promo</b> <code>{0}</code> reconnu avec succès",
    "zh": "👩🏽‍💻 <b>优惠码</b> <code>{0}</code> 成功识别",
    "ar": "👩🏽‍💻 <b>كود الخصم</b> <code>{0}</code> تم التعرف عليه بنجاح",
}
l_bot_progress_react = {
    "ru": "👩🏽‍💻 <b>Установи</b> реакцию на сообщение в @{0}-приложении",
    "en": "👩🏽‍💻 <b>Set</b> a reaction to the message in the @{0} app",
    "es": "👩🏽‍💻 <b>Establece</b> una reacción al mensaje en la aplicación @{0}",
    "fr": "👩🏽‍💻 <b>Installe</b> une réaction au message dans l'application @{0}",
    "zh": "👩🏽‍💻 <b>设置</b> 对 @{0} 应用中的消息的反应",
    "ar": "👩🏽‍💻 <b>قم بتعيين</b> رد فعل على الرسالة في تطبيق @{0}",
}
l_bot_progress_pay_spoiler_default = {
    "ru": "👩🏽‍💻 <b>Владелец</b> @{0}-приложения еще не создал платных сообщений, поэтому для прохождения задания можно совершить оплату следующего сообщения",
    "en": "👩🏽‍💻 <b>Owner</b> of the @{0} app has not created any paid messages yet, so to complete the task, you can make a payment for the next message.",
    "es": "👩🏽‍💻 <b>Propietario</b> de la aplicación @{0} aún no ha creado mensajes de pago, por lo que para completar la tarea se puede realizar el pago del siguiente mensaje.",
    "fr": "👩🏽‍💻 <b>Propriétaire</b> de l'application @{0} n'a pas encore créé de messages payants, donc pour compléter la tâche, vous pouvez effectuer le paiement du message suivant.",
    "zh": "👩🏽‍💻 <b>拥有者</b> @{0} 的应用程序尚未创建付费消息，因此可以通过支付下一条消息来完成任务。",
    "ar": "👩🏽‍💻 <b>مالك</b> @{0} لم ينشئ رسائل مدفوعة بعد، لذلك يمكن إتمام المهمة من خلال دفع الرسالة التالية",
}
l_bot_progress_usual_btn = {
    "ru": "Обычная кнопка",
    "en": "Regular button",
    "es": "Botón normal",
    "fr": "Bouton ordinaire",
    "zh": "普通按钮",
    "ar": "زر عادي",
}
l_bot_progress_usual_default = {
    "ru": "👩🏽‍💻 <b>Владелец</b> @{0}-приложения еще не создал сообщений c обычной кнопкой, поэтому для прохождения задания можно совершить нажатие на кнопку этого сообщения",
    "en": "👩🏽‍💻 <b>Owner</b> of the @{0} app has not created messages with a regular button yet, so to complete the task, you can click the button of this message.",
    "es": "👩🏽‍💻 <b>Propietario</b> de la aplicación @{0} aún no ha creado mensajes con un botón normal, por lo que para completar la tarea se puede hacer clic en el botón de este mensaje.",
    "fr": "👩🏽‍💻 <b>Propriétaire</b> de l'application @{0} n'a pas encore créé de messages avec un bouton standard, donc pour compléter la tâche, vous pouvez appuyer sur le bouton de ce message.",
    "zh": "👩🏽‍💻 <b>拥有者</b> @{0} 应用程序尚未创建带有常规按钮的消息，因此可以通过点击此消息的按钮来完成任务。",
    "ar": "👩🏽‍💻 <b>مالك</b> تطبيق @{0} لم ينشئ بعد رسائل مع زر عادي، لذلك يمكن إتمام المهمة من خلال الضغط على زر هذه الرسالة",
}
l_bot_progress_usual_btn_done = {
    "ru": "👩🏽‍💻 <b>Нажатие</b> на обычную-кнопку выполнено",
    "en": "👩🏽‍💻 <b>Click</b> on the regular button has been made",
    "es": "👩🏽‍💻 <b>Se ha hecho clic</b> en el botón normal",
    "fr": "👩🏽‍💻 <b>Cliquez</b> sur le bouton normal effectué",
    "zh": "👩🏽‍💻 <b>点击</b> 普通按钮已完成",
    "ar": "👩🏽‍💻 <b>تم الضغط</b> على الزر العادي",
}
l_bot_progress_pay_btn = {
    "ru": "Кнопка оплаты",
    "en": "Payment button",
    "es": "Botón de pago",
    "fr": "Bouton de paiement",
    "zh": "支付按钮",
    "ar": "زر الدفع",
}
l_bot_progress_pay_default = {
    "ru": "👩🏽‍💻 <b>Владелец</b> @{0}-приложения еще не создал сообщений c кнопкой оплаты, поэтому для прохождения задания можно совершить оплату по кнопке этого сообщения",
    "en": "👩🏽‍💻 <b>Owner</b> of the @{0} app has not created messages with a payment button yet, so to complete the task, you can make a payment by clicking the button in this message.",
    "es": "👩🏽‍💻 <b>Propietario</b> de la aplicación @{0} aún no ha creado mensajes con el botón de pago, por lo que para completar la tarea se puede realizar el pago a través del botón de este mensaje.",
    "fr": "👩🏽‍💻 <b>Propriétaire</b> de l'application @{0} n'a pas encore créé de messages avec un bouton de paiement, donc pour compléter la tâche, vous pouvez effectuer le paiement en cliquant sur le bouton de ce message.",
    "zh": "👩🏽‍💻 <b>拥有者</b> @{0} 的应用程序尚未创建带有支付按钮的消息，因此可以通过此消息的按钮进行支付以完成任务。",
    "ar": "👩🏽‍💻 <b>مالك</b> تطبيق @{0} لم ينشئ بعد رسائل تحتوي على زر الدفع، لذلك يمكن إتمام المهمة من خلال الدفع عبر زر هذه الرسالة",
}
l_bot_progress_like_btn = {
    "ru": "Лайк кнопка",
    "en": "Like button",
    "es": "Botón de me gusta",
    "fr": "Bouton J'aime",
    "zh": "点赞按钮",
    "ar": "زر الإعجاب",
}
l_bot_progress_like_default = {
    "ru": "👩🏽‍💻 <b>Владелец</b> @{0}-приложения еще не создал сообщений c лайк-кнопкой, поэтому для прохождения задания можно совершить нажатие на лайк-кнопку этого сообщения",
    "en": "👩🏽‍💻 <b>Owner</b> of the @{0} app has not created messages with a like button yet, so to complete the task, you can click the like button of this message.",
    "es": "👩🏽‍💻 <b>Propietario</b> de la aplicación @{0} aún no ha creado mensajes con el botón de me gusta, por lo que para completar la tarea se puede hacer clic en el botón de me gusta de este mensaje.",
    "fr": "👩🏽‍💻 <b>Propriétaire</b> de l'application @{0} n'a pas encore créé de messages avec le bouton de like, donc pour compléter la tâche, vous pouvez appuyer sur le bouton de like de ce message.",
    "zh": "👩🏽‍💻 <b>拥有者</b> @{0} 的应用程序尚未创建带有点赞按钮的消息，因此可以通过点击此消息的点赞按钮来完成任务。",
    "ar": "👩🏽‍💻 <b>مالك</b> تطبيق @{0} لم ينشئ بعد رسائل مع زر الإعجاب، لذلك يمكن إتمام المهمة من خلال الضغط على زر الإعجاب لهذه الرسالة",
}
l_bot_progress_like_btn_done = {
    "ru": "👩🏽‍💻 <b>Нажатие</b> на лайк-кнопку выполнено",
    "en": "👩🏽‍💻 <b>Click</b> on the like button has been made",
    "es": "👩🏽‍💻 <b>Se ha hecho clic</b> en el botón de me gusta",
    "fr": "👩🏽‍💻 <b>Cliquez</b> sur le bouton \"J'aime\" effectué",
    "zh": "👩🏽‍💻 <b>已点击</b> 点赞按钮",
    "ar": "👩🏽‍💻 <b>تم الضغط</b> على زر الإعجاب",
}
l_bot_progress_search_btn = {
    "ru": "Кнопка поиска",
    "en": "Search button",
    "es": "Botón de búsqueda",
    "fr": "Bouton de recherche",
    "zh": "搜索按钮",
    "ar": "زر البحث",
}
l_bot_progress_search_default = {
    "ru": "👩🏽‍💻 <b>Владелец</b> @{0}-приложения еще не создал сообщений c кнопкой поиска, поэтому для прохождения задания можно совершить нажатие на кнопку поиска этого сообщения",
    "en": "👩🏽‍💻 <b>Owner</b> of the @{0} app has not created messages with a search button yet, so to complete the task, you can click the search button of this message.",
    "es": "👩🏽‍💻 <b>Propietario</b> de la aplicación @{0} aún no ha creado mensajes con el botón de búsqueda, por lo que para completar la tarea se puede hacer clic en el botón de búsqueda de este mensaje.",
    "fr": "👩🏽‍💻 <b>Propriétaire</b> de l'application @{0} n'a pas encore créé de messages avec le bouton de recherche, donc pour compléter la tâche, vous pouvez appuyer sur le bouton de recherche de ce message.",
    "zh": "👩🏽‍💻 <b>拥有者</b> @{0} 应用程序尚未创建带有搜索按钮的消息，因此可以通过点击该消息的搜索按钮来完成任务。",
    "ar": "👩🏽‍💻 <b>مالك</b> تطبيق @{0} لم ينشئ بعد رسائل تحتوي على زر البحث، لذلك يمكن إتمام المهمة من خلال الضغط على زر البحث في هذه الرسالة.",
}
l_bot_progress_search_btn_done = {
    "ru": "👩🏽‍💻 <b>Нажатие</b> на кнопку поиска выполнено",
    "en": "👩🏽‍💻 <b>Search</b> button clicked",
    "es": "👩🏽‍💻 <b>Se ha hecho clic</b> en el botón de búsqueda",
    "fr": "👩🏽‍💻 <b>Cliquez</b> sur le bouton de recherche effectué",
    "zh": "👩🏽‍💻 <b>搜索</b> 按钮已被点击",
    "ar": "👩🏽‍💻 <b>تم الضغط</b> على زر البحث",
}
l_bot_progress_btn_done = {
    "ru": "Нажатие выполнено",
    "en": "Action completed",
    "es": "Presión realizada",
    "fr": "Action effectuée",
    "zh": "点击已完成",
    "ar": "تم الضغط",
}
l_bot_progress_contact_btn = {
    "ru": "Кнопка контакта",
    "en": "Contact button",
    "es": "Botón de contacto",
    "fr": "Bouton de contact",
    "zh": "联系按钮",
    "ar": "زر الاتصال",
}
l_bot_progress_contact_default = {
    "ru": "👩🏽‍💻 <b>Владелец</b> @{0}-приложения еще не создал сообщений c контакт-кнопкой, поэтому для прохождения задания можно совершить нажатие на контакт-кнопку этого сообщения",
    "en": "👩🏽‍💻 <b>Owner</b> of the @{0} app has not created messages with the contact button yet, so to complete the task, you can click on the contact button of this message.",
    "es": "👩🏽‍💻 <b>Propietario</b> de la aplicación @{0} aún no ha creado mensajes con el botón de contacto, por lo que para completar la tarea se puede hacer clic en el botón de contacto de este mensaje.",
    "fr": "👩🏽‍💻 <b>Propriétaire</b> de l'application @{0} n'a pas encore créé de messages avec le bouton de contact, donc pour compléter la tâche, vous pouvez appuyer sur le bouton de contact de ce message.",
    "zh": "👩🏽‍💻 <b>拥有者</b> @{0} 应用程序尚未创建带有联系按钮的消息，因此可以通过点击此消息的联系按钮来完成任务。",
    "ar": "👩🏽‍💻 <b>مالك</b> تطبيق @{0} لم ينشئ بعد رسائل مع زر الاتصال، لذلك يمكن إتمام المهمة من خلال الضغط على زر الاتصال في هذه الرسالة",
}
l_bot_progress_geo_btn = {
    "ru": "Кнопка геолокации",
    "en": "Geolocation button",
    "es": "Botón de geolocalización",
    "fr": "Bouton de géolocalisation",
    "zh": "地理位置按钮",
    "ar": "زر تحديد الموقع الجغرافي",
}
l_bot_progress_geo_default = {
    "ru": "👩🏽‍💻 <b>Владелец</b> @{0}-приложения еще не создал сообщений c кнопкой геолокации, поэтому для прохождения задания можно совершить нажатие на кнопку геолокации этого сообщения",
    "en": "👩🏽‍💻 <b>Owner</b> of the @{0} app has not created messages with the geolocation button yet, so to complete the task, you can press the geolocation button of this message.",
    "es": "👩🏽‍💻 <b>Propietario</b> de la aplicación @{0} aún no ha creado mensajes con el botón de geolocalización, por lo que para completar la tarea se puede hacer clic en el botón de geolocalización de este mensaje.",
    "fr": "👩🏽‍💻 <b>Propriétaire</b> de l'application @{0} n'a pas encore créé de messages avec le bouton de géolocalisation, donc pour accomplir la tâche, vous pouvez appuyer sur le bouton de géolocalisation de ce message.",
    "zh": "👩🏽‍💻 <b>拥有者</b> @{0} 的应用程序尚未创建带有地理位置按钮的消息，因此可以通过点击此消息的地理位置按钮来完成任务。",
    "ar": "👩🏽‍💻 <b>مالك</b> تطبيق @{0} لم ينشئ بعد رسائل تحتوي على زر تحديد الموقع، لذلك يمكن إتمام المهمة من خلال الضغط على زر تحديد الموقع في هذه الرسالة.",
}
l_bot_progress_blog_default = {
    "ru": "👩🏽‍💻 <b>Владелец</b> @{0}-приложения еще не создал сообщений c кнопкой telegra.ph блога, поэтому для прохождения задания можно совершить нажатие на кнопку блога этого сообщения",
    "en": "👩🏽‍💻 <b>Owner</b> of the @{0} app has not created messages with the telegra.ph blog button yet, so to complete the task, you can click the blog button of this message.",
    "es": "👩🏽‍💻 <b>Propietario</b> de la aplicación @{0} aún no ha creado mensajes con el botón telegra.ph del blog, por lo que para completar la tarea se puede hacer clic en el botón del blog de este mensaje.",
    "fr": "👩🏽‍💻 <b>Propriétaire</b> de l'application @{0} n'a pas encore créé de messages avec le bouton telegra.ph du blog, donc pour compléter la tâche, vous pouvez cliquer sur le bouton du blog de ce message.",
    "zh": "👩🏽‍💻 <b>拥有者</b> @{0} 的应用程序尚未创建带有 telegra.ph 博客按钮的消息，因此可以通过点击此消息的博客按钮来完成任务。",
    "ar": "👩🏽‍💻 <b>مالك</b> تطبيق @{0} لم ينشئ بعد رسائل مع زر telegra.ph للمدونة، لذلك يمكن إتمام المهمة من خلال الضغط على زر المدونة في هذه الرسالة",
}
l_bot_progress_blog_btn_done = {
    "ru": "👩🏽‍💻 <b>Нажатие</b> на кнопку блога выполнено",
    "en": "👩🏽‍💻 <b>Click</b> on the blog button has been made",
    "es": "👩🏽‍💻 <b>Se ha hecho clic</b> en el botón del blog",
    "fr": "👩🏽‍💻 <b>Cliquez</b> sur le bouton du blog effectué",
    "zh": "👩🏽‍💻 <b>已点击</b> 博客按钮",
    "ar": "👩🏽‍💻 <b>تم الضغط</b> على زر المدونة",
}
l_bot_progress_download_btn = {
    "ru": "Загрузка файла",
    "en": "File Upload",
    "es": "Cargando archivo",
    "fr": "Téléchargement du fichier",
    "zh": "文件正在加载",
    "ar": "تحميل الملف",
}
l_bot_progress_download_default = {
    "ru": "👩🏽‍💻 <b>Владелец</b> @{0}-приложения еще не создал сообщений c документами для загрузки, поэтому для прохождения задания можно совершить нажатие на иконку загрузки (в правом верхнем углу) этого сообщения",
    "en": "👩🏽‍💻 <b>Owner</b> of the @{0} app has not created messages with documents for upload yet, so to complete the task, you can click on the upload icon (in the top right corner) of this message.",
    "es": "👩🏽‍💻 <b>Propietario</b> de la aplicación @{0} aún no ha creado mensajes con documentos para cargar, por lo que para completar la tarea se puede hacer clic en el ícono de carga (en la esquina superior derecha) de este mensaje.",
    "fr": "👩🏽‍💻 <b>Propriétaire</b> de l'application @{0} n'a pas encore créé de messages avec des documents à télécharger, donc pour compléter la tâche, vous pouvez cliquer sur l'icône de téléchargement (en haut à droite) de ce message.",
    "zh": "👩🏽‍💻 <b>所有者</b> @{0} 的应用程序尚未创建带有文档的消息以供下载，因此要完成任务，可以点击此消息右上角的下载图标。",
    "ar": "👩🏽‍💻 <b>مالك</b> تطبيق @{0} لم ينشئ بعد رسائل تحتوي على مستندات للتحميل، لذلك يمكن إتمام المهمة من خلال الضغط على أيقونة التحميل (في الزاوية العلوية اليمنى) لهذه الرسالة",
}
l_bot_progress_web_btn = {
    "ru": "Веб кнопка",
    "en": "Web button",
    "es": "Botón web",
    "fr": "Bouton Web",
    "zh": "网页按钮",
    "ar": "زر الويب",
}
l_bot_progress_web_default = {
    "ru": "👩🏽‍💻 <b>Владелец</b> @{0}-приложения еще не создал сообщений c веб-кнопкой, поэтому для прохождения задания можно совершить нажатие на веб-кнопку этого сообщения",
    "en": "👩🏽‍💻 <b>Owner</b> of the @{0} app has not created messages with a web button yet, so to complete the task, you can click the web button of this message.",
    "es": "👩🏽‍💻 <b>Propietario</b> de la aplicación @{0} aún no ha creado mensajes con el botón web, por lo que para completar la tarea se puede hacer clic en el botón web de este mensaje.",
    "fr": "👩🏽‍💻 <b>Propriétaire</b> de l'application @{0} n'a pas encore créé de messages avec un bouton web, donc pour compléter la tâche, vous pouvez cliquer sur le bouton web de ce message.",
    "zh": "👩🏽‍💻 <b>拥有者</b> @{0} 应用程序尚未创建带有网页按钮的消息，因此可以通过点击此消息的网页按钮来完成任务。",
    "ar": "👩🏽‍💻 <b>مالك</b> تطبيق @{0} لم ينشئ بعد رسائل مع زر الويب، لذلك يمكن إتمام المهمة من خلال الضغط على زر الويب في هذه الرسالة",
}
l_bot_progress_share_btn = {
    "ru": "Кнопка Поделиться (веб)",
    "en": "Share Button (web)",
    "es": "Botón Compartir (web)",
    "fr": "Bouton Partager (web)",
    "zh": "分享按钮（网页）",
    "ar": "زر المشاركة (ويب)",
}
l_bot_progress_link_btn = {
    "ru": "Кнопка Ссылка (веб)",
    "en": "Button Link (web)",
    "es": "Botón Enlace (web)",
    "fr": "Bouton Lien (web)",
    "zh": "按钮 链接 (网页)",
    "ar": "زر الرابط (ويب)",
}
l_bot_progress_share_default = {
    "ru": "👩🏽‍💻 <b>Владелец</b> @{0}-приложения еще не создал сообщений c кнопкой Поделиться (веб), поэтому для прохождения задания можно совершить нажатие на кнопку Поделиться (веб) этого сообщения",
    "en": "👩🏽‍💻 <b>Owner</b> of the @{0} app has not yet created messages with the Share (web) button, so to complete the task, you can click the Share (web) button of this message.",
    "es": "👩🏽‍💻 <b>Propietario</b> de la aplicación @{0} aún no ha creado mensajes con el botón Compartir (web), por lo que para completar la tarea se puede hacer clic en el botón Compartir (web) de este mensaje.",
    "fr": "👩🏽‍💻 <b>Propriétaire</b> de l'application @{0} n'a pas encore créé de messages avec le bouton Partager (web), donc pour compléter la tâche, vous pouvez appuyer sur le bouton Partager (web) de ce message.",
    "zh": "👩🏽‍💻 <b>拥有者</b> @{0} 的应用程序尚未创建带有分享按钮（网页）的消息，因此可以通过点击此消息的分享按钮（网页）来完成任务。",
    "ar": "👩🏽‍💻 <b>مالك</b> تطبيق @{0} لم ينشئ بعد رسائل تحتوي على زر المشاركة (ويب)، لذلك يمكن إتمام المهمة من خلال الضغط على زر المشاركة (ويب) لهذه الرسالة",
}
l_bot_progress_link_default = {
    "ru": "👩🏽‍💻 <b>Владелец</b> @{0}-приложения еще не создал сообщений c кнопкой Ссылка (веб), поэтому для прохождения задания можно совершить нажатие на кнопку Ссылка (веб) этого сообщения",
    "en": "👩🏽‍💻 <b>Owner</b> of the @{0} app has not created messages with the Link (web) button yet, so to complete the task, you can click the Link (web) button of this message.",
    "es": "👩🏽‍💻 <b>Propietario</b> de la aplicación @{0} aún no ha creado mensajes con el botón Enlace (web), por lo que para completar la tarea se puede hacer clic en el botón Enlace (web) de este mensaje.",
    "fr": "👩🏽‍💻 <b>Propriétaire</b> de l'application @{0} n'a pas encore créé de messages avec le bouton Lien (web), donc pour compléter la tâche, vous pouvez cliquer sur le bouton Lien (web) de ce message.",
    "zh": "👩🏽‍💻 <b>拥有者</b> @{0} 的应用程序尚未创建带有链接按钮（网页）的消息，因此可以通过点击此消息的链接按钮（网页）来完成任务。",
    "ar": "👩🏽‍💻 <b>مالك</b> تطبيق @{0} لم ينشئ بعد رسائل تحتوي على زر الرابط (ويب)، لذلك يمكن إتمام المهمة من خلال الضغط على زر الرابط (ويب) في هذه الرسالة.",
}
# endregion


# region FereyChannelBot
l_chn_btn1 = {
    "ru": "➕ Канал",
    "en": "➕ Channel",
    "es": "➕ Canal",
    "fr": "➕ Chaîne",
    "zh": "➕ 渠道",
    "ar": "➕ القناة",
}
l_chn_btn2 = {
    "ru": "💨 Подписка",
    "en": "💨 Subscription",
    "es": "💨 Suscripción",
    "fr": "💨 Abonnement",
    "zh": "💨 订阅",
    "ar": "💨 الاشتراك",
}
l_chn_welcome = {
    "ru": "🌱 <b>{0}</b>, добро пожаловать в <i>@tg-приложение</i> администрирования <b>Telegram</b>-каналов:\n\n<blockquote>▪️монетизация и донаты\n▪️NFT-посты канала\n▪️FT-токен канала\n▪️маркетплейс постов и геймификация\n▪️нейро-генерация постов</blockquote>",
    "en": "🌱 <b>{0}</b>, welcome to the <i>@tg-application</i> for managing <b>Telegram</b> channels:\n\n<blockquote>▪️monetization and donations\n▪️NFT posts of the channel\n▪️FT token of the channel\n▪️marketplace for posts and gamification\n▪️neural generation of posts</blockquote>",
    "es": "🌱 <b>{0}</b>, bienvenido a <i>@tg-aplicación</i> de administración de <b>canales de Telegram</b>:\n\n<blockquote>▪️monetización y donaciones\n▪️publicaciones NFT del canal\n▪️token FT del canal\n▪️mercado de publicaciones y gamificación\n▪️neuro-generación de publicaciones</blockquote>",
    "fr": "🌱 <b>{0}</b>, bienvenue dans <i>@tg-application</i> d'administration des <b>canaux Telegram</b> :\n\n<blockquote>▪️monétisation et dons\n▪️posts NFT du canal\n▪️token FT du canal\n▪️place de marché des posts et gamification\n▪️génération de posts par IA</blockquote>",
    "zh": "🌱 <b>{0}</b>, 欢迎来到 <i>@tg-应用程序</i> 管理 <b>Telegram</b> 频道：\n\n<blockquote>▪️货币化和捐赠\n▪️频道的NFT帖子\n▪️频道的FT代币\n▪️帖子市场和游戏化\n▪️神经生成帖子</blockquote>",
    "ar": "🌱 <b>{0}</b>, مرحبًا بك في <i>@tg-تطبيق</i> إدارة قنوات <b>Telegram</b>:\n\n<blockquote>▪️تحقيق الدخل والتبرعات\n▪️منشورات NFT للقناة\n▪️رمز FT للقناة\n▪️سوق المنشورات والألعاب\n▪️توليد المنشورات بواسطة الذكاء الاصطناعي</blockquote>",
}
l_cmd_txt_chn = {
    "ru": "👩🏽‍💻 <b>Жми</b> [➕ Добавить канал]",
    "en": "👩🏽‍💻 <b>Click</b> [➕ Add channel]",
    "es": "👩🏽‍💻 <b>Haz clic</b> [➕ Agregar canal]",
    "fr": "👩🏽‍💻 <b>Cliquez</b> [➕ Ajouter un canal]",
    "zh": "👩🏽‍💻 <b>点击</b> [➕ 添加频道]",
    "ar": "👩🏽‍💻 <b>اضغط</b> [➕ إضافة قناة]",
}
l_channels = {
    "ru": "👩🏽‍💻 Каналы",
    "en": "👩🏽‍💻 Channels",
    "es": "👩🏽‍💻 Canales",
    "fr": "👩🏽‍💻 Canaux",
    "zh": "👩🏽‍💻 渠道",
    "ar": "👩🏽‍💻 القنوات",
}
l_add_chn_button = {
    "ru": "➕ Добавить канал",
    "en": "➕ Add channel",
    "es": "➕ Añadir canal",
    "fr": "➕ Ajouter un canal",
    "zh": "➕ 添加频道",
    "ar": "➕ إضافة قناة",
}
l_bot_removed = {
    "ru": "🚫 @{0}-приложение удалено из <b>{1}</b> [id=<code>{2}</code>]",
    "en": "🚫 @{0}-app removed from <b>{1}</b> [id=<code>{2}</code>]",
    "es": "🚫 @{0}-aplicación eliminada de <b>{1}</b> [id=<code>{2}</code>]",
    "fr": "🚫 @{0}-l'application a été supprimée de <b>{1}</b> [id=<code>{2}</code>]",
    "zh": "🚫 @{0}应用已从 <b>{1}</b> 中删除 [id=<code>{2}</code>]",
    "ar": "🚫 @{0} - تم حذف التطبيق من <b>{1}</b> [id=<code>{2}</code>]",
}
l_top_hashtags = {
    "ru": "\n<b>Топ #hashtags</b>:\n{0}\n",
    "en": "<b>Top #hashtags</b>:\n{0}",
    "es": "<b>Top #hashtags</b>:\n{0}",
    "fr": "<b>Top #hashtags</b> :\n{0}",
    "zh": "<b>热门 #hashtags</b>:\n{0}",
    "ar": "<b>أفضل #الهاشتاجات</b>:\n{0}",
}
l_info_reactions = {
    "ru": "Допуск emoji-реакций",
    "en": "Allow emoji reactions",
    "es": "Permitir reacciones emoji",
    "fr": "Autoriser les réactions emoji",
    "zh": "允许 emoji 反应",
    "ar": "السماح بتفاعلات الرموز التعبيرية",
}
l_admins = {
    "ru": "Администраторы",
    "en": "Administrators",
    "es": "Administradores",
    "fr": "Administrateurs",
    "zh": "管理员",
    "ar": "المسؤولون",
}
l_info_invite_admins = {
    "ru": "Назначение администраторов",
    "en": "Administrator Assignment",
    "es": "Asignación de administradores",
    "fr": "Attribution des administrateurs",
    "zh": "管理员的职责",
    "ar": "تعيين المشرفين",
}
l_info_cmd = {
    "ru": "⚙️ <b>Команды</b> /cmd",
    "en": "⚙️ <b>Commands</b> /cmd",
    "es": "⚙️ <b>Comandos</b> /cmd",
    "fr": "⚙️ <b>Commandes</b> /cmd",
    "zh": "⚙️ <b>命令</b> /cmd",
    "ar": "⚙️ <b>الأوامر</b> /cmd",
}
l_info_protect = {
    "ru": "<b>Сохранение контента</b>: ",
    "en": "<b>Content Saving</b>:",
    "es": "<b>Guardar contenido</b>:",
    "fr": "<b>Conservation du contenu</b>:",
    "zh": "<b>内容保存</b>:",
    "ar": "<b>حفظ المحتوى</b>:",
}
l_info_request = {
    "ru": "<b>Вступление после одобрения</b>: ",
    "en": "<b>Introduction after approval</b>:",
    "es": "<b>Introducción después de la aprobación</b>:",
    "fr": "<b>Introduction après approbation</b>:",
    "zh": "<b>批准后的介绍</b>:",
    "ar": "<b>المقدمة بعد الموافقة</b>:",
}
l_info_send = {
    "ru": "<b>Возможность писать после вступления</b>: ",
    "en": "<b>Ability to write after the introduction</b>:",
    "es": "<b>Posibilidad de escribir después de la introducción</b>:",
    "fr": "<b>Possibilité d'écrire après l'introduction</b>:",
    "zh": "<b>在引言后写作的可能性</b>:",
    "ar": "<b>إمكانية الكتابة بعد المقدمة</b>:",
}
l_info_subscribe = {
    "ru": "<b>Проверка 💨Подписки при вступлении в канал</b>: ",
    "en": "<b>Subscription Check 💨Upon Joining the Channel</b>:",
    "es": "<b>Verificación 💨 de la Suscripción al unirse al canal</b>:",
    "fr": "<b>Vérification 💨 de l'abonnement lors de l'adhésion au canal</b>:",
    "zh": "<b>检查 💨订阅加入频道</b>:",
    "ar": "<b>التحقق من 💨الاشتراك عند الانضمام إلى القناة</b>:",
}
l_info_restrict = {
    "ru": "запрещено\n",
    "en": "forbidden",
    "es": "prohibido",
    "fr": "interdit",
    "zh": "禁止",
    "ar": "ممنوع",
}
l_info_allow = {
    "ru": "разрешено\n",
    "en": "allowed",
    "es": "permitido",
    "fr": "autorisé",
    "zh": "允许",
    "ar": "مسموح",
}
l_transfer_start = {
    "ru": "👩🏽‍💻 <b>Пользователь</b> {0} должен /start-запустить @{1}",
    "en": "👩🏽‍💻 <b>User</b> {0} must /start-launch @{1}",
    "es": "👩🏽‍💻 <b>Usuario</b> {0} debe iniciar /start @{1}",
    "fr": "👩🏽‍💻 <b>Utilisateur</b> {0} doit /start-lancer @{1}",
    "zh": "👩🏽‍💻 <b>用户</b> {0} 必须 /start 启动 @{1}",
    "ar": "👩🏽‍💻 <b>المستخدم</b> {0} يجب أن يبدأ /start @{1}",
}
l_transfer_admin = {
    "ru": "👩🏽‍💻 <b>Пользователь</b> {0} должен быть <b>администратором</b> в <b>{1}</b>",
    "en": "👩🏽‍💻 <b>User</b> {0} must be a <b>administrator</b> in <b>{1}</b>",
    "es": "👩🏽‍💻 <b>El usuario</b> {0} debe ser <b>administrador</b> en <b>{1}</b>",
    "fr": "👩🏽‍💻 <b>L'utilisateur</b> {0} doit être <b>administrateur</b> dans <b>{1}</b>",
    "zh": "👩🏽‍💻 <b>用户</b> {0} 必须是 <b>管理员</b> 在 <b>{1}</b>",
    "ar": "👩🏽‍💻 <b>المستخدم</b> {0} يجب أن يكون <b>مديرًا</b> في <b>{1}</b>",
}
l_transfer_transfer = {
    "ru": "👩🏽‍💻 <b>Передать</b> права администратора на <b>{0}</b> пользователю {1} в @{2}-приложении?",
    "en": "👩🏽‍💻 <b>Transfer</b> admin rights to <b>{0}</b> for user {1} in the @{2} app?",
    "es": "👩🏽‍💻 <b>¿Transferir</b> los derechos de administrador a <b>{0}</b> al usuario {1} en la aplicación @{2}?",
    "fr": "👩🏽‍💻 <b>Transférer</b> les droits d'administrateur à <b>{0}</b> à l'utilisateur {1} dans l'application @{2} ?",
    "zh": "👩🏽‍💻 <b>将</b> 管理员权限转移到 <b>{0}</b> 用户 {1} 在 @{2} 应用程序中？",
    "ar": "👩🏽‍💻 <b>نقل</b> حقوق المسؤول إلى <b>{0}</b> للمستخدم {1} في تطبيق @{2}؟",
}
l_transfer_text = {
    "ru": "👩🏽‍💻 <b>Для</b> передачи admin-прав канала в @{0}-приложении используй команду:\n/transfer ID-ПОЛЬЗОВАТЕЛЯ, где пользователь: администратор канала и участник @{0}-приложения (/id)\n\n⚙️ <b>Команды</b> /cmd",
    "en": "👩🏽‍💻 <b>To</b> transfer admin rights of the channel in the @{0} app, use the command:\n/transfer USER-ID, where user: channel administrator and participant of the @{0} app (/id)\n\n⚙️ <b>Commands</b> /cmd",
    "es": "👩🏽‍💻 <b>Para</b> transferir los derechos de admin del canal en la aplicación @{0}, utiliza el comando:\n/transfer ID-USUARIO, donde usuario: administrador del canal y participante de la aplicación @{0} (/id)\n\n⚙️ <b>Comandos</b> /cmd",
    "fr": "👩🏽‍💻 <b>Pour</b> transférer les droits d'admin du canal dans l'application @{0}, utilise la commande :  \n/transfer ID-UTILISATEUR, où l'utilisateur : administrateur du canal et membre de l'application @{0} (/id)  \n\n⚙️ <b>Commandes</b> /cmd",
    "zh": "👩🏽‍💻 <b>要</b> 在 @{0} 应用中传递频道的管理员权限，请使用命令：  \n/transfer 用户ID，其中用户：频道管理员和 @{0} 应用的参与者 (/id)  \n\n⚙️ <b>命令</b> /cmd",
    "ar": "👩🏽‍💻 <b>لنقل</b> حقوق المسؤول للقناة في تطبيق @{0} استخدم الأمر:\n/transfer ID-المستخدم، حيث المستخدم: مسؤول القناة وعضو في تطبيق @{0} (/id)\n\n⚙️ <b>الأوامر</b> /cmd",
}
l_transfer_done_to = {
    "ru": "👩🏽‍💻 <b>Права</b> админиистратора на [<b>{0}</b>] успешно переданы {1}",
    "en": "👩🏽‍💻 <b>Administrator</b> rights for [<b>{0}</b>] have been successfully transferred {1}",
    "es": "👩🏽‍💻 <b>Los</b> derechos de administrador en [<b>{0}</b>] se han transferido con éxito {1}",
    "fr": "👩🏽‍💻 <b>Droits</b> de l'administrateur sur [<b>{0}</b>] ont été transférés avec succès {1}",
    "zh": "👩🏽‍💻 <b>管理员</b> 权限已成功转移到 [<b>{0}</b>] {1}",
    "ar": "👩🏽‍💻 <b>حقوق</b> المسؤول على [<b>{0}</b>] تم نقلها بنجاح {1}",
}
l_transfer_done_from = {
    "ru": "👩🏽‍💻 <b>Права</b> администратора на [<b>{0}</b>] успешно получены от {1}",
    "en": "👩🏽‍💻 <b>Administrator</b> rights on [<b>{0}</b>] have been successfully obtained from {1}",
    "es": "👩🏽‍💻 <b>Los</b> derechos de administrador en [<b>{0}</b>] se han obtenido con éxito de {1}",
    "fr": "👩🏽‍💻 <b>Droits</b> d'administrateur sur [<b>{0}</b>] obtenus avec succès de {1}",
    "zh": "👩🏽‍💻 <b>管理员</b> 权限已成功从 {1} 获得 [<b>{0}</b>]",
    "ar": "👩🏽‍💻 <b>حقوق</b> المسؤول على [<b>{0}</b>] تم الحصول عليها بنجاح من {1}",
}
l_add_chn_text = {
    "ru": "👮🏽‍♀️ <b>Добавь</b> @{0}-приложение как [<b>Администратор</b>] через настройки своего канала:\n\n<blockquote>[👤 Добавить администратора]</blockquote>",
    "en": "👮🏽‍♀️ <b>Add</b> the @{0} app as [<b>Administrator</b>] through your channel settings:\n\n<blockquote>[👤 Add administrator]</blockquote>",
    "es": "👮🏽‍♀️ <b>Agrega</b> @{0} la aplicación como [<b>Administrador</b>] a través de la configuración de tu canal:\n\n<blockquote>[👤 Agregar administrador]</blockquote>",
    "fr": "👮🏽‍♀️ <b>Ajoute</b> @{0} l'application en tant que [<b>Administrateur</b>] via les paramètres de ta chaîne :\n\n<blockquote>[👤 Ajouter un administrateur]</blockquote>",
    "zh": "👮🏽‍♀️ <b>添加</b> @{0} 应用程序作为 [<b>管理员</b>] 通过您的频道设置：\n\n<blockquote>[👤 添加管理员]</blockquote>",
    "ar": "👮🏽‍♀️ <b>أضف</b> @{0} - التطبيق كـ [<b>مدير</b>] من خلال إعدادات قناتك:\n\n<blockquote>[👤 إضافة مدير]</blockquote>",
}
l_add_chn_txt_call = {
    "ru": "👮🏽‍♀️ Добавь @{0}-приложение как Administrator через настройки своего канала: [👤Add Admin]",
    "en": "👮🏽‍♀️ Add the @{0} app as Administrator through your channel settings: [👤Add Admin]",
    "es": "👮🏽‍♀️ Agrega la aplicación @{0} como Administrador a través de la configuración de tu canal: [👤Agregar Admin]",
    "fr": "👮🏽‍♀️ Ajoute l'application @{0} en tant qu'administrateur via les paramètres de ta chaîne : [👤Ajouter un admin]",
    "zh": "👮🏽‍♀️ 将 @{0} 应用程序作为管理员通过您的频道设置添加： [👤添加管理员]",
    "ar": "👮🏽‍♀️ أضف تطبيق @{0} كمسؤول من خلال إعدادات قناتك: [👤إضافة مسؤول]",
}
l_chn_check = {
    "ru": "👩🏽‍💻 <b>Добавь</b> @{0}-приложение в канал для проверки подписки на него. Отправь мне корректную ссылку на канал:",
    "en": "👩🏽‍💻 <b>Add</b> the @{0} app to the channel for subscription verification. Send me the correct link to the channel:",
    "es": "👩🏽‍💻 <b>Agrega</b> la aplicación @{0} al canal para verificar la suscripción a ella. Envíame el enlace correcto al canal:",
    "fr": "👩🏽‍💻 <b>Ajoute</b> l'application @{0} au canal pour vérifier l'abonnement. Envoie-moi le lien correct vers le canal :",
    "zh": "👩🏽‍💻 <b>添加</b> @{0} 应用程序到频道以检查其订阅。请给我发送正确的频道链接：",
    "ar": "👩🏽‍💻 <b>أضف</b> @{0} - التطبيق إلى القناة للتحقق من الاشتراك فيه. أرسل لي الرابط الصحيح للقناة:",
}
l_podcast_rights = {
    "ru": "🎥 <b>В настройках</b> [Администраторы] вкл опцию для @{0}-приложения:\n[✅ Назначение администраторов]\n[✅ Управление трансляциями]\n\n🕚Подожди 1min",
    "en": "🎥 <b>In settings</b> [Administrators] enable the option for the @{0} application:  \n[✅ Assigning administrators]  \n[✅ Managing broadcasts]  \n\n🕚Wait 1min",
    "es": "🎥 <b>En la configuración</b> [Administradores] activa la opción para la aplicación @{0}:\n[✅ Asignación de administradores]\n[✅ Gestión de transmisiones]\n\n🕚Espera 1min",
    "fr": "🎥 <b>Dans les paramètres</b> [Administrateurs] active l'option pour l'application @{0} :\n[✅ Attribution des administrateurs]\n[✅ Gestion des diffusions]\n\n🕚Attends 1min",
    "zh": "🎥 <b>在设置</b> [管理员] 中启用 @{0} 应用程序的选项：\n[✅ 指定管理员]\n[✅ 管理直播]\n\n🕚等1分钟",
    "ar": "🎥 <b>في الإعدادات</b> [المسؤولون] قم بتفعيل الخيار لتطبيق @{0}:\n[✅ تعيين المسؤولين]\n[✅ إدارة البث]\n\n🕚انتظر 1 دقيقة",
}
l_podcast_handler = {
    "ru": "🎥 <b>Авто-анонс</b> <i>видео-подкаста</i> [/podcast d h] каждый <u>d</u>-день (1-31) на <u>h</u>-часов (1-168). Текущее значение: /podcast {0}\n\n<code>/podcast 1 1</code>  ежедневный видео-анонс длительностью 1 час\n<code>/podcast 0</code>    отключение опции\n\n⚙️ <b>Команды</b> /cmd",
    "en": "🎥 <b>Auto-announcement</b> <i>of the video podcast</i> [/podcast d h] every <u>d</u>-day (1-31) at <u>h</u>-hours (1-168). Current value: /podcast {0}\n\n<code>/podcast 1 1</code>  daily video announcement lasting 1 hour  \n<code>/podcast 0</code>    disable the option\n\n⚙️ <b>Commands</b> /cmd",
    "es": "🎥 <b>Auto-anuncio</b> <i>del video-podcast</i> [/podcast d h] cada <u>d</u>-día (1-31) a las <u>h</u>-horas (1-168). Valor actual: /podcast {0}\n\n<code>/podcast 1 1</code>  anuncio diario de video con una duración de 1 hora  \n<code>/podcast 0</code>    desactivar la opción\n\n⚙️ <b>Comandos</b> /cmd",
    "fr": "🎥 <b>Avis automatique</b> <i>du podcast vidéo</i> [/podcast d h] chaque <u>d</u>-jour (1-31) à <u>h</u>-heures (1-168). Valeur actuelle : /podcast {0}\n\n<code>/podcast 1 1</code>  avis vidéo quotidien d'une durée de 1 heure  \n<code>/podcast 0</code>    désactiver l'option\n\n⚙️ <b>Commandes</b> /cmd",
    "zh": "🎥 <b>自动预告</b> <i>视频播客</i> [/podcast d h] 每个 <u>d</u> 天 (1-31) 在 <u>h</u> 小时 (1-168)。当前值：/podcast {0}\n\n<code>/podcast 1 1</code>  每日视频预告时长 1 小时\n<code>/podcast 0</code>    关闭选项\n\n⚙️ <b>命令</b> /cmd",
    "ar": "🎥 <b>الإعلان التلقائي</b> <i>لبودكاست الفيديو</i> [/podcast d h] كل <u>d</u> يوم (1-31) في <u>h</u> ساعة (1-168). القيمة الحالية: /podcast {0}\n\n<code>/podcast 1 1</code>  إعلان فيديو يومي لمدة ساعة واحدة\n<code>/podcast 0</code>    تعطيل الخيار\n\n⚙️ <b>الأوامر</b> /cmd",
}
l_podcast_on = {
    "ru": "🎥 <b>Авто-анонс</b> <i>видео-подкаста</i>: каждый <u>{0}</u> день на <u>{1}</u> часов\n\n⚙️ <b>Команды</b> /cmd",
    "en": "🎥 <b>Auto-announcement</b> <i>of the video podcast</i>: every <u>{0}</u> day at <u>{1}</u> o'clock\n\n⚙️ <b>Commands</b> /cmd",
    "es": "🎥 <b>Auto-anuncio</b> <i>del video-podcast</i>: cada <u>{0}</u> día a las <u>{1}</u> horas\n\n⚙️ <b>Comandos</b> /cmd",
    "fr": "🎥 <b>Avis automatique</b> <i>du podcast vidéo</i> : chaque <u>{0}</u> jour à <u>{1}</u> heures\n\n⚙️ <b>Commandes</b> /cmd",
    "zh": "🎥 <b>自动预告</b> <i>视频播客</i>: 每个 <u>{0}</u> 天在 <u>{1}</u> 小时\n\n⚙️ <b>命令</b> /cmd",
    "ar": "🎥 <b>الإعلان التلقائي</b> <i>لبودكاست الفيديو</i>: كل <u>{0}</u> يوم في <u>{1}</u> ساعات\n\n⚙️ <b>الأوامر</b> /cmd",
}
l_podcast_off = {
    "ru": "🎥 <b>Авто-анонс</b> <i>видео-подкаста</i> отключен\n\n⚙️ <b>Команды</b> /cmd",
    "en": "🎥 <b>Auto-announcement</b> <i>of the video podcast</i> is disabled\n\n⚙️ <b>Commands</b> /cmd",
    "es": "🎥 <b>Auto-anuncio</b> <i>del video-podcast</i> desactivado\n\n⚙️ <b>Comandos</b> /cmd",
    "fr": "🎥 <b>Avis automatique</b> <i>du podcast vidéo</i> désactivé\n\n⚙️ <b>Commandes</b> /cmd",
    "zh": "🎥 <b>自动预告</b> <i>视频播客</i> 已禁用\n\n⚙️ <b>命令</b> /cmd",
    "ar": "🎥 <b>الإعلان التلقائي</b> <i>للبودكاست الفيديو</i> معطل\n\n⚙️ <b>الأوامر</b> /cmd",
}
l_podcast_start = {
    "ru": "👩🏽‍💻 Podcast",
    "en": "👩🏽‍💻 Podcast",
    "es": "👩🏽‍💻 Podcast",
    "fr": "👩🏽‍💻 Podcast",
    "zh": "👩🏽‍💻 播客",
    "ar": "👩🏽‍💻 بودكاست",
}
l_chn_info_start1 = {
    "ru": "👩🏽‍💻 <b>Информация</b>\n\n<b>Название</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> участ.]{5}{6}{7}",
    "en": "👩🏽‍💻 <b>Information</b>\n\n<b>Title</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> participants.]{5}{6}{7}",
    "es": "👩🏽‍💻 <b>Información</b>\n\n<b>Nombre</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> part.]{5}{6}{7}",
    "fr": "👩🏽‍💻 <b>Informations</b>\n\n<b>Nom</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> part.]{5}{6}{7}",
    "zh": "👩🏽‍💻 <b>信息</b>\n\n<b>名称</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> 参与者.]{5}{6}{7}",
    "ar": "👩🏽‍💻 <b>معلومات</b>\n\n<b>الاسم</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> مشارك.]{5}{6}{7}",
}
l_chn_stat_start1 = {
    "ru": "👩🏽‍💻 <b>Аналитика</b>\n\n<b>Название</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> участ.]{5}{6}{7}",
    "en": "👩🏽‍💻 <b>Analytics</b>\n\n<b>Name</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> participants.]{5}{6}{7}",
    "es": "👩🏽‍💻 <b>Analítica</b>\n\n<b>Nombre</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> part.]{5}{6}{7}",
    "fr": "👩🏽‍💻 <b>Analyse</b>\n\n<b>Nom</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> part.]{5}{6}{7}",
    "zh": "👩🏽‍💻 <b>分析</b>\n\n<b>名称</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> 参与者.]{5}{6}{7}",
    "ar": "👩🏽‍💻 <b>التحليل</b>\n\n<b>الاسم</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> المشاركين.]{5}{6}{7}",
}
l_chn_stat_start2 = {
    "ru": "\n<b>Ссылка</b>: {0}\n<b>Описание</b>: {1}\n<b>Привязанная группа</b>: <code>{2}</code>\n",
    "en": "<b>Link</b>: {0}  \n<b>Description</b>: {1}  \n<b>Attached group</b>: <code>{2}</code>",
    "es": "<b>Enlace</b>: {0}  \n<b>Descripción</b>: {1}  \n<b>Grupo vinculado</b>: <code>{2}</code>",
    "fr": "<b>Lien</b> : {0}  \n<b>Description</b> : {1}  \n<bGroupe associé</b> : <code>{2}</code>",
    "zh": "<b>链接</b>: {0}  \n<b>描述</b>: {1}  \n<b>绑定的组</b>: <code>{2}</code>",
    "ar": "<b>الرابط</b>: {0}  \n<b>الوصف</b>: {1}  \n<b>المجموعة المرتبطة</b>: <code>{2}</code>",
}
l_chn_stat_start3 = {
    "ru": "\n<b>ID последнего поста</b>: {0}\n<b>Посты</b>: {1}\n<b>Реакции</b>: {2}\n<b>Просмотры</b>: {3}\n<b>кѻмментарии</b>: {4}\n<b>$кэштеги</b>: {5}\n<b>#hashtag</b>: {6}\n",
    "en": "<b>Last post ID</b>: {0}  \n<b>Posts</b>: {1}  \n<b>Reactions</b>: {2}  \n<b>Views</b>: {3}  \n<b>Comments</b>: {4}  \n<b>$hashtags</b>: {5}  \n<b>#hashtag</b>: {6}",
    "es": "<b>ID de la última publicación</b>: {0}  \n<b>Publicaciones</b>: {1}  \n<b>Reacciones</b>: {2}  \n<b>Vistas</b>: {3}  \n<b>comentarios</b>: {4}  \n<b>$etiquetas</b>: {5}  \n<b>#hashtag</b>: {6}",
    "fr": "<b>ID du dernier post</b>: {0}  \n<b>Posts</b>: {1}  \n<b>Réactions</b>: {2}  \n<b>Vues</b>: {3}  \n<b>commentaires</b>: {4}  \n<b>$hashtags</b>: {5}  \n<b>#hashtag</b>: {6}",
    "zh": "<b>最后帖子ID</b>: {0}  \n<b>帖子</b>: {1}  \n<b>反应</b>: {2}  \n<b>浏览次数</b>: {3}  \n<b>评论</b>: {4}  \n<b>$标签</b>: {5}  \n<b>#话题标签</b>: {6}",
    "ar": "<b>معرف آخر منشور</b>: {0}  \n<b>المنشورات</b>: {1}  \n<b>ردود الفعل</b>: {2}  \n<b>المشاهدات</b>: {3}  \n<b>التعليقات</b>: {4}  \n<b>$الهاشتاجات</b>: {5}  \n<b>#هاشتاج</b>: {6}",
}
l_chn_commands_handler = {
    "ru": "⚙️ <b>Команды</b> /cmd для [<b>{0}</b>] {1} [<code>{2}</code>]\n\n<blockquote>/info информация о канале\n/stat статистика\n\n/parse [1] база подписчиков/лайков поста #1\n/random [1] рандомный лайкнувший пост #1\n/podcast 1 1 анонс видео-подкаста\n<code>/clean</code> очистка от deleted/scam-аккаунтов и по [<b>🕵🏽 Авто-бан</b>] правилам\n/delete <code>FROM TO</code> удаление за период\n/channel NAME канал проверки подписки\n/transfer передача ADMIN-прав</blockquote>\n\n💨 <b>Подписка</b>: <i>{3}</i>",
    "en": "⚙️ <b>Commands</b> /cmd for [<b>{0}</b>] {1} [<code>{2}</code>]\n\n<blockquote>/info information about the channel\n/stat statistics\n\n/parse [1] subscriber/like database for post #1\n/random [1] random liker of post #1\n/podcast 1 1 video podcast announcement\n<code>/clean</code> cleaning from deleted/scam accounts and by [<b>🕵🏽 Auto-ban</b>] rules\n/delete <code>FROM TO</code> deletion for the period\n/channel NAME subscription check channel\n/transfer transfer of ADMIN rights</blockquote>\n\n💨 <b>Subscription</b>: <i>{3}</i>",
    "es": "⚙️ <b>Comandos</b> /cmd para [<b>{0}</b>] {1} [<code>{2}</code>]\n\n<blockquote>/info información sobre el canal\n/stat estadísticas\n\n/parse [1] base de suscriptores/me gusta del post #1\n/random [1] usuario que le dio like al post #1\n/podcast 1 1 anuncio del video-podcast\n<code>/clean</code> limpieza de cuentas eliminadas/scam y según las reglas de [<b>🕵🏽 Auto-baneo</b>]\n/delete <code>FROM TO</code> eliminación por período\n/channel NAME canal de verificación de suscripción\n/transfer transferencia de derechos ADMIN</blockquote>\n\n💨 <b>Suscripción</b>: <i>{3}</i>",
    "fr": "⚙️ <b>Commandes</b> /cmd pour [<b>{0}</b>] {1} [<code>{2}</code>]\n\n<blockquote>/info informations sur le canal\n/stat statistiques\n\n/parse [1] base d'abonnés/likes du post #1\n/random [1] utilisateur aléatoire ayant aimé le post #1\n/podcast 1 1 annonce de la vidéo-podcast\n<code>/clean</code> nettoyage des comptes supprimés/scam et selon les règles [<b>🕵🏽 Auto-ban</b>]\n/delete <code>FROM TO</code> suppression sur une période\n/channel NAME canal de vérification d'abonnement\n/transfer transfert des droits ADMIN</blockquote>\n\n💨 <b>Abonnement</b> : <i>{3}</i>",
    "zh": "⚙️ <b>命令</b> /cmd для [<b>{0}</b>] {1} [<code>{2}</code>]\n\n<blockquote>/info 频道信息\n/stat 统计\n\n/parse [1] 订阅者/点赞者数据库 поста #1\n/random [1] 随机点赞者 поста #1\n/podcast 1 1 视频播客预告\n<code>/clean</code> 清除 deleted/scam-账户和根据 [<b>🕵🏽 自动封禁</b>] 规则\n/delete <code>FROM TO</code> 在指定期间内删除\n/channel NAME 订阅检查频道\n/transfer 转移 ADMIN 权限</blockquote>\n\n💨 <b>订阅</b>: <i>{3}</i>",
    "ar": "⚙️ <b>الأوامر</b> /cmd لـ [<b>{0}</b>] {1} [<code>{2}</code>]\n\n<blockquote>/info معلومات عن القناة\n/stat إحصائيات\n\n/parse [1] قاعدة المشتركين/الإعجابات للمنشور #1\n/random [1] إعجاب عشوائي للمنشور #1\n/podcast 1 1 إعلان فيديو البودكاست\n<code>/clean</code> تنظيف من الحسابات المحذوفة/الاحتيالية ووفقًا لقواعد [<b>🕵🏽 الحظر التلقائي</b>]\n/delete <code>FROM TO</code> حذف لفترة معينة\n/channel NAME قناة التحقق من الاشتراك\n/transfer نقل صلاحيات ADMIN</blockquote>\n\n💨 <b>الاشتراك</b>: <i>{3}</i>",
}
l_update_text = {
    "ru": "👩🏽‍💻 <b>Данные</b> о канале успешно обновлены:\n\n<b>{0}</b> [{1}]\n{2}\n<i>{3}</i>\n\n⚙️ <b>Команды</b> /cmd",
    "en": "👩🏽‍💻 <b>Channel</b> data has been successfully updated:\n\n<b>{0}</b> [{1}]\n{2}\n<i>{3}</i>\n\n⚙️ <b>Commands</b> /cmd",
    "es": "👩🏽‍💻 <b>Los</b> datos del canal se han actualizado correctamente:\n\n<b>{0}</b> [{1}]\n{2}\n<i>{3}</i>\n\n⚙️ <b>Comandos</b> /cmd",
    "fr": "👩🏽‍💻 <b>Données</b> sur le canal mises à jour avec succès :\n\n<b>{0}</b> [{1}]\n{2}\n<i>{3}</i>\n\n⚙️ <b>Commandes</b> /cmd",
    "zh": "👩🏽‍💻 <b>频道</b> 数据已成功更新：\n\n<b>{0}</b> [{1}]\n{2}\n<i>{3}</i>\n\n⚙️ <b>命令</b> /cmd",
    "ar": "👩🏽‍💻 <b>تم تحديث</b> بيانات القناة بنجاح:\n\n<b>{0}</b> [{1}]\n{2}\n<i>{3}</i>\n\n⚙️ <b>الأوامر</b> /cmd",
}
l_change_chn_info = {
    "ru": "Изменение профиля канала",
    "en": "Channel profile change",
    "es": "Cambio de perfil del canal",
    "fr": "Changement de profil de la chaîne",
    "zh": "频道资料修改",
    "ar": "تغيير ملف تعريف القناة",
}
l_send_messages = {
    "ru": "Отправка сообщений",
    "en": "Sending messages",
    "es": "Envío de mensajes",
    "fr": "Envoi de messages",
    "zh": "发送消息",
    "ar": "إرسال الرسائل",
}
l_chn_graph_yes = {
    "ru": "👩🏽‍💻 <b>Экстра</b>-статистика канала за неделю [{0}]\n\n▪️ Подписчики: {1} ({2}{3})\n▪️ Просмотры: {4} ({5}{6})\n▪️ Поделиться: {7} ({8}{9})\n▪️ Уведомления у {10}% подписчиков\n",
    "en": "👩🏽‍💻 <b>Extra</b> channel statistics for the week [{0}]\n\n▪️ Subscribers: {1} ({2}{3})\n▪️ Views: {4} ({5}{6})\n▪️ Share: {7} ({8}{9})\n▪️ Notifications for {10}% of subscribers",
    "es": "👩🏽‍💻 <b>Estadísticas</b> extra del canal por semana [{0}]\n\n▪️ Suscriptores: {1} ({2}{3})\n▪️ Vistas: {4} ({5}{6})\n▪️ Compartir: {7} ({8}{9})\n▪️ Notificaciones para el {10}% de los suscriptores",
    "fr": "👩🏽‍💻 <b>Statistiques</b> supplémentaires de la chaîne pour la semaine [{0}]\n\n▪️ Abonnés : {1} ({2}{3})\n▪️ Vues : {4} ({5}{6})\n▪️ Partager : {7} ({8}{9})\n▪️ Notifications pour {10}% des abonnés",
    "zh": "👩🏽‍💻 <b>额外</b>频道一周统计 [{0}]\n\n▪️ 订阅者: {1} ({2}{3})\n▪️ 浏览量: {4} ({5}{6})\n▪️ 分享: {7} ({8}{9})\n▪️ {10}% 的订阅者收到通知",
    "ar": "👩🏽‍💻 <b>إحصائيات</b> القناة الإضافية للأسبوع [{0}]\n\n▪️ المشتركين: {1} ({2}{3})\n▪️ المشاهدات: {4} ({5}{6})\n▪️ المشاركة: {7} ({8}{9})\n▪️ الإشعارات لدى {10}% من المشتركين",
}
l_chn_graph_no = {
    "ru": "👩🏽‍💻 <b>Вкл</b> [✅ Назначение администраторов] для @{0}, чтобы вывести <b>экстра</b>-графику канала за неделю",
    "en": "👩🏽‍💻 <b>On</b> [✅ Assign Administrators] for @{0} to display the <b>extra</b> channel graphics for the week",
    "es": "👩🏽‍💻 <b>Activar</b> [✅ Asignación de administradores] para @{0}, para mostrar la <b>extra</b> gráfica del canal de la semana",
    "fr": "👩🏽‍💻 <b>Activer</b> [✅ Attribution des administrateurs] pour @{0}, afin d'afficher la <b>graphique</b> supplémentaire du canal pour la semaine",
    "zh": "👩🏽‍💻 <b>开启</b> [✅ 管理员分配] 给 @{0}，以便在一周内显示频道的 <b>额外</b> 图形",
    "ar": "👩🏽‍💻 <b>تشغيل</b> [✅ تعيين المسؤولين] لـ @{0} لعرض <b>الرسوم البيانية</b> الإضافية للقناة خلال الأسبوع",
}
l_chn_already_taken = {
    "ru": "👮🏽 <b>Канал</b> [<b>{0}</b>] уже <i>администрируется</i> в @{1}-приложении",
    "en": "👮🏽 <b>Channel</b> [<b>{0}</b>] is already <i>administered</i> in the @{1} app",
    "es": "👮🏽 <b>Canal</b> [<b>{0}</b>] ya está <i>administrado</i> en la aplicación @{1}",
    "fr": "👮🏽 <b>Canal</b> [<b>{0}</b>] est déjà <i>administré</i> dans l'application @{1}",
    "zh": "👮🏽 <b>频道</b> [<b>{0}</b>] 已经 <i>在</i> @{1} 应用中 <i>管理</i>",
    "ar": "👮🏽 <b>القناة</b> [<b>{0}</b>] يتم <i>إدارتها</i> بالفعل في تطبيق @{1}",
}
l_chn_subscribe_call = {
    "ru": "👩🏽‍💻 Необходима подписка на канал",
    "en": "👩🏽‍💻 Subscription to the channel is required",
    "es": "👩🏽‍💻 Se requiere una suscripción al canal",
    "fr": "👩🏽‍💻 Un abonnement à la chaîne est nécessaire",
    "zh": "👩🏽‍💻 需要订阅频道",
    "ar": "👩🏽‍💻 تحتاج إلى الاشتراك في القناة",
}
l_chn_boost_call = {
    "ru": "👩🏽‍💻 Необходим буст-голос за канал",
    "en": "👩🏽‍💻 A boost-voice for the channel is needed",
    "es": "👩🏽‍💻 Se necesita un boost de voz para el canal",
    "fr": "👩🏽‍💻 Un boost de voix est nécessaire pour la chaîne",
    "zh": "👩🏽‍💻 需要为频道提升声音",
    "ar": "👩🏽‍💻 تحتاج إلى تعزيز صوت القناة",
}
l_content_types_sub_button = {
    "ru": "👮🏽 Я подписался",
    "en": "👮🏽 I subscribed",
    "es": "👮🏽 Me he suscrito",
    "fr": "👮🏽 Je me suis inscrit",
    "zh": "👮🏽 我已订阅",
    "ar": "👮🏽 لقد اشتركت",
}
l_wait_1_min = {
    "ru": "🕐 Подожди 1мин",
    "en": "🕐 Wait 1min",
    "es": "🕐 Espera 1min",
    "fr": "🕐 Attends 1min",
    "zh": "🕐 等待 1 分钟",
    "ar": "🕐 انتظر 1 دقيقة",
}
l_chat_join_request_handler = {
    "ru": "<blockquote>👮🏽 {0}, ты отправил(а) заявку на вступление в <b>{1}</b>\n\n👩🏽‍💻 <b>Выбери</b> <i>правильный вариант</i> за 2 минуты в соответствии с заданием на картинке, чтобы твоя <i>заявка</i> на вступление была <b>одобрена</b></blockquote>",
    "en": "<blockquote>👮🏽 {0}, you have submitted an application to join <b>{1}</b>\n\n👩🏽‍💻 <b>Select</b> <i>the correct option</i> within 2 minutes according to the task in the picture, so that your <i>application</i> to join is <b>approved</b></blockquote>",
    "es": "<blockquote>👮🏽 {0}, has enviado una solicitud para unirte a <b>{1}</b>\n\n👩🏽‍💻 <b>Elige</b> <i>la opción correcta</i> en 2 minutos de acuerdo con la tarea en la imagen, para que tu <i>solicitud</i> de ingreso sea <b>aprobada</b></blockquote>",
    "fr": "<blockquote>👮🏽 {0}, tu as envoyé une demande d'adhésion à <b>{1}</b>\n\n👩🏽‍💻 <b>Choisis</b> <i>la bonne option</i> en 2 minutes selon la tâche sur l'image, afin que ta <i>demande</i> d'adhésion soit <b>approuvée</b></blockquote>",
    "zh": "<blockquote>👮🏽 {0}，你已提交加入<b>{1}</b>的申请\n\n👩🏽‍💻 <b>选择</b> <i>正确的选项</i>，在2分钟内根据图片中的任务，以便你的<i>申请</i>能够<b>获得批准</b></blockquote>",
    "ar": "<blockquote>👮🏽 {0}، لقد أرسلت طلب الانضمام إلى <b>{1}</b>\n\n👩🏽‍💻 <b>اختر</b> <i>الخيار الصحيح</i> في غضون دقيقتين وفقًا للمهمة في الصورة، لكي يتم <i>قبول</i> طلبك للانضمام <b>الموافقة</b></blockquote>",
}
l_chn_need_sub_for_more_than_1_chn = {
    "ru": "👩🏽‍💻 <b>Оформи</b> подписку, чтобы добавлять более 1 канала",
    "en": "👩🏽‍💻 <b>Subscribe</b> to add more than 1 channel",
    "es": "👩🏽‍💻 <b>Suscríbete</b> para agregar más de 1 canal",
    "fr": "👩🏽‍💻 <b>Abonnez-vous</b> pour ajouter plus d'un canal",
    "zh": "👩🏽‍💻 <b>订阅</b> 以添加超过 1 个频道",
    "ar": "👩🏽‍💻 <b>اشترك</b> لإضافة أكثر من قناة واحدة",
}
l_chn_need_sub_for_more_than_2_chn = {
    "ru": "👩🏽‍💻 <b>Оформи</b> подписку, чтобы добавлять более 2 каналов",
    "en": "👩🏽‍💻 <b>Subscribe</b> to add more than 2 channels",
    "es": "👩🏽‍💻 <b>Suscríbete</b> para agregar más de 2 canales",
    "fr": "👩🏽‍💻 <b>Abonnez-vous</b> pour ajouter plus de 2 chaînes",
    "zh": "👩🏽‍💻 <b>订阅</b> 以添加超过 2 个频道",
    "ar": "👩🏽‍💻 <b>اشترك</b> لإضافة أكثر من قناتين",
}
l_cdelete_answer = {
    "ru": "🚫 @{0}-приложение отсоединено от [<b>{1}</b>] и не числится его в участниках!",
    "en": "🚫 @{0}-app is disconnected from [<b>{1}</b>] and is not listed among the participants!",
    "es": "🚫 @{0} la aplicación está desconectada de [<b>{1}</b>] y no está en la lista de participantes!",
    "fr": "🚫 @{0}-l'application est déconnectée de [<b>{1}</b>] et ne figure pas parmi les participants !",
    "zh": "🚫 @{0} 应用已从 [<b>{1}</b>] 断开连接，并且不在参与者中！",
    "ar": "🚫 @{0} - التطبيق مفصول عن [<b>{1}</b>] ولا يُعتبر من المشاركين!",
}
l_chn_done = {
    "ru": "👮🏽 <b>Готово!</b> Проверка подписки на {0} настроена\n\nОпцию можно включить в настройках, нажав [✅☑Вкл подписку]\n\n⚙️ Команды /cmd",
    "en": "👮🏽 <b>Done!</b> Subscription check for {0} is set up\n\nYou can enable the option in settings by clicking [✅☑Enable subscription]\n\n⚙️ Commands /cmd",
    "es": "👮🏽 <b>¡Listo!</b> La verificación de la suscripción a {0} está configurada\n\nPuedes activar la opción en la configuración, haciendo clic en [✅☑Activar suscripción]\n\n⚙️ Comandos /cmd",
    "fr": "👮🏽 <b>Prêt!</b> La vérification de l'abonnement à {0} est configurée\n\nL'option peut être activée dans les paramètres en cliquant sur [✅☑Activer l'abonnement]\n\n⚙️ Commandes /cmd",
    "zh": "👮🏽 <b>完成！</b> 对 {0} 的订阅检查已设置\n\n您可以通过点击 [✅☑启用订阅] 在设置中启用此选项\n\n⚙️ 命令 /cmd",
    "ar": "👮🏽 <b>جاهز!</b> تم إعداد التحقق من الاشتراك في {0}\n\nيمكن تفعيل الخيار في الإعدادات من خلال الضغط على [✅☑تفعيل الاشتراك]\n\n⚙️ الأوامر /cmd",
}
l_ban_users_start = {
    "ru": "👩🏽‍💻 <b>Очистка</b> запущена. <b>Текущее</b> количество пользователей в базе: <u>{0}</u>",
    "en": "👩🏽‍💻 <b>Cleanup</b> started. <b>Current</b> number of users in the database: <u>{0}</u>",
    "es": "👩🏽‍💻 <b>Limpieza</b> iniciada. <b>Cantidad</b> actual de usuarios en la base: <u>{0}</u>",
    "fr": "👩🏽‍💻 <b>Nettoyage</b> en cours. <b>Nombre</b> actuel d'utilisateurs dans la base : <u>{0}</u>",
    "zh": "👩🏽‍💻 <b>清理</b> 已启动。<b>当前</b> 数据库中的用户数量：<u>{0}</u>",
    "ar": "👩🏽‍💻 <b>تم بدء</b> التنظيف. <b>العدد الحالي</b> من المستخدمين في القاعدة: <u>{0}</u>",
}
l_ban_users_stop = {
    "ru": "👩🏽‍💻 <b>Очистка</b> завершена. <b>Текущее</b> количество пользователей в базе: <u>{0}</u> (-{1})",
    "en": "👩🏽‍💻 <b>Cleanup</b> completed. <b>Current</b> number of users in the database: <u>{0}</u> (-{1})",
    "es": "👩🏽‍💻 <b>Limpieza</b> completada. <b>El número</b> actual de usuarios en la base: <u>{0}</u> (-{1})",
    "fr": "👩🏽‍💻 <b>Nettoyage</b> terminé. <b>Nombre</b> actuel d'utilisateurs dans la base : <u>{0}</u> (-{1})",
    "zh": "👩🏽‍💻 <b>清理</b> 完成。 <b>当前</b> 数据库中的用户数量：<u>{0}</u> (-{1})",
    "ar": "👩🏽‍💻 <b>تم الانتهاء من التنظيف</b>. <b>العدد الحالي</b> من المستخدمين في القاعدة: <u>{0}</u> (-{1})",
}
l_chn_delete_parse = {
    "ru": "👩🏽‍💻 <b>Введи</b> дату начала/конца для удаления подписчиков из /parse-базы:\n<code>/delete {0} {1}</code>",
    "en": "👩🏽‍💻 <b>Enter</b> the start/end date to remove subscribers from the /parse database:\n<code>/delete {0} {1}</code>",
    "es": "👩🏽‍💻 <b>Introduce</b> la fecha de inicio/final para eliminar suscriptores de la base /parse:\n<code>/delete {0} {1}</code>",
    "fr": "👩🏽‍💻 <b>Entrez</b> la date de début/fin pour supprimer des abonnés de la base /parse :\n<code>/delete {0} {1}</code>",
    "zh": "👩🏽‍💻 <b>输入</b> 删除订阅者的开始/结束日期，从 /parse 数据库中：\n<code>/delete {0} {1}</code>",
    "ar": "👩🏽‍💻 <b>أدخل</b> تاريخ البدء/النهاية لحذف المشتركين من قاعدة بيانات /parse:\n<code>/delete {0} {1}</code>",
}
l_chn_delete_start = {
    "ru": "👩🏽‍💻 <b>Начинаем</b> удаление за период:\n<code>{0}</code>\n<code>{1}</code>",
    "en": "👩🏽‍💻 <b>Starting</b> deletion for the period:\n<code>{0}</code>\n<code>{1}</code>",
    "es": "👩🏽‍💻 <b>Comenzamos</b> la eliminación por período:\n<code>{0}</code>\n<code>{1}</code>",
    "fr": "👩🏽‍💻 <b>Nous commençons</b> la suppression pour la période :\n<code>{0}</code>\n<code>{1}</code>",
    "zh": "👩🏽‍💻 <b>开始</b> 删除期间：\n<code>{0}</code>\n<code>{1}</code>",
    "ar": "👩🏽‍💻 <b>نبدأ</b> حذف الفترة:\n<code>{0}</code>\n<code>{1}</code>",
}
l_chn_delete_finish = {
    "ru": "👩🏽‍💻 <b>Удаление</b> пользователей завершено:\n<u>{0}</u> [-{1}]",
    "en": "👩🏽‍💻 <b>Deletion</b> of users is complete:  \n<u>{0}</u> [-{1}]",
    "es": "👩🏽‍💻 <b>Eliminación</b> de usuarios completada:  \n<u>{0}</u> [-{1}]",
    "fr": "👩🏽‍💻 <b>Suppression</b> des utilisateurs terminée :  \n<u>{0}</u> [-{1}]",
    "zh": "👩🏽‍💻 <b>用户删除</b> 已完成：\n<u>{0}</u> [-{1}]",
    "ar": "👩🏽‍💻 <b>حذف</b> المستخدمين مكتمل:\n<u>{0}</u> [-{1}]",
}
l_ccheck_btn_name = {
    "ru": "✔ Я человек",
    "en": "✔ I am a person",
    "es": "✔ Soy una persona",
    "fr": "✔ Je suis une personne",
    "zh": "✔ 我是一个人",
    "ar": "✔ أنا إنسان",
}
l_ccheck_hello_txt = {
    "ru": "🌱 {name}, добро пожаловать в нашу <b>канал</b> {title}!",
    "en": "🌱 {name}, welcome to our <b>channel</b> {title}!",
    "es": "🌱 {name}, ¡bienvenido a nuestro <b>canal</b> {title}!",
    "fr": "🌱 {name}, bienvenue dans notre <b>canal</b> {title} !",
    "zh": "🌱 {name}，欢迎来到我们的 <b>频道</b> {title}！",
    "ar": "🌱 {name}, مرحبًا بك في <b>القناة</b> {title}!",
}
l_ccheck_add_channel = {
    "ru": "👮🏽 Для <i>проверки подписки</i> необходимо добавить канал командой:\n\n/channel ССЫЛКА НА КАНАЛ",
    "en": "👮🏽 To <i>check the subscription</i>, you need to add the channel with the command:\n\n/channel CHANNEL LINK",
    "es": "👮🏽 Para <i>verificar la suscripción</i> es necesario agregar el canal con el comando:\n\n/channel ENLACE AL CANAL",
    "fr": "👮🏽 Pour <i>vérifier l'abonnement</i>, il est nécessaire d'ajouter le canal avec la commande :\n\n/channel LIEN VERS LE CANAL",
    "zh": "👮🏽 要进行<i>订阅检查</i>，请使用以下命令添加频道：\n\n/channel 频道链接",
    "ar": "👮🏽 ل<i>التحقق من الاشتراك</i>، يجب إضافة القناة بالأمر:\n\n/channel رابط القناة",
}
l_chn_for_sub_pay = {
    "ru": "👩🏽‍💻 Для оплаты подписки",
    "en": "👩🏽‍💻 To pay for the subscription",
    "es": "👩🏽‍💻 Para pagar la suscripción",
    "fr": "👩🏽‍💻 Pour payer l'abonnement",
    "zh": "👩🏽‍💻 订阅付款",
    "ar": "👩🏽‍💻 لدفع الاشتراك",
}
l_chn_need_boost_for_story = {
    "ru": "👩🏽‍💻 <b>Необходимо</b>: {0}-буст-голосов для публикации сториз",
    "en": "👩🏽‍💻 <b>Required</b>: {0}-boost-votes for posting stories",
    "es": "👩🏽‍💻 <b>Necesario</b>: {0}-impulso-votos para publicar historias",
    "fr": "👩🏽‍💻 <b>Nécessaire</b>: {0}-boost-voix pour publier des stories",
    "zh": "👩🏽‍💻 <b>必要</b>: {0}个投票提升用于发布故事",
    "ar": "👩🏽‍💻 <b>مطلوب</b>: {0}-تعزيز-الأصوات لنشر القصص",
}
l_chn_no_rights_for_media = {
    "ru": "👩🏽‍💻 <b>Отсутствуют</b> административные права управления приложением: {0}-покидает канал",
    "en": "👩🏽‍💻 <b>Missing</b> administrative rights to manage the application: {0} leaves the channel",
    "es": "👩🏽‍💻 <b>No hay</b> derechos administrativos para gestionar la aplicación: {0} abandona el canal",
    "fr": "👩🏽‍💻 <b>Absence</b> de droits administratifs pour gérer l'application : {0} quitte le canal",
    "zh": "👩🏽‍💻 <b>缺少</b> 应用程序管理的管理员权限: {0} - 离开频道",
    "ar": "👩🏽‍💻 <b>لا توجد</b> حقوق إدارية لإدارة التطبيق: {0} يغادر القناة",
}
l_chn_collection_name = {
    "ru": "Коллекция постов канала",
    "en": "Channel post collection",
    "es": "Colección de publicaciones del canal",
    "fr": "Collection de publications de la chaîne",
    "zh": "频道帖子集合",
    "ar": "مجموعة منشورات القناة",
}
l_chn_collection_desc = {
    "ru": "Уникальные nft-посты, привязанные к реальным id-постам канала",
    "en": "Unique NFT posts linked to real channel post IDs",
    "es": "Publicaciones nft únicas, vinculadas a id de publicaciones reales del canal",
    "fr": "Des publications nft uniques, liées aux id de publications réelles du canal",
    "zh": "与频道真实帖子ID绑定的独特NFT帖子",
    "ar": "مشاركات nft الفريدة المرتبطة بمعرفات المشاركات الحقيقية لقناة",
}
l_chn_collection_address = {
    "ru": "👩🏽‍💻 <b>Адрес</b> коллекции:",
    "en": "👩🏽‍💻 <b>Collection</b> address:",
    "es": "👩🏽‍💻 <b>Dirección</b> de la colección:",
    "fr": "👩🏽‍💻 <b>Adresse</b> de la collection :",
    "zh": "👩🏽‍💻 <b>集合</b> 地址：",
    "ar": "👩🏽‍💻 <b>عنوان</b> المجموعة:",
}
l_chn_post_already_in_col = {
    "ru": "👩🏽‍💻 Пост уже в коллекции",
    "en": "👩🏽‍💻 The post is already in the collection",
    "es": "👩🏽‍💻 La publicación ya está en la colección",
    "fr": "👩🏽‍💻 Le post est déjà dans la collection",
    "zh": "👩🏽‍💻 文章已在收藏中",
    "ar": "👩🏽‍💻 المنشور موجود بالفعل في المجموعة",
}
l_chn_no_nft_logo = {
    "ru": "👩🏽‍💻 Генерация NFT-поста, повторите попытку позже",
    "en": "👩🏽‍💻 NFT post generation, please try again later",
    "es": "👩🏽‍💻 Generación de la publicación NFT, inténtelo de nuevo más tarde",
    "fr": "👩🏽‍💻 Génération de post NFT, veuillez réessayer plus tard",
    "zh": "👩🏽‍💻 生成NFT帖子，请稍后再试",
    "ar": "👩🏽‍💻 توليد منشور NFT، يرجى المحاولة لاحقًا",
}
l_chn_jetton_of_channel = {
    "ru": "Токен канала:",
    "en": "Channel token:",
    "es": "Token del canal:",
    "fr": "Jeton de canal :",
    "zh": "频道令牌：",
    "ar": "رمز القناة:",
}
l_chn_jetton_master_address = {
    "ru": "👩🏽‍💻 <b>Адрес</b> мастера-токена:",
    "en": "👩🏽‍💻 <b>Master token</b> address:",
    "es": "👩🏽‍💻 <b>Dirección</b> del maestro-token:",
    "fr": "👩🏽‍💻 <b>Adresse</b> du maître-token :",
    "zh": "👩🏽‍💻 <b>令牌大师的地址</b>:",
    "ar": "👩🏽‍💻 <b>عنوان</b> خبير الرمز:",
}
l_chn_detach = {
    "ru": "👩🏽‍💻 Открепить nft от",
    "en": "👩🏽‍💻 Unpin nft from",
    "es": "👩🏽‍💻 Desvincular nft de",
    "fr": "👩🏽‍💻 Détacher le nft de",
    "zh": "👩🏽‍💻 从中解除 nft 绑定",
    "ar": "👩🏽‍💻 إلغاء تثبيت nft من",
}
l_chn_err_transfer_rights = {
    "ru": "👩🏽‍💻 <b>Ошибка</b> передачи прав: оба участника должны быть администраторами канала и запустить @{0}",
    "en": "👩🏽‍💻 <b>Error</b> transferring rights: both participants must be channel administrators and start @{0}",
    "es": "👩🏽‍💻 <b>Error</b> de transferencia de derechos: ambos participantes deben ser administradores del canal y ejecutar @{0}",
    "fr": "👩🏽‍💻 <b>Erreur</b> de transfert de droits : les deux participants doivent être des administrateurs du canal et lancer @{0}",
    "zh": "👩🏽‍💻 <b>权限</b> 传递错误：两个参与者都必须是频道管理员并启动 @{0}",
    "ar": "👩🏽‍💻 <b>خطأ</b> في نقل الحقوق: يجب أن يكون كلا المشاركين مديري قناة وتشغيل @{0}",
}
# endregion


# region FereyGroupBot
l_grp_btn1 = {
    "ru": "➕ Группа",
    "en": "➕ Group",
    "es": "➕ Grupo",
    "fr": "➕ Groupe",
    "zh": "➕ 组",
    "ar": "➕ مجموعة",
}
l_grp_btn2 = {
    "ru": "💨 Подписка",
    "en": "💨 Subscription",
    "es": "💨 Suscripción",
    "fr": "💨 Abonnement",
    "zh": "💨 订阅",
    "ar": "💨 الاشتراك",
}
l_grp_welcome = {
    "ru": "🌱 <b>{0}</b>, добро пожаловать в <i>@tg-приложение</i> модерации <b>Telegram</b>-групп:\n\n<blockquote>▪️платная подписка и донаты\n▪️<b>голосование</b>/бан-ограничения\n▪️NFT-диалоги и блокчейн геймификация\n▪️нейро-диалог и стоп-слова\n▪️веб/платный постинг</blockquote>",
    "en": "🌱 <b>{0}</b>, welcome to the <i>@tg-app</i> moderation of <b>Telegram</b> groups:\n\n<blockquote>▪️paid subscription and donations\n▪️<b>voting</b>/ban restrictions\n▪️NFT dialogues and blockchain gamification\n▪️neuro-dialogue and stop words\n▪️web/paid posting</blockquote>",
    "es": "🌱 <b>{0}</b>, bienvenido a <i>@tg-aplicación</i> de moderación de grupos de <b>Telegram</b>:\n\n<blockquote>▪️suscripción paga y donaciones\n▪️<b>votación</b>/restricciones de baneo\n▪️diálogos NFT y gamificación en blockchain\n▪️diálogo neuro y palabras prohibidas\n▪️publicación web/paga</blockquote>",
    "fr": "🌱 <b>{0}</b>, bienvenue dans l<i>@tg-application</i> de modération des groupes <b>Telegram</b> :\n\n<blockquote>▪️abonnement payant et dons\n▪️<b>vote</b>/restrictions de ban\n▪️dialogues NFT et gamification blockchain\n▪️dialogue neuro et mots d'arrêt\n▪️publication web/payante</blockquote>",
    "zh": "🌱 <b>{0}</b>, 欢迎来到 <i>@tg-应用程序</i> 的 <b>Telegram</b> 群组管理：\n\n<blockquote>▪️付费订阅和捐赠\n▪️<b>投票</b>/禁令限制\n▪️NFT对话和区块链游戏化\n▪️神经对话和禁用词\n▪️网页/付费发布</blockquote>",
    "ar": "🌱 <b>{0}</b>, مرحبًا بك في <i>@tg-تطبيق</i> إدارة مجموعات <b>Telegram</b>:\n\n<blockquote>▪️اشتراك مدفوع وتبرعات\n▪️<b>تصويت</b>/قيود الحظر\n▪️حوارات NFT وألعاب البلوكشين\n▪️حوار عصبي وكلمات توقف\n▪️نشر ويب/مدفوع</blockquote>",
}
l_cmd_txt_grp = {
    "ru": "👩🏽‍💻 <b>Жми</b> [➕ Добавить группу]",
    "en": "👩🏽‍💻 <b>Click</b> [➕ Add group]",
    "es": "👩🏽‍💻 <b>Haz clic</b> [➕ Añadir grupo]",
    "fr": "👩🏽‍💻 <b>Clique</b> [➕ Ajouter un groupe]",
    "zh": "👩🏽‍💻 <b>点击</b> [➕ 添加组]",
    "ar": "👩🏽‍💻 <b>اضغط</b> [➕ إضافة مجموعة]",
}
l_add_group_text = {
    "ru": "👇🏽 <b>Жми</b> на [➕ Добавить группу], чтобы добавить в свою группу (с настройками по ум) приложение: @{0}\n\n<blockquote>👮🏽‍♀️ <b>Или</b> добавь приложение как [<b>Администратор</b>] через настройки своей группы:\n[👤 Добавить администратора]\n\n👮🏽‍♀️ <b>Если</b> не добавляется группа, то измени <b>Должность</b> (см. скрин)</blockquote>",
    "en": "👇🏽 <b>Click</b> on [➕ Add group] to add the application to your group (with default settings): @{0}\n\n<blockquote>👮🏽‍♀️ <b>Or</b> add the application as [<b>Administrator</b>] through your group's settings:\n[👤 Add administrator]\n\n👮🏽‍♀️ <b>If</b> the group cannot be added, then change the <b>Position</b> (see screenshot)</blockquote>",
    "es": "👇🏽 <b>Haz clic</b> en [➕ Agregar grupo], para añadir a tu grupo (con la configuración predeterminada) la aplicación: @{0}\n\n<blockquote>👮🏽‍♀️ <b>O</b> añade la aplicación como [<b>Administrador</b>] a través de la configuración de tu grupo:\n[👤 Agregar administrador]\n\n👮🏽‍♀️ <b>Si</b> no se puede añadir el grupo, cambia <b>Posición</b> (ver captura de pantalla)</blockquote>",
    "fr": "👇🏽 <b>Clique</b> sur [➕ Ajouter un groupe], pour ajouter à ton groupe (avec les paramètres par défaut) l'application : @{0}\n\n<blockquote>👮🏽‍♀️ <b>Ou</b> ajoute l'application en tant que [<b>Administrateur</b>] via les paramètres de ton groupe :\n[👤 Ajouter un administrateur]\n\n👮🏽‍♀️ <b>Si</b> le groupe ne s'ajoute pas, change <b>le Poste</b> (voir la capture d'écran)</blockquote>",
    "zh": "👇🏽 <b>点击</b> [➕ 添加组]，以将应用程序添加到您的组（默认设置）：@{0}\n\n<blockquote>👮🏽‍♀️ <b>或者</b>通过您的组设置将应用程序添加为 [<b>管理员</b>]：\n[👤 添加管理员]\n\n👮🏽‍♀️ <b>如果</b>组无法添加，请更改 <b>职位</b>（请参见截图）</blockquote>",
    "ar": "👇🏽 <b>اضغط</b> على [➕ إضافة مجموعة] لإضافة التطبيق إلى مجموعتك (مع إعدادات افتراضية): @{0}\n\n<blockquote>👮🏽‍♀️ <b>أو</b> أضف التطبيق كـ [<b>مدير</b>] من خلال إعدادات مجموعتك:\n[👤 إضافة مدير]\n\n👮🏽‍♀️ <b>إذا</b> لم تتم إضافة المجموعة، فقم بتغيير <b>الوظيفة</b> (انظر الصورة)</blockquote>",
}
l_add_group_button = {
    "ru": "➕ Добавить группу",
    "en": "➕ Add group",
    "es": "➕ Añadir grupo",
    "fr": "➕ Ajouter un groupe",
    "zh": "➕ 添加组",
    "ar": "➕ إضافة مجموعة",
}
l_grp_already_taken = {
    "ru": "👮🏽 <b>Группа</b> [<b>{0}</b>] уже <i>модерируется</i> в @{1}-приложении",
    "en": "👮🏽 <b>Group</b> [<b>{0}</b>] is already <i>being moderated</i> in the @{1} app",
    "es": "👮🏽 <b>Grupo</b> [<b>{0}</b>] ya está <i>moderando</i> en la aplicación @{1}",
    "fr": "👮🏽 <b>Groupe</b> [<b>{0}</b>] est déjà <i>modéré</i> dans l'application @{1}",
    "zh": "👮🏽 <b>组</b> [<b>{0}</b>] 已经 <i>正在审核</i> 在 @{1} 应用程序中",
    "ar": "👮🏽 <b>المجموعة</b> [<b>{0}</b>] يتم <i>تعديلها</i> بالفعل في تطبيق @{1}",
}
l_grp_subscribe_call = {
    "ru": "👩🏽‍💻 Необходима подписка на группу",
    "en": "👩🏽‍💻 Subscription to the group is required",
    "es": "👩🏽‍💻 Se requiere una suscripción al grupo",
    "fr": "👩🏽‍💻 Un abonnement au groupe est nécessaire",
    "zh": "👩🏽‍💻 需要订阅该小组",
    "ar": "👩🏽‍💻 تحتاج إلى الاشتراك في المجموعة",
}
l_groups = {
    "ru": "👩🏽‍💻 Группы",
    "en": "👩🏽‍💻 Groups",
    "es": "👩🏽‍💻 Grupos",
    "fr": "👩🏽‍💻 Groupes",
    "zh": "👩🏽‍💻 群组",
    "ar": "👩🏽‍💻 المجموعات",
}
l_add_grp_button = {
    "ru": "➕ Добавить группу",
    "en": "➕ Add group",
    "es": "➕ Añadir grupo",
    "fr": "➕ Ajouter un groupe",
    "zh": "➕ 添加组",
    "ar": "➕ إضافة مجموعة",
}
l_add_grp_text = {
    "ru": "👮🏽‍♀️ <b>Добавь</b> @{0}-приложение как [<b>Администратор</b>] через настройки своей группы:\n\n<blockquote>[👤 Добавить администратора]</blockquote>",
    "en": "👮🏽‍♀️ <b>Add</b> the @{0} app as [<b>Administrator</b>] through your group settings:\n\n<blockquote>[👤 Add administrator]</blockquote>",
    "es": "👮🏽‍♀️ <b>Agrega</b> @{0} la aplicación como [<b>Administrador</b>] a través de la configuración de tu grupo:\n\n<blockquote>[👤 Agregar administrador]</blockquote>",
    "fr": "👮🏽‍♀️ <b>Ajoute</b> @{0} l'application en tant que [<b>Administrateur</b>] via les paramètres de ton groupe :\n\n<blockquote>[👤 Ajouter un administrateur]</blockquote>",
    "zh": "👮🏽‍♀️ <b>添加</b> @{0} 应用程序作为 [<b>管理员</b>] 通过你的群组设置：\n\n<blockquote>[👤 添加管理员]</blockquote>",
    "ar": "👮🏽‍♀️ <b>أضف</b> @{0} - التطبيق كـ [<b>مدير</b>] من خلال إعدادات مجموعتك:\n\n<blockquote>[👤 إضافة مدير]</blockquote>",
}
l_add_grp_txt_call = {
    "ru": "👮🏽‍♀️ Добавь @{0}-приложение как Администратора через настройки своей группы: [👤Добавить администратора]",
    "en": "👮🏽‍♀️ Add the @{0} app as an Administrator through your group settings: [👤Add administrator]",
    "es": "👮🏽‍♀️ Agrega la aplicación @{0} como Administrador a través de la configuración de tu grupo: [👤Agregar administrador]",
    "fr": "👮🏽‍♀️ Ajoute l'application @{0} en tant qu'administrateur via les paramètres de ton groupe : [👤Ajouter un administrateur]",
    "zh": "👮🏽‍♀️ 通过你的群组设置将 @{0} 应用添加为管理员: [👤添加管理员]",
    "ar": "👮🏽‍♀️ أضف تطبيق @{0} كمدير من خلال إعدادات مجموعتك: [👤إضافة مدير]",
}
l_grp_check = {
    "ru": "👩🏽‍💻 <b>Добавь</b> @{0}-приложение в группу для проверки подписки на нее. Отправь мне корректную ссылку на канал:",
    "en": "👩🏽‍💻 <b>Add</b> the @{0} app to the group for subscription verification. Send me the correct link to the channel:",
    "es": "👩🏽‍💻 <b>Agrega</b> la aplicación @{0} al grupo para verificar la suscripción a ella. Envíame el enlace correcto al canal:",
    "fr": "👩🏽‍💻 <b>Ajoute</b> l'application @{0} au groupe pour vérifier l'abonnement. Envoie-moi le lien correct vers la chaîne :",
    "zh": "👩🏽‍💻 <b>添加</b> @{0} 应用程序到组以检查其订阅。请给我发送正确的频道链接：",
    "ar": "👩🏽‍💻 <b>أضف</b> @{0} - التطبيق إلى المجموعة للتحقق من الاشتراك فيه. أرسل لي الرابط الصحيح للقناة:",
}
l_grp_info_start1 = {
    "ru": "👩🏽‍💻 <b>Информация</b>\n\n<b>Название</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> участ.]{5}{6}{7}",
    "en": "👩🏽‍💻 <b>Information</b>\n\n<b>Name</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> participants.]{5}{6}{7}",
    "es": "👩🏽‍💻 <b>Información</b>\n\n<b>Nombre</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> part.]{5}{6}{7}",
    "fr": "👩🏽‍💻 <b>Informations</b>\n\n<b>Nom</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> part.]{5}{6}{7}",
    "zh": "👩🏽‍💻 <b>信息</b>\n\n<b>名称</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> 参与者.]{5}{6}{7}",
    "ar": "👩🏽‍💻 <b>معلومات</b>\n\n<b>الاسم</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> مشارك.]{5}{6}{7}",
}
l_grp_stat_start1 = {
    "ru": "👩🏽‍💻 <b>Аналитика</b>\n\n<b>Название</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> участ.]{5}{6}{7}",
    "en": "👩🏽‍💻 <b>Analytics</b>\n\n<b>Name</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> participants.]{5}{6}{7}",
    "es": "👩🏽‍💻 <b>Analítica</b>\n\n<b>Nombre</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> part.]{5}{6}{7}",
    "fr": "👩🏽‍💻 <b>Analyse</b>\n\n<b>Nom</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> part.]{5}{6}{7}",
    "zh": "👩🏽‍💻 <b>分析</b>\n\n<b>名称</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> 参与者.]{5}{6}{7}",
    "ar": "👩🏽‍💻 <b>التحليل</b>\n\n<b>الاسم</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> المشاركين.]{5}{6}{7}",
}
l_grp_stat_start2 = {
    "ru": "\n<b>Ссылка</b>: {0}\n<b>Описание</b>: {1}\n<b>Привязанный канал</b>: <code>{2}</code>\n",
    "en": "<b>Link</b>: {0}  \n<b>Description</b>: {1}  \n<b>Attached channel</b>: <code>{2}</code>",
    "es": "<b>Enlace</b>: {0}  \n<b>Descripción</b>: {1}  \n<b>Canal vinculado</b>: <code>{2}</code>",
    "fr": "<b>Lien</b>: {0}  \n<b>Description</b>: {1}  \n<b>Canal associé</b>: <code>{2}</code>",
    "zh": "<b>链接</b>: {0}  \n<b>描述</b>: {1}  \n<b>绑定频道</b>: <code>{2}</code>",
    "ar": "<b>الرابط</b>: {0}  \n<b>الوصف</b>: {1}  \n<b>القناة المرتبطة</b>: <code>{2}</code>",
}
l_grp_stat_start3 = {
    "ru": "\n<b>ID последнего поста</b>: {0}\n<b>Посты</b>: {1}\n<b>Реакции</b>: {2}\n<b>Просмотры</b>: {3}\n<b>кѻмментарии</b>: {4}\n<b>$кэштеги</b>: {5}\n<b>#hashtag</b>: {6}\n",
    "en": "<b>Last post ID</b>: {0}  \n<b>Posts</b>: {1}  \n<b>Reactions</b>: {2}  \n<b>Views</b>: {3}  \n<b>Comments</b>: {4}  \n<b>$hashtags</b>: {5}  \n<b>#hashtag</b>: {6}",
    "es": "<b>ID de la última publicación</b>: {0}  \n<b>Publicaciones</b>: {1}  \n<b>Reacciones</b>: {2}  \n<b>Vistas</b>: {3}  \n<b>comentarios</b>: {4}  \n<b>$etiquetas</b>: {5}  \n<b>#hashtag</b>: {6}",
    "fr": "<b>ID du dernier post</b>: {0}  \n<b>Posts</b>: {1}  \n<b>Réactions</b>: {2}  \n<b>Vues</b>: {3}  \n<b>Commentaires</b>: {4}  \n<b>$hashtags</b>: {5}  \n<b>#hashtag</b>: {6}",
    "zh": "<b>最后帖子ID</b>: {0}  \n<b>帖子</b>: {1}  \n<b>反应</b>: {2}  \n<b>浏览次数</b>: {3}  \n<b>评论</b>: {4}  \n<b>$标签</b>: {5}  \n<b>#话题标签</b>: {6}",
    "ar": "<b>معرف آخر منشور</b>: {0}  \n<b>المنشورات</b>: {1}  \n<b>ردود الفعل</b>: {2}  \n<b>المشاهدات</b>: {3}  \n<b>التعليقات</b>: {4}  \n<b>$الهاشتاجات</b>: {5}  \n<b>#هاشتاج</b>: {6}",
}
l_grp_commands_handler = {
    "ru": "⚙️ <b>Команды</b> /cmd для [<b>{0}</b>] {1} [<code>{2}</code>]\n\n<blockquote>/info информация о группе\n/stat статистика\n\n/parse [1] база подписчиков/лайков поста #1\n/random [1] рандомный лайкнувший пост #1\n/podcast 1 1 анонс видео-подкаста\n<code>/clean</code> очистка от deleted/scam-аккаунтов и по [<b>🕵🏽 Авто-бан</b>] правилам\n/delete <code>FROM TO</code> удаление за период\n/channel NAME канал проверки подписки\n/transfer передача ADMIN-прав</blockquote>\n\n💨 <b>Подписка</b>: <i>{3}</i>",
    "en": "⚙️ <b>Commands</b> /cmd for [<b>{0}</b>] {1} [<code>{2}</code>]\n\n<blockquote>/info information about the group\n/stat statistics\n\n/parse [1] subscriber/like database for post #1\n/random [1] random liker of post #1\n/podcast 1 1 video podcast announcement\n<code>/clean</code> cleaning from deleted/scam accounts and by [<b>🕵🏽 Auto-ban</b>] rules\n/delete <code>FROM TO</code> deletion for the period\n/channel NAME subscription check channel\n/transfer transfer ADMIN rights</blockquote>\n\n💨 <b>Subscription</b>: <i>{3}</i>",
    "es": "⚙️ <b>Comandos</b> /cmd para [<b>{0}</b>] {1} [<code>{2}</code>]\n\n<blockquote>/info información sobre el grupo\n/stat estadísticas\n\n/parse [1] base de suscriptores/me gusta del post #1\n/random [1] usuario aleatorio que le dio me gusta al post #1\n/podcast 1 1 anuncio del video-podcast\n<code>/clean</code> limpieza de cuentas eliminadas/scam y según las reglas de [<b>🕵🏽 Auto-baneo</b>]\n/delete <code>FROM TO</code> eliminación por período\n/channel NAME canal de verificación de suscripción\n/transfer transferencia de derechos ADMIN</blockquote>\n\n💨 <b>Suscripción</b>: <i>{3}</i>",
    "fr": "⚙️ <b>Commandes</b> /cmd pour [<b>{0}</b>] {1} [<code>{2}</code>]\n\n<blockquote>/info informations sur le groupe\n/stat statistiques\n\n/parse [1] base d'abonnés/likes du post #1\n/random [1] utilisateur ayant aimé le post #1 au hasard\n/podcast 1 1 annonce de la vidéo-podcast\n<code>/clean</code> nettoyage des comptes supprimés/scam et selon les règles [<b>🕵🏽 Auto-ban</b>]\n/delete <code>FROM TO</code> suppression sur une période\n/channel NAME canal de vérification d'abonnement\n/transfer transfert des droits ADMIN</blockquote>\n\n💨 <b>Abonnement</b> : <i>{3}</i>",
    "zh": "⚙️ <b>命令</b> /cmd для [<b>{0}</b>] {1} [<code>{2}</code>]\n\n<blockquote>/info 群组信息\n/stat 统计\n\n/parse [1] 订阅者/点赞者数据库 поста #1\n/random [1] 随机点赞 поста #1\n/podcast 1 1 视频播客预告\n<code>/clean</code> 清除 deleted/scam-账户和根据 [<b>🕵🏽 自动禁令</b>] 规则\n/delete <code>FROM TO</code> 在指定期间内删除\n/channel NAME 订阅检查频道\n/transfer 转移 ADMIN 权限</blockquote>\n\n💨 <b>订阅</b>: <i>{3}</i>",
    "ar": "⚙️ <b>الأوامر</b> /cmd لـ [<b>{0}</b>] {1} [<code>{2}</code>]\n\n<blockquote>/info معلومات عن المجموعة\n/stat إحصائيات\n\n/parse [1] قاعدة المشتركين/الإعجابات للمنشور #1\n/random [1] شخص عشوائي أعجب بالمنشور #1\n/podcast 1 1 إعلان فيديو البودكاست\n<code>/clean</code> تنظيف من الحسابات المحذوفة/المحتالة ووفقًا لقواعد [<b>🕵🏽 الحظر التلقائي</b>]\n/delete <code>FROM TO</code> الحذف لفترة معينة\n/channel NAME قناة التحقق من الاشتراك\n/transfer نقل صلاحيات ADMIN</blockquote>\n\n💨 <b>الاشتراك</b>: <i>{3}</i>",
}
l_change_grp_info = {
    "ru": "Изменение профиля группы",
    "en": "Group profile change",
    "es": "Cambio de perfil del grupo",
    "fr": "Changement de profil de groupe",
    "zh": "更改组配置文件",
    "ar": "تغيير ملف تعريف المجموعة",
}
l_grp_graph_yes = {
    "ru": "👩🏽‍💻 <b>Экстра</b>-статистика группы за неделю [{0}]\n\n▪️ Подписчики: {1} ({2}{3})\n▪️ Просмотры: {4} ({5}{6})\n▪️ Поделиться: {7} ({8}{9})\n▪️ Уведомления у {10}% подписчиков\n",
    "en": "👩🏽‍💻 <b>Extra</b> group statistics for the week [{0}]\n\n▪️ Subscribers: {1} ({2}{3})\n▪️ Views: {4} ({5}{6})\n▪️ Share: {7} ({8}{9})\n▪️ Notifications for {10}% of subscribers",
    "es": "👩🏽‍💻 <b>Estadísticas</b> extra del grupo por semana [{0}]\n\n▪️ Suscriptores: {1} ({2}{3})\n▪️ Vistas: {4} ({5}{6})\n▪️ Compartir: {7} ({8}{9})\n▪️ Notificaciones para el {10}% de los suscriptores",
    "fr": "👩🏽‍💻 <b>Statistiques</b> supplémentaires du groupe pour la semaine [{0}]\n\n▪️ Abonnés : {1} ({2}{3})\n▪️ Vues : {4} ({5}{6})\n▪️ Partager : {7} ({8}{9})\n▪️ Notifications pour {10}% des abonnés",
    "zh": "👩🏽‍💻 <b>额外</b> - 一周小组统计 [{0}]\n\n▪️ 订阅者: {1} ({2}{3})\n▪️ 浏览量: {4} ({5}{6})\n▪️ 分享: {7} ({8}{9})\n▪️ {10}% 的订阅者收到通知",
    "ar": "👩🏽‍💻 <b>إحصائيات</b> المجموعة الإضافية للأسبوع [{0}]\n\n▪️ المشتركين: {1} ({2}{3})\n▪️ المشاهدات: {4} ({5}{6})\n▪️ المشاركة: {7} ({8}{9})\n▪️ الإشعارات لدى {10}% من المشتركين",
}
l_grp_graph_no = {
    "ru": "👩🏽‍💻 <b>Вкл</b> [✅ Назначение администраторов] для @{0}, чтобы вывести <b>экстра</b>-графику группы за неделю",
    "en": "👩🏽‍💻 <b>On</b> [✅ Assign Administrators] for @{0} to display the <b>extra</b> group graphics for the week",
    "es": "👩🏽‍💻 <b>Activar</b> [✅ Asignación de administradores] para @{0}, para mostrar la <b>extra</b> gráfica del grupo de la semana",
    "fr": "👩🏽‍💻 <b>Activer</b> [✅ Attribution des administrateurs] pour @{0}, afin de générer la <b>graphique</b> supplémentaire du groupe pour la semaine",
    "zh": "👩🏽‍💻 <b>开启</b> [✅ 管理员分配] 给 @{0}，以便在一周内显示该组的 <b>额外</b> 图形",
    "ar": "👩🏽‍💻 <b>تشغيل</b> [✅ تعيين المسؤولين] لـ @{0} لعرض <b>الرسوم البيانية</b> الإضافية للمجموعة خلال الأسبوع",
}
l_grp_boost_call = {
    "ru": "👩🏽‍💻 Необходим буст-голос за группу",
    "en": "👩🏽‍💻 A boost-voice for the group is needed",
    "es": "👩🏽‍💻 Se necesita un boost-voz para el grupo",
    "fr": "👩🏽‍💻 Un boost vocal est nécessaire pour le groupe",
    "zh": "👩🏽‍💻 需要为小组提供提升声音",
    "ar": "👩🏽‍💻 تحتاج إلى تعزيز صوت المجموعة",
}
l_grp_need_sub_for_more_than_1_grp = {
    "ru": "👩🏽‍💻 <b>Оформи</b> подписку, чтобы добавлять более 1 группы",
    "en": "👩🏽‍💻 <b>Subscribe</b> to add more than 1 group",
    "es": "👩🏽‍💻 <b>Suscríbete</b> para agregar más de 1 grupo",
    "fr": "👩🏽‍💻 <b>Abonnez-vous</b> pour ajouter plus d'un groupe",
    "zh": "👩🏽‍💻 <b>订阅</b> 以添加超过 1 个组",
    "ar": "👩🏽‍💻 <b>اشترك</b> لإضافة أكثر من مجموعة واحدة",
}
l_grp_need_sub_for_more_than_2_grp = {
    "ru": "👩🏽‍💻 <b>Оформи</b> подписку, чтобы добавлять более 2 групп",
    "en": "👩🏽‍💻 <b>Subscribe</b> to add more than 2 groups",
    "es": "👩🏽‍💻 <b>Suscríbete</b> para agregar más de 2 grupos",
    "fr": "👩🏽‍💻 <b>Abonnez-vous</b> pour ajouter plus de 2 groupes",
    "zh": "👩🏽‍💻 <b>订阅</b> 以添加超过 2 个组",
    "ar": "👩🏽‍💻 <b>اشترك</b> لإضافة أكثر من مجموعتين",
}
l_grp_delete_parse = {
    "ru": "👩🏽‍💻 <b>Введи</b> дату начала/конца для удаления подписчиков из /parse-базы:\n<code>/delete {0} {1}</code>",
    "en": "👩🏽‍💻 <b>Enter</b> the start/end date to remove subscribers from the /parse database:\n<code>/delete {0} {1}</code>",
    "es": "👩🏽‍💻 <b>Introduce</b> la fecha de inicio/final para eliminar suscriptores de la base /parse:\n<code>/delete {0} {1}</code>",
    "fr": "👩🏽‍💻 <b>Entrez</b> la date de début/fin pour supprimer des abonnés de la base /parse :\n<code>/delete {0} {1}</code>",
    "zh": "👩🏽‍💻 <b>输入</b> 开始/结束日期以从 /parse 数据库中删除订阅者：\n<code>/delete {0} {1}</code>",
    "ar": "👩🏽‍💻 <b>أدخل</b> تاريخ البدء/النهاية لحذف المشتركين من قاعدة بيانات /parse:\n<code>/delete {0} {1}</code>",
}
l_grp_delete_start = {
    "ru": "👩🏽‍💻 <b>Начинаем</b> удаление за период:\n<code>{0}</code>\n<code>{1}</code>",
    "en": "👩🏽‍💻 <b>Starting</b> deletion for the period:\n<code>{0}</code>\n<code>{1}</code>",
    "es": "👩🏽‍💻 <b>Comenzamos</b> la eliminación por período:\n<code>{0}</code>\n<code>{1}</code>",
    "fr": "👩🏽‍💻 <b>Nous commençons</b> la suppression pour la période :\n<code>{0}</code>\n<code>{1}</code>",
    "zh": "👩🏽‍💻 <b>开始</b> 删除期间：\n<code>{0}</code>\n<code>{1}</code>",
    "ar": "👩🏽‍💻 <b>نبدأ</b> حذف الفترة:\n<code>{0}</code>\n<code>{1}</code>",
}
l_grp_delete_finish = {
    "ru": "👩🏽‍💻 <b>Удаление</b> пользователей завершено:\n<u>{0}</u> [-{1}]",
    "en": "👩🏽‍💻 <b>Deletion</b> of users is complete:  \n<u>{0}</u> [-{1}]",
    "es": "👩🏽‍💻 <b>Eliminación</b> de usuarios completada:  \n<u>{0}</u> [-{1}]",
    "fr": "👩🏽‍💻 <b>Suppression</b> des utilisateurs terminée :  \n<u>{0}</u> [-{1}]",
    "zh": "👩🏽‍💻 <b>用户删除</b> 已完成：\n<u>{0}</u> [-{1}]",
    "ar": "👩🏽‍💻 <b>حذف</b> المستخدمين مكتمل:\n<u>{0}</u> [-{1}]",
}
l_ccheck_add_group = {
    "ru": "👮🏽 Для <i>проверки подписки</i> необходимо добавить группу командой:\n\n/group ССЫЛКА НА ГРУППУ",
    "en": "👮🏽 To <i>check the subscription</i>, you need to add the group with the command:\n\n/group GROUP LINK",
    "es": "👮🏽 Para <i>verificar la suscripción</i> es necesario agregar el grupo con el comando:\n\n/group ENLACE AL GRUPO",
    "fr": "👮🏽 Pour <i>vérifier l'abonnement</i>, il est nécessaire d'ajouter le groupe avec la commande :\n\n/group LIEN VERS LE GROUPE",
    "zh": "👮🏽 要进行<i>订阅检查</i>，需要添加一个组，命令为：\n\n/group 群组链接",
    "ar": "👮🏽 ل<i>التحقق من الاشتراك</i>، يجب إضافة المجموعة باستخدام الأمر:\n\n/group رابط المجموعة",
}
l_grp_for_sub_pay = {
    "ru": "👩🏽‍💻 Для оплаты подписки",
    "en": "👩🏽‍💻 To pay for the subscription",
    "es": "👩🏽‍💻 Para pagar la suscripción",
    "fr": "👩🏽‍💻 Pour payer l'abonnement",
    "zh": "👩🏽‍💻 订阅付款",
    "ar": "👩🏽‍💻 لدفع الاشتراك",
}
l_grp_need_boost_for_story = {
    "ru": "👩🏽‍💻 <b>Необходимо</b>: {0}-буст-голосов для публикации сториз",
    "en": "👩🏽‍💻 <b>Required</b>: {0}-boost-votes for posting stories",
    "es": "👩🏽‍💻 <b>Necesario</b>: {0}-impulso-votos para publicar historias",
    "fr": "👩🏽‍💻 <b>Nécessaire</b>: {0}-boost-voix pour publier des stories",
    "zh": "👩🏽‍💻 <b>必要</b>: {0}个投票提升用于发布故事",
    "ar": "👩🏽‍💻 <b>مطلوب</b>: {0}-تعزيز-الأصوات لنشر القصص",
}
l_grp_no_rights_for_media = {
    "ru": "👩🏽‍💻 <b>Отсутствуют</b> административные права управления приложением: {0}-покидает группу",
    "en": "👩🏽‍💻 <b>Missing</b> administrative rights to manage the application: {0} leaves the group",
    "es": "👩🏽‍💻 <b>No hay</b> derechos administrativos para gestionar la aplicación: {0}-deja el grupo",
    "fr": "👩🏽‍💻 <b>Absence</b> de droits administratifs pour gérer l'application : {0} quitte le groupe",
    "zh": "👩🏽‍💻 <b>缺少</b> 应用程序管理的管理员权限: {0}-离开组",
    "ar": "👩🏽‍💻 <b>لا توجد</b> حقوق إدارية لإدارة التطبيق: {0} - يغادر المجموعة",
}
l_grp_collection_name = {
    "ru": "Коллекция NFT-диалогов группы",
    "en": "NFT Dialogs Group Collection",
    "es": "Colección de diálogos NFT del grupo",
    "fr": "Collection de dialogues NFT du groupe",
    "zh": "群组NFT对话集",
    "ar": "مجموعة محادثات NFT",
}
l_grp_collection_desc = {
    "ru": "NFT-диалоги, привязанные к реальным сообщениям группы",
    "en": "NFT dialogues linked to real group messages",
    "es": "Diálogos NFT vinculados a mensajes reales del grupo",
    "fr": "NFT-dialogues liés aux messages réels du groupe",
    "zh": "与群组真实消息相关的NFT对话",
    "ar": "NFT-الحوارات المرتبطة بالرسائل الحقيقية للمجموعة",
}
l_grp_collection_address = {
    "ru": "👩🏽‍💻 <b>Адрес</b> коллекции:",
    "en": "👩🏽‍💻 <b>Collection</b> address:",
    "es": "👩🏽‍💻 <b>Dirección</b> de la colección:",
    "fr": "👩🏽‍💻 <b>Adresse</b> de la collection :",
    "zh": "👩🏽‍💻 <b>集合</b> 地址：",
    "ar": "👩🏽‍💻 <b>عنوان</b> المجموعة:",
}
l_grp_post_already_in_col = {
    "ru": "👩🏽‍💻 NFT-диалог уже в коллекции",
    "en": "👩🏽‍💻 NFT-dialogue is already in the collection",
    "es": "👩🏽‍💻 El diálogo NFT ya está en la colección",
    "fr": "👩🏽‍💻 Le dialogue NFT est déjà dans la collection",
    "zh": "👩🏽‍💻 NFT对话已经在收藏中",
    "ar": "👩🏽‍💻 حوار NFT موجود بالفعل في المجموعة",
}
l_grp_no_nft_logo = {
    "ru": "👩🏽‍💻 Генерация NFT-диалогов, повторите попытку позже",
    "en": "👩🏽‍💻 Generating NFT dialogues, please try again later",
    "es": "👩🏽‍💻 Generación de diálogos NFT, inténtalo de nuevo más tarde",
    "fr": "👩🏽‍💻 Génération de dialogues NFT, veuillez réessayer plus tard",
    "zh": "👩🏽‍💻 生成NFT对话，请稍后再试",
    "ar": "👩🏽‍💻 توليد محادثات NFT، يرجى المحاولة لاحقًا",
}
l_grp_jetton_of_group = {
    "ru": "Токен группы:",
    "en": "Group token:",
    "es": "Token del grupo:",
    "fr": "Token de groupe :",
    "zh": "组的令牌：",
    "ar": "رمز المجموعة:",
}
l_grp_jetton_master_address = {
    "ru": "👩🏽‍💻 <b>Адрес</b> мастера-токена:",
    "en": "👩🏽‍💻 <b>Master token</b> address:",
    "es": "👩🏽‍💻 <b>Dirección</b> del maestro-token:",
    "fr": "👩🏽‍💻 <b>Adresse</b> du maître-token :",
    "zh": "👩🏽‍💻 <b>大师令牌的地址</b>:",
    "ar": "👩🏽‍💻 <b>عنوان</b> خبير الرمز:",
}
l_grp_detach = {
    "ru": "👩🏽‍💻 Открепить NFT от",
    "en": "👩🏽‍💻 Unpin NFT from",
    "es": "👩🏽‍💻 Desvincular NFT de",
    "fr": "👩🏽‍💻 Détacher le NFT de",
    "zh": "👩🏽‍💻 从中解除 NFT 绑定",
    "ar": "👩🏽‍💻 إلغاء تثبيت NFT من",
}
l_grp_err_transfer_rights = {
    "ru": "👩🏽‍💻 <b>Ошибка</b> передачи прав: оба участника должны быть администраторами группы и запустить @{0}",
    "en": "👩🏽‍💻 <b>Error</b> transferring rights: both participants must be group administrators and run @{0}",
    "es": "👩🏽‍💻 <b>Error</b> de transferencia de derechos: ambos participantes deben ser administradores del grupo y ejecutar @{0}",
    "fr": "👩🏽‍💻 <b>Erreur</b> de transfert de droits : les deux participants doivent être des administrateurs du groupe et lancer @{0}",
    "zh": "👩🏽‍💻 <b>权限</b> 传递错误：两个参与者必须都是群组管理员并启动 @{0}",
    "ar": "👩🏽‍💻 <b>خطأ</b> في نقل الحقوق: يجب أن يكون كلا المشاركين مديري المجموعة وتشغيل @{0}",
}
l_payment_check_token_grp = {
    "ru": "👩🏽‍💻 <b>Проверьте</b> свой токен для получения платажей (бот для приема платежей также должен быть Администратором группы)",
    "en": "👩🏽‍💻 <b>Check</b> your token for receiving payments (the payment bot must also be a Group Administrator)",
    "es": "👩🏽‍💻 <b>Verifique</b> su token para recibir pagos (el bot para recibir pagos también debe ser Administrador del grupo)",
    "fr": "👩🏽‍💻 <b>Vérifiez</b> votre jeton pour recevoir des paiements (le bot de réception des paiements doit également être Administrateur du groupe)",
    "zh": "👩🏽‍💻 <b>检查</b> 您的支付令牌（接收支付的机器人也必须是群组管理员）",
    "ar": "👩🏽‍💻 <b>تحقق</b> من الرمز الخاص بك لاستلام المدفوعات (يجب أن يكون البوت لاستلام المدفوعات أيضًا مسؤول المجموعة)",
}
l_from_group = {
    "ru": "из группы",
    "en": "from group",
    "es": "de grupo",
    "fr": "de groupe",
    "zh": "来自小组",
    "ar": "من المجموعة",
}
l_hand_msg_len = {
    "ru": "<blockquote>👩🏽‍💻 <b>Сообщение</b> более {0} символов</blockquote>",
    "en": "<blockquote>👩🏽‍💻 <b>Message</b> more than {0} characters</blockquote>",
    "es": "<blockquote>👩🏽‍💻 <b>Mensaje</b> de más de {0} caracteres</blockquote>",
    "fr": "<blockquote>👩🏽‍💻 <b>Message</b> de plus de {0} caractères</blockquote>",
    "zh": "<blockquote>👩🏽‍💻 <b>消息</b> 超过 {0} 个字符</blockquote>",
    "ar": "<blockquote>👩🏽‍💻 <b>الرسالة</b> أكثر من {0} حرف</blockquote>",
}
l_hand_msg_timer = {
    "ru": "<blockquote>👩🏽‍💻 <b>Кѻмментарий</b> написан слишком быстро</blockquote>",
    "en": "<blockquote>👩🏽‍💻 <b>Comment</b> was written too quickly</blockquote>",
    "es": "<blockquote>👩🏽‍💻 <b>Comentario</b> escrito demasiado rápido</blockquote>",
    "fr": "<blockquote>👩🏽‍💻 <b>Commentaire</b> écrit trop rapidement</blockquote>",
    "zh": "<blockquote>👩🏽‍💻 <b>评论</b> 写得太快了</blockquote>",
    "ar": "<blockquote>👩🏽‍💻 <b>التعليق</b> كُتب بسرعة كبيرة</blockquote>",
}
l_hand_msg_flood = {
    "ru": "<blockquote>💬 <i>Флуд</i>-сообщения</blockquote>",
    "en": "<blockquote>💬 <i>Flood</i> messages</blockquote>",
    "es": "<blockquote>💬 <i>Mensajes</i>-spam</blockquote>",
    "fr": "<blockquote>💬 <i>Flood</i> messages</blockquote>",
    "zh": "<blockquote>💬 <i>灌水</i>消息</blockquote>",
    "ar": "<blockquote>💬 <i>رسائل الفلود</i></blockquote>",
}
l_hand_msg_via_bot = {
    "ru": "<blockquote>🔗 <b>Сообщения</b> <i>от имени бота</i> не разрешены</blockquote>",
    "en": "<blockquote>🔗 <b>Messages</b> <i>on behalf of the bot</i> are not allowed</blockquote>",
    "es": "<blockquote>🔗 <b>Los mensajes</b> <i>en nombre del bot</i> no están permitidos</blockquote>",
    "fr": "<blockquote>🔗 <b>Les messages</b> <i>au nom du bot</i> ne sont pas autorisés</blockquote>",
    "zh": "<blockquote>🔗 <b>消息</b> <i>代表机器人的</i> 不被允许</blockquote>",
    "ar": "<blockquote>🔗 <b>الرسائل</b> <i>باسم البوت</i> غير مسموح بها</blockquote>",
}
l_hand_msg_channel = {
    "ru": "<blockquote>🫥 <b>Сообщения</b> <i>от имени канала</i> не разрешены</blockquote>",
    "en": "<blockquote>🫥 <b>Messages</b> <i>on behalf of the channel</i> are not allowed</blockquote>",
    "es": "<blockquote>🫥 <b>Los mensajes</b> <i>en nombre del canal</i> no están permitidos</blockquote>",
    "fr": "<blockquote>🫥 <b>Les messages</b> <i>au nom du canal</i> ne sont pas autorisés</blockquote>",
    "zh": "<blockquote>🫥 <b>消息</b> <i>代表频道</i> 不被允许</blockquote>",
    "ar": "<blockquote>🫥 <b>الرسائل</b> <i>باسم القناة</i> غير مسموح بها</blockquote>",
}
l_hand_msg_emoji = {
    "ru": "<blockquote>🫥 <b>Сообщения</b> <i>c эмоджи</i> не разрешены</blockquote>",
    "en": "<blockquote>🫥 <b>Messages</b> <i>with emojis</i> are not allowed</blockquote>",
    "es": "<blockquote>🫥 <b>Mensajes</b> <i>con emojis</i> no están permitidos</blockquote>",
    "fr": "<blockquote>🫥 <b>Messages</b> <i>avec des émojis</i> non autorisés</blockquote>",
    "zh": "<blockquote>🫥 <b>消息</b> <i>带表情符号</i> 不被允许</blockquote>",
    "ar": "<blockquote>🫥 <b>الرسائل</b> <i>مع الرموز التعبيرية</i> غير مسموح بها</blockquote>",
}
l_hand_msg_http = {
    "ru": "<blockquote>🔗 <b>Сообщения</b> <i>c внешними ссылками</i> не разрешены</blockquote>",
    "en": "<blockquote>🔗 <b>Messages</b> <i>with external links</i> are not allowed</blockquote>",
    "es": "<blockquote>🔗 <b>Mensajes</b> <i>con enlaces externos</i> no están permitidos</blockquote>",
    "fr": "<blockquote>🔗 <b>Les messages</b> <i>avec des liens externes</i> ne sont pas autorisés</blockquote>",
    "zh": "<blockquote>🔗 <b>消息</b> <i>带外部链接</i> 不被允许</blockquote>",
    "ar": "<blockquote>🔗 <b>الرسائل</b> <i>مع الروابط الخارجية</i> غير مسموح بها</blockquote>",
}
l_hand_msg_telegram = {
    "ru": "<blockquote>🔗 <b>Сообщения</b> <i>c телеграм-ссылками</i> не разрешены</blockquote>",
    "en": "<blockquote>🔗 <b>Messages</b> <i>with telegram links</i> are not allowed</blockquote>",
    "es": "<blockquote>🔗 <b>Los mensajes</b> <i>con enlaces de Telegram</i> no están permitidos</blockquote>",
    "fr": "<blockquote>🔗 <b>Les messages</b> <i>avec des liens Telegram</i> ne sont pas autorisés</blockquote>",
    "zh": "<blockquote>🔗 <b>消息</b> <i>带有电报链接</i> 不被允许</blockquote>",
    "ar": "<blockquote>🔗 <b>الرسائل</b> <i>مع روابط التليجرام</i> غير مسموح بها</blockquote>",
}
l_hand_msg_forward = {
    "ru": "<blockquote>🔗 <b>Сообщения</b> <i>c форвард-ссылками</i> не разрешены</blockquote>",
    "en": "<blockquote>🔗 <b>Messages</b> <i>with forward links</i> are not allowed</blockquote>",
    "es": "<blockquote>🔗 <b>Mensajes</b> <i>con enlaces de reenvío</i> no están permitidos</blockquote>",
    "fr": "<blockquote>🔗 <b>Les messages</b> <i>avec des liens de transfert</i> ne sont pas autorisés</blockquote>",
    "zh": "<blockquote>🔗 <b>消息</b> <i>带转发链接</i> 不被允许</blockquote>",
    "ar": "<blockquote>🔗 <b>الرسائل</b> <i>مع روابط إعادة التوجيه</i> غير مسموح بها</blockquote>",
}
l_hand_msg_zalgo = {
    "ru": "<blockquote>文 <b>Сообщения</b> <i>c <a href='https://www.zalgo.org'>zalgo-символами</a></i> не разрешены</blockquote>",
    "en": "<blockquote>Text <b>Messages</b> <i>with <a href='https://www.zalgo.org'>zalgo symbols</a></i> are not allowed</blockquote>",
    "es": "<blockquote>文 <b>Mensajes</b> <i>c <a href='https://www.zalgo.org'>símbolos zalgo</a></i> no están permitidos</blockquote>",
    "fr": "<blockquote>文 <b>Messages</b> <i>c <a href='https://www.zalgo.org'>symboles zalgo</a></i> non autorisés</blockquote>",
    "zh": "<blockquote>文 <b>消息</b> <i>c <a href='https://www.zalgo.org'>zalgo符号</a></i> 不被允许</blockquote>",
    "ar": "<blockquote>文 <b>الرسائل</b> <i>مع <a href='https://www.zalgo.org'>رموز زالجو</a></i> غير مسموح بها</blockquote>",
}
l_hand_msg_symbols = {
    "ru": "<blockquote>文 <b>Сообщения</b> <i>c 文ب-glyth символами</i> не разрешены</blockquote>",
    "en": "<blockquote>Messages <b>Messages</b> <i>with glyth characters</i> are not allowed</blockquote>",
    "es": "<blockquote>文 <b>Mensajes</b> <i>c 文ب-glyth símbolos</i> no están permitidos</blockquote>",
    "fr": "<blockquote>文 <b>Messages</b> <i>c 文ب-glyth caractères</i> non autorisés</blockquote>",
    "zh": "<blockquote>文 <b>消息</b> <i>c 文ب-glyth 符号</i> 不允许</blockquote>",
    "ar": "<blockquote>文 <b>الرسائل</b> <i>c 文ب-glyth الرموز</i> غير مسموح بها</blockquote>",
}
l_hand_msg_stop = {
    "ru": "<blockquote>🧾 <b>Сообщение</b> содержит <i>стоп-слова</i></blockquote>",
    "en": "<blockquote>🧾 <b>The message</b> contains <i>stop words</i></blockquote>",
    "es": "<blockquote>🧾 <b>El mensaje</b> contiene <i>palabras clave</i></blockquote>",
    "fr": "<blockquote>🧾 <b>Le message</b> contient des <i>mots interdits</i></blockquote>",
    "zh": "<blockquote>🧾 <b>消息</b> 包含 <i>停用词</i></blockquote>",
    "ar": "<blockquote>🧾 <b>الرسالة</b> تحتوي على <i>كلمات توقف</i></blockquote>",
}
l_hand_msg_edit = {
    "ru": "<blockquote>👥 <b>Редактирование</b> сообщений не разрешено</blockquote>",
    "en": "<blockquote>👥 <b>Editing</b> messages is not allowed</blockquote>",
    "es": "<blockquote>👥 <b>No se permite editar</b> mensajes</blockquote>",
    "fr": "<blockquote>👥 <b>La modification</b> des messages n'est pas autorisée</blockquote>",
    "zh": "<blockquote>👥 <b>不允许编辑</b> 消息</blockquote>",
    "ar": "<blockquote>👥 <b>تعديل</b> الرسائل غير مسموح</blockquote>",
}
l_ccomment_button = {
    "ru": "🪙 Оплата кѻмментов",
    "en": "🪙 Payment for comments",
    "es": "🪙 Pago de comentarios",
    "fr": "🪙 Paiement des commentaires",
    "zh": "🪙 评论支付",
    "ar": "🪙 دفع التعليقات",
}
l_content_types_invite_user_bot = {
    "ru": "<blockquote>🚶🏽 <b>Приглашение</b> @username/@name_bot не разрешено</blockquote>",
    "en": "<blockquote>🚶🏽 <b>Invitation</b> @username/@name_bot is not allowed</blockquote>",
    "es": "<blockquote>🚶🏽 <b>Invitación</b> @username/@name_bot no permitido</blockquote>",
    "fr": "<blockquote>🚶🏽 <b>Invitation</b> @username/@name_bot non autorisée</blockquote>",
    "zh": "<blockquote>🚶🏽 <b>邀请</b> @username/@name_bot 不被允许</blockquote>",
    "ar": "<blockquote>🚶🏽 <b>الدعوة</b> @username/@name_bot غير مسموح بها</blockquote>",
}
l_content_types_invite_user = {
    "ru": "<blockquote>🚶🏽 <b>Приглашение</b> @username не разрешено</blockquote>",
    "en": "<blockquote>🚶🏽 <b>Invitation</b> @username is not allowed</blockquote>",
    "es": "<blockquote>🚶🏽 <b>Invitación</b> @username no permitida</blockquote>",
    "fr": "<blockquote>🚶🏽 <b>Invitation</b> @username non autorisée</blockquote>",
    "zh": "<blockquote>🚶🏽 <b>邀请</b> @username 不被允许</blockquote>",
    "ar": "<blockquote>🚶🏽 <b>الدعوة</b> @username غير مسموح بها</blockquote>",
}
l_content_types_invite_bot = {
    "ru": "<blockquote>🚶🏽 <b>Приглашение</b> @name_bot не разрешено</blockquote>",
    "en": "<blockquote>🚶🏽 <b>Invitation</b> @name_bot is not allowed</blockquote>",
    "es": "<blockquote>🚶🏽 <b>Invitación</b> @name_bot no permitido</blockquote>",
    "fr": "<blockquote>🚶🏽 <b>Invitation</b> @name_bot non autorisée</blockquote>",
    "zh": "<blockquote>🚶🏽 <b>邀请</b> @name_bot 不被允许</blockquote>",
    "ar": "<blockquote>🚶🏽 <b>الدعوة</b> @name_bot غير مسموح بها</blockquote>",
}
l_content_types_button = {
    "ru": "<blockquote>👮🏽 {0}, <b>жми</b> на кнопку, чтобы вс︎тупить в группу</blockquote>",
    "en": "<blockquote>👮🏽 {0}, <b>click</b> the button to join the group</blockquote>",
    "es": "<blockquote>👮🏽 {0}, <b>haz</b> clic en el botón para unirte al grupo</blockquote>",
    "fr": "<blockquote>👮🏽 {0}, <b>clique</b> sur le bouton pour rejoindre le groupe</blockquote>",
    "zh": "<blockquote>👮🏽 {0}, <b>点击</b> 按钮以加入群组</blockquote>",
    "ar": "<blockquote>👮🏽 {0}, <b>اضغط</b> على الزر للانضمام إلى المجموعة</blockquote>",
}
l_content_types_subscribe = {
    "ru": "<blockquote>👮🏽 {0}, необходимо подписаться на {1}, чтобы заявка на вступление была одобрена</blockquote>",
    "en": "<blockquote>👮🏽 {0}, you need to subscribe to {1} for your application to join to be approved</blockquote>",
    "es": "<blockquote>👮🏽 {0}, es necesario suscribirse a {1} para que la solicitud de ingreso sea aprobada</blockquote>",
    "fr": "<blockquote>👮🏽 {0}, il est nécessaire de s'inscrire à {1} pour que la demande d'adhésion soit approuvée</blockquote>",
    "zh": "<blockquote>👮🏽 {0}，需要签署 {1}，以便入会申请获得批准</blockquote>",
    "ar": "<blockquote>👮🏽 {0}، يجب الاشتراك في {1} حتى يتم الموافقة على طلب الانضمام</blockquote>",
}
l_content_types_captcha = {
    "ru": "<blockquote>👮🏽 {0}, необходимо выбрать <i>правильный вариант</i> ответа, чтобы вс︎тупить в группу:\n\n{1}</blockquote>",
    "en": "<blockquote>👮🏽 {0}, you need to choose the <i>correct option</i> to join the group:\n\n{1}</blockquote>",
    "es": "<blockquote>👮🏽 {0}, es necesario elegir la <i>opción correcta</i> de respuesta para unirse al grupo:\n\n{1}</blockquote>",
    "fr": "<blockquote>👮🏽 {0}, il est nécessaire de choisir <i>la bonne option</i> de réponse pour rejoindre le groupe :\n\n{1}</blockquote>",
    "zh": "<blockquote>👮🏽 {0}，需要选择<i>正确的选项</i>以加入小组：\n\n{1}</blockquote>",
    "ar": "<blockquote>👮🏽 {0}، يجب اختيار <i>الخيار الصحيح</i> للإجابة للانضمام إلى المجموعة:\n\n{1}</blockquote>",
}
l_content_types_payment = {
    "ru": "<blockquote>👮🏽 {0}, необходимо оплатить подписку, чтобы вс︎тупить в группу</blockquote>",
    "en": "<blockquote>👮🏽 {0}, you need to pay for the subscription to join the group</blockquote>",
    "es": "<blockquote>👮🏽 {0}, es necesario pagar la suscripción para unirse al grupo</blockquote>",
    "fr": "<blockquote>👮🏽 {0}, il est nécessaire de payer l'abonnement pour rejoindre le groupe</blockquote>",
    "zh": "<blockquote>👮🏽 {0}，需要支付订阅费用才能加入群组</blockquote>",
    "ar": "<blockquote>👮🏽 {0}، يجب دفع الاشتراك للانضمام إلى المجموعة</blockquote>",
}
l_hand_msg_FLOOD_USERNAME = {
    "ru": "<blockquote>💬 <b>Пользователь</b> @{0} изменил <b>name/@username</b>! Возможно, шпион!</blockquote>",
    "en": "<blockquote>💬 <b>User</b> @{0} changed <b>name/@username</b>! Possibly a spy!</blockquote>",
    "es": "<blockquote>💬 <b>Usuario</b> @{0} ha cambiado <b>name/@username</b>! ¡Posiblemente un espía!</blockquote>",
    "fr": "<blockquote>💬 <b>Utilisateur</b> @{0} a modifié <b>name/@username</b> ! Peut-être un espion !</blockquote>",
    "zh": "<blockquote>💬 <b>用户</b> @{0} 修改了 <b>name/@username</b>！可能是间谍！</blockquote>",
    "ar": "<blockquote>💬 <b>المستخدم</b> @{0} غيّر <b>name/@username</b>! ربما يكون جاسوسًا!</blockquote>",
}
l_grp_vote = {
    "ru": "🪻 Голосование",
    "en": "🪻 Voting",
    "es": "🪻 Votación",
    "fr": "🪻 Vote",
    "zh": "🪻 投票",
    "ar": "🪻 التصويت",
}
l_grp_no_original_group_id = {
    "ru": "🫧 <b>Все классно</b>! Но не удается найти идентификатор группы. Возможные решения:\n\n<blockquote>▪️ проверить наличие @FereyGroupBot в группе с правами [Администратор]\n▪️ в пересылаемые сообщения добавить хотя бы одно ‘свежее’ сообщение с текстом (потом его можно будет удалить)\n▪️ для создания любых NFT-далогов без группы (в том числе приватных) можно сделать пересылку в @FereyTONestBot</blockquote>",
    "en": "🫧 <b>Everything is great</b>! But unable to find the group identifier. Possible solutions:\n\n<blockquote>▪️ check for the presence of @FereyGroupBot in the group with [Administrator] rights\n▪️ add at least one 'fresh' message with text to the forwarded messages (it can be deleted later)\n▪️ to create any NFT dialogues without a group (including private ones), you can forward to @FereyTONestBot</blockquote>",
    "es": "🫧 <b>¡Todo está genial!</b> Pero no se puede encontrar el identificador del grupo. Posibles soluciones:\n\n<blockquote>▪️ verificar la presencia de @FereyGroupBot en el grupo con derechos [Administrador]\n▪️ agregar al menos un mensaje 'nuevo' con texto a los mensajes reenviados (luego se puede eliminar)\n▪️ para crear cualquier diálogo NFT sin grupo (incluidos los privados) se puede reenviar a @FereyTONestBot</blockquote>",
    "fr": "🫧 <b>Tout est génial</b> ! Mais je ne parviens pas à trouver l'identifiant du groupe. Solutions possibles :\n\n<blockquote>▪️ vérifier la présence de @FereyGroupBot dans le groupe avec des droits [Administrateur]\n▪️ ajouter au moins un message ‘frais’ avec du texte dans les messages transférés (vous pourrez ensuite le supprimer)\n▪️ pour créer n'importe quel dialogue NFT sans groupe (y compris privés), vous pouvez transférer vers @FereyTONestBot</blockquote>",
    "zh": "🫧 <b>一切都很好</b>！但无法找到组的标识符。可能的解决方案：\n\n<blockquote>▪️ 检查群组中是否存在 @FereyGroupBot，且具有 [管理员] 权限\n▪️ 在转发的消息中添加至少一条“新鲜”的文本消息（之后可以删除）\n▪️ 要创建任何没有群组的 NFT 对话（包括私密的），可以转发到 @FereyTONestBot</blockquote>",
    "ar": "🫧 <b>كل شيء رائع</b>! لكن لا يمكن العثور على معرف المجموعة. الحلول الممكنة:\n\n<blockquote>▪️ تحقق من وجود @FereyGroupBot في المجموعة مع حقوق [مدير]\n▪️ أضف على الأقل رسالة واحدة 'جديدة' إلى الرسائل المعاد توجيهها (يمكنك حذفها لاحقًا)\n▪️ لإنشاء أي محادثات NFT بدون مجموعة (بما في ذلك الخاصة) يمكنك إعادة توجيهها إلى @FereyTONestBot</blockquote>",
}
l_grp_no_collection_addr = {
    "ru": "🫧 <b>Необходимо</b> сообщить владельцу группы, чтобы он создал в разделе [NFT-диалог] коллекцию, иначе пользователи не смогут превратить пересланные сообщения в NFT",
    "en": "🫧 <b>It is necessary</b> to inform the group owner to create a collection in the [NFT-dialog] section, otherwise users will not be able to turn forwarded messages into NFTs.",
    "es": "🫧 <b>Es necesario</b> informar al propietario del grupo para que cree una colección en la sección [NFT-diálogo], de lo contrario, los usuarios no podrán convertir los mensajes reenviados en NFT.",
    "fr": "🫧 <b>Il est nécessaire</b> d'informer le propriétaire du groupe de créer une collection dans la section [NFT-dialogue], sinon les utilisateurs ne pourront pas transformer les messages transférés en NFT.",
    "zh": "🫧 <b>需要</b> 通知群组所有者在 [NFT-对话] 部分创建一个收藏，否则用户将无法将转发的消息转换为 NFT",
    "ar": "🫧 <b>يجب</b> إبلاغ مالك المجموعة بإنشاء مجموعة في قسم [NFT-الحوار] ، وإلا فلن يتمكن المستخدمون من تحويل الرسائل المعاد توجيهها إلى NFT",
}
l_ban_handler = {
    "ru": "<blockquote>🪦 <b>Пользователь</b> {0} в /ban-списке на {1}</blockquote>",
    "en": "<blockquote>🪦 <b>User</b> {0} is in the /ban list on {1}</blockquote>",
    "es": "<blockquote>🪦 <b>Usuario</b> {0} en la lista de /ban en {1}</blockquote>",
    "fr": "<blockquote>🪦 <b>Utilisateur</b> {0} dans la liste de /ban sur {1}</blockquote>",
    "zh": "<blockquote>🪦 <b>用户</b> {0} 在 /ban-列表中于 {1}</blockquote>",
    "ar": "<blockquote>🪦 <b>المستخدم</b> {0} في قائمة الحظر على {1}</blockquote>",
}
l_ban_handler_chn = {
    "ru": "<blockquote>🪦 <b>Канал</b> <b>{0}</b> в /ban-списке на {1}</blockquote>",
    "en": "<blockquote>🪦 <b>Channel</b> <b>{0}</b> in the /ban list on {1}</blockquote>",
    "es": "<blockquote>🪦 <b>Canal</b> <b>{0}</b> en la lista de /ban en {1}</blockquote>",
    "fr": "<blockquote>🪦 <b>Canal</b> <b>{0}</b> dans la liste /ban sur {1}</blockquote>",
    "zh": "<blockquote>🪦 <b>频道</b> <b>{0}</b> 在 /ban-列表中于 {1}</blockquote>",
    "ar": "<blockquote>🪦 <b>القناة</b> <b>{0}</b> في قائمة الحظر على {1}</blockquote>",
}
l_ban_error = {
    "ru": "<blockquote>🪦 <b>Формат</b> /ban-команды: /ban (1m|1h|10d)</blockquote>",
    "en": "<blockquote>🪦 <b>Format</b> /ban command: /ban (1m|1h|10d)</blockquote>",
    "es": "<blockquote>🪦 <b>Formato</b> del comando /ban: /ban (1m|1h|10d)</blockquote>",
    "fr": "<blockquote>🪦 <b>Format</b> de la commande /ban : /ban (1m|1h|10d)</blockquote>",
    "zh": "<blockquote>🪦 <b>格式</b> /ban命令: /ban (1m|1h|10d)</blockquote>",
    "ar": "<blockquote>🪦 <b>التنسيق</b> /أوامر الحظر: /حظر (1م|1س|10ي)</blockquote>",
}
l_ban_unban = {
    "ru": "<blockquote>🪦 <b>Пользователь</b> {0} удален из /ban-списка</blockquote>",
    "en": "<blockquote>🪦 <b>User</b> {0} has been removed from the /ban list</blockquote>",
    "es": "<blockquote>🪦 <b>Usuario</b> {0} eliminado de la lista /ban</blockquote>",
    "fr": "<blockquote>🪦 <b>Utilisateur</b> {0} a été supprimé de la liste /ban</blockquote>",
    "zh": "<blockquote>🪦 <b>用户</b> {0} 已从 /ban-列表中删除</blockquote>",
    "ar": "<blockquote>🪦 <b>المستخدم</b> {0} تم حذفه من قائمة الحظر</blockquote>",
}
l_ban_unban_chn = {
    "ru": "<blockquote>🪦 <b>Канал</b> <b>{0}</b> удален из /ban-списка</blockquote>",
    "en": "<blockquote>🪦 <b>Channel</b> <b>{0}</b> has been removed from the /ban-list</blockquote>",
    "es": "<blockquote>🪦 <b>Canal</b> <b>{0}</b> eliminado de la lista /ban</blockquote>",
    "fr": "<blockquote>🪦 <b>Le canal</b> <b>{0}</b> a été supprimé de la liste /ban</blockquote>",
    "zh": "<blockquote>🪦 <b>频道</b> <b>{0}</b> 已从 /ban-列表中删除</blockquote>",
    "ar": "<blockquote>🪦 <b>القناة</b> <b>{0}</b> تمت إزالتها من قائمة الحظر</blockquote>",
}
l_mute_handler = {
    "ru": "<blockquote>💤 <b>Пользователь</b> {0} обеззвучен на {1}</blockquote>",
    "en": "<blockquote>💤 <b>User</b> {0} is muted for {1}</blockquote>",
    "es": "<blockquote>💤 <b>Usuario</b> {0} ha sido silenciado por {1}</blockquote>",
    "fr": "<blockquote>💤 <b>Utilisateur</b> {0} est muet sur {1}</blockquote>",
    "zh": "<blockquote>💤 <b>用户</b> {0} 在 {1} 被静音</blockquote>",
    "ar": "<blockquote>💤 <b>المستخدم</b> {0} تم كتم صوته في {1}</blockquote>",
}
l_mute_handler_chn = {
    "ru": "<blockquote>💤 <b>Канал</b> <b>{0}</b> не может быть обеззвучен на {1}</blockquote>",
    "en": "<blockquote>💤 <b>Channel</b> <b>{0}</b> cannot be muted on {1}</blockquote>",
    "es": "<blockquote>💤 <b>Canal</b> <b>{0}</b> no puede ser silenciado en {1}</blockquote>",
    "fr": "<blockquote>💤 <b>La chaîne</b> <b>{0}</b> ne peut pas être désactivée sur {1}</blockquote>",
    "zh": "<blockquote>💤 <b>频道</b> <b>{0}</b> 不能在 {1} 静音</blockquote>",
    "ar": "<blockquote>💤 <b>القناة</b> <b>{0}</b> لا يمكن كتم صوتها على {1}</blockquote>",
}
l_mute_error = {
    "ru": "<blockquote>💤 <b>Формат</b> /mute-команды: /mute (1m|1h|10d)</blockquote>",
    "en": "<blockquote>💤 <b>Format</b> /mute commands: /mute (1m|1h|10d)</blockquote>",
    "es": "<blockquote>💤 <b>Formato</b> /comandos de silencio: /silenciar (1m|1h|10d)</blockquote>",
    "fr": "<blockquote>💤 <b>Format</b> des commandes /mute : /mute (1m|1h|10d)</blockquote>",
    "zh": "<blockquote>💤 <b>格式</b> /mute命令: /mute (1m|1h|10d)</blockquote>",
    "ar": "<blockquote>💤 <b>التنسيق</b> /mute-الأوامر: /mute (1m|1h|10d)</blockquote>",
}
l_mute_unmute = {
    "ru": "<blockquote>💤 <b>Пользователь</b> {0} больше не обеззвучен</blockquote>",
    "en": "<blockquote>💤 <b>User</b> {0} is no longer muted</blockquote>",
    "es": "<blockquote>💤 <b>Usuario</b> {0} ya no está silenciado</blockquote>",
    "fr": "<blockquote>💤 <b>Utilisateur</b> {0} n'est plus muet</blockquote>",
    "zh": "<blockquote>💤 <b>用户</b> {0} 不再静音</blockquote>",
    "ar": "<blockquote>💤 <b>المستخدم</b> {0} لم يعد مكتوم الصوت</blockquote>",
}
l_mute_unmute_chn = {
    "ru": "<blockquote>💤 <b>Канал</b> <b>{0}</b> больше не обеззвучен</blockquote>",
    "en": "<blockquote>💤 <b>Channel</b> <b>{0}</b> is no longer muted</blockquote>",
    "es": "<blockquote>💤 <b>Canal</b> <b>{0}</b> ya no está silenciado</blockquote>",
    "fr": "<blockquote>💤 <b>La chaîne</b> <b>{0}</b> n'est plus muette</blockquote>",
    "zh": "<blockquote>💤 <b>频道</b> <b>{0}</b> 不再静音</blockquote>",
    "ar": "<blockquote>💤 <b>القناة</b> <b>{0}</b> لم تعد صامتة</blockquote>",
}
l_warn_handler = {
    "ru": "<blockquote>👩🏽‍💻 <b>От имени</b> группы <b>{0}</b> выносится предупреждение {1}{2}</blockquote>",
    "en": "<blockquote>👩🏽‍💻 <b>On behalf of</b> group <b>{0}</b> a warning is issued {1}{2}</blockquote>",
    "es": "<blockquote>👩🏽‍💻 <b>En nombre</b> del grupo <b>{0}</b> se emite una advertencia {1}{2}</blockquote>",
    "fr": "<blockquote>👩🏽‍💻 <b>Au nom</b> du groupe <b>{0}</b>, un avertissement est émis {1}{2}</blockquote>",
    "zh": "<blockquote>👩🏽‍💻 <b>代表</b> 组 <b>{0}</b> 发出警告 {1}{2}</blockquote>",
    "ar": "<blockquote>👩🏽‍💻 <b>باسم</b> المجموعة <b>{0}</b> يتم إصدار تحذير {1}{2}</blockquote>",
}
l_add_members = {
    "ru": "Добавление участников",
    "en": "Adding participants",
    "es": "Agregar participantes",
    "fr": "Ajout de participants",
    "zh": "添加参与者",
    "ar": "إضافة المشاركين",
}
l_embed_links = {
    "ru": "Предпросмотр ссылок",
    "en": "Link Preview",
    "es": "Vista previa de enlaces",
    "fr": "Aperçu des liens",
    "zh": "链接预览",
    "ar": "معاينة الروابط",
}
l_send_media = {
    "ru": "Отправка фото и видео",
    "en": "Sending photos and videos",
    "es": "Envío de fotos y videos",
    "fr": "Envoi de photos et vidéos",
    "zh": "发送照片和视频",
    "ar": "إرسال الصور ومقاطع الفيديو",
}
l_send_polls = {
    "ru": "Отправка опросов",
    "en": "Sending surveys",
    "es": "Envío de encuestas",
    "fr": "Envoi de sondages",
    "zh": "发送调查",
    "ar": "إرسال الاستطلاعات",
}
l_send_stickers = {
    "ru": "Отправка sticker/giff/via_bot",
    "en": "Sending sticker/giff/via_bot",
    "es": "Envío de sticker/giff/via_bot",
    "fr": "Envoi de sticker/giff/via_bot",
    "zh": "发送 sticker/giff/via_bot",
    "ar": "إرسال sticker/giff/via_bot",
}
l_stat_msg_cnt = {
    "ru": "Количество сообщ",
    "en": "Number of messages",
    "es": "Cantidad de mensajes",
    "fr": "Nombre de messages",
    "zh": "消息数量",
    "ar": "عدد الرسائل",
}
l_stat_history_for_new = {
    "ru": "История для новых участников",
    "en": "Story for new participants",
    "es": "Historia para nuevos participantes",
    "fr": "Histoire pour les nouveaux participants",
    "zh": "新参与者的故事",
    "ar": "تاريخ للمشاركين الجدد",
}
l_stat_history_turn_on = {
    "ru": "(для просмотра статистики <u>включите</u> [Историю группы])",
    "en": "(to view statistics <u>enable</u> [Group History])",
    "es": "(para ver las estadísticas <u>active</u> [Historial del grupo])",
    "fr": "(pour voir les statistiques <u>activez</u> [l'historique du groupe])",
    "zh": "(要查看统计信息 <u>请启用</u> [群组历史])",
    "ar": "(لرؤية الإحصائيات <u>قم بتفعيل</u> [تاريخ المجموعة])",
}
l_stat_first_msg_date = {
    "ru": "Дата 1-го сообщ",
    "en": "Date of the 1st message",
    "es": "Fecha del primer mensaje",
    "fr": "Date du 1er message",
    "zh": "日期 1 的消息",
    "ar": "تاريخ الرسالة الأولى",
}
l_stat_involved = {
    "ru": "Вовлеченность в чате",
    "en": "Engagement in chat",
    "es": "Involucramiento en el chat",
    "fr": "Engagement dans le chat",
    "zh": "聊天参与度",
    "ar": "الانخراط في الدردشة",
}
l_stat_sent = {
    "ru": "{0}\n@{1} написал(а): {2}  сообщ",
    "en": "{0}  \n@{1} wrote: {2} message",
    "es": "{0}  \n@{1} escribió: {2}  mensaje",
    "fr": "{0}  \n@{1} a écrit : {2}  message",
    "zh": "{0}  \n@{1} 写道：{2}  消息",
    "ar": "{0}  \n@{1} كتب(ت): {2}  رسالة",
}
l_stat_meet = {
    "ru": "{0}\n{1}. <i>{2}</i>..: встретилось {3} раз",
    "en": "{0}  \n{1}. <i>{2}</i>..: encountered {3} times",
    "es": "{0}  \n{1}. <i>{2}</i>..: se encontró {3} veces",
    "fr": "{0}  \n{1}. <i>{2}</i>..: rencontré {3} fois",
    "zh": "{0}  \n{1}. <i>{2}</i>..: 出现了 {3} 次",
    "ar": "{0}  \n{1}. <i>{2}</i>..: تم العثور عليه {3} مرة",
}
l_stat_top5users = {
    "ru": "Топ 5 пользователей (на 1000 сообщ)",
    "en": "Top 5 users (per 1000 messages)",
    "es": "Top 5 usuarios (por 1000 mensajes)",
    "fr": "Top 5 utilisateurs (pour 1000 messages)",
    "zh": "前五名用户（每1000条消息）",
    "ar": "أفضل 5 مستخدمين (لكل 1000 رسالة)",
}
l_stat_top5msgs = {
    "ru": "Топ 5 сообщ (из 1000)",
    "en": "Top 5 messages (out of 1000)",
    "es": "Top 5 mensajes (de 1000)",
    "fr": "Top 5 messages (sur 1000)",
    "zh": "前五条消息（共1000条）",
    "ar": "أفضل 5 رسائل (من 1000)",
}
l_status_for = {
    "ru": "<blockquote>👩🏽‍💻 <b>Статус</b> <b>{0}</b> для {1}:\n\n</blockquote>",
    "en": "<blockquote>👩🏽‍💻 <b>Status</b> <b>{0}</b> for {1}:\n\n</blockquote>",
    "es": "<blockquote>👩🏽‍💻 <b>Estado</b> <b>{0}</b> para {1}:\n\n</blockquote>",
    "fr": "<blockquote>👩🏽‍💻 <b>Statut</b> <b>{0}</b> pour {1}:\n\n</blockquote>",
    "zh": "<blockquote>👩🏽‍💻 <b>状态</b> <b>{0}</b> 对于 {1}:\n\n</blockquote>",
    "ar": "<blockquote>👩🏽‍💻 <b>الحالة</b> <b>{0}</b> لـ {1}:\n\n</blockquote>",
}
l_participants = {
    "ru": "участ.",
    "en": "participant.",
    "es": "participante.",
    "fr": "part.",
    "zh": "参与。",
    "ar": "مشارك.",
}
l_timer0_text = {
    "ru": "👩🏽‍💻 <b>Введи</b> <i>число</i> секунд задержки для 1го кѻмментария в привязанном канале {1}\n\n👩🏽‍💻 <b>Текущее</b> /timer-значение: {0}\n<code>/timer 100</code> задержка 1го кѻмментария\n<code>/timer 0</code> отключение опции",
    "en": "👩🏽‍💻 <b>Enter</b> <i>the</i> number of seconds delay for the 1st comment in the linked channel {1}\n\n👩🏽‍💻 <b>Current</b> /timer value: {0}\n<code>/timer 100</code> delay for the 1st comment\n<code>/timer 0</code> disable the option",
    "es": "👩🏽‍💻 <b>Introduce</b> <i>el</i> número de segundos de retraso para el 1er comentario en el canal vinculado {1}\n\n👩🏽‍💻 <b>Valor</b> actual de /timer: {0}\n<code>/timer 100</code> retraso del 1er comentario\n<code>/timer 0</code> desactivar la opción",
    "fr": "👩🏽‍💻 <b>Entrez</b> <i>le nombre</i> de secondes de délai pour le 1er commentaire dans le canal lié {1}\n\n👩🏽‍💻 <b>Valeur</b> /timer actuelle : {0}\n<code>/timer 100</code> délai du 1er commentaire\n<code>/timer 0</code> désactiver l'option",
    "zh": "👩🏽‍💻 <b>输入</b> <i>延迟</i> 秒数用于第一个评论在关联频道 {1}\n\n👩🏽‍💻 <b>当前</b> /timer-值: {0}\n<code>/timer 100</code> 第一个评论的延迟\n<code>/timer 0</code> 关闭选项",
    "ar": "👩🏽‍💻 <b>أدخل</b> <i>عدد</i> ثواني التأخير للتعليق الأول في القناة المرتبطة {1}\n\n👩🏽‍💻 <b>القيمة الحالية</b> /timer: {0}\n<code>/timer 100</code> تأخير التعليق الأول\n<code>/timer 0</code> تعطيل الخيار",
}
l_timer_finish = {
    "ru": "👩🏽‍💻 <b>Текущее</b> /timer-значение: {0}\n\n<code>/timer 100</code>  задержка 1го кѻмментария\n<code>/timer 0</code> отключение опции\n\n⚙️ Команды /cmd",
    "en": "👩🏽‍💻 <b>Current</b> /timer-value: {0}\n\n<code>/timer 100</code> delay for the 1st comment\n<code>/timer 0</code> disable option\n\n⚙️ Commands /cmd",
    "es": "👩🏽‍💻 <b>Actual</b> /valor-timer: {0}\n\n<code>/timer 100</code>  retraso del 1er comentario\n<code>/timer 0</code> desactivación de la opción\n\n⚙️ Comandos /cmd",
    "fr": "👩🏽‍💻 <b>Actuel</b> /valeur-timer: {0}\n\n<code>/timer 100</code> délai du 1er commentaire\n<code>/timer 0</code> désactiver l'option\n\n⚙️ Commandes /cmd",
    "zh": "👩🏽‍💻 <b>当前</b> /timer-值: {0}\n\n<code>/timer 100</code> 第一个评论的延迟\n<code>/timer 0</code> 关闭选项\n\n⚙️ 命令 /cmd",
    "ar": "👩🏽‍💻 <b>الحالي</b> /timer-القيمة: {0}\n\n<code>/timer 100</code> تأخير التعليق الأول\n<code>/timer 0</code> تعطيل الخيار\n\n⚙️ الأوامر /cmd",
}
l_work_text = {
    "ru": "👩🏽‍💻 <b>Введи</b> часы работы (возможность писать в группе)\n\n👩🏽‍💻 <b>Текущее</b> /work-значение: {0}\n<code>/work 09:00 21:00</code>   часы работы\n<code>/work 0</code> отключение опции\n\n📍 <b>Текущее</b> время: <u>{1}</u> ({2} по Гринвичу). Отправь <b>геопозицию</b>, чтобы <i>автоматически</i> определить часовой пояс",
    "en": "👩🏽‍💻 <b>Enter</b> working hours (ability to write in the group)\n\n👩🏽‍💻 <b>Current</b> /work-value: {0}\n<code>/work 09:00 21:00</code>   working hours\n<code>/work 0</code> disable the option\n\n📍 <b>Current</b> time: <u>{1}</u> ({2} GMT). Send <b>geolocation</b> to <i>automatically</i> determine the time zone",
    "es": "👩🏽‍💻 <b>Introduce</b> las horas de trabajo (posibilidad de escribir en el grupo)\n\n👩🏽‍💻 <b>Actual</b> /work-valor: {0}\n<code>/work 09:00 21:00</code>   horas de trabajo\n<code>/work 0</code> desactivar la opción\n\n📍 <b>Hora</b> actual: <u>{1}</u> ({2} en Greenwich). Envía <b>geolocalización</b> para <i>determinar</i> automáticamente la zona horaria",
    "fr": "👩🏽‍💻 <b>Entrez</b> les heures de travail (possibilité d'écrire dans le groupe)\n\n👩🏽‍💻 <b>Actuel</b> /work-valeur: {0}\n<code>/work 09:00 21:00</code>   heures de travail\n<code>/work 0</code> désactiver l'option\n\n📍 <b>Heure</b> actuelle: <u>{1}</u> ({2} à Greenwich). Envoyez <b>la géolocalisation</b> pour <i>déterminer automatiquement</i> le fuseau horaire",
    "zh": "👩🏽‍💻 <b>输入</b> 工作时间（在群组中写的能力）\n\n👩🏽‍💻 <b>当前</b> /work-值: {0}\n<code>/work 09:00 21:00</code>   工作时间\n<code>/work 0</code> 关闭选项\n\n📍 <b>当前</b> 时间: <u>{1}</u> ({2} 格林威治时间)。发送 <b>地理位置</b> 以 <i>自动</i> 确定时区",
    "ar": "👩🏽‍💻 <b>أدخل</b> ساعات العمل (إمكانية الكتابة في المجموعة)\n\n👩🏽‍💻 <b>الحالي</b> /work-القيمة: {0}\n<code>/work 09:00 21:00</code>   ساعات العمل\n<code>/work 0</code> تعطيل الخيار\n\n📍 <b>الوقت الحالي</b>: <u>{1}</u> ({2} بتوقيت غرينتش). أرسل <b>الموقع الجغرافي</b> لتحديد المنطقة الزمنية <i>بشكل تلقائي</i>",
}
l_work_finish = {
    "ru": "👩🏽‍💻 <b>Текущее</b> /work-значение: {0}\n\n<code>/work 09:00 21:00</code>    часы работы\n<code>/work 0</code>   отключение опции\n\n⚙️ Команды /cmd",
    "en": "👩🏽‍💻 <b>Current</b> /work-value: {0}\n\n<code>/work 09:00 21:00</code>    working hours\n<code>/work 0</code>   disable option\n\n⚙️ Commands /cmd",
    "es": "👩🏽‍💻 <b>Actual</b> /work-valor: {0}\n\n<code>/work 09:00 21:00</code>    horas de trabajo\n<code>/work 0</code>   desactivar opción\n\n⚙️ Comandos /cmd",
    "fr": "👩🏽‍💻 <b>Actuel</b> /valeur-de-travail: {0}\n\n<code>/work 09:00 21:00</code>    heures de travail\n<code>/work 0</code>   désactiver l'option\n\n⚙️ Commandes /cmd",
    "zh": "👩🏽‍💻 <b>当前</b> /work-值: {0}\n\n<code>/work 09:00 21:00</code>    工作时间\n<code>/work 0</code>   关闭选项\n\n⚙️ 命令 /cmd",
    "ar": "👩🏽‍💻 <b>الحالي</b> /work-القيمة: {0}\n\n<code>/work 09:00 21:00</code>    ساعات العمل\n<code>/work 0</code>   تعطيل الخيار\n\n⚙️ الأوامر /cmd",
}
l_len_finish = {
    "ru": "👩🏽‍💻 <b>Текущее</b> /len-значение: {0}\n\n<code>/len 160</code>  max-длина 160 символов\n<code>/len 0</code> отключение опции\n\n⚙️ Команды /cmd",
    "en": "👩🏽‍💻 <b>Current</b> /len-value: {0}\n\n<code>/len 160</code>  max-length 160 characters\n<code>/len 0</code> disable option\n\n⚙️ Commands /cmd",
    "es": "👩🏽‍💻 <b>Actual</b> /len-valor: {0}\n\n<code>/len 160</code>  longitud-máx 160 caracteres\n<code>/len 0</code> desactivar opción\n\n⚙️ Comandos /cmd",
    "fr": "👩🏽‍💻 <b>Actuel</b> /len-valeur: {0}\n\n<code>/len 160</code>  longueur-max 160 caractères\n<code>/len 0</code> désactiver l'option\n\n⚙️ Commandes /cmd",
    "zh": "👩🏽‍💻 <b>当前</b> /len-值: {0}\n\n<code>/len 160</code>  最大长度 160 个字符\n<code>/len 0</code>  关闭选项\n\n⚙️ 命令 /cmd",
    "ar": "👩🏽‍💻 <b>الحالي</b> /len-القيمة: {0}\n\n<code>/len 160</code>  الحد الأقصى للطول 160 حرفًا\n<code>/len 0</code> تعطيل الخيار\n\n⚙️ الأوامر /cmd",
}
l_work_msg = {
    "ru": "<blockquote>👩🏽‍💻 <b>Часы</b> работы группы: {0}-{1}</blockquote>",
    "en": "<blockquote>👩🏽‍💻 <b>Group</b> working hours: {0}-{1}</blockquote>",
    "es": "<blockquote>👩🏽‍💻 <b>Horas</b> de trabajo del grupo: {0}-{1}</blockquote>",
    "fr": "<blockquote>👩🏽‍💻 <b>Heures</b> de travail du groupe : {0}-{1}</blockquote>",
    "zh": "<blockquote>👩🏽‍💻 <b>小组</b> 工作时间: {0}-{1}</blockquote>",
    "ar": "<blockquote>👩🏽‍💻 <b>ساعات</b> عمل المجموعة: {0}-{1}</blockquote>",
}
l_help_handler = {
    "ru": "<blockquote>👩🏽‍💻 <b>Команды</b> пользователя:\n\n/report - сообщить о нарушении\n/happy - получить радость\n/thanks - поблагодарить\n/birthday - поздравить\n/vote - голосовать\n\n👩🏽‍💻 <b>Добавь</b> <i>кѻмментарий</i> после команды если необходимо</blockquote>",
    "en": "<blockquote>👩🏽‍💻 <b>User</b> commands:\n\n/report - report a violation\n/happy - receive joy\n/thanks - thank\n/birthday - congratulate\n/vote - vote\n\n👩🏽‍💻 <b>Add</b> <i>comment</i> after the command if necessary</blockquote>",
    "es": "<blockquote>👩🏽‍💻 <b>Comandos</b> del usuario:\n\n/reportar - informar sobre una infracción\n/feliz - obtener alegría\n/gracias - agradecer\n/cumpleaños - felicitar\n/votar - votar\n\n👩🏽‍💻 <b>Agrega</b> <i>un comentario</i> después del comando si es necesario</blockquote>",
    "fr": "<blockquote>👩🏽‍💻 <b>Commandes</b> de l'utilisateur :\n\n/report - signaler une violation\n/happy - obtenir de la joie\n/thanks - remercier\n/birthday - féliciter\n/vote - voter\n\n👩🏽‍💻 <b>Ajoutez</b> <i>un commentaire</i> après la commande si nécessaire</blockquote>",
    "zh": "<blockquote>👩🏽‍💻 <b>用户</b>的命令：\n\n/report - 举报违规\n/happy - 获得快乐\n/thanks - 表达感谢\n/birthday - 祝贺\n/vote - 投票\n\n👩🏽‍💻 <b>如果需要</b>，在命令后添加 <i>评论</i></blockquote>",
    "ar": "<blockquote>👩🏽‍💻 <b>أوامر</b> المستخدم:\n\n/report - الإبلاغ عن انتهاك\n/happy - الحصول على السعادة\n/thanks - شكر\n/birthday - تهنئة\n/vote - التصويت\n\n👩🏽‍💻 <b>أضف</b> <i>تعليقًا</i> بعد الأمر إذا لزم الأمر</blockquote>",
}
l_report_handler = {
    "ru": "<blockquote>❗️<b>Информация</b> передана администратору. Пользователь {0} взят на карандаш</blockquote>",
    "en": "<blockquote>❗️<b>Information</b> has been passed to the administrator. User {0} is under observation</blockquote>",
    "es": "<blockquote>❗️<b>Información</b> transmitida al administrador. El usuario {0} está bajo observación</blockquote>",
    "fr": "<blockquote>❗️<b>Informations</b> transmises à l'administrateur. L'utilisateur {0} est sous surveillance</blockquote>",
    "zh": "<blockquote>❗️<b>信息</b>已传递给管理员。用户 {0} 被记录在案</blockquote>",
    "ar": "<blockquote>❗️<b>تم نقل</b> المعلومات إلى المسؤول. المستخدم {0} تم وضعه تحت المراقبة</blockquote>",
}
l_report_handler_chn = {
    "ru": "<blockquote>❗️<b>Информация</b> передана администратору. Канал <b>{0}</b> взят на карандаш</blockquote>",
    "en": "<blockquote>❗️<b>Information</b> has been forwarded to the administrator. Channel <b>{0}</b> is under observation</blockquote>",
    "es": "<blockquote>❗️<b>Información</b> enviada al administrador. El canal <b>{0}</b> ha sido anotado</blockquote>",
    "fr": "<blockquote>❗️<b>Information</b> transmise à l'administrateur. Le canal <b>{0}</b> est pris en compte</blockquote>",
    "zh": "<blockquote>❗️<b>信息</b>已传递给管理员。频道 <b>{0}</b> 被记录在案</blockquote>",
    "ar": "<blockquote>❗️<b>تم نقل</b> المعلومات إلى المسؤول. تم أخذ القناة <b>{0}</b> بعين الاعتبار</blockquote>",
}
l_report_admin = {
    "ru": "<blockquote>❗️ <b>Пользователь</b> {0} в группе <b>{1}</b> просит обратить внимание на сообщение {2}{3}</blockquote>",
    "en": "<blockquote>❗️ <b>User</b> {0} in group <b>{1}</b> requests attention to the message {2}{3}</blockquote>",
    "es": "<blockquote>❗️ <b>Usuario</b> {0} en el grupo <b>{1}</b> pide atención al mensaje {2}{3}</blockquote>",
    "fr": "<blockquote>❗️ <b>Utilisateur</b> {0} dans le groupe <b>{1}</b> demande de prêter attention au message {2}{3}</blockquote>",
    "zh": "<blockquote>❗️ <b>用户</b> {0} 在群组 <b>{1}</b> 中请求关注消息 {2}{3}</blockquote>",
    "ar": "<blockquote>❗️ <b>المستخدم</b> {0} في المجموعة <b>{1}</b> يطلب الانتباه إلى الرسالة {2}{3}</blockquote>",
}
l_report_reply = {
    "ru": "<blockquote>❗ <b>Отправь</b> команду в ответ на сообщение пользователя</blockquote>",
    "en": "<blockquote>❗ <b>Send</b> a command in response to the user's message</blockquote>",
    "es": "<blockquote>❗ <b>Envía</b> un comando en respuesta al mensaje del usuario</blockquote>",
    "fr": "<blockquote>❗ <b>Envoyez</b> une commande en réponse au message de l'utilisateur</blockquote>",
    "zh": "<blockquote>❗ <b>发送</b> 命令以回复用户消息</blockquote>",
    "ar": "<blockquote>❗ <b>أرسل</b> الأمر ردًا على رسالة المستخدم</blockquote>",
}
l_thanks_handler = {
    "ru": "<blockquote>🎉 <b>От имени</b> группы <b>{0}</b> обьявляется благодарность {1}{2}</blockquote>",
    "en": "<blockquote>🎉 <b>On behalf of</b> the group <b>{0}</b>, gratitude is expressed {1}{2}</blockquote>",
    "es": "<blockquote>🎉 <b>En nombre</b> del grupo <b>{0}</b> se expresa agradecimiento {1}{2}</blockquote>",
    "fr": "<blockquote>🎉 <b>Au nom</b> du groupe <b>{0}</b> est exprimée la gratitude {1}{2}</blockquote>",
    "zh": "<blockquote>🎉 <b>代表</b> 小组 <b>{0}</b> 表达感谢 {1}{2}</blockquote>",
    "ar": "<blockquote>🎉 <b>بالنيابة عن</b> مجموعة <b>{0}</b> يتم الإعلان عن الشكر {1}{2}</blockquote>",
}
l_thanks_reply = {
    "ru": "<blockquote>🎉 <b>Отправь</b> команду в ответ на сообщение пользователя</blockquote>",
    "en": "<blockquote>🎉 <b>Send</b> a command in response to the user's message</blockquote>",
    "es": "<blockquote>🎉 <b>Envía</b> un comando en respuesta al mensaje del usuario</blockquote>",
    "fr": "<blockquote>🎉 <b>Envoyez</b> une équipe en réponse au message de l'utilisateur</blockquote>",
    "zh": "<blockquote>🎉 <b>发送</b> 团队以回复用户消息</blockquote>",
    "ar": "<blockquote>🎉 <b>أرسل</b> فريقًا ردًا على رسالة المستخدم</blockquote>",
}
l_birthday_handler = {
    "ru": "<blockquote>🥳 <b>От</b> имени группы <b>{0}</b> поздравляем с днем рождения {1}{2}</blockquote>",
    "en": "<blockquote>🥳 <b>On behalf of the group</b> <b>{0}</b> we congratulate you on your birthday {1}{2}</blockquote>",
    "es": "<blockquote>🥳 <b>De</b> parte del grupo <b>{0}</b> felicitamos por el cumpleaños de {1}{2}</blockquote>",
    "fr": "<blockquote>🥳 <b>De</b> la part du groupe <b>{0}</b> nous vous souhaitons un joyeux anniversaire {1}{2}</blockquote>",
    "zh": "<blockquote>🥳 <b>代表</b> 群组 <b>{0}</b> 祝 {1} 生日快乐{2}</blockquote>",
    "ar": "<blockquote>🥳 <b>من</b> اسم المجموعة <b>{0}</b> نهنئكم بعيد ميلاد {1}{2}</blockquote>",
}
l_vote_reply = {
    "ru": "<blockquote>🪻 <b>Отправь</b> команду в ответ на сообщение пользователя</blockquote>",
    "en": "<blockquote>🪻 <b>Send</b> a command in response to the user's message</blockquote>",
    "es": "<blockquote>🪻 <b>Envía</b> un comando en respuesta al mensaje del usuario</blockquote>",
    "fr": "<blockquote>🪻 <b>Envoyez</b> une commande en réponse au message de l'utilisateur</blockquote>",
    "zh": "<blockquote>🪻 <b>发送</b> 命令以回复用户消息</blockquote>",
    "ar": "<blockquote>🪻 <b>أرسل</b> فريقًا ردًا على رسالة المستخدم</blockquote>",
}
l_len_text = {
    "ru": "👩🏽‍💻 <b>Введи</b> max <i>длину</i> текста сообщения\n\n👩🏽‍💻 <b>Текущее</b> /len-значение: {0}\n<code>/len 160</code>  max-длина 160 символов\n<code>/len 0</code> отключение опции",
    "en": "👩🏽‍💻 <b>Enter</b> max <i>length</i> of the message text\n\n👩🏽‍💻 <b>Current</b> /len-value: {0}\n<code>/len 160</code>  max-length 160 characters\n<code>/len 0</code> disable the option",
    "es": "👩🏽‍💻 <b>Introduce</b> la longitud <i>máxima</i> del mensaje\n\n👩🏽‍💻 <b>Actual</b> /valor-len: {0}\n<code>/len 160</code>  longitud máxima 160 caracteres\n<code>/len 0</code> desactivar opción",
    "fr": "👩🏽‍💻 <b>Entrez</b> la longueur max <i>du</i> message\n\n👩🏽‍💻 <b>Actuel</b> /valeur-len: {0}\n<code>/len 160</code>  longueur max 160 caractères\n<code>/len 0</code> désactiver l'option",
    "zh": "👩🏽‍💻 <b>输入</b> 最大 <i>消息</i> 文本长度\n\n👩🏽‍💻 <b>当前</b> /len 值: {0}\n<code>/len 160</code> 最大长度 160 个字符\n<code>/len 0</code> 关闭选项",
    "ar": "👩🏽‍💻 <b>أدخل</b> max <i>طول</i> نص الرسالة\n\n👩🏽‍💻 <b>الحالي</b> /len-القيمة: {0}\n<code>/len 160</code>  max-الطول 160 حرفًا\n<code>/len 0</code> تعطيل الخيار",
}
l_cmd_reply = {
    "ru": "<blockquote>👩🏽‍💻 <b>Отправь</b> команду в ответ на сообщение </blockquote>",
    "en": "<blockquote>👩🏽‍💻 <b>Send</b> a command in response to the message </blockquote>",
    "es": "<blockquote>👩🏽‍💻 <b>Envía</b> un comando en respuesta al mensaje </blockquote>",
    "fr": "<blockquote>👩🏽‍💻 <b>Envoyez</b> une commande en réponse au message </blockquote>",
    "zh": "<blockquote>👩🏽‍💻 <b>发送</b> 命令以回复消息 </blockquote>",
    "ar": "<blockquote>👩🏽‍💻 <b>أرسل</b> الأمر ردًا على الرسالة </blockquote>",
}
l_status_pin = {
    "ru": "Закреп сообщ",
    "en": "Pin message",
    "es": "Fijar mensaje",
    "fr": "Épingler le message",
    "zh": "固定消息",
    "ar": "ثبّت الرسالة",
}
l_status_profile = {
    "ru": "Изменение профиля группы",
    "en": "Group profile change",
    "es": "Cambio de perfil del grupo",
    "fr": "Changement de profil de groupe",
    "zh": "更改组配置文件",
    "ar": "تغيير ملف تعريف المجموعة",
}
l_sendmsg = {
    "ru": "Отправка сообщ",
    "en": "Sending message",
    "es": "Envío de mensajes",
    "fr": "Envoi de message",
    "zh": "发送消息",
    "ar": "إرسال رسالة",
}
l_status_limit = {
    "ru": "Ограничения до",
    "en": "Restrictions until",
    "es": "Restricciones hasta",
    "fr": "Restrictions jusqu'à",
    "zh": "限制到",
    "ar": "القيود حتى",
}
l_status_without = {
    "ru": "(отсутствует) для",
    "en": "(available) for",
    "es": "(faltante) para",
    "fr": "(aucun) pour",
    "zh": "(缺失) 为",
    "ar": "(غير موجود) لـ",
}
l_karma_current = {
    "ru": "<blockquote><b>Текущая</b> карма пользователя</blockquote>",
    "en": "<blockquote><b>Current</b> user karma</blockquote>",
    "es": "<blockquote><b>La</b> karma actual del usuario</blockquote>",
    "fr": "<blockquote><b>La</b> karma actuelle de l'utilisateur</blockquote>",
    "zh": "<blockquote><b>当前</b>用户的业力</blockquote>",
    "ar": "<blockquote><b>الكارما</b> الحالية للمستخدم</blockquote>",
}
l_karma_add = {
    "ru": "👩🏽‍💻 <code>/k+</code> добавить карму",
    "en": "👩🏽‍💻 <code>/k+</code> add karma",
    "es": "👩🏽‍💻 <code>/k+</code> añadir karma",
    "fr": "👩🏽‍💻 <code>/k+</code> ajouter de la karma",
    "zh": "👩🏽‍💻 <code>/k+</code> 添加卡尔玛",
    "ar": "👩🏽‍💻 <code>/k+</code> إضافة الكارما",
}
l_karma_in_group = {
    "ru": "в группе",
    "en": "in the group",
    "es": "en el grupo",
    "fr": "dans le groupe",
    "zh": "在小组中",
    "ar": "في المجموعة",
}
l_karma_all = {
    "ru": "<blockquote>🪺 <b>Карма</b> пользователей группы <b>{0}</b></blockquote>",
    "en": "<blockquote>🪺 <b>Karma</b> of users in the group <b>{0}</b></blockquote>",
    "es": "<blockquote>🪺 <b>Karma</b> de los usuarios del grupo <b>{0}</b></blockquote>",
    "fr": "<blockquote>🪺 <b>Karma</b> des utilisateurs du groupe <b>{0}</b></blockquote>",
    "zh": "<blockquote>🪺 <b>用户</b> 群组 <b>{0}</b> 的 <b>业力</b></blockquote>",
    "ar": "<blockquote>🪺 <b>كارما</b> مستخدمي المجموعة <b>{0}</b></blockquote>",
}
l_karma_off = {
    "ru": "<blockquote>🪹 <b>Карма</b> пользователей группы <b>{0}</b> не установлена</blockquote>",
    "en": "<blockquote>🪹 <b>The karma</b> of the group users <b>{0}</b> is not set</blockquote>",
    "es": "<blockquote>🪹 <b>La karma</b> de los usuarios del grupo <b>{0}</b> no está establecida</blockquote>",
    "fr": "<blockquote>🪹 <b>La karma</b> des utilisateurs du groupe <b>{0}</b> n'est pas définie</blockquote>",
    "zh": "<blockquote>🪹 <b>用户</b> 群组 <b>{0}</b> 的 <b>业力</b> 尚未设置</blockquote>",
    "ar": "<blockquote>🪹 <b>كارما</b> مستخدمي المجموعة <b>{0}</b> غير محددة</blockquote>",
}
l_tag_handler = {
    "ru": "<blockquote>👩🏽‍💻 <b>Введи</b> сообщение при @-упоминании пользователей в формате:\n<code>/tag сообщение</code></blockquote>",
    "en": "<blockquote>👩🏽‍💻 <b>Enter</b> a message when @-mentioning users in the format: <code>/tag message</code></blockquote>",
    "es": "<blockquote>👩🏽‍💻 <b>Introduce</b> un mensaje al mencionar a usuarios en el formato:\n<code>/tag mensaje</code></blockquote>",
    "fr": "<blockquote>👩🏽‍💻 <b>Entrez</b> un message lors de la mention des utilisateurs avec le format :\n<code>/tag message</code></blockquote>",
    "zh": "<blockquote>👩🏽‍💻 <b>输入</b> 在@提及用户时的消息格式：\n<code>/tag 消息</code></blockquote>",
    "ar": "<blockquote>👩🏽‍💻 <b>أدخل</b> رسالة عند @-الإشارة إلى المستخدمين بالتنسيق:\n<code>/tag رسالة</code></blockquote>",
}
l_ccheck_call = {
    "ru": "👮🏽 Для проверки подписки необходимо добавить @{0}-приложение в дополнительный канал и выполнить команду:\n\n/channel ССЫЛКА НА КАНАЛ",
    "en": "👮🏽 To verify the subscription, you need to add the @{0} app to the additional channel and execute the command:\n\n/channel CHANNEL LINK",
    "es": "👮🏽 Para verificar la suscripción, es necesario agregar la aplicación @{0} al canal adicional y ejecutar el comando:\n\n/channel ENLACE AL CANAL",
    "fr": "👮🏽 Pour vérifier l'abonnement, vous devez ajouter l'application @{0} dans le canal supplémentaire et exécuter la commande :\n\n/channel LIEN VERS LE CANAL",
    "zh": "👮🏽 要检查订阅，您需要将 @{0} 应用程序添加到额外频道并执行命令：\n\n/channel 频道链接",
    "ar": "👮🏽 للتحقق من الاشتراك، يجب إضافة تطبيق @{0} إلى القناة الإضافية وتنفيذ الأمر:\n\n/channel رابط القناة",
}
l_delay_text = {
    "ru": "<blockquote>👥 <b>Введи</b> корректное <i>число</i> минут для первичного ограничения новых пользователей (перед написанием их <u>1</u>го сообщ)\n\n👩🏽‍💻 <b>Текущее</b> /delay-значение: {0}\n<code>/delay 3</code>   ограничение на 3 мин\n<code>/delay 0</code>  отключение опции</blockquote>",
    "en": "<blockquote>👥 <b>Enter</b> the correct <i>number</i> of minutes for the initial restriction of new users (before sending their <u>1</u>st message)\n\n👩🏽‍💻 <b>Current</b> /delay value: {0}\n<code>/delay 3</code>   restriction for 3 min\n<code>/delay 0</code>  disable the option</blockquote>",
    "es": "<blockquote>👥 <b>Introduce</b> un <i>número</i> correcto de minutos para la limitación inicial de nuevos usuarios (antes de escribir su <u>1</u>er mensaje)\n\n👩🏽‍💻 <b>Valor</b> actual de /delay: {0}\n<code>/delay 3</code>   limitación de 3 min\n<code>/delay 0</code>  desactivación de la opción</blockquote>",
    "fr": "<blockquote>👥 <b>Entrez</b> un <i>nombre</i> correct de minutes pour la limitation initiale des nouveaux utilisateurs (avant d'écrire leur <u>1</u>er message)\n\n👩🏽‍💻 <b>Valeur</b> actuelle de /delay : {0}\n<code>/delay 3</code>   limitation à 3 min\n<code>/delay 0</code>  désactivation de l'option</blockquote>",
    "zh": "<blockquote>👥 <b>请输入</b> 正确的 <i>分钟</i> 数字，以限制新用户的初始消息（在他们发送 <u>第</u> 一条消息之前）\n\n👩🏽‍💻 <b>当前</b> /delay 值: {0}\n<code>/delay 3</code>   限制为 3 分钟\n<code>/delay 0</code>  关闭选项</blockquote>",
    "ar": "<blockquote>👥 <b>أدخل</b> عدد <i>الدقائق</i> الصحيح للحد الأولي من المستخدمين الجدد (قبل كتابة رسالتهم <u>1</u>)\n\n👩🏽‍💻 <b>القيمة الحالية</b> /delay: {0}\n<code>/delay 3</code>   حد لمدة 3 دقائق\n<code>/delay 0</code>  تعطيل الخيار</blockquote>",
}
l_delay_finish = {
    "ru": "<blockquote>👩🏽‍💻 <b>Текущее</b> /delay-значение: {0}\n\n<code>/delay 3</code>    ограничение на 3 мин\n<code>/delay 0</code>   отключение опции\n\n⚙️ Команды /cmd</blockquote>",
    "en": "<blockquote>👩🏽‍💻 <b>Current</b> /delay value: {0}\n\n<code>/delay 3</code>    limit to 3 min\n<code>/delay 0</code>   disable option\n\n⚙️ Commands /cmd</blockquote>",
    "es": "<blockquote>👩🏽‍💻 <b>Actual</b> /valor-de-retraso: {0}\n\n<code>/retraso 3</code>    límite de 3 min\n<code>/retraso 0</code>   desactivación de la opción\n\n⚙️ Comandos /cmd</blockquote>",
    "fr": "<blockquote>👩🏽‍💻 <b>Actuel</b> /valeur-de-délai: {0}\n\n<code>/delay 3</code>    limite de 3 min\n<code>/delay 0</code>   désactivation de l'option\n\n⚙️ Commandes /cmd</blockquote>",
    "zh": "<blockquote>👩🏽‍💻 <b>当前</b> /delay-值: {0}\n\n<code>/delay 3</code>    限制为 3 分钟\n<code>/delay 0</code>   关闭选项\n\n⚙️ 命令 /cmd</blockquote>",
    "ar": "<blockquote>👩🏽‍💻 <b>الحالي</b> /قيمة التأخير: {0}\n\n<code>/تأخير 3</code>    حد 3 دقائق\n<code>/تأخير 0</code>   تعطيل الخيار\n\n⚙️ الأوامر /cmd</blockquote>",
}
l_chn_correct = {
    "ru": "<blockquote>👮🏽 <b>Добавь</b> @{0}-приложение в канал и отправь корректную <i>ссылку</i> этого канала\n\n👩🏽‍💻 Например, <code>/channel {1}</code></blockquote>",
    "en": "<blockquote>👮🏽 <b>Add</b> the @{0} app to the channel and send the correct <i>link</i> to this channel\n\n👩🏽‍💻 For example, <code>/channel {1}</code></blockquote>",
    "es": "<blockquote>👮🏽 <b>Agrega</b> @{0} a la canal y envía el <i>enlace</i> correcto de este canal\n\n👩🏽‍💻 Por ejemplo, <code>/channel {1}</code></blockquote>",
    "fr": "<blockquote>👮🏽 <b>Ajoute</b> l'application @{0} au canal et envoie le <i>lien</i> correct de ce canal\n\n👩🏽‍💻 Par exemple, <code>/channel {1}</code></blockquote>",
    "zh": "<blockquote>👮🏽 <b>添加</b> @{0} 应用到频道并发送该频道的正确 <i>链接</i>\n\n👩🏽‍💻 例如，<code>/channel {1}</code></blockquote>",
    "ar": "<blockquote>👮🏽 <b>أضف</b> @{0} إلى القناة وأرسل <i>رابط</i> صحيح لهذه القناة\n\n👩🏽‍💻 على سبيل المثال، <code>/channel {1}</code></blockquote>",
}
l_fsm_stop_add_caption = {
    "ru": "<blockquote>🧾 <b>Готово!</b> <b>Текущее</b> количество стоп-слов в {0}-файле: <u>{1}</u></blockquote>",
    "en": "<blockquote>🧾 <b>Done!</b> <b>Current</b> number of stop words in the {0} file: <u>{1}</u></blockquote>",
    "es": "<blockquote>🧾 <b>¡Listo!</b> <b>Cantidad</b> actual de palabras de parada en el archivo {0}: <u>{1}</u></blockquote>",
    "fr": "<blockquote>🧾 <b>Prêt!</b> <b>Nombre</b> actuel de mots d'arrêt dans le fichier {0} : <u>{1}</u></blockquote>",
    "zh": "<blockquote>🧾 <b>完成！</b> <b>当前</b> 在 {0} 文件中的停用词数量：<u>{1}</u></blockquote>",
    "ar": "<blockquote>🧾 <b>تم!</b> <b>العدد الحالي</b> من كلمات التوقف في ملف {0}: <u>{1}</u></blockquote>",
}
l_button_handler = {
    "ru": "<blockquote>👮🏽 <b>Готово!</b> Текущее <b>имя кнопки</b> на <i>входном контроле</i> установлено: {0}\n\n⚙️ Команды /cmd</blockquote>",
    "en": "<blockquote>👮🏽 <b>Done!</b> The current <b>button name</b> on the <i>input control</i> is set to: {0}\n\n⚙️ Commands /cmd</blockquote>",
    "es": "<blockquote>👮🏽 <b>¡Listo!</b> El <b>nombre del botón</b> actual en el <i>control de entrada</i> está establecido en: {0}\n\n⚙️ Comandos /cmd</blockquote>",
    "fr": "<blockquote>👮🏽 <b>Prêt!</b> Le <b>nom du bouton</b> actuel sur le <i>contrôle d'entrée</i> est défini sur : {0}\n\n⚙️ Commandes /cmd</blockquote>",
    "zh": "<blockquote>👮🏽 <b>完成！</b> 当前 <b>按钮名称</b> 在 <i>输入控制</i> 中设置为：{0}\n\n⚙️ 命令 /cmd</blockquote>",
    "ar": "<blockquote>👮🏽 <b>جاهز!</b> الاسم الحالي <b>للزر</b> على <i>وحدة التحكم المدخلة</i> تم تعيينه: {0}\n\n⚙️ الأوامر /cmd</blockquote>",
}
l_button_correct = {
    "ru": "<blockquote>👮🏽 <b>Введи</b> корректное название <i>для имени кнопки</i> 👮🏽 Входного контроля\n\n👩🏽‍💻 Например, <code>/button {0}</code></blockquote>",
    "en": "<blockquote>👮🏽 <b>Enter</b> a valid name <i>for the button</i> 👮🏽 Access Control\n\n👩🏽‍💻 For example, <code>/button {0}</code></blockquote>",
    "es": "<blockquote>👮🏽 <b>Introduce</b> un nombre correcto <i>para el nombre del botón</i> 👮🏽 de control de acceso\n\n👩🏽‍💻 Por ejemplo, <code>/button {0}</code></blockquote>",
    "fr": "<blockquote>👮🏽 <b>Entrez</b> un nom correct <i>pour le nom du bouton</i> 👮🏽 de contrôle d'accès\n\n👩🏽‍💻 Par exemple, <code>/button {0}</code></blockquote>",
    "zh": "<blockquote>👮🏽 <b>输入</b> 正确的名称 <i>作为按钮名称</i> 👮🏽 入口控制\n\n👩🏽‍💻 例如，<code>/button {0}</code></blockquote>",
    "ar": "<blockquote>👮🏽 <b>أدخل</b> اسمًا صحيحًا <i>لزر الاسم</i> 👮🏽 للتحكم في الدخول\n\n👩🏽‍💻 على سبيل المثال، <code>/button {0}</code></blockquote>",
}
l_GROUPP_CCHECKBTNNAME = {
    "ru": "✔ Я человек",
    "en": "✔ I am a person",
    "es": "✔ Soy una persona",
    "fr": "✔ Je suis une personne",
    "zh": "✔ 我是一个人",
    "ar": "✔ أنا إنسان",
}
_ccheck_other_person = {
    "ru": "👮🏽 Эта кнопка не для тебя",
    "en": "👮🏽 This button is not for you",
    "es": "👮🏽 Este botón no es para ti",
    "fr": "👮🏽 Ce bouton n'est pas pour toi",
    "zh": "👮🏽 这个按钮不适合你",
    "ar": "👮🏽 هذه الزر ليست لك",
}
l_ccheckchannel_link = {
    "ru": "👮🏽 Ссылка на {0} не доступна",
    "en": "👮🏽 The link to {0} is not available",
    "es": "👮🏽 El enlace a {0} no está disponible",
    "fr": "👮🏽 Le lien vers {0} n'est pas disponible",
    "zh": "👮🏽 {0} 的链接不可用",
    "ar": "👮🏽 الرابط إلى {0} غير متاح",
}
l_ccheckchannel_chn = {
    "ru": "👮🏽 Необходимо вступить в {0}\n\nПопробуй ещё раз позже",
    "en": "👮🏽 You need to join {0}\n\nPlease try again later",
    "es": "👮🏽 Es necesario unirse a {0}\n\nInténtalo de nuevo más tarde",
    "fr": "👮🏽 Vous devez rejoindre {0}\n\nEssayez encore une fois plus tard",
    "zh": "👮🏽 需要加入 {0}\n\n稍后再试",
    "ar": "👮🏽 يجب الانضمام إلى {0}\n\nحاول مرة أخرى لاحقًا",
}
l_ccheck_ban = {
    "ru": "👮🏽‍ <b>Пользователь</b> {0} не прошел входной контроль и был удален из группы",
    "en": "👮🏽‍ <b>User</b> {0} did not pass the entry control and was removed from the group",
    "es": "👮🏽‍ <b>Usuario</b> {0} no pasó el control de entrada y fue eliminado del grupo",
    "fr": "👮🏽‍ <b>Utilisateur</b> {0} n'a pas réussi le contrôle d'entrée et a été retiré du groupe",
    "zh": "👮🏽‍ <b>用户</b> {0} 未通过入场检查并已被移出群组",
    "ar": "👮🏽‍ <b>المستخدم</b> {0} لم يجتاز اختبار الدخول وتم حذفه من المجموعة",
}
l_ccheckchannel_error = {
    "ru": "👮🏽 Ошибка проверки",
    "en": "👮🏽 Verification error",
    "es": "👮🏽 Error de verificación",
    "fr": "👮🏽 Erreur de vérification",
    "zh": "👮🏽 检查错误",
    "ar": "👮🏽 خطأ في التحقق",
}
l_ccheck_wrong = {
    "ru": "👮🏽 К сожалению, ответ неверный\n\nПопробуй ещё раз позже",
    "en": "👮🏽 Unfortunately, the answer is incorrect\n\nPlease try again later",
    "es": "👮🏽 Lamentablemente, la respuesta es incorrecta\n\nInténtalo de nuevo más tarde",
    "fr": "👮🏽 Malheureusement, la réponse est incorrecte\n\nEssayez encore une fois plus tard",
    "zh": "👮🏽 很遗憾，答案不正确\n\n请稍后再试",
    "ar": "👮🏽 للأسف، الإجابة غير صحيحة\n\nحاول مرة أخرى لاحقًا",
}
l_ccheck_time = {
    "ru": "👮🏽 Входной контроль пройден за {0} сек",
    "en": "👮🏽 Entry control passed in {0} sec",
    "es": "👮🏽 Control de entrada superado en {0} seg",
    "fr": "👮🏽 Le contrôle d'entrée a été passé en {0} sec",
    "zh": "👮🏽 入境检查已在 {0} 秒内通过",
    "ar": "👮🏽 تم اجتياز الفحص المدخلي في {0} ثانية",
}
l_ccheck_other_person = {
    "ru": "👮🏽 Эта кнопка не для тебя",
    "en": "👮🏽 This button is not for you",
    "es": "👮🏽 Este botón no es para ti",
    "fr": "👮🏽 Ce bouton n'est pas pour toi",
    "zh": "👮🏽 这个按钮不适合你",
    "ar": "👮🏽 هذه الزر ليس لك",
}
l_grp_need_super = {
    "ru": "🚫 @{0}-приложение удалено из <b>{1}</b> [id=<code>{2}</code>]. Группа слишком маленькая, необходимо дождаться преобразовавния в супергруппу",
    "en": "🚫 @{0}-app removed from <b>{1}</b> [id=<code>{2}</code>]. The group is too small, you need to wait for it to be converted to a supergroup.",
    "es": "🚫 @{0} - la aplicación ha sido eliminada de <b>{1}</b> [id=<code>{2}</code>]. El grupo es demasiado pequeño, es necesario esperar a la conversión en un supergrupo.",
    "fr": "🚫 @{0}-l'application a été supprimée de <b>{1}</b> [id=<code>{2}</code>]. Le groupe est trop petit, il est nécessaire d'attendre la transformation en supergroupe.",
    "zh": "🚫 @{0} 应用已从 <b>{1}</b> 中删除 [id=<code>{2}</code>]。群组太小，需要等待转换为超级群组。",
    "ar": "🚫 @{0} - تم حذف التطبيق من <b>{1}</b> [id=<code>{2}</code>]. المجموعة صغيرة جدًا، يجب الانتظار حتى تتحول إلى مجموعة سوبر.",
}
# endregion


# region FereyUserBot
l_usr_btn1 = {
    "ru": "👩🏽‍💻 Аккаунты",
    "en": "👩🏽‍💻 Accounts",
    "es": "👩🏽‍💻 Cuentas",
    "fr": "👩🏽‍💻 Comptes",
    "zh": "👩🏽‍💻 账户",
    "ar": "👩🏽‍💻 الحسابات",
}
l_usr_btn2 = {
    "ru": "💨 Подписка",
    "en": "💨 Subscription",
    "es": "💨 Suscripción",
    "fr": "💨 Abonnement",
    "zh": "💨 订阅",
    "ar": "💨 الاشتراك",
}
l_usr_welcome = {
    "ru": "🌱 <b>{0}</b>, добро пожаловать в #нейро-автоматизацию <b>Telegram</b>-аккаунтов:\n\n<blockquote>▪️авто-перевод/транскрибация\n▪️мониторинг групп/каналов\n▪️статусы и нейро-поиск\n▪️авто-реакции/декор\n▪️нотификации и команды</blockquote>",
    "en": "🌱 <b>{0}</b>, welcome to #neuro-automation of <b>Telegram</b> accounts:\n\n<blockquote>▪️auto-translation/transcription\n▪️group/channel monitoring\n▪️statuses and neuro-search\n▪️auto-reactions/decor\n▪️notifications and commands</blockquote>",
    "es": "🌱 <b>{0}</b>, bienvenido a la #neuro-automatización de cuentas de <b>Telegram</b>:\n\n<blockquote>▪️auto-traducción/transcripción\n▪️monitoreo de grupos/canales\n▪️estados y neuro-búsqueda\n▪️auto-reacciones/decoración\n▪️notificaciones y comandos</blockquote>",
    "fr": "🌱 <b>{0}</b>, bienvenue dans l'#neuro-automatisation des comptes <b>Telegram</b> :\n\n<blockquote>▪️auto-traduction/transcription\n▪️surveillance des groupes/canaux\n▪️statuts et neuro-recherche\n▪️auto-réactions/décor\n▪️notifications et commandes</blockquote>",
    "zh": "🌱 <b>{0}</b>, 欢迎来到 #神经自动化 <b>Telegram</b> 账户：\n\n<blockquote>▪️自动翻译/转录\n▪️群组/频道监控\n▪️状态和神经搜索\n▪️自动反应/装饰\n▪️通知和命令</blockquote>",
    "ar": "🌱 <b>{0}</b>, مرحبًا بك في #الأتمتة-العصبية <b>حسابات Telegram</b>:\n\n<blockquote>▪️الترجمة التلقائية/التفريغ\n▪️مراقبة المجموعات/القنوات\n▪️الحالات والبحث العصبي\n▪️ردود الفعل التلقائية/الزخرفة\n▪️الإشعارات والأوامر</blockquote>",
}
l_add_owner_to_contacts = {
    "ru": "📇 Контакт <b>{0}</b> успешно добавлен!",
    "en": "📇 Contact <b>{0}</b> has been successfully added!",
    "es": "📇 ¡Contacto <b>{0}</b> agregado exitosamente!",
    "fr": "📇 Contact <b>{0}</b> ajouté avec succès !",
    "zh": "📇 联系人 <b>{0}</b> 已成功添加！",
    "ar": "📇 تم إضافة جهة الاتصال <b>{0}</b> بنجاح!",
}
l_commands_handler_userbot = {
    "ru": "⚙️ <b>Команды</b> /cmd для @{0} работают также и в @{1}\n\n<code>/info</code>   <i>информация об аккаунте</i>\n<code>/stat</code>   <i>аналитика</i>\n<code>/update</code> <i>обновление профиля</i>\n<code>/status</code> <i>статус</i>\n<code>/off</code>  <i>выключение</i>\n<code>/repair</code> <i>очистка: чтение истории</i>\n<code>/reset</code>  <i>сброс: удаление диалогов</i>\n\n<code>/parse</code>      <i>[ссылка/id на чат] [аргумент]</i>\n<code>/spambot</code>    <i>карма аккаунта</i>\n<code>/leave</code>   <i>покинуть все группы и каналы</i>\n<code>/delete</code>  <i>удалить все диалоги</i>\n\n👩🏽‍💻 <b>Только</b> от имени аккаунта\n<code>/screen</code> <i>скриншот-уведомление</i>\n<code>/type +сообщ</code>   <i>печатание</i>\n<code>/think</code>   <i>обдумывание</i>\n<code>/emoji</code>  <i>подвижный emoji</i>\n<code>* отправка 📍гео возвращает @username-список</code>\n\n💨 <b>Подписка</b>: <i>{2}</i>",
    "en": "⚙️ <b>Commands</b> /cmd for @{0} also work in @{1}\n\n<code>/info</code>   <i>account information</i>\n<code>/stat</code>   <i>analytics</i>\n<code>/update</code> <i>profile update</i>\n<code>/status</code> <i>status</i>\n<code>/off</code>  <i>turn off</i>\n<code>/repair</code> <i>cleanup: reading history</i>\n<code>/reset</code>  <i>reset: deleting dialogs</i>\n\n<code>/parse</code>      <i>[link/id to chat] [argument]</i>\n<code>/spambot</code>    <i>account karma</i>\n<code>/leave</code>   <i>leave all groups and channels</i>\n<code>/delete</code>  <i>delete all dialogs</i>\n\n👩🏽‍💻 <b>Only</b> on behalf of the account\n<code>/screen</code> <i>screenshot notification</i>\n<code>/type +message</code>   <i>typing</i>\n<code>/think</code>   <i>thinking</i>\n<code>/emoji</code>  <i>animated emoji</i>\n<code>* sending 📍geo returns @username-list</code>\n\n💨 <b>Subscription</b>: <i>{2}</i>",
    "es": "⚙️ <b>Comandos</b> /cmd para @{0} también funcionan en @{1}\n\n<code>/info</code>   <i>información sobre la cuenta</i>\n<code>/stat</code>   <i>análisis</i>\n<code>/update</code> <i>actualización del perfil</i>\n<code>/status</code> <i>estado</i>\n<code>/off</code>  <i>apagado</i>\n<code>/repair</code> <i>limpieza: lectura del historial</i>\n<code>/reset</code>  <i>reinicio: eliminación de diálogos</i>\n\n<code>/parse</code>      <i>[enlace/id al chat] [argumento]</i>\n<code>/spambot</code>    <i>karma de la cuenta</i>\n<code>/leave</code>   <i>salir de todos los grupos y canales</i>\n<code>/delete</code>  <i>eliminar todos los diálogos</i>\n\n👩🏽‍💻 <b>Solo</b> en nombre de la cuenta\n<code>/screen</code> <i>notificación de captura de pantalla</i>\n<code>/type +mensaje</code>   <i>escribiendo</i>\n<code>/think</code>   <i>pensando</i>\n<code>/emoji</code>  <i>emoji animado</i>\n<code>* enviar 📍geolocalización devuelve la lista de @username</code>\n\n💨 <b>Suscripción</b>: <i>{2}</i>",
    "fr": "⚙️ <b>Commandes</b> /cmd pour @{0} fonctionnent également dans @{1}\n\n<code>/info</code>   <i>informations sur le compte</i>\n<code>/stat</code>   <i>analytique</i>\n<code>/update</code> <i>mise à jour du profil</i>\n<code>/status</code> <i>statut</i>\n<code>/off</code>  <i>désactivation</i>\n<code>/repair</code> <i>nettoyage : lecture de l'historique</i>\n<code>/reset</code>  <i>réinitialisation : suppression des dialogues</i>\n\n<code>/parse</code>      <i>[lien/id de chat] [argument]</i>\n<code>/spambot</code>    <i>karma du compte</i>\n<code>/leave</code>   <i>quitter tous les groupes et canaux</i>\n<code>/delete</code>  <i>supprimer tous les dialogues</i>\n\n👩🏽‍💻 <b>Uniquement</b> au nom du compte\n<code>/screen</code> <i>notification de capture d'écran</i>\n<code>/type +message</code>   <i>taper</i>\n<code>/think</code>   <i>réflexion</i>\n<code>/emoji</code>  <i>emoji animé</i>\n<code>* envoi 📍geo renvoie la liste @username</code>\n\n💨 <b>Abonnement</b> : <i>{2}</i>",
    "zh": "⚙️ <b>命令</b> /cmd 对 @{0} 同样适用于 @{1}\n\n<code>/info</code>   <i>账户信息</i>\n<code>/stat</code>   <i>分析</i>\n<code>/update</code> <i>更新资料</i>\n<code>/status</code> <i>状态</i>\n<code>/off</code>  <i>关闭</i>\n<code>/repair</code> <i>清理：读取历史</i>\n<code>/reset</code>  <i>重置：删除对话</i>\n\n<code>/parse</code>      <i>[链接/id 到聊天] [参数]</i>\n<code>/spambot</code>    <i>账户的声望</i>\n<code>/leave</code>   <i>离开所有群组和频道</i>\n<code>/delete</code>  <i>删除所有对话</i>\n\n👩🏽‍💻 <b>仅限</b> 以账户名义\n<code>/screen</code> <i>截图通知</i>\n<code>/type +消息</code>   <i>打字</i>\n<code>/think</code>   <i>思考</i>\n<code>/emoji</code>  <i>动态 emoji</i>\n<code>* 发送 📍地理位置返回 @username-列表</code>\n\n💨 <b>订阅</b>: <i>{2}</i>",
    "ar": "⚙️ <b>الأوامر</b> /cmd لـ @{0} تعمل أيضًا في @{1}\n\n<code>/info</code>   <i>معلومات عن الحساب</i>\n<code>/stat</code>   <i>التحليلات</i>\n<code>/update</code> <i>تحديث الملف الشخصي</i>\n<code>/status</code> <i>الحالة</i>\n<code>/off</code>  <i>إيقاف التشغيل</i>\n<code>/repair</code> <i>تنظيف: قراءة السجل</i>\n<code>/reset</code>  <i>إعادة تعيين: حذف المحادثات</i>\n\n<code>/parse</code>      <i>[رابط/معرف الدردشة] [حجة]</i>\n<code>/spambot</code>    <i>كارما الحساب</i>\n<code>/leave</code>   <i>مغادرة جميع المجموعات والقنوات</i>\n<code>/delete</code>  <i>حذف جميع المحادثات</i>\n\n👩🏽‍💻 <b>فقط</b> باسم الحساب\n<code>/screen</code> <i>إشعار لقطة الشاشة</i>\n<code>/type +رسالة</code>   <i>الكتابة</i>\n<code>/think</code>   <i>التفكير</i>\n<code>/emoji</code>  <i>إيموجي متحرك</i>\n<code>* الإرسال 📍الجغرافيا يعيد قائمة @username</code>\n\n💨 <b>الاشتراك</b>: <i>{2}</i>",
}
l_current_auth = {
    "ru": "текущая",
    "en": "current",
    "es": "actual",
    "fr": "actuel",
    "zh": "当前",
    "ar": "الحالية",
}
l_ctranscribe_res = {
    "ru": "👩🏽‍💻 <b>Транскрибация</b> <i>{0}</i> для {1}",
    "en": "👩🏽‍💻 <b>Transcription</b> <i>{0}</i> for {1}",
    "es": "👩🏽‍💻 <b>Transcripción</b> <i>{0}</i> para {1}",
    "fr": "👩🏽‍💻 <b>Transcription</b> <i>{0}</i> pour {1}",
    "zh": "👩🏽‍💻 <b>转录</b> <i>{0}</i> 为 {1}",
    "ar": "👩🏽‍💻 <b>نسخ</b> <i>{0}</i> لـ {1}",
}
l_cservice_user_online = {
    "ru": "<b>👩🏽‍💻 Пользователь</b>: {0} в сети",
    "en": "<b>👩🏽‍💻 User</b>: {0} online",
    "es": "<b>👩🏽‍💻 Usuario</b>: {0} en línea",
    "fr": "<b>👩🏽‍💻 Utilisateur</b>: {0} en ligne",
    "zh": "<b>👩🏽‍💻 用户</b>: {0} 在线",
    "ar": "<b>👩🏽‍💻 المستخدم</b>: {0} متصل بالإنترنت",
}
l_cword_find = {
    "ru": "👩🏽‍💻 <b>Мониторинг слов</b>: <code>{0}</code> [{1}]",
    "en": "👩🏽‍💻 <b>Word Monitoring</b>: <code>{0}</code> [{1}]",
    "es": "👩🏽‍💻 <b>Monitoreo de palabras</b>: <code>{0}</code> [{1}]",
    "fr": "👩🏽‍💻 <b>Suivi des mots</b>: <code>{0}</code> [{1}]",
    "zh": "👩🏽‍💻 <b>词监控</b>: <code>{0}</code> [{1}]",
    "ar": "👩🏽‍💻 <b>مراقبة الكلمات</b>: <code>{0}</code> [{1}]",
}
l_delete_handler = {
    "ru": "👩🏽‍💻 <b>Удаление</b> диалогов выполнено",
    "en": "👩🏽‍💻 <b>Dialog</b> deletion completed",
    "es": "👩🏽‍💻 <b>Eliminación</b> de diálogos completada",
    "fr": "👩🏽‍💻 <b>Suppression</b> des dialogues effectuée",
    "zh": "👩🏽‍💻 <b>对话</b> 删除完成",
    "ar": "👩🏽‍💻 <b>تم حذف</b> المحادثات",
}
l_forward_message = {
    "ru": "👩🏽‍💻 <b>Пересылка</b> от {0}:",
    "en": "👩🏽‍💻 <b>Forwarding</b> from {0}:",
    "es": "👩🏽‍💻 <b>Reenvío</b> de {0}:",
    "fr": "👩🏽‍💻 <b>Transfert</b> de {0} :",
    "zh": "👩🏽‍💻 <b>转发</b> 来自 {0}:",
    "ar": "👩🏽‍💻 <b>إعادة توجيه</b> من {0}:",
}
l_have_read = {
    "ru": "👩🏽‍💻 {0} прочитал сообщение",
    "en": "👩🏽‍💻 {0} read the message",
    "es": "👩🏽‍💻 {0} leyó el mensaje",
    "fr": "👩🏽‍💻 {0} a lu le message",
    "zh": "👩🏽‍💻 {0} 阅读了消息",
    "ar": "👩🏽‍💻 {0} قرأ الرسالة",
}
l_idea = {
    "ru": "💡 <b>Идея!</b>",
    "en": "💡 <b>Idea!</b>",
    "es": "💡 <b>¡Idea!</b>",
    "fr": "💡 <b>Idée!</b>",
    "zh": "💡 <b>想法！</b>",
    "ar": "💡 <b>فكرة!</b>",
}
l_leave_handler = {
    "ru": "👩🏽‍💻 <b>Выход</b> из групп/каналов выполнен",
    "en": "👩🏽‍💻 <b>Exit</b> from groups/channels completed",
    "es": "👩🏽‍💻 <b>Salida</b> de grupos/canales completada",
    "fr": "👩🏽‍💻 <b>Sortie</b> des groupes/canaux effectuée",
    "zh": "👩🏽‍💻 <b>已退出</b> 群组/频道",
    "ar": "👩🏽‍💻 <b>تم الخروج</b> من المجموعات/القنوات",
}
l_parse_handler_err = {
    "ru": "👩🏽‍💻 Вставь корректную ссылку, повтори операцию или попробуй вступить вручную",
    "en": "👩🏽‍💻 Insert the correct link, repeat the operation, or try to join manually",
    "es": "👩🏽‍💻 Inserta el enlace correcto, repite la operación o intenta unirte manualmente",
    "fr": "👩🏽‍💻 Insérez le lien correct, répétez l'opération ou essayez de rejoindre manuellement.",
    "zh": "👩🏽‍💻 插入正确的链接，重复操作或尝试手动加入",
    "ar": "👩🏽‍💻 أدخل الرابط الصحيح، أعد العملية أو حاول الانضمام يدويًا",
}
l_think_handler = {
    "ru": "💭 Думаю об этом.. {0}%",
    "en": "💭 I'm thinking about it.. {0}%",
    "es": "💭 Estoy pensando en esto.. {0}%",
    "fr": "💭 Je pense à ça.. {0}%",
    "zh": "💭 我在想这个.. {0}%",
    "ar": "💭 أفكر في ذلك.. {0}%",
}
l_translated_in = {
    "ru": "👩🏽‍💻 <b>Переведено</b> в [{0}]-язык для {1} [<code>{2}</code>]",
    "en": "👩🏽‍💻 <b>Translated</b> to [{0}] language for {1} [<code>{2}</code>]",
    "es": "👩🏽‍💻 <b>Traducido</b> al [{0}] idioma para {1} [<code>{2}</code>]",
    "fr": "👩🏽‍💻 <b>Traduit</b> en [{0}] langue pour {1} [<code>{2}</code>]",
    "zh": "👩🏽‍💻 <b>翻译</b> 为 [{0}] 语言以供 {1} [<code>{2}</code>]",
    "ar": "👩🏽‍💻 <b>مترجم</b> إلى [{0}] لغة لـ {1} [<code>{2}</code>]",
}
l_update_fun = {
    "ru": "👩🏽‍💻 <b>Аккаунт:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n<b>Био:</b> {3}\n\n✅ <i>Профиль обновлен</i>\n\n⚙️ <b>Команды</b> /cmd",
    "en": "👩🏽‍💻 <b>Account:</b> {0}  \n[<b>id</b>=<code>{1}</code>, +{2}]  \n<b>Bio:</b> {3}  \n\n✅ <i>Profile updated</i>  \n\n⚙️ <b>Commands</b> /cmd",
    "es": "👩🏽‍💻 <b>Cuenta:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n<b>Bio:</b> {3}\n\n✅ <i>Perfil actualizado</i>\n\n⚙️ <b>Comandos</b> /cmd",
    "fr": "👩🏽‍💻 <b>Compte :</b> {0}  \n[<b>id</b>=<code>{1}</code>, +{2}]  \n<b>Bio :</b> {3}  \n\n✅ <i>Profil mis à jour</i>  \n\n⚙️ <b>Commandes</b> /cmd",
    "zh": "👩🏽‍💻 <b>账户:</b> {0}  \n[<b>id</b>=<code>{1}</code>, +{2}]  \n<b>简介:</b> {3}  \n\n✅ <i>个人资料已更新</i>  \n\n⚙️ <b>命令</b> /cmd",
    "ar": "👩🏽‍💻 <b>الحساب:</b> {0}  \n[<b>معرف</b>=<code>{1}</code>, +{2}]  \n<b>السيرة الذاتية:</b> {3}  \n\n✅ <i>تم تحديث الملف الشخصي</i>  \n\n⚙️ <b>الأوامر</b> /cmd",
}
l_usr_flt_delhistory_done = {
    "ru": "👩🏽‍💻 <b>Удаление</b> <u>{0}</u> своих сообщений в <code>{1}</code> завершено",
    "en": "👩🏽‍💻 <b>Deletion</b> <u>{0}</u> of your messages in <code>{1}</code> is complete",
    "es": "👩🏽‍💻 <b>Eliminación</b> <u>{0}</u> de sus mensajes en <code>{1}</code> completada",
    "fr": "👩🏽‍💻 <b>Suppression</b> <u>{0}</u> de vos messages dans <code>{1}</code> terminée",
    "zh": "👩🏽‍💻 <b>删除</b> <u>{0}</u> 在 <code>{1}</code> 的消息已完成",
    "ar": "👩🏽‍💻 <b>حذف</b> <u>{0}</u> رسائلك في <code>{1}</code> مكتمل",
}
l_usr_flt_usrhistory = {
    "ru": "👩🏽‍💻 <b>Необходимо</b> указать:\n\n<code>/usrhistory chat_id user_id cnt_limit</code>, где\n<blockquote>chat_id - группа\nuser_id - пользователь\ncnt_limit - количество сообщений\n</blockquote>",
    "en": "👩🏽‍💻 <b>It is necessary</b> to specify:\n\n<code>/usrhistory chat_id user_id cnt_limit</code>, where\n<blockquote>chat_id - group\nuser_id - user\ncnt_limit - number of messages\n</blockquote>",
    "es": "👩🏽‍💻 <b>Es necesario</b> indicar:\n\n<code>/usrhistory chat_id user_id cnt_limit</code>, donde\n<blockquote>chat_id - grupo\nuser_id - usuario\ncnt_limit - número de mensajes\n</blockquote>",
    "fr": "👩🏽‍💻 <b>Il est nécessaire</b> de spécifier :\n\n<code>/usrhistory chat_id user_id cnt_limit</code>, où\n<blockquote>chat_id - groupe\nuser_id - utilisateur\ncnt_limit - nombre de messages\n</blockquote>",
    "zh": "👩🏽‍💻 <b>必须</b> 指定：\n\n<code>/usrhistory chat_id user_id cnt_limit</code>，其中\n<blockquote>chat_id - 群组\nuser_id - 用户\ncnt_limit - 消息数量\n</blockquote>",
    "ar": "👩🏽‍💻 <b>يجب</b> تحديد:\n\n<code>/usrhistory chat_id user_id cnt_limit</code>، حيث\n<blockquote>chat_id - المجموعة\nuser_id - المستخدم\ncnt_limit - عدد الرسائل\n</blockquote>",
}
l_usr_flt_usrhistory_not_found = {
    "ru": "👩🏽‍💻 <b>Сообщений</b> от пользователя {0} в {1} не найдено",
    "en": "👩🏽‍💻 <b>No messages</b> from user {0} in {1} found",
    "es": "👩🏽‍💻 <b>No se encontraron</b> mensajes del usuario {0} en {1}",
    "fr": "👩🏽‍💻 <b>Aucun message</b> de l'utilisateur {0} dans {1} n'a été trouvé",
    "zh": "👩🏽‍💻 <b>未找到</b> 用户 {0} 在 {1} 的消息",
    "ar": "👩🏽‍💻 <b>لا توجد رسائل</b> من المستخدم {0} في {1}",
}
l_usr_flt_usrhistory_done = {
    "ru": "👩🏽‍💻 <b>Сообщения</b> от пользователя {0} в {1}: <u>{2}</u>",
    "en": "👩🏽‍💻 <b>Messages</b> from user {0} in {1}: <u>{2}</u>",
    "es": "👩🏽‍💻 <b>Mensajes</b> del usuario {0} en {1}: <u>{2}</u>",
    "fr": "👩🏽‍💻 <b>Messages</b> de l'utilisateur {0} dans {1} : <u>{2}</u>",
    "zh": "👩🏽‍💻 <b>来自用户 {0} 在 {1} 的消息</b>: <u>{2}</u>",
    "ar": "👩🏽‍💻 <b>الرسائل</b> من المستخدم {0} في {1}: <u>{2}</u>",
}
l_usr_karma_ok = {
    "ru": "👩🏽‍💻 <b>Карма</b>:\n{0} - локальная\n{1} - глобальная\n<i>{2}</i>\n\n⚙️ <b>Команды</b> /cmd",
    "en": "👩🏽‍💻 <b>Karma</b>:\n{0} - local\n{1} - global\n<i>{2}</i>\n\n⚙️ <b>Commands</b> /cmd",
    "es": "👩🏽‍💻 <b>Carma</b>:\n{0} - local\n{1} - global\n<i>{2}</i>\n\n⚙️ <b>Comandos</b> /cmd",
    "fr": "👩🏽‍💻 <b>Karma</b>:\n{0} - locale\n{1} - globale\n<i>{2}</i>\n\n⚙️ <b>Commandes</b> /cmd",
    "zh": "👩🏽‍💻 <b>业力</b>:\n{0} - 本地\n{1} - 全球\n<i>{2}</i>\n\n⚙️ <b>命令</b> /cmd",
    "ar": "👩🏽‍💻 <b>الكارما</b>:\n{0} - محلية\n{1} - عالمية\n<i>{2}</i>\n\n⚙️ <b>الأوامر</b> /cmd",
}
l_userbot_cmd_acc = {
    "ru": "👩🏽‍💻 <b>Информация:</b> {0}\n[<b>id</b>=<code>{1}</code>]\n<b>Био:</b> {2}",
    "en": "👩🏽‍💻 <b>Information:</b> {0}  \n[<b>id</b>=<code>{1}</code>]  \n<b>Bio:</b> {2}",
    "es": "👩🏽‍💻 <b>Información:</b> {0}\n[<b>id</b>=<code>{1}</code>]\n<b>Bio:</b> {2}",
    "fr": "👩🏽‍💻 <b>Informations :</b> {0}  \n[<b>id</b>=<code>{1}</code>]  \n<b>Bio :</b> {2}",
    "zh": "👩🏽‍💻 <b>信息：</b> {0}  \n[<b>id</b>=<code>{1}</code>]  \n<b>简介：</b> {2}",
    "ar": "👩🏽‍💻 <b>معلومات:</b> {0}  \n[<b>معرف</b>=<code>{1}</code>]  \n<b>السيرة الذاتية:</b> {2}",
}
l_userbot_cmd_acc2 = {
    "ru": "👩🏽‍💻 <b>Информация:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]",
    "en": "👩🏽‍💻 <b>Information:</b> {0}  \n[<b>id</b>=<code>{1}</code>, +{2}]",
    "es": "👩🏽‍💻 <b>Información:</b> {0}  \n[<b>id</b>=<code>{1}</code>, +{2}]",
    "fr": "👩🏽‍💻 <b>Informations :</b> {0}  \n[<b>id</b>=<code>{1}</code>, +{2}]",
    "zh": "👩🏽‍💻 <b>信息：</b> {0}  \n[<b>id</b>=<code>{1}</code>, +{2}]",
    "ar": "👩🏽‍💻 <b>معلومات:</b> {0}  \n[<b>معرف</b>=<code>{1}</code>, +{2}]",
}
l_userbot_cmd_all = {
    "ru": "\n<b>Пользователи/приложения/группы/каналы</b>: {0}",
    "en": "<b>Users/apps/groups/channels</b>: {0}",
    "es": "<b>Usuarios/aplicaciones/grupos/canales</b>: {0}",
    "fr": "<b>Utilisateurs/applications/groupes/canaux</b>: {0}",
    "zh": "<b>用户/应用/组/频道</b>: {0}",
    "ar": "<b>المستخدمون/التطبيقات/المجموعات/القنوات</b>: {0}",
}
l_userbot_cmd_admin = {
    "ru": "\n\n<b>Администратор</b> <u>групп/каналов</u>: <code>{0}</code>\n{1}",
    "en": "<b>Administrator</b> <u>of groups/channels</u>: <code>{0}</code>\n{1}",
    "es": "<b>Administrador</b> <u>de grupos/canales</u>: <code>{0}</code>\n{1}",
    "fr": "<b>Administrateur</b> <u>de groupes/canaux</u>: <code>{0}</code>\n{1}",
    "zh": "<b>管理员</b> <u>群组/频道</u>: <code>{0}</code>\n{1}",
    "ar": "<b>مدير</b> <u>المجموعات/القنوات</u>: <code>{0}</code>\n{1}",
}
l_userbot_cmd_authorizations = {
    "ru": "\n<b>Авторизации:</b> <code>{0}</code>\n{1}",
    "en": "<b>Authorization:</b> <code>{0}</code>\n{1}",
    "es": "<b>Autorización:</b> <code>{0}</code>\n{1}",
    "fr": "<b>Autorisation :</b> <code>{0}</code>\n{1}",
    "zh": "<b>授权:</b> <code>{0}</code>\n{1}",
    "ar": "<b>التوثيق:</b> <code>{0}</code>\n{1}",
}
l_userbot_cmd_auto_archive = {
    "ru": "<b>Авто-архив spam-пользователей:</b> ",
    "en": "<b>Auto-archive of spam users:</b>",
    "es": "<b>Archivo automático de usuarios spam:</b>",
    "fr": "<b>Auto-archive des utilisateurs de spam :</b>",
    "zh": "<b>自动归档垃圾用户：</b>",
    "ar": "<b>أرشيف تلقائي لمستخدمي البريد العشوائي:</b>",
}
l_userbot_cmd_black = {
    "ru": "\n<b>Черный список</b>: <code>{0}</code>",
    "en": "<b>Blacklist</b>: <code>{0}</code>",
    "es": "<b>Lista negra</b>: <code>{0}</code>",
    "fr": "<b>Liste noire</b>: <code>{0}</code>",
    "zh": "<b>黑名单</b>: <code>{0}</code>",
    "ar": "<b>القائمة السوداء</b>: <code>{0}</code>",
}
l_userbot_cmd_bot_father = {
    "ru": "\n\n<b>Приложения {0}</b>: <code>{1}/20</code>\n{2}",
    "en": "<b>Applications {0}</b>: <code>{1}/20</code>\n{2}",
    "es": "<b>Aplicaciones {0}</b>: <code>{1}/20</code>\n{2}",
    "fr": "<b>Applications {0}</b>: <code>{1}/20</code>\n{2}",
    "zh": "<b>应用程序 {0}</b>: <code>{1}/20</code>\n{2}",
    "ar": "<b>التطبيقات {0}</b>: <code>{1}/20</code>\n{2}",
}
l_userbot_cmd_cmds = {
    "ru": "\n\n⚙️ <b>Команды</b> /cmd",
    "en": "⚙️ <b>Commands</b> /cmd",
    "es": "⚙️ <b>Comandos</b> /cmd",
    "fr": "⚙️ <b>Commandes</b> /cmd",
    "zh": "⚙️ <b>命令</b> /cmd",
    "ar": "⚙️ <b>الأوامر</b> /cmd",
}
l_userbot_cmd_cloud_pswd = {
    "ru": "<b>Облачный пароль</b>: <code>{0}</code>",
    "en": "<b>Cloud password</b>: <code>{0}</code>",
    "es": "<b>Contraseña en la nube</b>: <code>{0}</code>",
    "fr": "<b>Mot de passe cloud</b>: <code>{0}</code>",
    "zh": "<b>云密码</b>: <code>{0}</code>",
    "ar": "<b>كلمة المرور السحابية</b>: <code>{0}</code>",
}
l_userbot_cmd_common_chats = {
    "ru": "\n<b>Общие чаты:</b> {0}",
    "en": "<b>General chats:</b> {0}",
    "es": "<b>Chats generales:</b> {0}",
    "fr": "<b>Chats généraux :</b> {0}",
    "zh": "<b>公共聊天：</b> {0}",
    "ar": "<b>الدردشات العامة:</b> {0}",
}
l_userbot_cmd_contacts = {
    "ru": "\n<b>Контакты</b> <u>взаимные/недавние/все</u>: {0}",
    "en": "<b>Contacts</b> <u>mutual/recent/all</u>: {0}",
    "es": "<b>Contactos</b> <u>mutuos/recentes/todos</u>: {0}",
    "fr": "<b>Contacts</b> <u>mutuels/récents/tous</u>: {0}",
    "zh": "<b>联系方式</b> <u>相互/最近/所有</u>: {0}",
    "ar": "<b>جهات الاتصال</b> <u>متبادلة/حديثة/الجميع</u>: {0}",
}
l_userbot_cmd_dlgs = {
    "ru": "\n<b>Диалоги</b> <u>архив/закреп/все</u>: {0}",
    "en": "<b>Dialogs</b> <u>archive/pin/all</u>: {0}",
    "es": "<b>Diálogos</b> <u>archivo/fijar/todos</u>: {0}",
    "fr": "<b>Dialogues</b> <u>archive/épingler/tous</u>: {0}",
    "zh": "<b>对话</b> <u>归档/固定/全部</u>: {0}",
    "ar": "<b>الحوارات</b> <u>الأرشيف/التثبيت/الكل</u>: {0}",
}
l_userbot_cmd_drafts = {
    "ru": "\n<b>Черновики/помеченные:</b> <code>{0}/{1}</code>",
    "en": "<b>Drafts/marked:</b> <code>{0}/{1}</code>",
    "es": "<b>Borradores/marcados:</b> <code>{0}/{1}</code>",
    "fr": "<b>Brouillons/marqués :</b> <code>{0}/{1}</code>",
    "zh": "<b>草稿/标记：</b> <code>{0}/{1}</code>",
    "ar": "<b>المسودات/المُعَلَّمَة:</b> <code>{0}/{1}</code>",
}
l_userbot_cmd_fld_bots = {
    "ru": "приложения",
    "en": "applications",
    "es": "aplicaciones",
    "fr": "applications",
    "zh": "应用程序",
    "ar": "التطبيقات",
}
l_userbot_cmd_fld_chns = {
    "ru": "каналы",
    "en": "channels",
    "es": "canales",
    "fr": "canaux",
    "zh": "频道",
    "ar": "قنوات",
}
l_userbot_cmd_fld_grps = {
    "ru": "группы",
    "en": "groups",
    "es": "grupos",
    "fr": "groupes",
    "zh": "组",
    "ar": "المجموعات",
}
l_userbot_cmd_fld_fave = {
    "ru": "избранное",
    "en": "favorites",
    "es": "favoritos",
    "fr": "favoris",
    "zh": "收藏夹",
    "ar": "المفضلة",
}
l_userbot_cmd_fld_users = {
    "ru": "пользователи",
    "en": "users",
    "es": "usuarios",
    "fr": "utilisateurs",
    "zh": "用户",
    "ar": "المستخدمون",
}
l_userbot_cmd_flds = {
    "ru": "\n<b>Папки</b>: <code>{0}</code>\n{1}",
    "en": "<b>Folders</b>: <code>{0}</code>\n{1}",
    "es": "<b>Carpetas</b>: <code>{0}</code>\n{1}",
    "fr": "<b>Dossiers</b>: <code>{0}</code>\n{1}",
    "zh": "<b>文件夹</b>: <code>{0}</code>\n{1}",
    "ar": "<b>المجلدات</b>: <code>{0}</code>\n{1}",
}
l_userbot_cmd_info_fun = {
    "ru": "👩🏽‍💻 <b>Информация:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}, цвет: {3}, тема: {4}, dc: {5}]\n<b>Био:</b> {6}",
    "en": "👩🏽‍💻 <b>Information:</b> {0}  \n[<b>id</b>=<code>{1}</code>, +{2}, color: {3}, subject: {4}, dc: {5}]  \n<b>Bio:</b> {6}",
    "es": "👩🏽‍💻 <b>Información:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}, color: {3}, tema: {4}, dc: {5}]\n<b>Bio:</b> {6}",
    "fr": "👩🏽‍💻 <b>Informations :</b> {0}  \n[<b>id</b>=<code>{1}</code>, +{2}, couleur : {3}, thème : {4}, dc : {5}]  \n<b>Bio :</b> {6}",
    "zh": "👩🏽‍💻 <b>信息：</b> {0}  \n[<b>id</b>=<code>{1}</code>, +{2}, 颜色：{3}, 主题：{4}, dc：{5}]  \n<b>简介：</b> {6}",
    "ar": "👩🏽‍💻 <b>معلومات:</b> {0}  \n[<b>معرف</b>=<code>{1}</code>, +{2}, اللون: {3}, الموضوع: {4}, dc: {5}]  \n<b>السيرة الذاتية:</b> {6}",
}
l_userbot_cmd_info_confident = {
    "ru": "\n\n<b>Конфиденциальность:</b>\n{0}",
    "en": "<b>Confidentiality:</b>\n{0}",
    "es": "<b>Privacidad:</b>\n{0}",
    "fr": "<b>Confidentialité :</b>\n{0}",
    "zh": "<b>隐私：</b>\n{0}",
    "ar": "<b>الخصوصية:</b>\n{0}",
}
l_userbot_cmd_info_status = {
    "ru": "{0}-<i>эмоджи-статус</i>",
    "en": "{0}-<i>emoji-status</i>",
    "es": "{0}-<i>estado-emoticono</i>",
    "fr": "{0}-<i>statut-emoji</i>",
    "zh": "{0}-<i>表情符号状态</i>",
    "ar": "{0}-<i>حالة-رمز تعبيري</i>",
}
l_userbot_cmd_info_premium = {
    "ru": "\n<b>Премиум:</b> {0}",
    "en": "<b>Premium:</b> {0}",
    "es": "<b>Premium:</b> {0}",
    "fr": "<b>Premium :</b> {0}",
    "zh": "<b>高级:</b> {0}",
    "ar": "<b>بريميوم:</b> {0}",
}
l_userbot_cmd_info_fake = {
    "ru": "\n<b>Фейк:</b> да",
    "en": "<b>Fake:</b> yes",
    "es": "<b>Falso:</b> sí",
    "fr": "<b>Faux :</b> oui",
    "zh": "<b>假:</b> 是",
    "ar": "<b>زيف:</b> نعم",
}
l_userbot_cmd_info_scam = {
    "ru": "\n<b>Скам:</b> да",
    "en": "<b>Scam:</b> yes",
    "es": "<b>Estafa:</b> sí",
    "fr": "<b>Escroquerie :</b> oui",
    "zh": "<b>骗局：</b> 是",
    "ar": "<b>احتيال:</b> نعم",
}
l_userbot_cmd_info_restricted = {
    "ru": "\n<b>Ограничен:</b> да",
    "en": "<b>Limited:</b> yes",
    "es": "<b>Limitado:</b> sí",
    "fr": "<b>Limité :</b> oui",
    "zh": "<b>限制：</b> 是",
    "ar": "<b>محدود:</b> نعم",
}
l_userbot_cmd_info_extra = {
    "ru": "\n<b>Цвет:</b> да",
    "en": "<b>Color:</b> yes",
    "es": "<b>Color:</b> sí",
    "fr": "<b>Couleur :</b> oui",
    "zh": "<b>颜色：</b> 是",
    "ar": "<b>اللون:</b> نعم",
}
l_userbot_cmd_nsfw = {
    "ru": "<b>NSFW (/sensitive контент):</b> ",
    "en": "<b>NSFW (/sensitive content):</b>",
    "es": "<b>NSFW (/contenido sensible):</b>",
    "fr": "<b>NSFW (/contenu sensible):</b>",
    "zh": "<b>NSFW (/敏感内容):</b>",
    "ar": "<b>محتوى NSFW (/محتوى حساس):</b>",
}
l_userbot_cmd_profile_photo = {
    "ru": "\n<b>Фото профиля</b>: {0}",
    "en": "<b>Profile photo</b>: {0}",
    "es": "<b>Foto de perfil</b>: {0}",
    "fr": "<b>Photo de profil</b>: {0}",
    "zh": "<b>个人资料照片</b>: {0}",
    "ar": "<b>صورة الملف الشخصي</b>: {0}",
}
l_userbot_cmd_lang = {
    "ru": "\n<b>Язык</b>: <code>{0}</code>",
    "en": "<b>Language</b>: <code>{0}</code>",
    "es": "<b>Idioma</b>: <code>{0}</code>",
    "fr": "<b>Langue</b>: <code>{0}</code>",
    "zh": "<b>语言</b>: <code>{0}</code>",
    "ar": "<b>اللغة</b>: <code>{0}</code>",
}
l_userbot_cmd_react = {
    "ru": "\n<b>Стандарт-реакции:</b> <code>{0}</code>",
    "en": "<b>Standard reactions:</b> <code>{0}</code>",
    "es": "<b>Reacciones estándar:</b> <code>{0}</code>",
    "fr": "<b>Réactions standard :</b> <code>{0}</code>",
    "zh": "<b>标准反应：</b> <code>{0}</code>",
    "ar": "<b>ردود الفعل القياسية:</b> <code>{0}</code>",
}
l_userbot_cmd_gif_mask = {
    "ru": "\n<b>Сохраненные гиф/маски:</b> <code>{0}/{1}</code>",
    "en": "<b>Saved GIFs/masks:</b> <code>{0}/{1}</code>",
    "es": "<b>GIFs/mascarillas guardados:</b> <code>{0}/{1}</code>",
    "fr": "<b>GIF/maskes enregistrés :</b> <code>{0}/{1}</code>",
    "zh": "<b>保存的GIF/面具：</b> <code>{0}/{1}</code>",
    "ar": "<b>الصور المتحركة/الماسكات المحفوظة:</b> <code>{0}/{1}</code>",
}
l_userbot_cmd_theme_wall = {
    "ru": "\n<b>Темы/Обои:</b> <code>{0}/{1}</code> {2}",
    "en": "<b>Themes/Wallpapers:</b> <code>{0}/{1}</code> {2}",
    "es": "<b>Temas/Fondos:</b> <code>{0}/{1}</code> {2}",
    "fr": "<b>Sujets/Fonds d'écran :</b> <code>{0}/{1}</code> {2}",
    "zh": "<b>主题/壁纸：</b> <code>{0}/{1}</code> {2}",
    "ar": "<b>المواضيع/الخلفيات:</b> <code>{0}/{1}</code> {2}",
}
l_userbot_cmd_sick_emoj = {
    "ru": "\n<b>Stickers/Emoji</b>: <code>{0}/{1}</code>{2}",
    "en": "\n<b>Stickers/Emoji</b>: <code>{0}/{1}</code>{2}",
    "es": "\n<b>Stickers/Emoji</b>: <code>{0}/{1}</code>{2}",
    "fr": "<b>Autocollants/Émoji</b>: <code>{0}/{1}</code>{2}",
    "zh": "<b>贴纸/表情符号</b>: <code>{0}/{1}</code>{2}",
    "ar": "<b>ملصقات/رموز تعبيرية</b>: <code>{0}/{1}</code>{2}",
}
l_userbot_cmd_bot = {
    "ru": "\n\n<b>Приложение:</b> @{0} ({1})",
    "en": "<b>Application:</b> @{0} ({1})",
    "es": "<b>Aplicación:</b> @{0} ({1})",
    "fr": "<b>Application :</b> @{0} ({1})",
    "zh": "<b>应用程序：</b> @{0} ({1})",
    "ar": "<b>التطبيق:</b> @{0} ({1})",
}
l_userbot_cmd_chn = {
    "ru": "\n<b>Канал:</b> @{0} ({1})",
    "en": "<b>Channel:</b> @{0} ({1})",
    "es": "<b>Canal:</b> @{0} ({1})",
    "fr": "<b>Canal :</b> @{0} ({1})",
    "zh": "<b>频道：</b> @{0} ({1})",
    "ar": "<b>القناة:</b> @{0} ({1})",
}
l_userbot_cmd_bot_chn = {
    "ru": "\n<i>[приложение и публичный канал необходимы для работы со сложными постами]</i>",
    "en": "<i>[the app and public channel are necessary for working with complex posts]</i>",
    "es": "<i>[la aplicación y el canal público son necesarios para trabajar con publicaciones complejas]</i>",
    "fr": "<i>[l'application et le canal public sont nécessaires pour travailler avec des publications complexes]</i>",
    "zh": "<i>[应用程序和公共频道对于处理复杂帖子是必需的]</i>",
    "ar": "<i>[التطبيق والقناة العامة ضروريان للعمل مع المنشورات المعقدة]</i>",
}
l_userbot_cmd_top_send = {
    "ru": "\n@{0} написал(а): {1} сообщ",
    "en": "@{0} wrote: {1} message",
    "es": "@{0} escribió: {1} mensaje",
    "fr": "@{0} a écrit(e) : {1} message",
    "zh": "@{0} 写道： {1} 消息",
    "ar": "@{0} كتب(ت): {1} رسالة",
}
l_userbot_cmd_top_users = {
    "ru": "<b>\n\n👩🏽‍💻 Топ пользователей (на 1000 сообщ)</b>: {0}\n",
    "en": "<b>\n\n👩🏽‍💻 Top users (per 1000 messages)</b>: {0}",
    "es": "<b>\n\n👩🏽‍💻 Mejores usuarios (por 1000 mensajes)</b>: {0}",
    "fr": "<b>\n\n👩🏽‍💻 Top des utilisateurs (pour 1000 messages)</b>: {0}",
    "zh": "<b>\n\n👩🏽‍💻 每千条消息的用户排名</b>: {0}",
    "ar": "<b>\n\n👩🏽‍💻 أفضل المستخدمين (لكل 1000 رسالة)</b>: {0}",
}
l_userbot_cmd_top_words = {
    "ru": "\n{0}. <i>{1}</i>..: встретилось {2} раз",
    "en": "{0}. <i>{1}</i>..: encountered {2} times",
    "es": "{0}. <i>{1}</i>..: se encontró {2} veces",
    "fr": "{0}. <i>{1}</i>..: rencontré {2} fois",
    "zh": "{0}. <i>{1}</i>..: 出现了 {2} 次",
    "ar": "{0}. <i>{1}</i>..: تم العثور عليه {2} مرة",
}
l_userbot_cmd_top_msgs = {
    "ru": "<b>\n👩🏽‍💻 Топ сообщ (из 1000)</b>: {0}\n",
    "en": "<b>\n👩🏽‍💻 Top message (out of 1000)</b>: {0}",
    "es": "<b>\n👩🏽‍💻 Top mensajes (de 1000)</b>: {0}",
    "fr": "<b>\n👩🏽‍💻 Top message (sur 1000)</b>: {0}",
    "zh": "<b>\n👩🏽‍💻 顶部消息（来自1000条）</b>: {0}",
    "ar": "<b>\n👩🏽‍💻 أعلى المشاركات (من 1000)</b>: {0}",
}
l_userbot_cmd_life_time = {
    "ru": "\n\n<b>Время жизни аккаунта:</b> ~{0} дней",
    "en": "<b>Account lifetime:</b> ~{0} days",
    "es": "<b>Tiempo de vida de la cuenta:</b> ~{0} días",
    "fr": "<b>Durée de vie du compte :</b> ~{0} jours",
    "zh": "<b>账户的生命周期：</b> ~{0} 天",
    "ar": "<b>مدة حياة الحساب:</b> ~{0} يومًا",
}
l_userbot_cmd_first_dlg = {
    "ru": "\n<b>Дата первого диалога:</b> ~{0}",
    "en": "<b>First dialogue date:</b> ~{0}",
    "es": "<b>Fecha del primer diálogo:</b> ~{0}",
    "fr": "<b>Date du premier dialogue :</b> ~{0}",
    "zh": "<b>第一次对话的日期：</b> ~{0}",
    "ar": "<b>تاريخ الحوار الأول:</b> ~{0}",
}
l_userbot_cmd_first_karma = {
    "ru": "\n<b>Карма:</b> <code>{0}</code> /spambot",
    "en": "<b>Karma:</b> <code>{0}</code> /spambot",
    "es": "<b>Carma:</b> <code>{0}</code> /spambot",
    "fr": "<b>Carma :</b> <code>{0}</code> /spambot",
    "zh": "<b>业力：</b> <code>{0}</code> /spambot",
    "ar": "<b>كارما:</b> <code>{0}</code> /spambot",
}
l_userbot_cmd_ring = {
    "ru": "\n<b>Рингтоны:</b> <code>{0}</code>",
    "en": "<b>Ringtones:</b> <code>{0}</code>",
    "es": "<b>Toneladas:</b> <code>{0}</code>",
    "fr": "<b>Sonneries :</b> <code>{0}</code>",
    "zh": "<b>铃声：</b> <code>{0}</code>",
    "ar": "<b>نغمات الرنين:</b> <code>{0}</code>",
}
l_userbot_cmd_notify = {
    "ru": "\n<b>Особые уведомления:</b> {0}",
    "en": "<b>Special notifications:</b> {0}",
    "es": "<b>Notificaciones especiales:</b> {0}",
    "fr": "<b>Avis spéciaux :</b> {0}",
    "zh": "<b>特别通知：</b> {0}",
    "ar": "<b>إشعارات خاصة:</b> {0}",
}
l_userbot_cmd_sched = {
    "ru": "\n<b>Отложенные/посты/офферы</b>: {0}",
    "en": "<b>Deferred/posts/offers</b>: {0}",
    "es": "<b>Publicaciones/Ofertas/Posts</b>: {0}",
    "fr": "<b>Retards/publications/offres</b>: {0}",
    "zh": "<b>延迟/帖子/优惠</b>: {0}",
    "ar": "<b>المؤجلات/المنشورات/العروض</b>: {0}",
}
l_userbot_cmd_last_react = {
    "ru": "\n<b>Последние реакции:</b> {0}",
    "en": "<b>Latest reactions:</b> {0}",
    "es": "<b>Últimas reacciones:</b> {0}",
    "fr": "<b>Dernières réactions :</b> {0}",
    "zh": "<b>最新反应：</b> {0}",
    "ar": "<b>آخر التفاعلات:</b> {0}",
}
l_userbot_cmd_unread_react = {
    "ru": "\n<b>Непрочитанные @тэги/реакции:</b> <code>{0}/{1}</code>",
    "en": "<b>Unread @tags/reactions:</b> <code>{0}/{1}</code>",
    "es": "<b>Etiquetas/reacciones no leídas:</b> <code>{0}/{1}</code>",
    "fr": "<b>Tags/réactions non lus :</b> <code>{0}/{1}</code>",
    "zh": "<b>未读 @标签/反应：</b> <code>{0}/{1}</code>",
    "ar": "<b>العلامات/ردود الفعل غير المقروءة:</b> <code>{0}/{1}</code>",
}
l_userbot_cmd_unread_msgs = {
    "ru": "\n<b>Непрочитанные сообщ (и архив):</b> <code>{0}</code>",
    "en": "<b>Unread messages (and archive):</b> <code>{0}</code>",
    "es": "<b>Mensajes no leídos (y archivo):</b> <code>{0}</code>",
    "fr": "<b>Messages non lus (et archive) :</b> <code>{0}</code>",
    "zh": "<b>未读消息（和归档）：</b> <code>{0}</code>",
    "ar": "<b>الرسائل غير المقروءة (والأرشيف):</b> <code>{0}</code>",
}
l_userbot_cmd_owner = {
    "ru": "\n\n<b>Владелец</b> <u>групп/каналов</u>: <code>{0}</code>\n{1}",
    "en": "<b>Owner</b> <u>of groups/channels</u>: <code>{0}</code>\n{1}",
    "es": "<b>Propietario</b> <u>de grupos/canales</u>: <code>{0}</code>\n{1}",
    "fr": "<b>Propriétaire</b> <u>de groupes/canaux</u>: <code>{0}</code>\n{1}",
    "zh": "<b>所有者</b> <u>组/频道</u>: <code>{0}</code>\n{1}",
    "ar": "<b>مالك</b> <u>المجموعات/القنوات</u>: <code>{0}</code>\n{1}",
}
l_userbot_cmd_top_affects = {
    "ru": "\n\n<b>Топ взаимодействий</b>:\n{0}",
    "en": "<b>Top interactions</b>:\n{0}",
    "es": "<b>Top interacciones</b>:\n{0}",
    "fr": "<b>Top des interactions</b> :  \n{0}",
    "zh": "<b>互动排行榜</b>:\n{0}",
    "ar": "<b>أفضل التفاعلات</b>:\n{0}",
}
l_userbot_cmd_last_msgs = {
    "ru": "\n\n<b>Последние сообщения</b>:\n{0}",
    "en": "<b>Latest messages</b>:\n{0}",
    "es": "<b>Últimos mensajes</b>:\n{0}",
    "fr": "<b>Derniers messages</b> :  \n{0}",
    "zh": "<b>最新消息</b>:\n{0}",
    "ar": "<b>آخر الرسائل</b>:\n{0}",
}
l_userbot_cmd_parse_fun = {
    "ru": "👩🏽‍💻 Готово! Для <b>{0}</b> собрано реальных <b>{1}</b>-участников: <u>{2}</u>{3}",
    "en": "👩🏽‍💻 Done! For <b>{0}</b> a total of <b>{1}</b> real participants have been gathered: <u>{2}</u>{3}",
    "es": "👩🏽‍💻 ¡Listo! Se han reunido <b>{1}</b> participantes reales para <b>{0}</b>: <u>{2}</u>{3}",
    "fr": "👩🏽‍💻 Prêt ! Pour <b>{0}</b>, <b>{1}</b> participants réels ont été rassemblés : <u>{2}</u>{3}",
    "zh": "👩🏽‍💻 完成了！为 <b>{0}</b> 收集了真实的 <b>{1}</b> 名参与者：<u>{2}</u>{3}",
    "ar": "👩🏽‍💻 جاهز! تم جمع <b>{0}</b> من المشاركين الحقيقيين <b>{1}</b>: <u>{2}</u>{3}",
}
l_userbot_cmd_update_err = {
    "ru": "👩🏽‍💻 <b>Ошибка</b> обновления профиля",
    "en": "👩🏽‍💻 <b>Error</b> updating profile",
    "es": "👩🏽‍💻 <b>Error</b> al actualizar el perfil",
    "fr": "👩🏽‍💻 <b>Erreur</b> de mise à jour du profil",
    "zh": "👩🏽‍💻 <b>更新个人资料时出错</b>",
    "ar": "👩🏽‍💻 <b>خطأ</b> في تحديث الملف الشخصي",
}
l_userbot_cmd_update_info = {
    "ru": "👩🏽‍💻 <b>Ошибка</b> получения профиля",
    "en": "👩🏽‍💻 <b>Error</b> retrieving profile",
    "es": "👩🏽‍💻 <b>Error</b> al obtener el perfil",
    "fr": "👩🏽‍💻 <b>Erreur</b> de récupération du profil",
    "zh": "👩🏽‍💻 <b>获取个人资料时出错</b>",
    "ar": "👩🏽‍💻 <b>خطأ</b> في الحصول على الملف الشخصي",
}
l_userbot_cmd_update_stat = {
    "ru": "👩🏽‍💻 <b>Ошибка</b> получения статистики",
    "en": "👩🏽‍💻 <b>Error</b> retrieving statistics",
    "es": "👩🏽‍💻 <b>Error</b> al obtener estadísticas",
    "fr": "👩🏽‍💻 <b>Erreur</b> lors de l'obtention des statistiques",
    "zh": "👩🏽‍💻 <b>获取统计信息时出错</b>",
    "ar": "👩🏽‍💻 <b>خطأ</b> في الحصول على الإحصائيات",
}
l_userbot_res_repair = {
    "ru": "👩🏽‍💻 <b>Аккаунт:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n ✅ Очистка черновиков..\n ✅ Открепление сообщений..\n ✅ Просмотр упоминаний..\n ✅ Сброс уведомлений..\n ✅ Чтение истории..\n ✅ Отмена таймеров удаления..\n ✅ Удаление отложенной отправки..\n ✅ Обновление папок..\n\n⚙️ <b>Команды</b> /cmd",
    "en": "👩🏽‍💻 <b>Account:</b> {0}  \n[<b>id</b>=<code>{1}</code>, +{2}]  \n\n ✅ Clearing drafts..  \n ✅ Unpinning messages..  \n ✅ Viewing mentions..  \n ✅ Resetting notifications..  \n ✅ Reading history..  \n ✅ Cancelling deletion timers..  \n ✅ Deleting scheduled sends..  \n ✅ Updating folders..  \n\n⚙️ <b>Commands</b> /cmd",
    "es": "👩🏽‍💻 <b>Cuenta:</b> {0}  \n[<b>id</b>=<code>{1}</code>, +{2}]  \n\n ✅ Limpiando borradores..  \n ✅ Desanclando mensajes..  \n ✅ Revisando menciones..  \n ✅ Restableciendo notificaciones..  \n ✅ Leyendo el historial..  \n ✅ Cancelando temporizadores de eliminación..  \n ✅ Eliminando envíos programados..  \n ✅ Actualizando carpetas..  \n\n⚙️ <b>Comandos</b> /cmd",
    "fr": "👩🏽‍💻 <b>Compte :</b> {0}  \n[<b>id</b>=<code>{1}</code>, +{2}]  \n\n ✅ Nettoyage des brouillons..  \n ✅ Détachement des messages..  \n ✅ Consultation des mentions..  \n ✅ Réinitialisation des notifications..  \n ✅ Lecture de l'historique..  \n ✅ Annulation des minuteries de suppression..  \n ✅ Suppression de l'envoi différé..  \n ✅ Mise à jour des dossiers..  \n\n⚙️ <b>Commandes</b> /cmd",
    "zh": "👩🏽‍💻 <b>账户:</b> {0}  \n[<b>id</b>=<code>{1}</code>, +{2}]  \n\n ✅ 清理草稿..  \n ✅ 解除消息固定..  \n ✅ 查看提及..  \n ✅ 重置通知..  \n ✅ 阅读历史..  \n ✅ 取消删除计时器..  \n ✅ 删除延迟发送..  \n ✅ 更新文件夹..  \n\n⚙️ <b>命令</b> /cmd",
    "ar": "👩🏽‍💻 <b>الحساب:</b> {0}  \n[<b>id</b>=<code>{1}</code>, +{2}]  \n\n ✅ مسح المسودات..  \n ✅ إلغاء تثبيت الرسائل..  \n ✅ عرض الإشارات..  \n ✅ إعادة تعيين الإشعارات..  \n ✅ قراءة السجل..  \n ✅ إلغاء مؤقتات الحذف..  \n ✅ حذف الإرسال المؤجل..  \n ✅ تحديث المجلدات..  \n\n⚙️ <b>الأوامر</b> /cmd",
}
l_userbot_res_reset = {
    "ru": "👩🏽‍💻 <b>Аккаунт:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n ✅ Сброс настроек..\n ✅ Удаление контактов..\n ✅ Удаление Telegram-приложений..\n ✅ Удаление диалогов..\n ✅ Выход из групп и каналов..\n ✅ Удаление платежной информации..\n ✅ Удаление истории звонков..\n ✅ Удаление стикеров/эможди..\n ✅ Сброс настроек оповещения..\n ✅ Очистка галереи обоев..\n\n⚙️ <b>Команды</b> /cmd",
    "en": "👩🏽‍💻 <b>Account:</b> {0}  \n[<b>id</b>=<code>{1}</code>, +{2}]  \n\n ✅ Resetting settings..  \n ✅ Deleting contacts..  \n ✅ Deleting Telegram apps..  \n ✅ Deleting chats..  \n ✅ Leaving groups and channels..  \n ✅ Deleting payment information..  \n ✅ Deleting call history..  \n ✅ Deleting stickers/emojis..  \n ✅ Resetting notification settings..  \n ✅ Clearing wallpaper gallery..  \n\n⚙️ <b>Commands</b> /cmd",
    "es": "👩🏽‍💻 <b>Cuenta:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n ✅ Restablecer configuraciones..\n ✅ Eliminar contactos..\n ✅ Eliminar aplicaciones de Telegram..\n ✅ Eliminar diálogos..\n ✅ Salir de grupos y canales..\n ✅ Eliminar información de pago..\n ✅ Eliminar historial de llamadas..\n ✅ Eliminar stickers/emojis..\n ✅ Restablecer configuraciones de notificación..\n ✅ Limpiar galería de fondos de pantalla..\n\n⚙️ <b>Comandos</b> /cmd",
    "fr": "👩🏽‍💻 <b>Compte :</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n ✅ Réinitialisation des paramètres..\n ✅ Suppression des contacts..\n ✅ Suppression des applications Telegram..\n ✅ Suppression des dialogues..\n ✅ Sortie des groupes et des chaînes..\n ✅ Suppression des informations de paiement..\n ✅ Suppression de l'historique des appels..\n ✅ Suppression des autocollants/émoticônes..\n ✅ Réinitialisation des paramètres de notification..\n ✅ Nettoyage de la galerie de fonds d'écran..\n\n⚙️ <b>Commandes</b> /cmd",
    "zh": "👩🏽‍💻 <b>账户:</b> {0}  \n[<b>id</b>=<code>{1}</code>, +{2}]  \n\n ✅ 重置设置..  \n ✅ 删除联系人..  \n ✅ 删除Telegram应用..  \n ✅ 删除对话..  \n ✅ 退出群组和频道..  \n ✅ 删除支付信息..  \n ✅ 删除通话记录..  \n ✅ 删除贴纸/表情符号..  \n ✅ 重置通知设置..  \n ✅ 清理壁纸图库..  \n\n⚙️ <b>命令</b> /cmd",
    "ar": "👩🏽‍💻 <b>الحساب:</b> {0}  \n[<b>id</b>=<code>{1}</code>, +{2}]  \n\n ✅ إعادة ضبط الإعدادات..  \n ✅ حذف جهات الاتصال..  \n ✅ حذف تطبيقات Telegram..  \n ✅ حذف المحادثات..  \n ✅ الخروج من المجموعات والقنوات..  \n ✅ حذف معلومات الدفع..  \n ✅ حذف سجل المكالمات..  \n ✅ حذف الملصقات/الإيموجي..  \n ✅ إعادة ضبط إعدادات الإشعارات..  \n ✅ مسح معرض الخلفيات..  \n\n⚙️ <b>الأوامر</b> /cmd",
}
l_userbot_res_spambot = {
    "ru": "👩🏽‍💻 <b>Аккаунт:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n@spambot: {3}\n\n👩🏽‍💻 <b>Карма:</b>\n{4}: локальная\n{5}: глобальная\n\n⚙️ <b>Команды</b> /cmd",
    "en": "👩🏽‍💻 <b>Account:</b> {0}  \n[<b>id</b>=<code>{1}</code>, +{2}]  \n\n@spambot: {3}  \n\n👩🏽‍💻 <b>Karma:</b>  \n{4}: local  \n{5}: global  \n\n⚙️ <b>Commands</b> /cmd",
    "es": "👩🏽‍💻 <b>Cuenta:</b> {0}  \n[<b>id</b>=<code>{1}</code>, +{2}]  \n\n@spambot: {3}  \n\n👩🏽‍💻 <b>Karama:</b>  \n{4}: local  \n{5}: global  \n\n⚙️ <b>Comandos</b> /cmd",
    "fr": "👩🏽‍💻 <b>Compte :</b> {0}  \n[<b>id</b>=<code>{1}</code>, +{2}]  \n\n@spambot : {3}  \n\n👩🏽‍💻 <b>Karma :</b>  \n{4} : local  \n{5} : global  \n\n⚙️ <b>Commandes</b> /cmd",
    "zh": "👩🏽‍💻 <b>账户:</b> {0}  \n[<b>id</b>=<code>{1}</code>, +{2}]  \n\n@spambot: {3}  \n\n👩🏽‍💻 <b>声望:</b>  \n{4}: 本地  \n{5}: 全球  \n\n⚙️ <b>命令</b> /cmd",
    "ar": "👩🏽‍💻 <b>الحساب:</b> {0}  \n[<b>id</b>=<code>{1}</code>, +{2}]  \n\n@spambot: {3}  \n\n👩🏽‍💻 <b>الكارما:</b>  \n{4}: محلية  \n{5}: عالمية  \n\n⚙️ <b>الأوامر</b> /cmd",
}
l_status_handler = {
    "ru": "👩🏽‍💻 <b>Аккаунт</b>-статус: {0}",
    "en": "👩🏽‍💻 <b>Account</b> status: {0}",
    "es": "👩🏽‍💻 <b>Estado</b> de la cuenta: {0}",
    "fr": "👩🏽‍💻 <b>Statut</b> du compte : {0}",
    "zh": "👩🏽‍💻 <b>账户</b>状态: {0}",
    "ar": "👩🏽‍💻 <b>حالة</b> الحساب: {0}",
}
l_fsm_auth_done = {
    "ru": "👩🏽‍💻 <b>Готово!</b> Аккаунт <b>{0}</b> \n[<b>id</b>=<code>{1}</code>, <code>+{2}</code>] успешно <i>прикреплен</i> к @{3}\n\n👩🏽‍💻 <b>Добавь</b> <b>{4}</b> ({5}) в свои контакты и отправь любое сообщение",
    "en": "👩🏽‍💻 <b>Done!</b> Account <b>{0}</b> \n[<b>id</b>=<code>{1}</code>, <code>+{2}</code>] successfully <i>attached</i> to @{3}\n\n👩🏽‍💻 <b>Add</b> <b>{4}</b> ({5}) to your contacts and send any message",
    "es": "👩🏽‍💻 <b>¡Listo!</b> La cuenta <b>{0}</b> \n[<b>id</b>=<code>{1}</code>, <code>+{2}</code>] se ha <i>vinculado</i> exitosamente a @{3}\n\n👩🏽‍💻 <b>Agrega</b> <b>{4}</b> ({5}) a tus contactos y envía cualquier mensaje",
    "fr": "👩🏽‍💻 <b>Prêt!</b> Le compte <b>{0}</b>  \n[<b>id</b>=<code>{1}</code>, <code>+{2}</code>] a été <i>attaché</i> à @{3}\n\n👩🏽‍💻 <b>Ajoute</b> <b>{4}</b> ({5}) à tes contacts et envoie n'importe quel message",
    "zh": "👩🏽‍💻 <b>完成！</b> 账户 <b>{0}</b> \n[<b>id</b>=<code>{1}</code>, <code>+{2}</code>] 成功 <i>附加</i> 到 @{3}\n\n👩🏽‍💻 <b>添加</b> <b>{4}</b> ({5}) 到你的联系人并发送任何消息",
    "ar": "👩🏽‍💻 <b>تم!</b> الحساب <b>{0}</b>  \n[<b>معرف</b>=<code>{1}</code>, <code>+{2}</code>] تم <i>ربطه</i> بنجاح بـ @{3}\n\n👩🏽‍💻 <b>أضف</b> <b>{4}</b> ({5}) إلى جهات الاتصال الخاصة بك وأرسل أي رسالة",
}
l_fsm_cloud_current = {
    "ru": "👩🏽‍💻 <b>Укажи</b> текущий <i>облачный пароль</i>",
    "en": "👩🏽‍💻 <b>Specify</b> the current <i>cloud password</i>",
    "es": "👩🏽‍💻 <b>Indica</b> la <i>contraseña en la nube</i> actual",
    "fr": "👩🏽‍💻 <b>Indiquez</b> le <i>mot de passe cloud</i> actuel",
    "zh": "👩🏽‍💻 <b>请输入</b> 当前 <i>云密码</i>",
    "ar": "👩🏽‍💻 <b>حدد</b> كلمة المرور <i>السحابية الحالية</i>",
}
l_fsm_auth_error = {
    "ru": "👩🏽‍💻 <b>Ошибка</b> Telegram, попробуй еще раз! <b>Создай</b>/<code>используй дополнительный</code> <i>Telegram</i>-аккаунт через <b>мобильное</b> приложение, а затем отправь его <u>номер</u> телефона℡\n\n👩🏽‍💻 Например, <code>34663072680</code>",
    "en": "👩🏽‍💻 <b>Error</b> Telegram, please try again! <b>Create</b>/<code>use an additional</code> <i>Telegram</i> account through the <b>mobile</b> app, and then send its <u>phone</u> number℡\n\n👩🏽‍💻 For example, <code>34663072680</code>",
    "es": "👩🏽‍💻 <b>Error</b> de Telegram, ¡inténtalo de nuevo! <b>Crea</b>/<code>usa una</code> <i>cuenta</i> de Telegram <b>móvil</b> a través de la aplicación, y luego envía su <u>número</u> de teléfono℡\n\n👩🏽‍💻 Por ejemplo, <code>34663072680</code>",
    "fr": "👩🏽‍💻 <b>Erreur</b> Telegram, essaie encore ! <b>Crée</b>/<code>utilise un</code> <i>compte</i> Telegram <b>mobile</b>, puis envoie son <u>numéro</u> de téléphone℡\n\n👩🏽‍💻 Par exemple, <code>34663072680</code>",
    "zh": "👩🏽‍💻 <b>错误</b> Telegram，请再试一次！ <b>创建</b>/<code>使用额外的</code> <i>Telegram</i>账户通过 <b>移动</b> 应用程序，然后发送它的 <u>电话号码</u>℡\n\n👩🏽‍💻 例如，<code>34663072680</code>",
    "ar": "👩🏽‍💻 <b>خطأ</b> في Telegram، حاول مرة أخرى! <b>أنشئ</b>/<code>استخدم حساب</code> <i>Telegram</i> إضافي من خلال <b>التطبيق</b> المحمول، ثم أرسل <u>رقم</u> هاتفه℡\n\n👩🏽‍💻 على سبيل المثال، <code>34663072680</code>",
}
l_fsm_code_error = {
    "ru": "👩🏽‍💻 <b>Отправь</b> корректный числовой код",
    "en": "👩🏽‍💻 <b>Send</b> the correct numeric code",
    "es": "👩🏽‍💻 <b>Envía</b> el código numérico correcto",
    "fr": "👩🏽‍💻 <b>Envoyez</b> un code numérique correct",
    "zh": "👩🏽‍💻 <b>发送</b> 正确的数字代码",
    "ar": "👩🏽‍💻 <b>أرسل</b> رمز رقمي صحيح",
}
l_fsm_code_ban = {
    "ru": "👩🏽‍💻 <b>Telegram</b> забанил аккаунт на отправку кода\n\n#длительность {0}",
    "en": "👩🏽‍💻 <b>Telegram</b> banned the account from sending the code\n\n#duration {0}",
    "es": "👩🏽‍💻 <b>Telegram</b> ha bloqueado la cuenta para enviar el código\n\n#duración {0}",
    "fr": "👩🏽‍💻 <b>Telegram</b> a bloqué le compte pour l'envoi de code\n\n#durée {0}",
    "zh": "👩🏽‍💻 <b>Telegram</b> 禁止了发送代码的账户\n\n#持续时间 {0}",
    "ar": "👩🏽‍💻 <b>تيليجرام</b> حظر الحساب من إرسال الرمز\n\n#المدة {0}",
}
l_parse_done_app = {
    "ru": "👩🏽‍💻 <b>Список</b> реальных участников <code>{0}</code> (режим: {1}, количество: {2})\n\n<blockquote>{3}</blockquote>",
    "en": "👩🏽‍💻 <b>List</b> of real participants <code>{0}</code> (mode: {1}, count: {2})\n\n<blockquote>{3}</blockquote>",
    "es": "👩🏽‍💻 <b>Lista</b> de participantes reales <code>{0}</code> (modo: {1}, cantidad: {2})\n\n<blockquote>{3}</blockquote>",
    "fr": "👩🏽‍💻 <b>Liste</b> des participants réels <code>{0}</code> (mode : {1}, nombre : {2})\n\n<blockquote>{3}</blockquote>",
    "zh": "👩🏽‍💻 <b>真实参与者</b> <code>{0}</code>（模式：{1}，数量：{2}）\n\n<blockquote>{3}</blockquote>",
    "ar": "👩🏽‍💻 <b>قائمة</b> المشاركين الحقيقيين <code>{0}</code> (الوضع: {1}, العدد: {2})\n\n<blockquote>{3}</blockquote>",
}
# endregion


# region FereyPostBot
l_post_btn1 = {
    "ru": "👩🏽‍💻 Посты",
    "en": "👩🏽‍💻 Posts",
    "es": "👩🏽‍💻 Publicaciones",
    "fr": "👩🏽‍💻 Publications",
    "zh": "👩🏽‍💻 帖子",
    "ar": "👩🏽‍💻 المشاركات",
}
l_post_btn2 = {
    "ru": "💨 Подписка",
    "en": "💨 Subscription",
    "es": "💨 Suscripción",
    "fr": "💨 Abonnement",
    "zh": "💨 订阅",
    "ar": "💨 الاشتراك",
}
l_post_welcome = {
    "ru": "🌱 <b>{0}</b>, добро пожаловать в <i>@tg-приложение</i> создания креативных постов:\n\n<blockquote>▪️кнопочный счетчик\n▪️винил/инлайн-телескопы\n▪️выгрузка просмотров/кликов\n▪️шёпот-сообщения\n▪️веб-мини постинг</blockquote>",
    "en": "🌱 <b>{0}</b>, welcome to the <i>@tg-app</i> for creating creative posts:\n\n<blockquote>▪️button counter\n▪️vinyl/inline telescopes\n▪️views/clicks export\n▪️whisper messages\n▪️web mini posting</blockquote>",
    "es": "🌱 <b>{0}</b>, bienvenido a <i>@tg-aplicación</i> para crear publicaciones creativas:\n\n<blockquote>▪️contador de botones\n▪️vinilos/telescopios en línea\n▪️exportación de vistas/clics\n▪️mensajes susurrados\n▪️publicación web mini</blockquote>",
    "fr": "🌱 <b>{0}</b>, bienvenue dans <i>@tg-application</i> de création de posts créatifs :\n\n<blockquote>▪️compteur à boutons\n▪️télescopes vinyle/en ligne\n▪️exportation des vues/clics\n▪️messages chuchotés\n▪️mini publication web</blockquote>",
    "zh": "🌱 <b>{0}</b>, 欢迎来到 <i>@tg-应用程序</i> 创建创意帖子：\n\n<blockquote>▪️按钮计数器\n▪️黑胶/在线望远镜\n▪️查看/点击导出\n▪️耳语消息\n▪️网页迷你发布</blockquote>",
    "ar": "🌱 <b>{0}</b>، مرحبًا بك في <i>@tg-تطبيق</i> لإنشاء منشورات إبداعية:\n\n<blockquote>▪️عداد زري\n▪️فينييل/تلسكوبات داخلية\n▪️تحميل المشاهدات/النقرات\n▪️رسائل همس\n▪️نشر ويب مصغر</blockquote>",
}
l_post_bot_button_push = {
    "ru": "👩🏽‍💻 <b>Пользователь</b>: {0} нажал на: [{1}] (пост #<u>{2}</u>)\n\n<code>/parse {3}</code> - все клики поста",
    "en": "👩🏽‍💻 <b>User</b>: {0} clicked on: [{1}] (post #<u>{2}</u>)\n\n<code>/parse {3}</code> - all clicks of the post",
    "es": "👩🏽‍💻 <b>Usuario</b>: {0} hizo clic en: [{1}] (publicación #<u>{2}</u>)\n\n<code>/parse {3}</code> - todos los clics de la publicación",
    "fr": "👩🏽‍💻 <b>Utilisateur</b>: {0} a cliqué sur : [{1}] (post #<u>{2}</u>)\n\n<code>/parse {3}</code> - tous les clics du post",
    "zh": "👩🏽‍💻 <b>用户</b>: {0} 点击了: [{1}] (帖子 #<u>{2}</u>)\n\n<code>/parse {3}</code> - 所有帖子点击",
    "ar": "👩🏽‍💻 <b>المستخدم</b>: {0} ضغط على: [{1}] (المنشور #<u>{2}</u>)\n\n<code>/parse {3}</code> - جميع النقرات على المنشور",
}
l_post_parse = {
    "ru": "👩🏽‍💻 <b>Список</b> кликов поста #{0}: <u>{1}</u>\n\n<blockquote>👩🏽‍💻 <b>Оформи</b> <a href='{2}'>💨Подписку</a> для получения имен пользователей</blockquote>",
    "en": "👩🏽‍💻 <b>List</b> of clicks for post #{0}: <u>{1}</u>\n\n<blockquote>👩🏽‍💻 <b>Subscribe</b> <a href='{2}'>💨to get usernames</a></blockquote>",
    "es": "👩🏽‍💻 <b>Lista</b> de clics de la publicación #{0}: <u>{1}</u>\n\n<blockquote>👩🏽‍💻 <b>Haz</b> <a href='{2}'>💨Suscripción</a> para recibir los nombres de usuario</blockquote>",
    "fr": "👩🏽‍💻 <b>Liste</b> des clics du post #{0}: <u>{1}</u>\n\n<blockquote>👩🏽‍💻 <b>Faites</b> <a href='{2}'>💨L'abonnement</a> pour recevoir les noms d'utilisateur</blockquote>",
    "zh": "👩🏽‍💻 <b>帖子</b> 点击列表 #{0}: <u>{1}</u>\n\n<blockquote>👩🏽‍💻 <b>订阅</b> <a href='{2}'>💨以获取用户名</a></blockquote>",
    "ar": "👩🏽‍💻 <b>قائمة</b> نقرات المنشور #{0}: <u>{1}</u>\n\n<blockquote>👩🏽‍💻 <b>قم بعمل</b> <a href='{2}'>💨اشتراك</a> للحصول على أسماء المستخدمين</blockquote>",
}
l_post_whisper_btn = {
    "ru": "Показать",
    "en": "Show",
    "es": "Mostrar",
    "fr": "Afficher",
    "zh": "显示",
    "ar": "عرض",
}
l_post_whisper_message_text = {
    "ru": "👩🏽‍💻 <b>Секретный</b> шёпот только для: ",
    "en": "👩🏽‍💻 <b>Secret</b> whisper only for:",
    "es": "👩🏽‍💻 <b>Susurro</b> secreto solo para:",
    "fr": "👩🏽‍💻 <b>Chuchotement</b> secret uniquement pour :",
    "zh": "👩🏽‍💻 <b>秘密</b> 低语仅适用于：",
    "ar": "👩🏽‍💻 <b>همس سري</b> فقط لـ:",
}
l_post_whisper_title = {
    "ru": "👩🏽‍💻 Шёпот",
    "en": "👩🏽‍💻 Whisper",
    "es": "👩🏽‍💻 Susurro",
    "fr": "👩🏽‍💻 Chuchotement",
    "zh": "👩🏽‍💻 低语",
    "ar": "👩🏽‍💻 همس",
}
l_post_whisper_deleted = {
    "ru": "👩🏽‍💻 Шёпот удален",
    "en": "👩🏽‍💻 Whisper removed",
    "es": "👩🏽‍💻 Susurro eliminado",
    "fr": "👩🏽‍💻 Le chuchotement a été supprimé",
    "zh": "👩🏽‍💻 低语已删除",
    "ar": "👩🏽‍💻 تم حذف الهمس",
}
l_post_whisper_outdate = {
    "ru": "👩🏽‍💻 Шёпот просрочен после 3х дней",
    "en": "👩🏽‍💻 The whisper is overdue after 3 days",
    "es": "👩🏽‍💻 El susurro ha caducado después de 3 días",
    "fr": "👩🏽‍💻 Le chuchotement est expiré après 3 jours",
    "zh": "👩🏽‍💻 低语在3天后过期",
    "ar": "👩🏽‍💻 همس قد انتهت صلاحيتها بعد 3 أيام",
}
l_post_whisper_skip = {
    "ru": "👩🏽‍💻 Ты не видишь этот шёпот, потому что он был отправлен не тебе",
    "en": "👩🏽‍💻 You don't see this whisper because it wasn't sent to you",
    "es": "👩🏽‍💻 No ves este susurro porque no fue enviado a ti",
    "fr": "👩🏽‍💻 Tu ne vois pas ce chuchotement, car il n'a pas été envoyé pour toi",
    "zh": "👩🏽‍💻 你看不到这个低语，因为它不是发给你的",
    "ar": "👩🏽‍💻 أنت لا ترى هذه الهمسة لأنها لم تُرسل إليك",
}
l_post_whisper_alert = {
    "ru": "👩🏽‍💻 <b>Пользователь</b>: {0} прочитал шёпот: [{1}]",
    "en": "👩🏽‍💻 <b>User</b>: {0} read the whisper: [{1}]",
    "es": "👩🏽‍💻 <b>Usuario</b>: {0} leyó el susurro: [{1}]",
    "fr": "👩🏽‍💻 <b>Utilisateur</b>: {0} a lu le murmure : [{1}]",
    "zh": "👩🏽‍💻 <b>用户</b>: {0} 阅读了低语: [{1}]",
    "ar": "👩🏽‍💻 <b>المستخدم</b>: {0} قرأ الهمس: [{1}]",
}
l_post_whisper_text = {
    "ru": "👩🏽‍💻 <b>Шепот</b> - секретные сообщения для заданного количества пользователей в группе, которые открываются нажатием на кнопку",
    "en": "👩🏽‍💻 <b>Whisper</b> - secret messages for a specified number of users in a group that are revealed by clicking a button",
    "es": "👩🏽‍💻 <b>Susurro</b> - mensajes secretos para un número determinado de usuarios en el grupo, que se abren al hacer clic en un botón",
    "fr": "👩🏽‍💻 <b>Chuchotement</b> - messages secrets pour un nombre donné d'utilisateurs dans le groupe, qui s'ouvrent en appuyant sur un bouton",
    "zh": "👩🏽‍💻 <b>低语</b> - 针对特定数量用户的秘密消息，在组中通过点击按钮打开",
    "ar": "👩🏽‍💻 <b>همسات</b> - رسائل سرية لعدد محدد من المستخدمين في المجموعة، تفتح عند الضغط على الزر",
}
l_post_whisper_txt = {
    "ru": "посмотри личные сообщения",
    "en": "check your direct messages",
    "es": "mira los mensajes personales",
    "fr": "regarde les messages privés",
    "zh": "查看私信",
    "ar": "انظر الرسائل الشخصية",
}
l_post_whisper_example = {
    "ru": "💨 Например",
    "en": "💨 For example",
    "es": "💨 Por ejemplo",
    "fr": "💨 Par exemple",
    "zh": "💨 例如",
    "ar": "💨 على سبيل المثال",
}
# endregion


# region FereyMediaBot
l_media_btn1 = {
    "ru": "👩🏽‍💻 Медиа",
    "en": "👩🏽‍💻 Media",
    "es": "👩🏽‍💻 Medios",
    "fr": "👩🏽‍💻 Médias",
    "zh": "👩🏽‍💻 媒体",
    "ar": "👩🏽‍💻 وسائل الإعلام",
}
l_media_btn2 = {
    "ru": "💨 Подписка",
    "en": "💨 Subscription",
    "es": "💨 Suscripción",
    "fr": "💨 Abonnement",
    "zh": "💨 订阅",
    "ar": "💨 الاشتراك",
}
l_media_welcome = {
    "ru": "🌱 <b>{0}</b>, добро пожаловать в <i>@tg-приложение</i> создания медиа-креативов:\n\n<blockquote>▪️стикеры из текста и фото\n▪️аудио-тренды\n▪️видео-заметки\n▪️кнопочные нейро-титры</blockquote>",
    "en": "🌱 <b>{0}</b>, welcome to the <i>@tg-app</i> for creating media creatives:\n\n<blockquote>▪️stickers from text and photos\n▪️audio trends\n▪️video notes\n▪️button neuro-captions</blockquote>",
    "es": "🌱 <b>{0}</b>, bienvenido a <i>@tg-aplicación</i> para crear medios creativos:\n\n<blockquote>▪️stickers de texto y foto\n▪️tendencias de audio\n▪️notas de video\n▪️subtítulos neuronales en botones</blockquote>",
    "fr": "🌱 <b>{0}</b>, bienvenue dans <i>@tg-application</i> de création de médias créatifs :\n\n<blockquote>▪️stickers à partir de texte et de photos\n▪️tendances audio\n▪️notes vidéo\n▪️sous-titres neuronaux à boutons</blockquote>",
    "zh": "🌱 <b>{0}</b>, 欢迎来到 <i>@tg-应用程序</i> 创建媒体创意：\n\n<blockquote>▪️从文本和照片制作贴纸\n▪️音频趋势\n▪️视频笔记\n▪️按钮式神经字幕</blockquote>",
    "ar": "🌱 <b>{0}</b>, مرحبًا بك في <i>@tg-تطبيق</i> لإنشاء الإبداعات الإعلامية:\n\n<blockquote>▪️ملصقات من النص والصور\n▪️اتجاهات الصوت\n▪️ملاحظات الفيديو\n▪️عناوين عصبية بأزرار</blockquote>",
}
l_media_text = {
    "ru": "👩🏽‍💻 <b>Выбери</b> тип выпадающих медиа-креативов (/add | /del)",
    "en": "👩🏽‍💻 <b>Select</b> the type of dropdown media creatives (/add | /del)",
    "es": "👩🏽‍💻 <b>Elige</b> el tipo de creativos multimedia desplegables (/add | /del)",
    "fr": "👩🏽‍💻 <b>Choisis</b> le type de médias créatifs déroulants (/add | /del)",
    "zh": "👩🏽‍💻 <b>选择</b> 下拉媒体创意类型 (/add | /del)",
    "ar": "👩🏽‍💻 <b>اختر</b> نوع الوسائط المنبثقة (/add | /del)",
}
l_media_del = {
    "ru": "👩🏽‍💻 <b>Выбери</b> медиа-креатив для удаления",
    "en": "👩🏽‍💻 <b>Select</b> the media creative to delete",
    "es": "👩🏽‍💻 <b>Elige</b> el medio creativo para eliminar",
    "fr": "👩🏽‍💻 <b>Choisissez</b> un média créatif à supprimer",
    "zh": "👩🏽‍💻 <b>选择</b> 要删除的媒体创意",
    "ar": "👩🏽‍💻 <b>اختر</b> الإبداع الإعلامي للحذف",
}
l_media_show = {
    "ru": "👩🏽‍💻 <b>Введи</b> запрос для поиска по медиа-креативам",
    "en": "👩🏽‍💻 <b>Enter</b> a query to search for media creatives",
    "es": "👩🏽‍💻 <b>Introduce</b> una consulta para buscar en los medios creativos",
    "fr": "👩🏽‍💻 <b>Entrez</b> une requête pour rechercher des créations médiatiques",
    "zh": "👩🏽‍💻 <b>输入</b> 媒体创意搜索请求",
    "ar": "👩🏽‍💻 <b>أدخل</b> استعلامًا للبحث في الإبداعات الإعلامية",
}
l_media_random = {
    "ru": "🎲 Случайный выбор",
    "en": "🎲 Random selection",
    "es": "🎲 Selección aleatoria",
    "fr": "🎲 Choix aléatoire",
    "zh": "🎲 随机选择",
    "ar": "🎲 اختيار عشوائي",
}
l_media_none = {
    "ru": "👩🏽‍💻 <b>Медиа</b>-креатива не найдено",
    "en": "👩🏽‍💻 <b>Media</b> creative not found",
    "es": "👩🏽‍💻 <b>No se encontró</b> media-creativa",
    "fr": "👩🏽‍💻 <b>Aucun</b> média créatif trouvé",
    "zh": "👩🏽‍💻 <b>媒体</b>创意未找到",
    "ar": "👩🏽‍💻 <b>الإبداع</b> الإعلامي غير موجود",
}
l_media_file = {
    "ru": "👩🏽‍💻 1/2. <b>Прикрепи</b> аудио/видео, текст/фото контент для создания медиа-креатива",
    "en": "👩🏽‍💻 1/2. <b>Attach</b> audio/video, text/photo content to create a media creative",
    "es": "👩🏽‍💻 1/2. <b>Adjunta</b> audio/video, texto/foto contenido para crear un medio creativo",
    "fr": "👩🏽‍💻 1/2. <b>Joins</b> audio/vidéo, texte/photo contenu pour créer un média créatif",
    "zh": "👩🏽‍💻 1/2. <b>附加</b> 音频/视频、文本/照片内容以创建媒体创意",
    "ar": "👩🏽‍💻 1/2. <b>أرفق</b> محتوى صوتي/مرئي، نص/صورة لإنشاء إبداع وسائط",
}
l_media_title1 = {
    "ru": "👩🏽‍💻 2/2. <b>Введи</b> <code>ключевые слова</code> для твоего медиа-креатива\n\n<blockquote>изменить ключевые слова нельзя</blockquote>",
    "en": "👩🏽‍💻 2/2. <b>Enter</b> <code>keywords</code> for your media creative\n\n<blockquote>keywords cannot be changed</blockquote>",
    "es": "👩🏽‍💻 2/2. <b>Introduce</b> <code>palabras clave</code> para tu medio creativo\n\n<blockquote>no se pueden cambiar las palabras clave</blockquote>",
    "fr": "👩🏽‍💻 2/2. <b>Entrez</b> <code>des mots-clés</code> pour votre création média\n\n<blockquote>les mots-clés ne peuvent pas être modifiés</blockquote>",
    "zh": "👩🏽‍💻 2/2. <b>输入</b> <code>关键字</code> 以用于你的媒体创意\n\n<blockquote>无法更改关键字</blockquote>",
    "ar": "👩🏽‍💻 2/2. <b>أدخل</b> <code>الكلمات الرئيسية</code> لإبداعك الإعلامي\n\n<blockquote>لا يمكن تغيير الكلمات الرئيسية</blockquote>",
}
l_media_title2 = {
    "ru": "👩🏽‍💻 2/2. <b>Текущие</b> ключевые слова для твоего медиа-креатива\n\n<blockquote>{0}</blockquote>\n\n[отправь новые или жми {1}]",
    "en": "👩🏽‍💻 2/2. <b>Current</b> keywords for your media creative\n\n<blockquote>{0}</blockquote>\n\n[send new ones or click {1}]",
    "es": "👩🏽‍💻 2/2. <b>Palabras</b> clave actuales para tu creatividad mediática\n\n<blockquote>{0}</blockquote>\n\n[envía nuevas o presiona {1}]",
    "fr": "👩🏽‍💻 2/2. <b>Mots-clés</b> actuels pour ta création média\n\n<blockquote>{0}</blockquote>\n\n[envoie de nouveaux ou clique sur {1}]",
    "zh": "👩🏽‍💻 2/2. <b>当前</b> 关键字用于你的媒体创意\n\n<blockquote>{0}</blockquote>\n\n[发送新内容或点击 {1}]",
    "ar": "👩🏽‍💻 2/2. <b>الكلمات</b> الرئيسية الحالية لإبداعك الإعلامي\n\n<blockquote>{0}</blockquote>\n\n[أرسل جديدة أو اضغط {1}]",
}
l_media_confirm = {
    "ru": "🏁 Завершить",
    "en": "🏁 Finish",
    "es": "🏁 Finalizar",
    "fr": "🏁 Terminer",
    "zh": "🏁 完成",
    "ar": "🏁 إنهاء",
}
l_media_error = {
    "ru": "👩🏽‍💻 <b>Ошибка</b>: попробуй позже или загрузи другой медиа-файл",
    "en": "👩🏽‍💻 <b>Error</b>: try again later or upload a different media file",
    "es": "👩🏽‍💻 <b>Error</b>: intenta más tarde o carga otro archivo multimedia",
    "fr": "👩🏽‍💻 <b>Erreur</b> : essaie plus tard ou télécharge un autre fichier multimédia",
    "zh": "👩🏽‍💻 <b>错误</b>: 请稍后再试或上传其他媒体文件",
    "ar": "👩🏽‍💻 <b>خطأ</b>: حاول لاحقًا أو قم بتحميل ملف وسائط آخر",
}
l_media_finish = {
    "ru": "👩🏽‍💻 <b>Медиа</b>-креатив успешно создан",
    "en": "👩🏽‍💻 <b>Media</b> creative has been successfully created",
    "es": "👩🏽‍💻 <b>Medios</b>-creativo creado con éxito",
    "fr": "👩🏽‍💻 <b>Média</b>-créatif créé avec succès",
    "zh": "👩🏽‍💻 <b>媒体</b>创意成功创建",
    "ar": "👩🏽‍💻 <b>الإبداع</b> الإعلامي تم إنشاؤه بنجاح",
}
l_media_publish = {
    "ru": "🔗 Список",
    "en": "🔗 List",
    "es": "🔗 Lista",
    "fr": "🔗 Liste",
    "zh": "🔗 列表",
    "ar": "🔗 قائمة",
}
l_media_check = {
    "ru": "🔗 Проверка",
    "en": "🔗 Check",
    "es": "🔗 Verificación",
    "fr": "🔗 Vérification",
    "zh": "🔗 检查",
    "ar": "🔗 التحقق",
}
l_media_hasdeleted = {
    "ru": "👩🏽‍💻 <b>Медиа</b>-креатив удален",
    "en": "👩🏽‍💻 <b>Media</b> creative removed",
    "es": "👩🏽‍💻 <b>Medios</b>-creativo eliminado",
    "fr": "👩🏽‍💻 <b>Média</b>-créatif supprimé",
    "zh": "👩🏽‍💻 <b>媒体</b>创意已删除",
    "ar": "👩🏽‍💻 <b>تم حذف</b> الإبداع الإعلامي",
}
l_media_delprepare = {
    "ru": "🔗 Выбрать",
    "en": "🔗 Select",
    "es": "🔗 Seleccionar",
    "fr": "🔗 Choisir",
    "zh": "🔗 选择",
    "ar": "🔗 اختر",
}
l_media_share = {
    "ru": "🔗 Поделиться",
    "en": "🔗 Share",
    "es": "🔗 Compartir",
    "fr": "🔗 Partager",
    "zh": "🔗 分享",
    "ar": "🔗 شارك",
}
l_titles_file = {
    "ru": "👩🏽‍💻 1/2. <b>Прикрепи</b> аудио/видео-контент со звуком для создания #нейро-титров",
    "en": "👩🏽‍💻 1/2. <b>Attach</b> audio/video content with sound to create #neuro-subtitles",
    "es": "👩🏽‍💻 1/2. <b>Adjunta</b> contenido de audio/video con sonido para crear #neuro-subtítulos",
    "fr": "👩🏽‍💻 1/2. <b>Joins</b> du contenu audio/vidéo avec son pour créer des #neuro-sous-titres",
    "zh": "👩🏽‍💻 1/2. <b>附加</b> 带声音的音频/视频内容以创建 #神经字幕",
    "ar": "👩🏽‍💻 1/2. <b>أرفق</b> محتوى صوتي/مرئي مع الصوت لإنشاء #نيرو-تسميات",
}
l_titles_error = {
    "ru": "👩🏽‍💻 <b>Ошибка</b> создания титров к медиа-креативу: попробуй ещё раз позже или загрузи другой медиа-файл",
    "en": "👩🏽‍💻 <b>Error</b> creating subtitles for the media creative: please try again later or upload a different media file",
    "es": "👩🏽‍💻 <b>Error</b> al crear subtítulos para el medio creativo: intenta de nuevo más tarde o carga otro archivo multimedia.",
    "fr": "👩🏽‍💻 <b>Erreur</b> de création de sous-titres pour le média créatif : essaie encore plus tard ou télécharge un autre fichier média.",
    "zh": "👩🏽‍💻 <b>创建媒体创意的字幕时出错</b>：请稍后再试或上传其他媒体文件",
    "ar": "👩🏽‍💻 <b>خطأ</b> في إنشاء الترجمة للإبداع الإعلامي: حاول مرة أخرى لاحقًا أو قم بتحميل ملف وسائط آخر",
}

# endregion


# region FereyFindBot
l_find_btn1 = {
    "ru": "👩🏽‍💻 Поиск",
    "en": "👩🏽‍💻 Search",
    "es": "👩🏽‍💻 Búsqueda",
    "fr": "👩🏽‍💻 Recherche",
    "zh": "👩🏽‍💻 搜索",
    "ar": "👩🏽‍💻 البحث",
}
l_find_btn2 = {
    "ru": "📍 Гео поиск",
    "en": "📍 Geo search",
    "es": "📍 Búsqueda geográfica",
    "fr": "📍 Recherche géo",
    "zh": "📍 地理搜索",
    "ar": "📍 البحث الجغرافي",
}
l_find_btn3 = {
    "ru": "🔔 Уведомления",
    "en": "🔔 Notifications",
    "es": "🔔 Notificaciones",
    "fr": "🔔 Notifications",
    "zh": "🔔 通知",
    "ar": "🔔 الإشعارات",
}
l_find_btn4 = {
    "ru": "💨 Подписка",
    "en": "💨 Subscription",
    "es": "💨 Suscripción",
    "fr": "💨 Abonnement",
    "zh": "💨 订阅",
    "ar": "💨 الاشتراك",
}
l_find_welcome = {
    "ru": "🌱 <b>{0}</b>, добро пожаловать в <i>@tg-приложение</i> премиум поиска в <b>Telegram</b>:\n\n<blockquote>▪️поиск каналов/групп\n▪️приложения web/nft</blockquote>",
    "en": "🌱 <b>{0}</b>, welcome to the <i>@tg-app</i> premium search in <b>Telegram</b>:\n\n<blockquote>▪️channel/group search\n▪️web/nft applications</blockquote>",
    "es": "🌱 <b>{0}</b>, bienvenido a <i>@tg-aplicación</i> de búsqueda premium en <b>Telegram</b>:\n\n<blockquote>▪️búsqueda de canales/grupos\n▪️aplicaciones web/nft</blockquote>",
    "fr": "🌱 <b>{0}</b>, bienvenue dans <i>@tg-application</i> de recherche premium dans <b>Telegram</b> :\n\n<blockquote>▪️recherche de chaînes/groupes\n▪️applications web/nft</blockquote>",
    "zh": "🌱 <b>{0}</b>, 欢迎来到 <i>@tg-应用程序</i> 的 <b>Telegram</b> 高级搜索：\n\n<blockquote>▪️搜索频道/群组\n▪️web/nft 应用程序</blockquote>",
    "ar": "🌱 <b>{0}</b>، مرحبًا بك في <i>@tg-التطبيق</i> للبحث المتميز في <b>Telegram</b>:\n\n<blockquote>▪️بحث القنوات/المجموعات\n▪️تطبيقات الويب/nft</blockquote>",
}
l_subscribe_find = {
    "ru": "👩🏽‍💻 <b>Оформи</b> ежемесячную подписку:\n\n¹ [<b>Все приложения</b> и проекты (-<u>22</u>%)]\n² [@{0}-приложение]:\n<blockquote>▪️<b>уведомления</b> о ключевых словах\n(<i>ссылка на сообщение</i>)\n▪️<b>увеличение</b> лимитов уведомлений\n(<i>до 10 ключевых слов/групп/каналов</i>)\n▪️<b>приоритетная</b> выдача при поиске\n(<i>выше чем premium/verified</i>)</blockquote>",
    "en": "👩🏽‍💻 <b>Subscribe</b> to a monthly plan:\n\n¹ [<b>All apps</b> and projects (-<u>22</u>%)]\n² [@{0}-app]:\n<blockquote>▪️<b>notifications</b> for keywords\n(<i>link to message</i>)\n▪️<b>increased</b> notification limits\n(<i>up to 10 keywords/groups/channels</i>)\n▪️<b>priority</b> results in search\n(<i>higher than premium/verified</i>)</blockquote>",
    "es": "👩🏽‍💻 <b>Suscríbete</b> a una suscripción mensual:\n\n¹ [<b>Todas las aplicaciones</b> y proyectos (-<u>22</u>%)]\n² [@{0}-aplicación]:\n<blockquote>▪️<b>notificaciones</b> de palabras clave\n(<i>enlace al mensaje</i>)\n▪️<b>aumento</b> de los límites de notificaciones\n(<i>hasta 10 palabras clave/grupos/canales</i>)\n▪️<b>prioridad</b> en los resultados de búsqueda\n(<i>más alto que premium/verified</i>)</blockquote>",
    "fr": "👩🏽‍💻 <b>Abonnez-vous</b> à un abonnement mensuel :\n\n¹ [<b>Toutes les applications</b> et projets (-<u>22</u>%)]\n² [@{0}-application] :\n<blockquote>▪️<b>notifications</b> sur les mots-clés\n(<i>lien vers le message</i>)\n▪️<b>augmentation</b> des limites de notifications\n(<i>jusqu'à 10 mots-clés/groupes/canaux</i>)\n▪️<b>priorité</b> dans les résultats de recherche\n(<i>plus haut que premium/vérifié</i>)</blockquote>",
    "zh": "👩🏽‍💻 <b>办理</b> 每月订阅：\n\n¹ [<b>所有应用</b>和项目 (-<u>22</u>%)]\n² [@{0}-应用程序]:\n<blockquote>▪️<b>关键字</b>通知\n(<i>消息链接</i>)\n▪️<b>增加</b>通知限制\n(<i>最多 10 个关键字/组/频道</i>)\n▪️<b>优先</b>搜索结果\n(<i>高于 premium/verified</i>)</blockquote>",
    "ar": "👩🏽‍💻 <b>اشترك</b> في الاشتراك الشهري:\n\n¹ [<b>جميع التطبيقات</b> والمشاريع (-<u>22</u>%)]\n² [@{0}-تطبيق]:\n<blockquote>▪️<b>إشعارات</b> عن الكلمات الرئيسية\n(<i>رابط الرسالة</i>)\n▪️<b>زيادة</b> حدود الإشعارات\n(<i>حتى 10 كلمات رئيسية/مجموعات/قنوات</i>)\n▪️<b>أولوية</b> في نتائج البحث\n(<i>أعلى من premium/verified</i>)</blockquote>",
}
l_find_bot_text_find = {
    "ru": "👩🏽‍💻 <b>Источник</b>: {0}, ссылка на публикацию: [{1}] (ключевое слово: <u>{2}</u>)",
    "en": "👩🏽‍💻 <b>Source</b>: {0}, link to the publication: [{1}] (keyword: <u>{2}</u>)",
    "es": "👩🏽‍💻 <b>Fuente</b>: {0}, enlace a la publicación: [{1}] (palabra clave: <u>{2}</u>)",
    "fr": "👩🏽‍💻 <b>Source</b>: {0}, lien vers la publication : [{1}] (mot-clé : <u>{2}</u>)",
    "zh": "👩🏽‍💻 <b>来源</b>: {0}, 文章链接: [{1}] (关键词: <u>{2}</u>)",
    "ar": "👩🏽‍💻 <b>المصدر</b>: {0}, رابط النشر: [{1}] (الكلمة الرئيسية: <u>{2}</u>)",
}
l_geo_minus = {
    "ru": "-",
    "en": "-",
    "es": "-",
    "fr": "-",
    "zh": "-",
    "ar": "-",
}
l_geo_current = {
    "ru": "📍R: {0}m",
    "en": "📍R: {0}m",
    "es": "📍R: {0}m",
    "fr": "📍R: {0}m",
    "zh": "📍R: {0}米",
    "ar": "📍R: {0}م",
}
l_geo_plus = {
    "ru": "+",
    "en": "+",
    "es": "+",
    "fr": "+",
    "zh": "+",
    "ar": "+",
}
l_geo_text1 = {
    "ru": "📍 <b>Гео</b>-поиск пользователей\n\n<blockquote>👩🏽‍💻 <b>Жми</b> на -/+, чтобы настроить [<b>📍Radius</b>]</blockquote>",
    "en": "📍 <b>Geo</b>-search for users\n\n<blockquote>👩🏽‍💻 <b>Click</b> on -/+, to set up [<b>📍Radius</b>]</blockquote>",
    "es": "📍 <b>Búsqueda</b> de usuarios por geolocalización\n\n<blockquote>👩🏽‍💻 <b>Haz clic</b> en -/+, para ajustar [<b>📍Radio</b>]</blockquote>",
    "fr": "📍 <b>Recherche</b> géo des utilisateurs\n\n<blockquote>👩🏽‍💻 <b>Clique</b> sur -/+, pour configurer [<b>📍Rayon</b>]</blockquote>",
    "zh": "📍 <b>地理</b>用户搜索\n\n<blockquote>👩🏽‍💻 <b>点击</b> -/+, 以设置 [<b>📍半径</b>]</blockquote>",
    "ar": "📍 <b>البحث الجغرافي</b> عن المستخدمين\n\n<blockquote>👩🏽‍💻 <b>اضغط</b> على -/+, لتكوين [<b>📍نطاق</b>]</blockquote>",
}
l_geo_text2 = {
    "ru": "👩🏽‍💻 <b>Прикрепи</b> геопозицию через 📎-меню вложений или <b>жми</b> на кнопку ниже:\n\n<blockquote>[📍Отправить гео]</blockquote>",
    "en": "👩🏽‍💻 <b>Attach</b> your geolocation via the 📎-attachment menu or <b>click</b> the button below:\n\n<blockquote>[📍Send geo]</blockquote>",
    "es": "👩🏽‍💻 <b>Adjunta</b> la geolocalización a través del menú de adjuntos 📎 o <b>haz</b> clic en el botón de abajo:\n\n<blockquote>[📍Enviar geo]</blockquote>",
    "fr": "👩🏽‍💻 <b>Attache</b> ta géolocalisation via le menu 📎 des pièces jointes ou <b>appuie</b> sur le bouton ci-dessous :\n\n<blockquote>[📍Envoyer la géo]</blockquote>",
    "zh": "👩🏽‍💻 <b>附加</b> 地理位置通过 📎 附件菜单或 <b>点击</b> 下面的按钮：\n\n<blockquote>[📍发送地理位置]</blockquote>",
    "ar": "👩🏽‍💻 <b>أرفق</b> الموقع الجغرافي من خلال قائمة 📎-المرفقات أو <b>اضغط</b> على الزر أدناه:\n\n<blockquote>[📍إرسال الموقع]</blockquote>",
}
l_geo_send = {
    "ru": "📍Отправить гео",
    "en": "📍Send geo",
    "es": "📍Enviar geolocalización",
    "fr": "📍Envoyer la géolocalisation",
    "zh": "📍发送地理位置",
    "ar": "📍إرسال الموقع",
}
l_geo_start = {
    "ru": "🔎 <b>Начинаем</b> поиск..",
    "en": "🔎 <b>Starting</b> the search..",
    "es": "🔎 <b>Comenzamos</b> la búsqueda..",
    "fr": "🔎 <b>Nous commençons</b> la recherche..",
    "zh": "🔎 <b>开始</b> 搜索..",
    "ar": "🔎 <b>نبدأ</b> البحث..",
}
l_geo_no = {
    "ru": "📍 Пользователей (@username) в данной геопозиции не найдено",
    "en": "📍 Users (@username) not found in this geolocation",
    "es": "📍 No se encontraron usuarios (@username) en esta geolocalización.",
    "fr": "📍 Aucun utilisateur (@username) n'a été trouvé à cette géoposition.",
    "zh": "📍 在该地理位置未找到用户 (@username)",
    "ar": "📍 لم يتم العثور على مستخدمين (@username) في هذا الموقع الجغرافي",
}
l_geo_finish = {
    "ru": "📍 <b>В <a href='https://maps.google.com/?q={0},{1}'>геолокации</a></b> найдено пользователей: <u>{2}</u>",
    "en": "📍 <b>In <a href='https://maps.google.com/?q={0},{1}'>geolocation</a></b> found users: <u>{2}</u>",
    "es": "📍 <b>En <a href='https://maps.google.com/?q={0},{1}'>geolocalización</a></b> se encontraron usuarios: <u>{2}</u>",
    "fr": "📍 <b>Dans <a href='https://maps.google.com/?q={0},{1}'>la géolocalisation</a></b> utilisateurs trouvés : <u>{2}</u>",
    "zh": "📍 <b>在<a href='https://maps.google.com/?q={0},{1}'>地理位置</a></b>找到的用户: <u>{2}</u>",
    "ar": "📍 <b>في <a href='https://maps.google.com/?q={0},{1}'>الموقع الجغرافي</a></b> تم العثور على المستخدمين: <u>{2}</u>",
}
l_find_add_cmd = {
    "ru": "👩🏽‍💻 <b>Отправь</b> ссылку на канал/группу/приложение",
    "en": "👩🏽‍💻 <b>Send</b> the link to the channel/group/app",
    "es": "👩🏽‍💻 <b>Envía</b> el enlace al canal/grupo/aplicación",
    "fr": "👩🏽‍💻 <b>Envoyer</b> le lien vers le canal/groupe/application",
    "zh": "👩🏽‍💻 <b>发送</b> 频道/群组/应用程序的链接",
    "ar": "👩🏽‍💻 <b>أرسل</b> رابط القناة/المجموعة/التطبيق",
}
l_find_err_cmd = {
    "ru": "👩🏽‍💻 <b>Ошибка</b> (вставь корректную ссылку или повтори позже)",
    "en": "👩🏽‍💻 <b>Error</b> (insert a valid link or try again later)",
    "es": "👩🏽‍💻 <b>Error</b> (inserta un enlace correcto o intenta de nuevo más tarde)",
    "fr": "👩🏽‍💻 <b>Erreur</b> (insérez un lien correct ou réessayez plus tard)",
    "zh": "👩🏽‍💻 <b>错误</b>（插入正确的链接或稍后重试）",
    "ar": "👩🏽‍💻 <b>خطأ</b> (أدخل رابطًا صحيحًا أو حاول مرة أخرى لاحقًا)",
}
l_find_ok_cmd = {
    "ru": "👩🏽‍💻 <b>Ссылка</b> успешно добавлена!",
    "en": "👩🏽‍💻 <b>Link</b> has been successfully added!",
    "es": "👩🏽‍💻 <b>¡Enlace</b> añadido con éxito!",
    "fr": "👩🏽‍💻 <b>Lien</b> ajouté avec succès !",
    "zh": "👩🏽‍💻 <b>链接</b> 已成功添加！",
    "ar": "👩🏽‍💻 <b>الرابط</b> تمت إضافته بنجاح!",
}
l_find_check = {
    "ru": "🔗 Проверка",
    "en": "🔗 Check",
    "es": "🔗 Verificación",
    "fr": "🔗 Vérification",
    "zh": "🔗 检查",
    "ar": "🔗 التحقق",
}
l_find_menu = {
    "ru": "↩ Menu",
    "en": "↩ Menu",
    "es": "↩ Menú",
    "fr": "↩ Menu",
    "zh": "↩ 菜单",
    "ar": "↩ القائمة",
}
l_find_text = {
    "ru": "<b>🔎 Сбор целевой аудитории (ЦА)</b>\n\n<blockquote>▪️<b>top</b> каналы/группы ЦА\n▪️<b>lead</b> конкуренты по нише\n▪️каталог <b>vip</b> приложений</blockquote>",
    "en": "<b>🔎 Target Audience (TA) Collection</b>\n\n<blockquote>▪️<b>top</b> channels/groups of TA\n▪️<b>lead</b> competitors in the niche\n▪️catalog of <b>vip</b> applications</blockquote>",
    "es": "<b>🔎 Recolección de la audiencia objetivo (AO)</b>\n\n<blockquote>▪️<b>top</b> canales/grupos de AO\n▪️<b>lead</b> competidores en el nicho\n▪️catálogo de <b>vip</b> aplicaciones</blockquote>",
    "fr": "<b>🔎 Collecte de l'audience cible (AC)</b>\n\n<blockquote>▪️<b>top</b> canaux/groupes AC\n▪️<b>lead</b> concurrents dans la niche\n▪️catalogue <b>vip</b> d'applications</blockquote>",
    "zh": "<b>🔎 目标受众（ЦА）收集</b>\n\n<blockquote>▪️<b>顶级</b> 渠道/群组 ЦА\n▪️<b>领先</b> 竞争对手\n▪️<b>VIP</b> 应用程序目录</blockquote>",
    "ar": "<b>🔎 جمع الجمهور المستهدف (CA)</b>\n\n<blockquote>▪️<b>أفضل</b> القنوات/المجموعات للجمهور المستهدف\n▪️<b>الرائد</b> المنافسون في المجال\n▪️دليل <b>vip</b> للتطبيقات</blockquote>",
}
l_find_category_typing = {
    "ru": "✅ ввести свои параметры",
    "en": "✅ enter your parameters",
    "es": "✅ ingresar tus parámetros",
    "fr": "✅ entrer vos paramètres",
    "zh": "✅ 输入您的参数",
    "ar": "✅ أدخل معلماتك",
}
l_find_desc = {
    "ru": "<b>Описание:</b> {0}",
    "en": "<b>Description:</b> {0}",
    "es": "<b>Descripción:</b> {0}",
    "fr": "<b>Description :</b> {0}",
    "zh": "<b>描述：</b> {0}",
    "ar": "<b>الوصف:</b> {0}",
}
l_find_reacts = {
    "ru": "<b>Реакции:</b> {0}",
    "en": "<b>Reactions:</b> {0}",
    "es": "<b>Reacciones:</b> {0}",
    "fr": "<b>Réactions :</b> {0}",
    "zh": "<b>反应：</b> {0}",
    "ar": "<b>ردود الفعل:</b> {0}",
}
l_find_send = {
    "ru": "<b>Сообщ/медиа/инлайн/инвайт:</b> {0}/{1}/{2}/{3}",
    "en": "<b>Message/media/inline/invite:</b> {0}/{1}/{2}/{3}",
    "es": "<b>Mensaje/média/in-line/invitación:</b> {0}/{1}/{2}/{3}",
    "fr": "<b>Message/média/en ligne/invitation :</b> {0}/{1}/{2}/{3}",
    "zh": "<b>消息/媒体/内联/邀请：</b> {0}/{1}/{2}/{3}",
    "ar": "<b>رسالة/وسائط/خط/دعوة:</b> {0}/{1}/{2}/{3}",
}
l_find_bio = {
    "ru": "<b>Био:</b> {0}",
    "en": "<b>Bio:</b> {0}",
    "es": "<b>Bio:</b> {0}",
    "fr": "<b>Bio :</b> {0}",
    "zh": "<b>简介：</b> {0}",
    "ar": "<b>السيرة الذاتية:</b> {0}",
}
l_find_about = {
    "ru": "<b>Описание:</b> {0}",
    "en": "<b>Description:</b> {0}",
    "es": "<b>Descripción:</b> {0}",
    "fr": "<b>Description :</b> {0}",
    "zh": "<b>描述：</b> {0}",
    "ar": "<b>الوصف:</b> {0}",
}
l_find_description = {
    "ru": "<b>Подробнее:</b> {0}",
    "en": "<b>More details:</b> {0}",
    "es": "<b>Más información:</b> {0}",
    "fr": "<b>Plus d'infos :</b> {0}",
    "zh": "<b>更多信息：</b> {0}",
    "ar": "<b>المزيد:</b> {0}",
}
l_find_commands = {
    "ru": "<b>Команды:</b> {0}",
    "en": "<b>Commands:</b> {0}",
    "es": "<b>Comandos:</b> {0}",
    "fr": "<b>Commandes :</b> {0}",
    "zh": "<b>命令：</b> {0}",
    "ar": "<b>الأوامر:</b> {0}",
}
l_find_chn = {
    "ru": "📰 Каналы",
    "en": "📰 Channels",
    "es": "📰 Canales",
    "fr": "📰 Canaux",
    "zh": "📰 渠道",
    "ar": "📰 القنوات",
}
l_find_grp = {
    "ru": "📁 Группы",
    "en": "📁 Groups",
    "es": "📁 Grupos",
    "fr": "📁 Groupes",
    "zh": "📁 组别",
    "ar": "📁 المجموعات",
}
l_find_usr = {
    "ru": "🕵️ Конкуренты",
    "en": "🕵️ Competitors",
    "es": "🕵️ Competidores",
    "fr": "🕵️ Concurrents",
    "zh": "🕵️ 竞争对手",
    "ar": "🕵️ المنافسون",
}
l_find_bot = {
    "ru": "🫥 Приложения",
    "en": "🫥 Applications",
    "es": "🫥 Aplicaciones",
    "fr": "🫥 Applications",
    "zh": "🫥 应用程序",
    "ar": "🫥 التطبيقات",
}
l_find_chn_choose = {
    "ru": "📰 <b>Выбери категорию</b> для выгрузки каналов",
    "en": "📰 <b>Select a category</b> for channel export",
    "es": "📰 <b>Elige una categoría</b> para la exportación de canales",
    "fr": "📰 <b>Choisissez une catégorie</b> pour l'exportation des chaînes",
    "zh": "📰 <b>选择类别</b> 以导出频道",
    "ar": "📰 <b>اختر فئة</b> لتحميل القنوات",
}
l_find_grp_choose = {
    "ru": "📁 <b>Выбери категорию</b> для выгрузки групп",
    "en": "📁 <b>Select a category</b> for group export",
    "es": "📁 <b>Selecciona una categoría</b> para exportar grupos",
    "fr": "📁 <b>Choisissez une catégorie</b> pour l'exportation des groupes",
    "zh": "📁 <b>选择类别</b> 以导出组",
    "ar": "📁 <b>اختر فئة</b> لتحميل المجموعات",
}
l_find_usr_choose = {
    "ru": "🕵️ <b>Выбери категорию</b> для выгрузки пользователей",
    "en": "🕵️ <b>Select a category</b> for exporting users",
    "es": "🕵️ <b>Elige una categoría</b> para exportar usuarios",
    "fr": "🕵️ <b>Choisissez une catégorie</b> pour l'exportation des utilisateurs",
    "zh": "🕵️ <b>选择类别</b> 以导出用户",
    "ar": "🕵️ <b>اختر فئة</b> لتحميل المستخدمين",
}
l_find_bot_choose = {
    "ru": "🫥 <b>Выбери категорию</b> для выгрузки приложений",
    "en": "🫥 <b>Select a category</b> for exporting applications",
    "es": "🫥 <b>Elige una categoría</b> para la exportación de aplicaciones",
    "fr": "🫥 <b>Choisissez une catégorie</b> pour l'exportation des applications",
    "zh": "🫥 <b>选择类别</b> 以导出应用程序",
    "ar": "🫥 <b>اختر فئة</b> لتحميل التطبيقات",
}
l_find_chn_find = {
    "ru": "🔎 Поиск каналов",
    "en": "🔎 Channel search",
    "es": "🔎 Búsqueda de canales",
    "fr": "🔎 Recherche de chaînes",
    "zh": "🔎 搜索频道",
    "ar": "🔎 البحث عن القنوات",
}
l_find_grp_find = {
    "ru": "🔎 Поиск групп",
    "en": "🔎 Group Search",
    "es": "🔎 Búsqueda de grupos",
    "fr": "🔎 Recherche de groupes",
    "zh": "🔎 搜索组",
    "ar": "🔎 البحث عن المجموعات",
}
l_find_usr_find = {
    "ru": "🔎 Поиск конкурентов",
    "en": "🔎 Competitor Search",
    "es": "🔎 Búsqueda de competidores",
    "fr": "🔎 Recherche de concurrents",
    "zh": "🔎 竞争对手搜索",
    "ar": "🔎 بحث المنافسين",
}
l_find_bot_find = {
    "ru": "🔎 Поиск приложений",
    "en": "🔎 Application Search",
    "es": "🔎 Búsqueda de aplicaciones",
    "fr": "🔎 Recherche d'applications",
    "zh": "🔎 应用程序搜索",
    "ar": "🔎 البحث عن التطبيقات",
}
l_find_chn_link = {
    "ru": "🔗 Перейти к каналу",
    "en": "🔗 Go to channel",
    "es": "🔗 Ir al canal",
    "fr": "🔗 Aller au canal",
    "zh": "🔗 前往频道",
    "ar": "🔗 الانتقال إلى القناة",
}
l_find_grp_link = {
    "ru": "🔗 Перейти к группе",
    "en": "🔗 Go to the group",
    "es": "🔗 Ir al grupo",
    "fr": "🔗 Aller au groupe",
    "zh": "🔗 前往小组",
    "ar": "🔗 الانتقال إلى المجموعة",
}
l_find_usr_link = {
    "ru": "🔗 Перейти к пользователю",
    "en": "🔗 Go to user",
    "es": "🔗 Ir al usuario",
    "fr": "🔗 Aller à l'utilisateur",
    "zh": "🔗 前往用户",
    "ar": "🔗 الانتقال إلى المستخدم",
}
l_find_bot_link = {
    "ru": "🔗 Перейти к приложению",
    "en": "🔗 Go to the app",
    "es": "🔗 Ir a la aplicación",
    "fr": "🔗 Accéder à l'application",
    "zh": "🔗 前往应用程序",
    "ar": "🔗 الانتقال إلى التطبيق",
}
l_find_category_blog = {
    "ru": "#блогер",
    "en": "#blogger",
    "es": "#bloguero",
    "fr": "#blogueur",
    "zh": "#博主",
    "ar": "#مدون",
}
l_find_category_digit = {
    "ru": "#оцифровка",
    "en": "#digitization",
    "es": "#digitalización",
    "fr": "#numérisation",
    "zh": "#数字化",
    "ar": "#الرقمنة",
}
l_find_category_smm = {
    "ru": "#смм",
    "en": "#smm",
    "es": "#smm",
    "fr": "#smm",
    "zh": "#社交媒体营销",
    "ar": "#سما",
}
l_find_category_recruit = {
    "ru": "#рекрут",
    "en": "#recruit",
    "es": "#reclutamiento",
    "fr": "#recrut",
    "zh": "#招聘",
    "ar": "#توظيف",
}
l_find_category_design = {
    "ru": "#дизайн",
    "en": "#design",
    "es": "#diseño",
    "fr": "#design",
    "zh": "#设计",
    "ar": "#تصميم",
}
l_find_category_coach = {
    "ru": "#коуч",
    "en": "#coach",
    "es": "#entrenador",
    "fr": "#coach",
    "zh": "#教练",
    "ar": "#مدرب",
}
l_find_category_it = {
    "ru": "#ИТ",
    "en": "#IT",
    "es": "#IT",
    "fr": "#IT",
    "zh": "#IT",
    "ar": "#تكنولوجيا المعلومات",
}
l_find_category_course = {
    "ru": "#курсы",
    "en": "#courses",
    "es": "#cursos",
    "fr": "#cours",
    "zh": "#课程",
    "ar": "#الدورات",
}
l_find_category_business = {
    "ru": "#бизнес",
    "en": "#business",
    "es": "#negocios",
    "fr": "#entreprise",
    "zh": "#商业",
    "ar": "#الأعمال",
}
l_find_category_goods = {
    "ru": "#товарка",
    "en": "#product",
    "es": "#producto",
    "fr": "#produit",
    "zh": "#商品",
    "ar": "#المنتج",
}
l_find_category_offline = {
    "ru": "#оффлайн",
    "en": "#offline",
    "es": "#offline",
    "fr": "#hors ligne",
    "zh": "#离线",
    "ar": "#أوفلاين",
}
l_find_category_lawyer = {
    "ru": "#юрист",
    "en": "#lawyer",
    "es": "#abogado",
    "fr": "#avocat",
    "zh": "#律师",
    "ar": "#محامي",
}
l_find_category_verified = {
    "ru": "#верифиц",
    "en": "#verify",
    "es": "#verificación",
    "fr": "#vérifié",
    "zh": "#验证",
    "ar": "#التحقق",
}
l_find_category_premium = {
    "ru": "#премиум",
    "en": "#premium",
    "es": "#premium",
    "fr": "#premium",
    "zh": "#优质",
    "ar": "#بريميوم",
}
l_find_category_health = {
    "ru": "#здоровье",
    "en": "#health",
    "es": "#salud",
    "fr": "#santé",
    "zh": "#健康",
    "ar": "#الصحة",
}
l_find_category_getting = {
    "ru": "🔎 Выгружаем <b>категорию</b> {0}..\n\n#длительность 0мин",
    "en": "🔎 Exporting <b>category</b> {0}..\n\n#duration 0min",
    "es": "🔎 Exportando <b>categoría</b> {0}..\n\n#duración 0min",
    "fr": "🔎 Nous exportons la <b>catégorie</b> {0}..\n\n#durée 0min",
    "zh": "🔎 正在导出 <b>类别</b> {0}..\n\n#持续时间 0分钟",
    "ar": "🔎 نقوم بتصدير <b>الفئة</b> {0}..\n\n#المدة 0دقيقة",
}
l_find_keyword_getting = {
    "ru": "🔎 Выгружаем базу по ключевым словам <i>{0}</i>..\n\n#длительность 1мин",
    "en": "🔎 Exporting the database by keywords <i>{0}</i>..\n\n#duration 1min",
    "es": "🔎 Exportamos la base por palabras clave <i>{0}</i>..\n\n#duración 1min",
    "fr": "🔎 Nous exportons la base par mots-clés <i>{0}</i>..\n\n#durée 1min",
    "zh": "🔎 正在导出关键字数据库 <i>{0}</i>..\n\n#持续时间 1分钟",
    "ar": "🔎 نقوم بتصدير قاعدة البيانات بناءً على الكلمات الرئيسية <i>{0}</i>..\n\n#المدة 1دقيقة",
}
l_find_category_keywords = {
    "ru": "📰 <b>Введи</b> ключевые слова для поиска через пробелы или разделители",
    "en": "📰 <b>Enter</b> keywords for search separated by spaces or delimiters",
    "es": "📰 <b>Introduce</b> palabras clave para buscar separadas por espacios o delimitadores",
    "fr": "📰 <b>Entrez</b> des mots-clés pour la recherche séparés par des espaces ou des délimiteurs",
    "zh": "📰 <b>输入</b> 关键字以通过空格或分隔符进行搜索",
    "ar": "📰 <b>أدخل</b> الكلمات الرئيسية للبحث باستخدام المسافات أو الفواصل",
}
l_find_reached = {
    "ru": "<b>Охват</b>: <u>{0}</u> польз.",
    "en": "<b>Reach</b>: <u>{0}</u> users.",
    "es": "<b>Alcance</b>: <u>{0}</u> usuarios.",
    "fr": "<b>Portée</b> : <u>{0}</u> utilisateurs.",
    "zh": "<b>覆盖范围</b>: <u>{0}</u> 用户。",
    "ar": "<b>الوصول</b>: <u>{0}</u> مستخدم.",
}
l_find_watch = {
    "ru": "🔎 Просмотр",
    "en": "🔎 View",
    "es": "🔎 Vista",
    "fr": "🔎 Vue",
    "zh": "🔎 查看",
    "ar": "🔎 عرض",
}
l_add_join_err = {
    "ru": "👩🏽‍💻 <b>Ошибка</b> (вставь корректную ссылку или повтори позже)",
    "en": "👩🏽‍💻 <b>Error</b> (insert a valid link or try again later)",
    "es": "👩🏽‍💻 <b>Error</b> (inserta un enlace correcto o intenta de nuevo más tarde)",
    "fr": "👩🏽‍💻 <b>Erreur</b> (insérez un lien correct ou réessayez plus tard)",
    "zh": "👩🏽‍💻 <b>错误</b>（插入正确的链接或稍后重试）",
    "ar": "👩🏽‍💻 <b>خطأ</b> (أدخل رابطًا صحيحًا أو حاول مرة أخرى لاحقًا)",
}
l_add_chn_fail = {
    "ru": "🚫 <b>Канал</b> {0} не добавлен в базу\n\n<blockquote>{1} аватар\n{2} описание\n{3} более {4} подписчиков\n{5} последний пост менее {6} дней назад\n{7} скам</blockquote>",
    "en": "🚫 <b>Channel</b> {0} not added to the database\n\n<blockquote>{1} avatar\n{2} description\n{3} more than {4} subscribers\n{5} last post less than {6} days ago\n{7} scam</blockquote>",
    "es": "🚫 <b>Canal</b> {0} no añadido a la base\n\n<blockquote>{1} avatar\n{2} descripción\n{3} más de {4} suscriptores\n{5} última publicación hace menos de {6} días\n{7} estafa</blockquote>",
    "fr": "🚫 <b>Canal</b> {0} non ajouté à la base\n\n<blockquote>{1} avatar\n{2} description\n{3} plus de {4} abonnés\n{5} dernier post il y a moins de {6} jours\n{7} arnaque</blockquote>",
    "zh": "🚫 <b>频道</b> {0} 未添加到数据库\n\n<blockquote>{1} 头像\n{2} 描述\n{3} 超过 {4} 个订阅者\n{5} 最近的帖子少于 {6} 天前\n{7} 诈骗</blockquote>",
    "ar": "🚫 <b>القناة</b> {0} لم تُضاف إلى القاعدة\n\n<blockquote>{1} الصورة الرمزية\n{2} الوصف\n{3} أكثر من {4} مشتركين\n{5} آخر منشور منذ أقل من {6} يومًا\n{7} احتيال</blockquote>",
}
l_add_grp_fail = {
    "ru": "🚫 <b>Группа</b> {0} не добавлена в базу\n\n<blockquote>{1} аватар\n{2} описание\n{3} более {4} участников\n{5} последний пост менее {6} дней назад\n{7} скам</blockquote>",
    "en": "🚫 <b>Group</b> {0} not added to the database\n\n<blockquote>{1} avatar\n{2} description\n{3} more than {4} members\n{5} last post less than {6} days ago\n{7} scam</blockquote>",
    "es": "🚫 <b>Grupo</b> {0} no añadido a la base\n\n<blockquote>{1} avatar\n{2} descripción\n{3} más de {4} participantes\n{5} última publicación hace menos de {6} días\n{7} estafa</blockquote>",
    "fr": "🚫 <b>Groupe</b> {0} non ajouté à la base\n\n<blockquote>{1} avatar\n{2} description\n{3} plus de {4} participants\n{5} dernier post il y a moins de {6} jours\n{7} arnaque</blockquote>",
    "zh": "🚫 <b>组</b> {0} 未添加到数据库\n\n<blockquote>{1} 头像\n{2} 描述\n{3} 超过 {4} 名参与者\n{5} 最后帖子在 {6} 天前\n{7} 诈骗</blockquote>",
    "ar": "🚫 <b>المجموعة</b> {0} لم تُضاف إلى القاعدة\n\n<blockquote>{1} الصورة الرمزية\n{2} الوصف\n{3} أكثر من {4} أعضاء\n{5} آخر منشور منذ أقل من {6} أيام\n{7} احتيال</blockquote>",
}
l_add_usr_fail = {
    "ru": "🚫 <b>Пользователь</b> {0} не добавлен в базу\n\n<blockquote>{1} аватар\n{2} @username\n{3} био\n{4} скам</blockquote>",
    "en": "🚫 <b>User</b> {0} not added to the database\n\n<blockquote>{1} avatar\n{2} @username\n{3} bio\n{4} scam</blockquote>",
    "es": "🚫 <b>Usuario</b> {0} no añadido a la base de datos\n\n<blockquote>{1} avatar\n{2} @username\n{3} bio\n{4} estafa</blockquote>",
    "fr": "🚫 <b>Utilisateur</b> {0} non ajouté à la base\n\n<blockquote>{1} avatar\n{2} @username\n{3} bio\n{4} arnaque</blockquote>",
    "zh": "🚫 <b>用户</b> {0} 未添加到数据库\n\n<blockquote>{1} 头像\n{2} @用户名\n{3} 简介\n{4} 诈骗</blockquote>",
    "ar": "🚫 <b>المستخدم</b> {0} لم يُضاف إلى القاعدة\n\n<blockquote>{1} الصورة الرمزية\n{2} @username\n{3} السيرة الذاتية\n{4} احتيال</blockquote>",
}
l_add_bot_fail = {
    "ru": "🚫 <b>Приложение</b> {0} не добавлено в базу\n\n<blockquote>{1} аватар\n{2} описание\n{3} скам</blockquote>",
    "en": "🚫 <b>Application</b> {0} not added to the database\n\n<blockquote>{1} avatar\n{2} description\n{3} scam</blockquote>",
    "es": "🚫 <b>Aplicación</b> {0} no añadida a la base\n\n<blockquote>{1} avatar\n{2} descripción\n{3} estafa</blockquote>",
    "fr": "🚫 <b>Application</b> {0} non ajouté à la base\n\n<blockquote>{1} avatar\n{2} description\n{3} arnaque</blockquote>",
    "zh": "🚫 <b>应用程序</b> {0} 未添加到数据库\n\n<blockquote>{1} 头像\n{2} 描述\n{3} 诈骗</blockquote>",
    "ar": "🚫 <b>التطبيق</b> {0} لم يُضاف إلى القاعدة\n\n<blockquote>{1} الصورة الرمزية\n{2} الوصف\n{3} احتيال</blockquote>",
}
l_add_chn_done = {
    "ru": "✅ <b>Канал</b> {0} - добавлен в базу и обновлен",
    "en": "✅ <b>Channel</b> {0} - added to the database and updated",
    "es": "✅ <b>Canal</b> {0} - añadido a la base y actualizado",
    "fr": "✅ <b>Canal</b> {0} - ajouté à la base et mis à jour",
    "zh": "✅ <b>频道</b> {0} - 已添加到数据库并更新",
    "ar": "✅ <b>القناة</b> {0} - تمت إضافتها إلى القاعدة وتم تحديثها",
}
l_add_grp_done = {
    "ru": "✅ <b>Группа</b> {0} - добавлена в базу и обновлена",
    "en": "✅ <b>Group</b> {0} - added to the database and updated",
    "es": "✅ <b>Grupo</b> {0} - añadido a la base de datos y actualizado",
    "fr": "✅ <b>Groupe</b> {0} - ajouté à la base et mis à jour",
    "zh": "✅ <b>组</b> {0} - 已添加到数据库并更新",
    "ar": "✅ <b>المجموعة</b> {0} - تمت إضافتها إلى القاعدة وتم تحديثها",
}
l_add_usr_done = {
    "ru": "✅ <b>Пользователь</b> {0} - добавлен в базу и обновлен",
    "en": "✅ <b>User</b> {0} - added to the database and updated",
    "es": "✅ <b>Usuario</b> {0} - añadido a la base y actualizado",
    "fr": "✅ <b>Utilisateur</b> {0} - ajouté à la base et mis à jour",
    "zh": "✅ <b>用户</b> {0} - 已添加到数据库并更新",
    "ar": "✅ <b>المستخدم</b> {0} - تمت إضافته إلى القاعدة وتم تحديثه",
}
l_add_bot_done = {
    "ru": "✅ <b>Приложение</b> {0} - добавлено в базу и обновлено",
    "en": "✅ <b>Application</b> {0} - added to the database and updated",
    "es": "✅ <b>Aplicación</b> {0} - añadida a la base y actualizada",
    "fr": "✅ <b>Application</b> {0} - ajouté à la base et mis à jour",
    "zh": "✅ <b>应用程序</b> {0} - 已添加到数据库并更新",
    "ar": "✅ <b>التطبيق</b> {0} - تمت إضافته إلى القاعدة وتم تحديثه",
}
l_find_chn_done = {
    "ru": "👩🏽‍💻 <b>Готово!</b> По {0} собрано <u>{1}</u> каналов, сегментированных по <i>ключевым</i> словам\n\n<blockquote><b>Охват</b>: <u>{2}</u> польз\n\nМожно связаться с администраторами каналов, чтобы заказать рекламу</blockquote>",
    "en": "👩🏽‍💻 <b>Done!</b> {0} has collected <u>{1}</u> channels, segmented by <i>keywords</i>\n\n<blockquote><b>Reach</b>: <u>{2}</u> users\n\nYou can contact the channel administrators to order advertising</blockquote>",
    "es": "👩🏽‍💻 <b>¡Listo!</b> Se han recopilado <u>{1}</u> canales segmentados por <i>palabras</i> clave en {0}\n\n<blockquote><b>Alcance</b>: <u>{2}</u> usuarios\n\nSe puede contactar a los administradores de los canales para solicitar publicidad</blockquote>",
    "fr": "👩🏽‍💻 <b>Prêt!</b> Sur {0}, <u>{1}</u> canaux ont été collectés, segmentés par <i>mots-clés</i>\n\n<blockquote><b>Portée</b>: <u>{2}</u> utilisateurs\n\nVous pouvez contacter les administrateurs des canaux pour commander de la publicité</blockquote>",
    "zh": "👩🏽‍💻 <b>完成！</b> 在 {0} 收集了 <u>{1}</u> 个按 <i>关键</i> 词细分的频道\n\n<blockquote><b>覆盖范围</b>: <u>{2}</u> 用户\n\n可以联系频道管理员以订购广告</blockquote>",
    "ar": "👩🏽‍💻 <b>جاهز!</b> تم جمع <u>{1}</u> قنوات حسب {0}، مقسمة حسب <i>الكلمات</i> الرئيسية\n\n<blockquote><b>الوصول</b>: <u>{2}</u> مستخدم\n\nيمكنك الاتصال بمديري القنوات لطلب الإعلان</blockquote>",
}
l_find_grp_done = {
    "ru": "👩🏽‍💻 <b>Готово!</b> По {0} собрано <u>{1}</u> чатов, сегментированных по <i>ключевым</i> словам\n\n<blockquote><b>Охват</b>: <u>{2}</u> польз\n\nМожно сделать <b>рассылку</b> по группам</blockquote>",
    "en": "👩🏽‍💻 <b>Done!</b> {0} has collected <u>{1}</u> chats, segmented by <i>keywords</i>\n\n<blockquote><b>Reach</b>: <u>{2}</u> users\n\nYou can make a <b>mailing</b> to groups</blockquote>",
    "es": "👩🏽‍💻 <b>¡Listo!</b> Se han recopilado <u>{1}</u> chats segmentados por <i>palabras</i> clave en {0}\n\n<blockquote><b>Alcance</b>: <u>{2}</u> usuarios\n\nSe puede hacer <b>envío</b> a grupos</blockquote>",
    "fr": "👩🏽‍💻 <b>Prêt!</b> Sur {0}, <u>{1}</u> chats ont été collectés, segmentés par <i>mots-clés</i>\n\n<blockquote><b>Portée</b>: <u>{2}</u> utilisateurs\n\nIl est possible de faire une <b>diffusion</b> par groupes</blockquote>",
    "zh": "👩🏽‍💻 <b>完成！</b> 在 {0} 收集了 <u>{1}</u> 个按 <i>关键</i> 词分段的聊天\n\n<blockquote><b>覆盖范围</b>: <u>{2}</u> 用户\n\n可以对群组进行 <b>发送</b></blockquote>",
    "ar": "👩🏽‍💻 <b>تم!</b> تم جمع <u>{1}</u> دردشات حسب <i>الكلمات</i> الرئيسية في {0}\n\n<blockquote><b>الوصول</b>: <u>{2}</u> مستخدمين\n\nيمكنك إجراء <b>إرسال</b> إلى المجموعات</blockquote>",
}
l_find_usr_done = {
    "ru": "👩🏽‍💻 <b>Готово!</b> По {0} собрано <u>{1}</u> пользователей, сегментированных по <i>ключевым</i> словам",
    "en": "👩🏽‍💻 <b>Done!</b> A total of {0} has gathered <u>{1}</u> users, segmented by <i>keywords</i>",
    "es": "👩🏽‍💻 <b>¡Listo!</b> Se han recopilado <u>{1}</u> usuarios en {0}, segmentados por <i>palabras clave</i>",
    "fr": "👩🏽‍💻 <b>Prêt!</b> Sur {0}, <u>{1}</u> utilisateurs ont été collectés, segmentés par <i>mots-clés</i>",
    "zh": "👩🏽‍💻 <b>完成！</b> 在 {0} 中收集了 <u>{1}</u> 名用户，按 <i>关键</i> 词进行细分",
    "ar": "👩🏽‍💻 <b>تم!</b> تم جمع <u>{1}</u> مستخدمين حسب {0} ، مقسمين حسب <i>الكلمات الرئيسية</i>",
}
l_find_bot_done = {
    "ru": "👩🏽‍💻 <b>Готово!</b> По {0} собрано <u>{1}</u> приложений, сегментированных по <i>ключевым</i> словам",
    "en": "👩🏽‍💻 <b>Done!</b> A total of {0} has collected <u>{1}</u> applications, segmented by <i>keywords</i>",
    "es": "👩🏽‍💻 <b>¡Listo!</b> Se han recopilado <u>{1}</u> aplicaciones en {0}, segmentadas por <i>palabras clave</i>",
    "fr": "👩🏽‍💻 <b>Prêt!</b> Pour {0}, <u>{1}</u> applications ont été collectées, segmentées par <i>mots-clés</i>",
    "zh": "👩🏽‍💻 <b>完成！</b> 在 {0} 收集了 <u>{1}</u> 个按 <i>关键</i> 词分类的应用程序",
    "ar": "👩🏽‍💻 <b>تم!</b> تم جمع <u>{1}</u> تطبيقات في {0}، مقسمة حسب <i>الكلمات</i> الرئيسية",
}
l_hashtag_categories = {
    "BLOG": [
        "блог", "влог", "блогер", "контентмейкер", "ютуб", "путешестви",
        "курс", "геткурс", "английск", "школ", "запуск", "заняти", "урок", "воркшоп",
        "языков", "онлайн-школ", "лингвист", "марафон", "практикум", "семинар",
        "вебинар", "лаборатор", "хакатон", "интенсив", "обучени", "колледж", "институт",
        "университет", "лекци", "мастермайнд", "симпозиум", "тренинг", "тимбилдинг", "мастерск", "образовани",
        "blog", "vlog", "blogger", "contentmak", "youtube", "travel",
        "course", "getcourse", "english", "school", "launch", "lesson", "workshop",
        "languag", "online-school", "linguist", "marathon", "practicum", "seminar",
        "webinar", "laborat", "hackathon", "intensiv", "educat", "college", "institut",
        "university", "lectur", "mastermind", "symposium", "train", "teambuild", "masterclass",
        "blogue", "vlogue", "blogueur", "créateurdecontenu", "voyag",
        "cours", "école", "lancement", "leçon", "atelier", "langue", "école-en-ligne",
        "linguiste", "pratic", "séminaire", "webinaire", "laboratoire",
        "éducation", "collège", "conférenc", "formation", "teambuilding", "maîtredeclasse",
        "تعليم", "مدرسة", "لغة", "دورة", "سفر", "يوتيوب", "ندوة", "محاضرة",
        "ورشة", "تعليمي", "هاكاثون", "مؤتمر", "فريق", "إطلاق",
        "bloguear", "vloguear", "bloguero", "creadordecontenidos", "viaj",
        "curso", "escuela", "lanzamiento", "lección", "taller", "idioma", "escuela-online",
        "lingüist", "maratón", "práctica", "seminario", "webinario", "laboratori",
        "hackatón", "educación", "colegio", "conferencia", "simposio", "entrenamiento", "clase",
        "博客", "视频博客", "内容创作者", "旅行", "课程", "英语", "学校", "网络学校",
        "语言", "马拉松", "实践", "研讨会", "在线研讨会", "实验室", "教育", "大学", "学院",
        "发布", "密集", "讲座", "专题研讨会", "培训", "团队建设", "大师课"
    ],
    "BUSINESS": [
        "бизнес", "инвест", "франш", "кредит", "торг", "консалт",
        "доход", "представит", "предпринимат", "коммерц", "фирм", "предприят", "компани", "промышл",
        "производст", "капитал", "корпорац", "агентств", "пассив",
        "дистриб", "акцио", "холдин", "прибыл", "рубл", "стартап",
        "business", "invest", "franchis", "credit", "trade", "consult",
        "income", "represent", "entrepreneu", "commerc", "firm", "enterpris", "compan", "industr",
        "product", "capital", "corporat", "agency", "passiv",
        "distrib", "sharehold", "holding", "profit", "rubl", "startup",
        "affaire", "investiss", "franchis", "crédit", "commerce", "consult",
        "revenu", "représent", "entrepren", "commercial", "entrepris", "compagn", "industr",
        "product", "capital", "corporat", "agenc", "passif",
        "distrib", "action", "holding", "bénéf", "rouble", "start-up",
        "أعمال", "استثمار", "فرانش", "ائتمان", "تجارة", "استشارة",
        "دخل", "ممثل", "ريادة", "تجاري", "شركة", "مؤسسة", "صناعة",
        "إنتاج", "رأس مال", "شركة", "وكالة", "سلبي", "توزيع",
        "مساهم", "ربح", "روبل", "شركة ناشئة",
        "negocio", "invers", "franquic", "crédit", "comerc", "consult",
        "ingres", "represent", "emprend", "comercial", "firm", "empresa", "industr",
        "product", "capital", "corporat", "agenc", "pasiv",
        "distrib", "accion", "holding", "benefic", "rublo", "startup",
        "商业", "投资", "特许经营", "信用", "贸易", "咨询",
        "收入", "代表", "企业家", "商业", "公司", "企业", "工业",
        "生产", "资本", "公司", "代理", "被动", "分销",
        "股东", "盈利", "卢布", "初创"
    ],
    "HEALTH": [
        "бьюти", "красота", "здоров", "нутрициол", "косметик", "косметол", "йога",
        "питани", "доктор", "диет", "похуден", "волос", "маникюр", "макияж", "клиник", "ресниц", "эпиляц",
        "парикмах", "медицин", "медик", "стоматол", "психо",
        "врач", "фитнес", "медиц", "лекарств", "спортив",
        "семья", "дети", "ребенок",
        "beauty", "health", "nutrition", "cosmetic", "cosmetolog", "yoga",
        "diet", "doctor", "slim", "hair", "manicur", "makeup", "clinic", "lash", "epilat",
        "hairdress", "medicin", "medic", "dentist", "psycho",
        "fitness", "drug", "sport", "family", "child", "kid",
        "beauté", "santé", "nutrition", "cosmét", "cosmétolog", "yoga",
        "régime", "docteur", "maigri", "cheveu", "manicure", "maquill", "clinique", "cil", "épilat",
        "coiffeur", "médecin", "dentist", "psycho",
        "forme", "médicament", "sportif", "famille", "enfant",
        "صحة", "جمال", "تغذية", "تجميل", "يوغا", "حمية", "طبيب",
        "تنحيف", "شعر", "أظافر", "ماكياج", "عيادة", "رموش", "إزالة الشعر",
        "حلاق", "طب", "طبيب أسنان", "نفسية", "رياضة", "أسرة", "طفل",
        "salud", "bellez", "nutrición", "cosmétic", "yoga",
        "dieta", "doctor", "adelgaz", "cabello", "manicura", "maquill", "clínic", "pestaña", "depilat",
        "peluquer", "medicin", "dentista", "psicol", "deport", "famil", "niño",
        "健康", "美容", "营养", "化妆品", "瑜伽", "饮食", "医生", "减肥",
        "头发", "美甲", "化妆", "诊所", "睫毛", "脱毛", "理发", "医学",
        "药物", "牙医", "心理", "健身", "运动", "家庭", "孩子"
    ],
    "NEURO": [
      "нейросет", "нейрон", "нейросеть", "нейро", "искусствен", "искусственныйинтеллект", "искусственный интеллект",
      "чатгпт", "чат-gpt", "чат gpt", "gpt", "llm", "модельязыка", "генеративн", "генеративный",
      "машинн", "машинноеобучен", "машинное обучение", "глубок", "глубокоеобучен", "deeplearn", "deep learn",
      "deep learning", "machinelearn", "machine learning", "transformer", "нейроинженер", "инференц",
      "diffus", "diffusion", "stable diffusion", "dall", "dalle", "midjourney", "imagen", "gan",
      "ai", "artificialintellig", "artificial intelligence", "neural", "neuralnet", "neural network", "large language",
      "chatgpt", "generative ai", "generative", "model", "inference", "prompt", "prompting", "fine-tun",
      "人工智能", "AI", "神经网", "神经网络", "神经", "生成式", "生成 模型", "大模型", "大语言模型", "聊天gpt",
      "chatgpt", "机器学", "机器学习", "深度学", "深度学习", "图像生成", "文生图",
      "ذكاء اصطناعي", "AI", "تعلم الآلة", "شبكة عصبية", "عصب", "نماذج كبيرة", "تشات جي بي تي", "شات جي بي تي",
      "تعلّم عميق", "توليد", "مولد", "نموذج لغوي", "LLM", "برمجة الذكاء", "تحفيز",
      "inteligenciaartificial", "inteligenc", "ia", "aprendizaje", "aprendizaje automático", "machinelearning",
      "red neuronal", "neural", "chatgpt", "gpt", "modelo de lenguaje", "modelo grande", "generativo", "difusión",
      "aprendizaje profundo",
      "intelligenceartificielle", "ia", "intellig", "apprentissage", "apprentissage automatique", "réseauneur",
      "réseauneuronal", "réseauneurones", "réseauréel", "chatgpt", "gpt", "modèledelangage", "LLM", "transformer",
      "génératif", "diffusion", "apprentissage profond"
    ],
    "SMM": [
        "смм", "инст", "фейсбук", "тикток", "тик-ток", "ютуб", "маркето",
        "маркет", "таргет", "распаковка", "продвижение", "сео", "бренд", "агентство",
        "лиды", "вконтакте", "лидов", "реклам", "таплинк", "прогрев", "блог", "визуал", "запуск",
        "трафик", "мвп", "редакция", "директ",
        "smm", "insta", "facebook", "tiktok", "youtube", "marketo",
        "market", "target", "unboxing", "promotion", "seo", "brand", "agency",
        "leads", "vk", "lead", "adver", "taplink", "warmup", "blog", "visual", "launch",
        "traffic", "mvp", "edit", "direct",
        "smm", "insta", "facebook", "tiktok", "youtube", "marché",
        "ciblage", "déballage", "promotion", "seo", "marque", "agence",
        "pistes", "vk", "annonce", "taplink", "réchauff", "blog", "visuel", "lancement",
        "trafic", "mvp", "rédaction", "direct",
        "تسويق", "انستغرام", "فيسبوك", "تيك توك", "يوتيوب", "سوق", "استهداف",
        "تفريغ", "ترويج", "سيو", "علامة تجارية", "وكالة", "عملاء متوقعون", "vk",
        "إعلانات", "تاپلينك", "إحماء", "مدونة", "مرئي", "إطلاق", "حركة مرور", "mvp",
        "تحرير", "مباشر",
        "smm", "insta", "facebook", "tiktok", "youtube", "mercado",
        "objetivo", "desempaquet", "promoción", "seo", "marca", "agencia",
        "clientes", "vk", "anuncio", "taplink", "calentam", "blog", "visual", "lanzamiento",
        "tráfico", "mvp", "edición", "directo",
        "社交媒体", "微博", "脸书", "抖音", "油管", "市场", "目标",
        "开箱", "推广", "搜索引擎优化", "品牌", "代理", "潜在客户", "vk",
        "广告", "taplink", "预热", "博客", "视觉", "发布", "流量", "mvp",
        "编辑", "直达"
    ],
    "GOODS": [
        "вайлд", "ozon", "озон", "авито", "авторск", "одежд", "китай",
        "китая", "складчина", "подарк", "модн", "маркетплейс", "вещи",
        "одежда", "обувь", "товар",
        "wild", "ozon", "avito", "author", "cloth", "china",
        "gift", "fashion", "marketplac", "thing", "shoe", "product", "item",
        "sauvage", "ozon", "avito", "auteur", "vêtement", "chine",
        "cadeau", "mode", "place de marché", "objet", "chaussure", "produit",
        "بضاعة", "أوزون", "أفيتو", "مؤلف", "ملابس", "صين", "هدية", "موضة",
        "سوق", "أشياء", "أحذية", "منتجات", "سلع",
        "mercancías", "ozon", "avito", "autor", "ropa", "china",
        "regalo", "moda", "mercado", "cosas", "zapatos", "producto",
        "商品", "野生", "ozon", "avito", "作者", "衣服", "中国",
        "礼物", "时尚", "市场", "物品", "鞋", "产品"
    ],
    "EDUCATION": [
        "коуч", "консульт", "продюсер", "бизнес", "наставн", "оратор", "энерг", "эксперт", "психо",
        "трекер", "гайд",
        "практик", "бренд", "тайм", "мотива", "логопед", "мышлен", "нумеролог", "таролог", "йог",
        "ментор", "тренер", "гештальт", "предприним", "метафори", "денеж", "диагност",
        "coach", "consult", "producer", "business", "mentor", "speaker", "energ", "expert", "psycho",
        "tracker", "guide",
        "practic", "brand", "time", "motivat", "speech", "think", "numerolog", "tarot", "yoga",
        "mentor", "trainer", "gestalt", "entrepreneu", "metaphor", "money", "diagnost",
        "coach", "conseil", "producteur", "business", "mentor", "orateur", "énergie", "expert", "psycho",
        "suivi", "guide",
        "pratiqu", "marque", "temps", "motivat", "orthophon", "pensé", "numérolog", "tarot", "yoga",
        "formateur", "gestalt", "entrepren", "métaphore", "argent", "diagnost",
        "مدرب", "مستشار", "منتج", "عمل", "مرشد", "متحدث", "طاقة", "خبير", "نفسي",
        "متعقب", "دليل", "ممارس", "علامة", "وقت", "تحفيز", "أخصائي نطق", "تفكير", "علم الأعداد",
        "تاروت", "يوغا", "مرشد", "مدرب", "جشتالت", "ريادة", "استعارة", "مال", "تشخيص",
        "educación", "coach", "consult", "productor", "negocio", "mentor", "orador", "energ", "experto", "psico",
        "rastreador", "guía", "práctic", "marca", "tiempo", "motivac", "logopeda", "pensam", "numerolog", "tarot",
        "yoga", "mentor", "entrenador", "gestalt", "emprend", "metáfora", "dinero", "diagnóstic",
        "教育", "教练", "顾问", "制作人", "商业", "导师", "演讲者", "能量", "专家", "心理",
        "追踪器", "指南", "实践", "品牌", "时间", "激励", "语言治疗", "思维", "数字学", "塔罗",
        "瑜伽", "指导", "教练", "格式塔", "创业", "隐喻", "金钱", "诊断"
    ],
    "RECRUIT": [
        "рекрут", "роп", "работа", "фрила", "найм", "эйчар", "пиар", "персонал", "менеджер",
        "продаж", "ассист", "риелтор", "млм", "управлен", "наем", "сотрудн", "делегир", "карьер",
        "recruit", "rop", "job", "freelanc", "hire", "hr", "pr", "staff", "manager",
        "sales", "assist", "realtor", "mlm", "manag", "employ", "collabor", "delegat", "career",
        "recrut", "rop", "travail", "freelanc", "embauch", "rh", "pr", "personnel", "manager",
        "vente", "assist", "agent immobilier", "mlm", "gestion", "employé", "délég", "carrièr",
        "توظيف", "روپ", "عمل", "عمل حر", "تعيين", "موارد بشرية", "علاقات عامة", "طاقم", "مدير",
        "مبيعات", "مساعد", "سمسار", "تسويق شبكي", "إدارة", "موظف", "تفويض", "مسار وظيفي",
        "reclut", "rop", "trabajo", "freelanc", "contrat", "rh", "pr", "personal", "gerente",
        "ventas", "asist", "realtor", "mlm", "gestión", "emple", "colabor", "deleg", "carrer",
        "招聘", "工作", "自由职业", "雇用", "人力资源", "公关", "员工", "经理",
        "销售", "助理", "房地产", "传销", "管理", "雇员", "委托", "职业"
    ],
    "FINANCE": [
        "оцифров", "фин.", "финан", "бух", "инвест", "франш", "трейд", "бирж", "кредит", "учет",
        "банк", "торг", "кассы", "денежн", "консалт", "выручка", "доход", "прибыль",
        "digit", "fin.", "financ", "accoun", "invest", "franchis", "trade", "exchang", "credit", "account",
        "bank", "commerc", "cash", "money", "consult", "revenue", "income", "profit",
        "numéris", "fin.", "financ", "comptab", "invest", "franchis", "échange", "crédit", "compt",
        "banque", "commerce", "caisse", "monétaire", "conseil", "revenu", "bénéfice", "profit",
        "تمويل", "مال.", "مالية", "محاسب", "استثمار", "فرانشايز", "تجارة", "بورصة", "ائتمان", "حساب",
        "بنك", "تداول", "نقد", "أموال", "استشارة", "إيرادات", "دخل", "أرباح",
        "finanzas", "digit", "fin.", "financ", "contabilid", "invers", "franquicia", "comerc", "bolsa", "crédit",
        "banco", "comerci", "caja", "dinero", "consult", "ingres", "benefici", "gananci",
        "财务", "数字化", "金融", "会计", "投资", "特许经营", "交易", "交易所", "信贷", "账目",
        "银行", "贸易", "现金", "金钱", "咨询", "收入", "收益", "利润"
    ],
    "OFFLINE": [
        "салон", "студи", "логист", "грузопер", "свечи", "букеты", "клиник",
        "магазин", "производств", "эпиляц", "парикмах", "кондитер",
        "пищев", "кулинар", "оффлайн", "адрес", "храм", "церковь", "транспорт",
        "недвижимость", "стоматол",
        "salon", "studio", "logist", "freight", "candl", "bouquet", "clinic",
        "store", "product", "epilat", "hairdress", "confection",
        "food", "culinar", "offline", "address", "temple", "church", "transport",
        "realest", "dentist",
        "salon", "studio", "logistiqu", "fret", "bougi", "bouquet", "clinique",
        "magasin", "production", "épilation", "coiffur", "pâtisseri",
        "alimentair", "culinair", "hors ligne", "adress", "temple", "église", "transpor",
        "immobili", "dentair",
        "صالون", "استوديو", "لوجستيات", "نقل بضائع", "شموع", "باقة", "عيادة",
        "متجر", "إنتاج", "إزالة الشعر", "حلاق", "حلواني",
        "غذائي", "طبخ", "غير متصل", "عنوان", "معبد", "كنيسة", "نقل",
        "عقارات", "طبيب أسنان",
        "salón", "estudio", "logístic", "transporte de carga", "vela", "ramo", "clínica",
        "tienda", "producción", "depilación", "peluquer", "pasteler",
        "alimentar", "culinar", "desconectado", "dirección", "templo", "iglesia", "transporte",
        "inmobiliari", "dentist",
        "沙龙", "工作室", "物流", "货运", "蜡烛", "花束", "诊所",
        "商店", "生产", "脱毛", "理发师", "糕点师",
        "食品", "烹饪", "离线", "地址", "寺庙", "教堂", "运输",
        "房地产", "牙医"
    ],
    "ART": [
        "дизайн", "интерьер", "декор", "мебел", "3д", "архитект", "двери", "ремонт", "строител",
        "фасад", "тексти", "рису", "креатив", "визуал", "ландшафт", "художн", "картин",
        "имидж", "камин", "монтаж", "граф", "искусств", "рукодел",
        "design", "interior", "decor", "furnitur", "3d", "architect", "door", "repair", "builder",
        "facad", "text", "draw", "creativ", "visual", "landscap", "art", "paint",
        "image", "fireplac", "mount", "graph", "art", "handcraft",
        "design", "intérieur", "décor", "meubl", "3d", "architect", "porte", "réparation", "constructeur",
        "façad", "texte", "dessin", "créatif", "visuel", "paysag", "art", "peintur",
        "image", "cheminée", "montage", "graph", "art", "artisanat",
        "تصميم", "ديكور", "أثاث", "ثلاثي الأبعاد", "معمار", "باب", "إصلاح", "بناء",
        "واجهة", "نص", "رسم", "إبداعي", "بصري", "مناظر طبيعية", "فن", "لوحة",
        "صورة", "مدفأة", "تركيب", "رسوم بيانية", "فن", "حرف يدوي",
        "diseño", "interior", "decoración", "mueble", "3d", "arquitecto", "puerta", "reparación", "constructor",
        "fachada", "texto", "dibujo", "creatividad", "visual", "paisaj", "arte", "pintura",
        "imagen", "chimenea", "montaje", "gráfico", "arte", "artesanía",
        "设计", "室内", "装饰", "家具", "3d", "建筑", "门", "修理", "建筑工",
        "立面", "文本", "画", "创意", "视觉", "景观", "艺术", "画作",
        "形象", "壁炉", "安装", "图形", "艺术", "手工艺"
    ],
    "TECHNOLOGY": [
        "лендинг", "блокчейн", "срм", "программирова", "тильда", "битрикс", "автоматизаци", "автоворон",
        "разработч", "нфт", "смарт-контракт", "кодинг", "стартап",
        "java", "kotlin", "swift", "flutter", "c++", "c#", "unity", "angular",
        "amocrm", "powerbi", "frontend", "backend", "python", "ux/ui",
        "landing", "blockchain", "crm", "programming", "tilda", "bitrix", "automation", "autoresp",
        "developer", "nft", "smart-contract", "coding", "startup",
        "الصفحة المقصودة", "بلوك تشين", "إدارة علاقات العملاء", "برمجة", "تيلدا", "بيتركس", "أتمتة", "مسار تلقائي",
        "مطور", "NFT", "عقد ذكي", "ترميز", "شركة ناشئة",
        "جافا", "كوتلن", "سويفت", "فلاتر", "C++", "C#", "يونيتي", "أنغولار",
        "着陆页", "区块链", "客户关系管理", "编程", "Tilda", "Bitrix", "自动化", "自动漏斗",
        "开发者", "NFT", "智能合约", "编码", "初创企业",
    ],
    "WEB3": [
      "блокч", "блокчейн", "смарт", "смартконтракт", "смарт-контракт", "биткоин", "btc", "эфир", "эфириум", "ethereum", "ton", "тон", "toncoin",
      "дефи", "defi", "gamefi", "socialfi", "nft", "нфт", "ft", "фт", "токен", "токены", "token", "tokens",
      "ванити", "vanity", "vanityaddress", "ванитиадрес", "адресванити", "vantity", "vantity address",
      "tact", "func", "fift", "tolk", "tact-lang", "func-lang",
      "роялти", "royalty", "royalties", "tv l", "tvl", "тоталлокд", "total value locked", "распределённ", "распределённаяликвидност",
      "ликвидн", "ликвидность", "кошел", "кошелёк", "wallet", "транзакц", "транзакция", "tx", "txs",
      "телеграмподар", "telegramgift", "telegramgifts", "подаркителеграм", "nftusername", "nft username",
      "nftтелефон", "nft номера", "nft номера телефонов", "nftпост", "nftпосты", "nftдиалог", "nftдиалоги",
      "nft коллекц", "nft коллекция", "sbt", "soulbound", "soulboundtoken", "минтлесс", "mintless", "минт", "минтинг",
      "смартассет", "onchain", "offchain", "multisig", "seed", "mnemonic", "custodi", "noncustodial", "dex", "dexpool",
      "тонкеепер", "tonkeeper", "ton dns", "ton dns", "tvm", "blockexplorer", "scan", "bridge", "wrapped", "wrapping",

      "blockchain", "block", "smart", "smartcontract", "smart-contract", "bitcoin", "btc", "ethereum", "eth", "ton", "toncoin",
      "defi", "decentralized finance", "gamefi", "socialfi", "nft", "ft", "token", "tokens", "vanity", "vanity address",
      "tact", "func", "fift", "tolk", "tact/func/fift/tolk",
      "royalty", "royalties", "tvl", "total value locked", "distributed liquidity", "liquidity", "wallet", "transaction", "tx",
      "telegram gift", "telegramgifts", "nft username", "nft phone", "nft phone number", "nft posts", "nft dialogues",
      "nft collections", "sbt", "soulbound", "mintless", "mintless minting", "on-chain", "off-chain", "multisig", "seedphrase",
      "mnemonic", "non-custodial", "custodial", "dex", "amm", "bridge", "wrapped", "tonkeeper", "ton dns", "explorer",

      "区块链", "区块", "智能合约", "智能合", "比特币", "btc", "以太坊", "以太", "eth", "TON", "TON币", "ton",
      "去中心化金", "DeFi", "GameFi", "SocialFi", "NFT", "FT", "代币", "token", "代币",
      "范式地址", "虚荣地址", "vanity", "vanity地址",
      "tact", "func", "fift", "tolk", "tact/func/fift/tolk",
      "版税", "版税收益", "royalty", "TVL", "总锁仓价值", "分布式流动性", "流动性", "钱包", "交易", "tx",
      "电报礼物", "Telegram礼物", "NFT用户名", "NFT手机号", "NFT帖子", "NFT对话", "NFT合集", "SBT", "灵魂绑定",
      "免铸造", "mintless", "链上", "链下", "多签", "助记词", "种子短语", "桥", "浏览器", "Tonkeeper",

      "بلوكتشين", "بلوك", "عقود ذكية", "عقد ذكي", "بتكوين", "btc", "إيثريوم", "eth", "تون", "TON", "toncoin",
      "دي فاي", "DeFi", "GameFi", "SocialFi", "NFT", "FT", "توكن", "توكنات", "token",
      "عناوين فانيتي", "vanity address", "vanity",
      "tact", "func", "fift", "tolk", "tact/func/fift/tolk",
      "رويالتي", "عوائد الملكية", "TVL", "القيمة الإجمالية المغلقة", "السيولة الموزعة", "سيولة", "محفظة", "معاملة", "tx",
      "هدايا تليجرام", "هدية تليجرام", "nft اسم مستخدم", "nft رقم هاتف", "nft منشورات", "nft حوارات", "مجموعات nft",
      "SBT", "توكن مربوط بالروح", "mintless", "بدون مينت", "سلسلة", "خارج السلسلة", "محفظة متعددة توقيع",

      "blockchain", "bloque", "contrato inteligente", "smartcontract", "bitcoin", "btc", "ethereum", "eth", "ton", "toncoin",
      "defi", "decentralized finance", "gamefi", "socialfi", "nft", "ft", "token", "tokens",
      "dirección vanity", "vanity", "vanity address",
      "tact", "func", "fift", "tolk", "tact/func/fift/tolk",
      "royalties", "regalías", "tvl", "valor total bloqueado", "liquidez distribuida", "liquidez", "cartera", "wallet",
      "transacción", "tx", "regalos telegram", "nft username", "nft teléfono", "nft posts", "nft diálogos", "colecciones nft",
      "sbt", "soulbound", "mintless", "sin mint", "onchain", "offchain", "multisig", "seed", "mnemonic", "bridge",

      "blockchain", "bloc", "contrat intelligent", "smartcontract", "bitcoin", "btc", "ethereum", "eth", "ton", "toncoin",
      "defi", "finance décentralisée", "gamefi", "socialfi", "nft", "ft", "jeton", "token",
      "adresse vanity", "vanity", "vanity address",
      "tact", "func", "fift", "tolk", "tact/func/fift/tolk",
      "redevances", "royalties", "TVL", "valeur totale verrouillée", "liquidité distribuée", "liquidité", "portefeuille", "wallet",
      "transaction", "tx", "cadeaux telegram", "nft username", "nft téléphone", "nft posts", "nft dialogues", "collections nft",
      "sbt", "soulbound", "mintless", "sans mint", "on-chain", "off-chain", "multisig", "mnemonic"
    ],
    "GAME": [
        "игр", "игра", "игры", "геймер", "геймин", "игров", "стрим", "стример", "стриминг",
        "консол", "пк", "мобил", "мобайл", "телефон", "плейстейш", "пс", "xbox", "ниндзя", "nintendo",
        "шутер", "fps", "рпг", "rpg", "ммо", "mmo", "моба", "moba", "инди", "казуал", "аркад",
        "платформ", "квест", "загадк", "стратег", "тактик", "кооп", "pvp", "ранк", "турнир", "киберспорт",
        "донат", "донатит", "микротранзакц", "внутриигр", "скин", "лот", "loot", "гайд", "проход", "speedrun",
        "мод", "моды", "сервер", "мап", "маяч", "matchmak", "leaderboard", "ачив", "achievement",

        "game", "games", "gamer", "gaming", "stream", "streamer", "twitch", "steam", "ps", "playstation",
        "xbox", "nintendo", "pc", "mobile", "console", "shooter", "fps", "rpg", "mmo", "moba",
        "indie", "casual", "arcade", "platformer", "puzzle", "quest", "strategy", "tactical",
        "coop", "pvp", "rank", "tournament", "esport", "esports", "donate", "microtrans", "in-game",
        "skin", "loot", "mod", "server", "map", "matchmaking", "leaderboard", "walkthrough", "guide",

        "游戏", "游玩", "玩家", "手游", "端游", "主机", "单机", "网游", "多人", "独立", "独立游", "射击",
        "角色", "扮演", "策略", "解谜", "关卡", "任务", "皮肤", "掉落", "Loot", "模组", "mod", "服务器",
        "联机", "匹配", "速通", "直播", "主播", "腾讯", "网易", "任天堂",

        "لعب", "لعبة", "ألعاب", "لاعب", "لاعبين", "بلايستيشن", "اكس_بوكس", "نينتندو", "محمول", "هاتف",
        "كمبيوتر", "كونسول", "متعدد", "شوتر", "تصويب", "تقمص", "استراتيجي", "ألغاز", "مهمة", "مستوى",
        "سكين", "غنيمة", "loot", "مود", "خادم", "توصيل_مباراة", "بث", "ستريمر", "بطولة", "رياضات_إلكترونية",

        "jueg", "juego", "juegos", "jugador", "gaming", "stream", "streamer", "twitch", "steam",
        "consola", "ps", "xbox", "nintendo", "pc", "móvil", "movil", "shooter", "disparos", "rpg",
        "mmo", "moba", "indie", "casual", "arcade", "plataforma", "puzzle", "misión", "nivel", "skin",
        "botín", "loot", "mod", "servidor", "mapa", "matchmaking", "torneo", "esports", "guía",

        "jeu", "jeux", "joueur", "joueuse", "gaming", "stream", "streamer", "twitch", "steam",
        "console", "ps", "playstation", "xbox", "nintendo", "pc", "mobile", "shooter", "fps", "rpg",
        "mmo", "moba", "indé", "indie", "casual", "arcade", "plateforme", "puzzle", "quête", "niveau",
        "skin", "loot", "mod", "serveur", "carte", "matchmaking", "tournoi", "esport", "guide"
    ],
    "UTILITIES": [
        "утилит", "утилита", "сервис", "сервис", "инструм", "инструмент", "обслуживан", "поддержк",
        "мессендж", "почт", "почта", "скрипт", "скрипты", "плагин", "плагин", "модуль", "апи", "api", "sdk",
        "драйвер", "драйв", "бэкап", "резерв", "архив", "хранилищ", "облачн", "cloud", "хостинг", "хост",
        "сетев", "сетевы", "безопасн", "антивирус", "фаервол", "файрвол", "vpn", "прокси", "proxy",
        "аутентиф", "аутентикац", "auth", "логин", "регистрац", "парол", "шифрован", "шифр", "encrypt",
        "encrypt", "шифровани", "compress", "сжат", "архивир", "конверт", "converter", "convertidor",
        "монитор", "мониторинг", "uptime", "метрик", "телеметр", "scheduler", "cron", "демон", "daemon",
        "cli", "gui", "hook", "webhook", "интеграц", "middleware", "автоматиз", "automation", "devops",
        "подключени", "connector", "sync", "синхр", "репликац", "replic", "backup-tool", "restore",
        "support", "техподдержк", "поддержка", "управлен", "админ", "администр", "manage", "управл",
        "service-mesh", "observab", "логг", "логирование", "log", "storage", "файлов", "файловая",
        "почтов", "email", "mail", "smtp", "imap", "pop3", "ftp", "sftp", "ssh", "proxy", "gateway",

        "utilit", "utility", "utilities", "service", "services", "tool", "tools", "cloud", "storage",
        "backup", "archive", "encrypt", "encryption", "security", "antivirus", "firewall", "email",
        "script", "plugin", "extension", "driver", "converter", "compress", "network", "proxy", "vpn",
        "auth", "authenticate", "login", "api", "sdk", "support", "maintenance", "monitor", "monitoring",
        "scheduler", "cron", "daemon", "cli", "gui", "webhook", "integration", "automation", "devops",

        "实用", "工具", "服务", "云", "存储", "备份", "加密", "安全", "防火墙", "杀毒", "邮箱", "邮件",
        "脚本", "插件", "驱动", "转换", "压缩", "网络", "代理", "认证", "登录", "接口", "api", "sdk",
        "监控", "维护", "自动化", "集成", "同步", "还原",

        "أداه", "أدوات", "خدم", "خدمة", "خدمات", "سحابي", "تخزين", "نسخ", "نسخاحتياطي", "أمان", "تشفير",
        "جدارناري", "جدار_ناري", "مكافح_فيروسات", "بريد", "بريد_إلكتروني", "سكريبت", "ملحق", "سائق",
        "محول", "ضغط", "شبكة", "وكيل", "vpn", "توثيق", "تسجيل", "api", "sdk", "دعم", "صيانة", "مراقب",

        "utilit", "utilidad", "utilidades", "servic", "servicio", "servicios", "herramient", "herramienta",
        "nube", "almacen", "copia", "respaldo", "segurid", "cifrad", "antivirus", "firewall", "correo",
        "email", "script", "plugin", "driver", "convertidor", "comprimir", "red", "proxy", "vpn", "auth",
        "login", "api", "sdk", "soporte", "mantenimiento", "monitor", "automatiz",

        "outil", "outils", "service", "services", "utilit", "cloud", "stockag", "sauvegard", "backup",
        "sécur", "chiffr", "antivirus", "pare-feu", "mail", "courriel", "script", "plugin", "pilote",
        "convertiss", "compresse", "réseau", "proxy", "vpn", "authent", "connexion", "api", "sdk",
        "support", "maintenance", "monitor", "automatis", "intégration"
    ]
}
l_hashtag_translate = {
    "BLOG": {
        'ru': "#блогер",
        'en': "#blogger",
        'es': "#blogger",
        'fr': "#blogueur",
        'zh': "#博客作者",
        'ar': "#مدون",
    },
    "DIGIT": {
        'ru': "#оцифровка",
        'en': "#digit",
        'es': "#digitalización",
        'fr': "#numérisation",
        'zh': "#数字化",
        'ar': "#الرقمنة",
    },
    "SMM": {
        'ru': "#смм",
        'en': "#smm",
        'es': "#blogger",
        'fr': "#blogger",
        'zh': "#blogger",
        'ar': "#سم",
    },
    "RECRUIT": {
        'ru': "#рекрут",
        'en': "#recruit",
        'es': "#recluta",
        'fr': "#recruter",
        'zh': "#招聘人员",
        'ar': "#تجنيد",
    },
    "DESIGN": {
        'ru': "#дизайн",
        'en': "#design",
        'es': "#diseño",
        'fr': "#conception",
        'zh': "#设计",
        'ar': "#التصميم",
    },
    "COACH": {
        'ru': "#коуч",
        'en': "#coach",
        'es': "#entrenador",
        'fr': "#entraîneur",
        'zh': "#教练",
        'ar': "#مدرب",
    },
    "IT": {
        'ru': "#ИТ",
        'en': "#IT",
        'es': "#IT",
        'fr': "#IT",
        'zh': "#信息技术",
        'ar': "#تقانةالمعلومات",
    },
    "BUSINESS": {
        'ru': "#бизнес",
        'en': "#business",
        'es': "#negocios",
        'fr': "#affaires",
        'zh': "#业务",
        'ar': "#الأعمال",
    },
    "GOODS": {
        'ru': "#товарка",
        'en': "#products",
        'es': "#mercancía",
        'fr': "#articles",
        'zh': "#产品中心",
        'ar': "#المنتجات",
    },
    "OFFLINE": {
        'ru': "#оффлайн",
        'en': "#offline",
        'es': "#fueradelínea",
        'fr': "#horsligne",
        'zh': "#离线状态",
        'ar': "#غيرمتصل",
    },
    "HEALTH": {
        'ru': "#здоровье",
        'en': "#health",
        'es': "#blogger",
        'fr': "#blogger",
        'zh': "#blogger",
        'ar': "#blogger",
    },
    "ISVERIFIED": {
        'ru': "#верифиц",
        'en': "#verified",
        'es': "#verificado",
        'fr': "#vérifié",
        'zh': "#已核实",
        'ar': "#التحقق",
    },
    "ISPREMIUM": {
        'ru': "#премиум",
        'en': "#premium",
        'es': "#prima",
        'fr': "#prime",
        'zh': "#保费",
        'ar': "#قسط",
    },
}

l_find_alert = {
    "ru": "👩🏽‍💻 <b>Жми</b> на ✅/☑️, чтобы вкл/выкл <i>уведомления</i> о появлении отслеживаемых слов в публичных группах/каналах\n\n<blockquote>🔔 <b>Отслеживаемые</b> слова: <code>{0}</code>\n🔔 <b>Отслеживаемые</b> группы/каналы: <code>{1}</code></blockquote>",
    "en": "👩🏽‍💻 <b>Click</b> on ✅/☑️ to turn on/off <i>notifications</i> for tracked words in public groups/channels\n\n<blockquote>🔔 <b>Tracked</b> words: <code>{0}</code>\n🔔 <b>Tracked</b> groups/channels: <code>{1}</code></blockquote>",
    "es": "👩🏽‍💻 <b>Haz clic</b> en ✅/☑️ para activar/desactivar <i>notificaciones</i> sobre la aparición de palabras rastreadas en grupos/canales públicos\n\n<blockquote>🔔 <b>Palabras</b> rastreadas: <code>{0}</code>\n🔔 <b>Grupos/canales</b> rastreados: <code>{1}</code></blockquote>",
    "fr": "👩🏽‍💻 <b>Clique</b> sur ✅/☑️ pour activer/désactiver <i>les notifications</i> concernant l'apparition de mots suivis dans des groupes/canaux publics\n\n<blockquote>🔔 <b>Mots</b> suivis : <code>{0}</code>\n🔔 <b>Groupes</b>/canaux suivis : <code>{1}</code></blockquote>",
    "zh": "👩🏽‍💻 <b>点击</b> ✅/☑️ 来开启/关闭 <i>通知</i> 关于在公共群组/频道中出现的跟踪词\n\n<blockquote>🔔 <b>跟踪</b> 词: <code>{0}</code>\n🔔 <b>跟踪</b> 群组/频道: <code>{1}</code></blockquote>",
    "ar": "👩🏽‍💻 <b>اضغط</b> على ✅/☑️ لتفعيل/إلغاء <i>الإشعارات</i> حول ظهور الكلمات المتعقبة في المجموعات/القنوات العامة\n\n<blockquote>🔔 <b>الكلمات</b> المتعقبة: <code>{0}</code>\n🔔 <b>المجموعات/القنوات</b> المتعقبة: <code>{1}</code></blockquote>",
}
l_find_alert_alert = {
    "ru": "🔔 Нет отслеживаемых слов/групп/каналов\nЖми ⚙️Настроить",
    "en": "🔔 No tracked words/groups/channels  \nClick ⚙️Settings",
    "es": "🔔 No hay palabras/grupos/canales rastreados  \nHaz clic en ⚙️Configurar",
    "fr": "🔔 Aucun mot/groupe/canal suivi  \nClique sur ⚙️Configurer",
    "zh": "🔔 没有跟踪的词/组/频道  \n点击 ⚙️设置",
    "ar": "🔔 لا توجد كلمات/مجموعات/قنوات متعقبة  \nاضغط ⚙️لتكوين",
}
l_find_alert_words = {
    "ru": "👩🏽‍💻 <b>1. Вставь</b> отслеживаемые слова (более <u>3</u> символов) через <i>пробельные или разделительные</i> символы (без 💨Подписки: <u>1</u> слово)\n\n<blockquote>▪️регистр не важен\n▪️* в конце слова учитывает вхождение</blockquote>\n\n👩🏽‍💻 <b>Например</b>, для <b>психо*</b> отслеживание сработает на фразы: <i>анти<u>психо</u>лог, <u>Психо</u>терапевт..</i>\n\n<blockquote>🔔 <b>Отслеживаемые</b>  слова: <code>{0}</code>\n🔔 <b>Отслеживаемые</b> группы/каналы: <code>{1}</code></blockquote>",
    "en": "👩🏽‍💻 <b>1. Insert</b> tracked words (more than <u>3</u> characters) separated by <i>space or delimiter</i> characters (without 💨Subscription: <u>1</u> word)\n\n<blockquote>▪️case does not matter\n▪️* at the end of the word counts as a match</blockquote>\n\n👩🏽‍💻 <b>For example</b>, for <b>psycho*</b> tracking will work on phrases: <i>anti<u>psycho</u>logist, <u>Psycho</u>therapist..</i>\n\n<blockquote>🔔 <b>Tracked</b> words: <code>{0}</code>\n🔔 <b>Tracked</b> groups/channels: <code>{1}</code></blockquote>",
    "es": "👩🏽‍💻 <b>1. Inserta</b> palabras rastreadas (más de <u>3</u> caracteres) a través de <i>espacios o caracteres separadores</i> (sin 💨Suscripción: <u>1</u> palabra)\n\n<blockquote>▪️no importa el registro\n▪️* al final de la palabra cuenta como coincidencia</blockquote>\n\n👩🏽‍💻 <b>Por ejemplo</b>, para <b>psico*</b> el rastreo funcionará en frases: <i>anti<u>psico</u>logo, <u>Psico</u>terapeuta..</i>\n\n<blockquote>🔔 <b>Palabras</b> rastreadas: <code>{0}</code>\n🔔 <b>Grupos/canales</b> rastreados: <code>{1}</code></blockquote>",
    "fr": "👩🏽‍💻 <b>1. Insérez</b> des mots suivis (plus de <u>3</u> caractères) via des <i>espaces ou des</i> caractères de séparation (sans 💨Abonnement : <u>1</u> mot)\n\n<blockquote>▪️la casse n'est pas importante\n▪️* à la fin du mot prend en compte l'occurrence</blockquote>\n\n👩🏽‍💻 <b>Par exemple</b>, pour <b>psycho*</b> le suivi fonctionnera sur les phrases : <i>anti<u>psycho</u>logue, <u>Psycho</u>thérapeute..</i>\n\n<blockquote>🔔 <b>Mots</b> suivis : <code>{0}</code>\n🔔 <b>Groupes/chaînes</b> suivis : <code>{1}</code></blockquote>",
    "zh": "👩🏽‍💻 <b>1. 插入</b> 可追踪的词汇（超过 <u>3</u> 个字符）通过 <i>空格或分隔</i> 符号（不包括 💨订阅：<u>1</u> 个词）\n\n<blockquote>▪️大小写不重要\n▪️* 在词尾考虑包含</blockquote>\n\n👩🏽‍💻 <b>例如</b>，对于 <b>心理*</b> 追踪将适用于短语：<i>反<u>心理</u>学家，<u>心理</u>治疗师..</i>\n\n<blockquote>🔔 <b>可追踪的</b> 词汇：<code>{0}</code>\n🔔 <b>可追踪的</b> 群组/频道：<code>{1}</code></blockquote>",
    "ar": "👩🏽‍💻 <b>1. أدخل</b> الكلمات المتعقبة (أكثر من <u>3</u> أحرف) عبر <i>فراغات أو رموز فصيلة</i> (بدون 💨اشتراك: <u>1</u> كلمة)\n\n<blockquote>▪️الحالة غير مهمة\n▪️* في نهاية الكلمة تأخذ في الاعتبار الظهور</blockquote>\n\n👩🏽‍💻 <b>على سبيل المثال</b>، بالنسبة لـ <b>نفسي*</b> سيتحقق التعقب على العبارات: <i>مضاد<u>نفسي</u>، <u>نفسي</u>علاج..</i>\n\n<blockquote>🔔 <b>الكلمات</b> المتعقبة: <code>{0}</code>\n🔔 <b>المجموعات/القنوات</b> المتعقبة: <code>{1}</code></blockquote>",
}
l_find_alert_sources = {
    "ru": "👩🏽‍💻 <b>2. Вставь</b> публичные ссылки на группы/каналы (для отслеживаемых слов) через <i>пробелы/раздели</i> (без 💨Подписки: <u>1</u> группа/канал)\n\n<blockquote>🔔 <b>Отслеживаемые</b>  слова: <code>{0}</code>\n🔔 <b>Отслеживаемые</b> группы/каналы: <code>{1}</code></blockquote>",
    "en": "👩🏽‍💻 <b>2. Insert</b> public links to groups/channels (for tracked words) through <i>spaces/separators</i> (without 💨Subscriptions: <u>1</u> group/channel)\n\n<blockquote>🔔 <b>Tracked</b> words: <code>{0}</code>\n🔔 <b>Tracked</b> groups/channels: <code>{1}</code></blockquote>",
    "es": "👩🏽‍💻 <b>2. Inserta</b> enlaces públicos a grupos/canales (para las palabras rastreadas) a través de <i>espacios/separadores</i> (sin 💨Suscripciones: <u>1</u> grupo/canal)\n\n<blockquote>🔔 <b>Palabras</b> rastreadas: <code>{0}</code>\n🔔 <b>Grupos/canales</b> rastreados: <code>{1}</code></blockquote>",
    "fr": "👩🏽‍💻 <b>2. Insère</b> des liens publics vers des groupes/canaux (pour les mots suivis) via <i>espaces/séparateurs</i> (sans 💨Abonnements : <u>1</u> groupe/canal)\n\n<blockquote>🔔 <b>Mots suivis</b> : <code>{0}</code>\n🔔 <b>Groupes/canaux suivis</b> : <code>{1}</code></blockquote>",
    "zh": "👩🏽‍💻 <b>2. 插入</b> 公开链接到群组/频道（用于跟踪的词）通过 <i>空格/分隔符</i> （不包括 💨订阅: <u>1</u> 群组/频道）\n\n<blockquote>🔔 <b>跟踪的</b> 词: <code>{0}</code>\n🔔 <b>跟踪的</b> 群组/频道: <code>{1}</code></blockquote>",
    "ar": "👩🏽‍💻 <b>2. أدخل</b> الروابط العامة للمجموعات/القنوات (للكلمات المتعقبة) عبر <i>المسافات/الفواصل</i> (بدون 💨الاشتراكات: <u>1</u> مجموعة/قناة)\n\n<blockquote>🔔 <b>الكلمات المتعقبة</b>: <code>{0}</code>\n🔔 <b>المجموعات/القنوات المتعقبة</b>: <code>{1}</code></blockquote>",
}
l_find_need_subscribe = {
    "ru": "👩🏽‍💻 <b>Для</b> получения ссылки на сообщение и заказчика оформи 💨Подписку на @FereyFindBot-приложение:\n\nhttps://t.me",
    "en": "👩🏽‍💻 <b>To</b> get a link to the message and the client, subscribe to the 💨@FereyFindBot app:\n\nhttps://t.me",
    "es": "👩🏽‍💻 <b>Para</b> obtener el enlace al mensaje y al cliente, suscríbete 💨 a la aplicación @FereyFindBot:\n\nhttps://t.me",
    "fr": "👩🏽‍💻 <b>Pour</b> obtenir le lien vers le message et le client, abonne-toi 💨 à l'application @FereyFindBot :\n\nhttps://t.me",
    "zh": "👩🏽‍💻 <b>要</b> 获取消息和客户的链接，请订阅 💨@FereyFindBot 应用程序：\n\nhttps://t.me",
    "ar": "👩🏽‍💻 <b>للحصول</b> على رابط الرسالة والعميل، قم بعمل 💨اشتراك في تطبيق @FereyFindBot:\n\nhttps://t.me",
}
# endregion


# region FereyTONestBot
l_tonest_btn1 = {
    "ru": "👩🏽‍💻 Блокчейн-активы",
    "en": "👩🏽‍💻 Blockchain assets",
    "es": "👩🏽‍💻 Activos de blockchain",
    "fr": "👩🏽‍💻 Actifs blockchain",
    "zh": "👩🏽‍💻 区块链资产",
    "ar": "👩🏽‍💻 أصول البلوكشين",
}
l_tonest_btn2 = {
    "ru": "💨 Подписка",
    "en": "💨 Subscription",
    "es": "💨 Suscripción",
    "fr": "💨 Abonnement",
    "zh": "💨 订阅",
    "ar": "💨 الاشتراك",
}
l_tonest_welcome = {
    "ru": "🌱 <b>{0}</b>, добро пожаловать в <i>@tg-приложение</i> создания Web3ᵀᴼᴺ-проектов на блокчейне:\n\n<blockquote>▪️соло/альбом NFT\n▪️монеты (токены) FT\n▪️смарт-контракты\n▪️NFT-диалоги</blockquote>",
    "en": "🌱 <b>{0}</b>, welcome to the <i>@tg-app</i> for creating Web3ᵀᴼᴺ projects on the blockchain:\n\n<blockquote>▪️solo/album NFT\n▪️coins (tokens) FT\n▪️smart contracts\n▪️NFT dialogues</blockquote>",
    "es": "🌱 <b>{0}</b>, bienvenido a <i>@tg-aplicación</i> para la creación de proyectos Web3ᵀᴼᴺ en la blockchain:\n\n<blockquote>▪️sólo/álbum NFT\n▪️monedas (tokens) FT\n▪️contratos inteligentes\n▪️diálogos NFT</blockquote>",
    "fr": "🌱 <b>{0}</b>, bienvenue dans <i>@tg-application</i> de création de projets Web3ᵀᴼᴺ sur la blockchain :\n\n<blockquote>▪️solo/album NFT\n▪️monnaies (tokens) FT\n▪️contrats intelligents\n▪️dialogues NFT</blockquote>",
    "zh": "🌱 <b>{0}</b>, 欢迎来到 <i>@tg-应用程序</i> 创建基于区块链的 Web3ᵀᴼᴺ 项目：\n\n<blockquote>▪️单曲/专辑 NFT\n▪️货币（代币）FT\n▪️智能合约\n▪️NFT 对话</blockquote>",
    "ar": "🌱 <b>{0}</b>, مرحبًا بك في <i>@tg-تطبيق</i> لإنشاء مشاريع Web3ᵀᴼᴺ على البلوكشين:\n\n<blockquote>▪️سولو/ألبوم NFT\n▪️عملات (رموز) FT\n▪️عقود ذكية\n▪️حوارات NFT</blockquote>",
}
l_tonest_dialog_online = {
    "ru": "в сети",
    "en": "in the network",
    "es": "en línea",
    "fr": "dans le réseau",
    "zh": "在网络上",
    "ar": "في الشبكة",
}
l_tonest_participants_of_dialog = {
    "ru": "участников диалога",
    "en": "dialogue participants",
    "es": "participantes del diálogo",
    "fr": "participants du dialogue",
    "zh": "对话参与者",
    "ar": "مشاركي الحوار",
}
l_tonest_dialog_without_sub = {
    "ru": "👩🏽‍💻 <b>Без подписки</b> можно отчеканить не более 10 реплик в NFT-диалог",
    "en": "👩🏽‍💻 <b>Without a subscription</b>, you can mint no more than 10 replies in the NFT dialogue",
    "es": "👩🏽‍💻 <b>Sin suscripción</b> se pueden acuñar no más de 10 réplicas en el diálogo NFT",
    "fr": "👩🏽‍💻 <b>Sans abonnement</b>, vous pouvez frapper jusqu'à 10 répliques dans le dialogue NFT",
    "zh": "👩🏽‍💻 <b>没有订阅</b>，最多可以在NFT对话中铸造10个回复",
    "ar": "👩🏽‍💻 <b>بدون اشتراك</b> يمكنك سك ما لا يزيد عن 10 ردود في حوار NFT",
}
l_tonest_dialog_limit_50 = {
    "ru": "👩🏽‍💻 <b>Можно</b> отчеканить не более 50 реплик в NFT-диалог",
    "en": "👩🏽‍💻 <b>You can</b> mint no more than 50 replicas in the NFT dialogue",
    "es": "👩🏽‍💻 <b>Se pueden</b> acuñar no más de 50 réplicas en el diálogo NFT",
    "fr": "👩🏽‍💻 <b>Vous pouvez</b> frapper pas plus de 50 répliques dans le dialogue NFT",
    "zh": "👩🏽‍💻 <b>最多</b> 可以铸造 50 个 NFT 对话的副本",
    "ar": "👩🏽‍💻 <b>يمكن</b> سكّ ما لا يزيد عن 50 ردًا في حوار NFT",
}
l_tonest_dialog_need_correct_msgs = {
    "ru": "👩🏽‍💻 <b>Необходимо</b> переслать корректные сообщения (сообщения от приложения или аудио формат невозможно переслать)",
    "en": "👩🏽‍💻 <b>It is necessary</b> to forward the correct messages (messages from the app or audio format cannot be forwarded)",
    "es": "👩🏽‍💻 <b>Es necesario</b> reenviar mensajes correctos (no se pueden reenviar mensajes de la aplicación o en formato de audio)",
    "fr": "👩🏽‍💻 <b>Il est nécessaire</b> de transférer des messages corrects (les messages de l'application ou au format audio ne peuvent pas être transférés)",
    "zh": "👩🏽‍💻 <b>必须</b> 转发正确的消息（应用程序的消息或音频格式无法转发）",
    "ar": "👩🏽‍💻 <b>يجب</b> إعادة إرسال الرسائل الصحيحة (لا يمكن إعادة إرسال الرسائل من التطبيق أو تنسيق الصوت)",
}
l_tonest_nft_dialog = {
    "ru": "💬 NFT-диалог",
    "en": "💬 NFT-dialogue",
    "es": "💬 Diálogo NFT",
    "fr": "💬 Dialogue NFT",
    "zh": "💬 NFT对话",
    "ar": "💬 حوار NFT",
}
l_tonest_dialog_creating = {
    "ru": "👩🏽‍💻 <b>Жми</b> на [💬 NFT-диалог], чтобы просмотреть и подтвердить создание NFT-диалога",
    "en": "👩🏽‍💻 <b>Click</b> on [💬 NFT-dialog] to view and confirm the creation of the NFT-dialog",
    "es": "👩🏽‍💻 <b>Haz clic</b> en [💬 Diálogo NFT] para ver y confirmar la creación del diálogo NFT",
    "fr": "👩🏽‍💻 <b>Clique</b> sur [💬 dialogue NFT] pour voir et confirmer la création du dialogue NFT",
    "zh": "👩🏽‍💻 <b>点击</b> [💬 NFT对话] 以查看和确认创建NFT对话",
    "ar": "👩🏽‍💻 <b>اضغط</b> على [💬 حوار NFT] لمعاينة وتأكيد إنشاء حوار NFT",
}
# endregion


# region FereyStickerBot
l_sticker_btn1 = {
    "ru": "👩🏽‍💻 Стикеры",
    "en": "👩🏽‍💻 Stickers",
    "es": "👩🏽‍💻 Stickers",
    "fr": "👩🏽‍💻 Autocollants",
    "zh": "👩🏽‍💻 贴纸",
    "ar": "👩🏽‍💻 ملصقات",
}
l_sticker_btn2 = {
    "ru": "💨 Подписка",
    "en": "💨 Subscription",
    "es": "💨 Suscripción",
    "fr": "💨 Abonnement",
    "zh": "💨 订阅",
    "ar": "💨 الاشتراك",
}
l_sticker_welcome = {
    "ru": "🌱 <b>{0}</b>, добро пожаловать в <i>@tg-приложение</i> создания эмоджи/стикер наборов:\n\n<blockquote>▪️<b>static/video/animated</b>\n▪️преобразование фото в видео</blockquote>",
    "en": "🌱 <b>{0}</b>, welcome to the <i>@tg-app</i> for creating emoji/sticker sets:\n\n<blockquote>▪️<b>static/video/animated</b>\n▪️photo to video conversion</blockquote>",
    "es": "🌱 <b>{0}</b>, bienvenido a <i>@tg-aplicación</i> para crear conjuntos de emojis/stickers:\n\n<blockquote>▪️<b>estático/video/animado</b>\n▪️transformación de fotos en videos</blockquote>",
    "fr": "🌱 <b>{0}</b>, bienvenue dans <i>@tg-application</i> de création de jeux d'émojis/stickers :\n\n<blockquote>▪️<b>statique/vidéo/animé</b>\n▪️conversion de photos en vidéos</blockquote>",
    "zh": "🌱 <b>{0}</b>, 欢迎来到 <i>@tg-应用程序</i> 创建表情符号/贴纸包：\n\n<blockquote>▪️<b>静态/视频/动画</b>\n▪️将照片转换为视频</blockquote>",
    "ar": "🌱 <b>{0}</b>, مرحبًا بك في <i>@tg-تطبيق</i> لإنشاء مجموعات الإيموجي/الملصقات:\n\n<blockquote>▪️<b>ثابت/فيديو/متحرك</b>\n▪️تحويل الصور إلى فيديو</blockquote>",
}
l_pack_type = {
    "ru": "✏️ 1. <b>Выбери</b> тип создаваемого набора <a href='https://t.me/addstickers/ResistanceDog'>sticker</a>/<a href='https://t.me/addemoji/ApplicationEmoji'>emoji</a>\n\n(<i>жми «➡️️/Next», чтобы перейти к следующему шагу</i>)",
    "en": "✏️ 1. <b>Select</b> the type of the set you are creating <a href='https://t.me/addstickers/ResistanceDog'>sticker</a>/<a href='https://t.me/addemoji/ApplicationEmoji'>emoji</a>\n\n(<i>press \"➡️️/Next\" to proceed to the next step</i>)",
    "es": "✏️ 1. <b>Elige</b> el tipo de conjunto que deseas crear <a href='https://t.me/addstickers/ResistanceDog'>sticker</a>/<a href='https://t.me/addemoji/ApplicationEmoji'>emoji</a>\n\n(<i>presiona «➡️️/Siguiente» para pasar al siguiente paso</i>)",
    "fr": "✏️ 1. <b>Choisis</b> le type de set à créer <a href='https://t.me/addstickers/ResistanceDog'>sticker</a>/<a href='https://t.me/addemoji/ApplicationEmoji'>emoji</a>\n\n(<i>appuie sur «➡️️/Suivant» pour passer à l'étape suivante</i>)",
    "zh": "✏️ 1. <b>选择</b> 创建的套件类型 <a href='https://t.me/addstickers/ResistanceDog'>贴纸</a>/<a href='https://t.me/addemoji/ApplicationEmoji'>表情</a>\n\n(<i>点击“➡️️/下一步”以进入下一步</i>)",
    "ar": "✏️ 1. <b>اختر</b> نوع المجموعة التي سيتم إنشاؤها <a href='https://t.me/addstickers/ResistanceDog'>ملصق</a>/<a href='https://t.me/addemoji/ApplicationEmoji'>رمز تعبيري</a>\n\n(<i>اضغط «➡️️/التالي» للانتقال إلى الخطوة التالية</i>)",
}
l_pack_username = {
    "ru": "✏️ 2. <b>Введи</b> @username <b>{0}</b>-набора (до 45 символов), отображаемого в ссылке\n\n<i>или жми «➡️️/Next», чтобы использовать рандомный:\n<blockquote>{1}</blockquote></i>",
    "en": "✏️ 2. <b>Enter</b> @username <b>{0}</b>-set (up to 45 characters), displayed in the link\n\n<i>or press \"➡️️/Next\" to use a random one:\n<blockquote>{1}</blockquote></i>",
    "es": "✏️ 2. <b>Introduce</b> @username <b>{0}</b>-conjunto (hasta 45 caracteres), que se muestra en el enlace\n\n<i>o presiona «➡️️/Siguiente» para usar uno aleatorio:\n<blockquote>{1}</blockquote></i>",
    "fr": "✏️ 2. <b>Entrez</b> @username <b>{0}</b>-ensemble (jusqu'à 45 caractères), affiché dans le lien\n\n<i>ou appuyez sur «➡️️/Suivant» pour utiliser aléatoirement :\n<blockquote>{1}</blockquote></i>",
    "zh": "✏️ 2. <b>输入</b> @username <b>{0}</b> - 集合（最多 45 个字符），在链接中显示\n\n<i>或者点击“➡️️/下一步”，以使用随机：\n<blockquote>{1}</blockquote></i>",
    "ar": "✏️ 2. <b>أدخل</b> @username <b>{0}</b>-مجموعة (حتى 45 حرفًا) ، المعروضة في الرابط\n\n<i>أو اضغط على \"➡️️/التالي\" لاستخدام عشوائي:\n<blockquote>{1}</blockquote></i>",
}
l_pack_title = {
    "ru": "✏️ 3. <b>Введи</b> название <b>{0}</b>-набора (до 64 символов), отображаемого в заголовке: <b>Title</b>\n\n<i>или жми «➡️️/Next», чтобы использовать рандомное:\n<blockquote>{1}</blockquote></i>",
    "en": "✏️ 3. <b>Enter</b> the name of the <b>{0}</b> set (up to 64 characters) displayed in the header: <b>Title</b>\n\n<i>or press \"➡️️/Next\" to use a random one:\n<blockquote>{1}</blockquote></i>",
    "es": "✏️ 3. <b>Introduce</b> el nombre del <b>{0}</b> conjunto (hasta 64 caracteres), que se mostrará en el encabezado: <b>Título</b>\n\n<i>o presiona «➡️️/Siguiente» para usar uno aleatorio:\n<blockquote>{1}</blockquote></i>",
    "fr": "✏️ 3. <b>Entrez</b> le nom du <b>{0}</b>-ensemble (jusqu'à 64 caractères), affiché dans le titre : <b>Titre</b>\n\n<i>ou appuyez sur «➡️️/Suivant» pour utiliser aléatoirement :\n<blockquote>{1}</blockquote></i>",
    "zh": "✏️ 3. <b>输入</b> 套件名称 <b>{0}</b>（最多 64 个字符），显示在标题中：<b>标题</b>\n\n<i>或者点击“➡️️/下一步”，以使用随机：\n<blockquote>{1}</blockquote></i>",
    "ar": "✏️ 3. <b>أدخل</b> اسم <b>{0}</b>-مجموعة (حتى 64 حرفًا)، المعروض في العنوان: <b>العنوان</b>\n\n<i>أو اضغط على «➡️️/التالي» لاستخدام عشوائي:\n<blockquote>{1}</blockquote></i>",
}
l_pack_kind = {
    "ru": "✏️ 4. <b>Укажи</b> вид <b>{0}</b>-набора: ¹<a href='{1}'>статический</a>/²<a href='{2}'>видео</a>/³<a href='{3}'>анимация</a>\n\n<blockquote>¹static (.webp/.png, px: {7}, 512Kb, max: {4})\n²video (.webm/3 сек, px: {7}, 256Kb, max: {5})\n³animated (.tgs/3 сек, px: {7}, 64Kb, max: {6})</blockquote>",
    "en": "✏️ 4. <b>Specify</b> the type of <b>{0}</b> set: ¹<a href='{1}'>static</a>/²<a href='{2}'>video</a>/³<a href='{3}'>animation</a>\n\n<blockquote>¹static (.webp/.png, px: {7}, 512Kb, max: {4})  \n²video (.webm/3 sec, px: {7}, 256Kb, max: {5})  \n³animated (.tgs/3 sec, px: {7}, 64Kb, max: {6})</blockquote>",
    "es": "✏️ 4. <b>Indica</b> el tipo de <b>{0}</b>-conjunto: ¹<a href='{1}'>estático</a>/²<a href='{2}'>video</a>/³<a href='{3}'>animación</a>\n\n<blockquote>¹estático (.webp/.png, px: {7}, 512Kb, max: {4})\n²video (.webm/3 seg, px: {7}, 256Kb, max: {5})\n³animado (.tgs/3 seg, px: {7}, 64Kb, max: {6})</blockquote>",
    "fr": "✏️ 4. <b>Indique</b> le type de <b>{0}</b>-ensemble : ¹<a href='{1}'>statique</a>/²<a href='{2}'>vidéo</a>/³<a href='{3}'>animation</a>\n\n<blockquote>¹statique (.webp/.png, px : {7}, 512Ko, max : {4})  \n²vidéo (.webm/3 sec, px : {7}, 256Ko, max : {5})  \n³animé (.tgs/3 sec, px : {7}, 64Ko, max : {6})</blockquote>",
    "zh": "✏️ 4. <b>指定</b> 类型 <b>{0}</b> 集合: ¹<a href='{1}'>静态</a>/²<a href='{2}'>视频</a>/³<a href='{3}'>动画</a>\n\n<blockquote>¹静态 (.webp/.png, 像素: {7}, 512Kb, 最大: {4})\n²视频 (.webm/3 秒, 像素: {7}, 256Kb, 最大: {5})\n³动画 (.tgs/3 秒, 像素: {7}, 64Kb, 最大: {6})</blockquote>",
    "ar": "✏️ 4. <b>حدد</b> نوع <b>{0}</b>-مجموعة: ¹<a href='{1}'>ثابت</a>/²<a href='{2}'>فيديو</a>/³<a href='{3}'>رسوم متحركة</a>\n\n<blockquote>¹ثابت (.webp/.png, بكسل: {7}, 512Kb, الحد الأقصى: {4})\n²فيديو (.webm/3 ثوان, بكسل: {7}, 256Kb, الحد الأقصى: {5})\n³رسوم متحركة (.tgs/3 ثوان, بكسل: {7}, 64Kb, الحد الأقصى: {6})</blockquote>",
}
l_pck_new = {
    "ru": "🏔️ Создать",
    "en": "🏔️ Create",
    "es": "🏔️ Crear",
    "fr": "🏔️ Créer",
    "zh": "🏔️ 创建",
    "ar": "🏔️ إنشاء",
}
l_pck_edt = {
    "ru": "♻️ Изменить",
    "en": "♻️ Change",
    "es": "♻️ Cambiar",
    "fr": "♻️ Modifier",
    "zh": "♻️ 更改",
    "ar": "♻️ تغيير",
}
l_pck_del = {
    "ru": "🚫 Удалить",
    "en": "🚫 Delete",
    "es": "🚫 Eliminar",
    "fr": "🚫 Supprimer",
    "zh": "🚫 删除",
    "ar": "🚫 حذف",
}
l_pack_sticker = {
    "ru": "стикер",
    "en": "sticker",
    "es": "sticker",
    "fr": "sticker",
    "zh": "贴纸",
    "ar": "ملصق",
}
l_pack_emoji = {
    "ru": "эмоджи",
    "en": "emoji",
    "es": "emojis",
    "fr": "émoticône",
    "zh": "表情符号",
    "ar": "الإيموجي",
}
l_pack_static = {
    "ru": "статический",
    "en": "static",
    "es": "estático",
    "fr": "statique",
    "zh": "静态",
    "ar": "ثابت",
}
l_pack_video = {
    "ru": "видео",
    "en": "video",
    "es": "video",
    "fr": "vidéo",
    "zh": "视频",
    "ar": "فيديو",
}
l_pack_animation = {
    "ru": "анимация",
    "en": "animation",
    "es": "animación",
    "fr": "animation",
    "zh": "动画",
    "ar": "الرسوم المتحركة",
}
l_item_media = {
    "ru": "✏️ 1. <b>Отправь</b> sticker/emoji или photo/video/gif для добавления в [{0}]\n\n<blockquote>или выбери из набора существующий <b>{1}</b> для редактирования/удаления - чтобы ускорить изменения удали и добавь набор снова</blockquote>\n<blockquote>жми ⚫️/🙌🏽/🔄, чтобы закруглить/удалить фон фото/конвертировать фото в видео</blockquote>",
    "en": "✏️ 1. <b>Send</b> a sticker/emoji or photo/video/gif to add to [{0}]\n\n<blockquote>or choose an existing <b>{1}</b> from the set for editing/deleting - to speed up changes, remove and add the set again</blockquote>\n<blockquote>press ⚫️/🙌🏽/🔄 to round off/delete the photo background/convert the photo to video</blockquote>",
    "es": "✏️ 1. <b>Envía</b> un sticker/emoji o una foto/video/gif para agregar a [{0}]\n\n<blockquote>o elige un <b>{1}</b> existente del conjunto para editar/eliminar - para acelerar los cambios, elimina y agrega el conjunto nuevamente</blockquote>\n<blockquote>presiona ⚫️/🙌🏽/🔄, para redondear/eliminar el fondo de la foto/convertir la foto en video</blockquote>",
    "fr": "✏️ 1. <b>Envoie</b> un sticker/emoji ou une photo/vidéo/gif pour l'ajouter à [{0}]\n\n<blockquote>ou choisis un <b>{1}</b> existant dans l'ensemble pour l'éditer/supprimer - pour accélérer les modifications, supprime et ajoute à nouveau l'ensemble</blockquote>\n<blockquote>appuie sur ⚫️/🙌🏽/🔄 pour arrondir/supprimer l'arrière-plan de la photo/convertir la photo en vidéo</blockquote>",
    "zh": "✏️ 1. <b>发送</b> sticker/emoji 或 photo/video/gif 以添加到 [{0}]\n\n<blockquote>或选择现有的 <b>{1}</b> 进行编辑/删除 - 为了加快更改，请删除并重新添加该集合</blockquote>\n<blockquote>点击 ⚫️/🙌🏽/🔄，以圆化/删除照片背景/将照片转换为视频</blockquote>",
    "ar": "✏️ 1. <b>أرسل</b> ملصق/رمز تعبيري أو صورة/فيديو/GIF لإضافته إلى [{0}]\n\n<blockquote>أو اختر من المجموعة الموجودة <b>{1}</b> للتعديل/الحذف - لتسريع التغييرات، احذف وأعد إضافة المجموعة مرة أخرى</blockquote>\n<blockquote>اضغط ⚫️/🙌🏽/🔄، لتدوير/حذف خلفية الصورة/تحويل الصورة إلى فيديو</blockquote>",
}
l_item_format = {
    "ru": "✏️ 2. <b>Выбери</b> формат для <b>{0}</b>\n\n<blockquote>или жми «➡️️/Next», чтобы перейти к следующему шагу</blockquote>",
    "en": "✏️ 2. <b>Select</b> a format for <b>{0}</b>\n\n<blockquote>or press \"➡️️/Next\" to proceed to the next step</blockquote>",
    "es": "✏️ 2. <b>Elige</b> el formato para <b>{0}</b>\n\n<blockquote>o presiona «➡️️/Siguiente» para pasar al siguiente paso</blockquote>",
    "fr": "✏️ 2. <b>Choisis</b> le format pour <b>{0}</b>\n\n<blockquote>ou appuie sur «➡️️/Suivant» pour passer à l'étape suivante</blockquote>",
    "zh": "✏️ 2. <b>选择</b> 格式为 <b>{0}</b>\n\n<blockquote>或者点击“➡️️/下一步”，以进入下一步</blockquote>",
    "ar": "✏️ 2. <b>اختر</b> تنسيق لـ <b>{0}</b>\n\n<blockquote>أو اضغط على \"➡️️/التالي\" للانتقال إلى الخطوة التالية</blockquote>",
}
l_item_emoji = {
    "ru": "✏️ 2. <b>Укажи</b> эмоджи (до 20), которые будут ассоциированы с загруженным <b>{0}</b>\n\n<blockquote>или жми «➡️️/Next», чтобы перейти к следующему шагу</blockquote>",
    "en": "✏️ 2. <b>Specify</b> the emojis (up to 20) that will be associated with the uploaded <b>{0}</b>\n\n<blockquote>or click \"➡️️/Next\" to proceed to the next step</blockquote>",
    "es": "✏️ 2. <b>Indica</b> los emojis (hasta 20) que estarán asociados con el <b>{0}</b> cargado\n\n<blockquote>o presiona «➡️️/Siguiente» para pasar al siguiente paso</blockquote>",
    "fr": "✏️ 2. <b>Indique</b> les émojis (jusqu'à 20) qui seront associés au <b>{0}</b> téléchargé\n\n<blockquote>ou appuie sur «➡️️/Suivant» pour passer à l'étape suivante</blockquote>",
    "zh": "✏️ 2. <b>请指定</b> 与上传的 <b>{0}</b> 相关联的表情符号（最多 20 个）\n\n<blockquote>或者点击“➡️️/下一步”，以进入下一步</blockquote>",
    "ar": "✏️ 2. <b>حدد</b> الرموز التعبيرية (حتى 20) التي ستُرتبط بـ <b>{0}</b>\n\n<blockquote>أو اضغط على \"➡️️/التالي\" للانتقال إلى الخطوة التالية</blockquote>",
}
l_item_keyword = {
    "ru": "✏️ 3. <b>Укажи</b> ключевые слова (до 64 символов), которые будут ассоциированы с загруженным <b>{0}</b>\n\n<blockquote>или жми «➡️️/Next», чтобы перейти к следующему шагу</blockquote>",
    "en": "✏️ 3. <b>Specify</b> the keywords (up to 64 characters) that will be associated with the uploaded <b>{0}</b>\n\n<blockquote>or click \"➡️️/Next\" to proceed to the next step</blockquote>",
    "es": "✏️ 3. <b>Indica</b> las palabras clave (hasta 64 caracteres) que se asociarán con el <b>{0}</b> cargado\n\n<blockquote>o presiona «➡️️/Siguiente» para pasar al siguiente paso</blockquote>",
    "fr": "✏️ 3. <b>Indique</b> les mots-clés (jusqu'à 64 caractères) qui seront associés au <b>{0}</b> téléchargé\n\n<blockquote>ou appuie sur «➡️️/Suivant» pour passer à l'étape suivante</blockquote>",
    "zh": "✏️ 3. <b>请指定</b> 关键字（最多 64 个字符），这些关键字将与上传的 <b>{0}</b> 相关联\n\n<blockquote>或者点击“➡️️/下一步”，以进入下一步</blockquote>",
    "ar": "✏️ 3. <b>حدد</b> الكلمات الرئيسية (حتى 64 حرفًا) التي ستُرتبط بـ <b>{0}</b> المحملة\n\n<blockquote>أو اضغط على \"➡️️/التالي\" للانتقال إلى الخطوة التالية</blockquote>",
}
l_pck_title = {
    "ru": "🏔️ Название",
    "en": "🏔️ Title",
    "es": "🏔️ Título",
    "fr": "🏔️ Titre",
    "zh": "🏔️ 名称",
    "ar": "🏔️ الاسم",
}
l_itm_words = {
    "ru": "💬 Слова",
    "en": "💬 Words",
    "es": "💬 Palabras",
    "fr": "💬 Mots",
    "zh": "💬 词语",
    "ar": "💬 الكلمات",
}
l_itm_emoji = {
    "ru": "❤️ Эмоджи",
    "en": "❤️ Emoji",
    "es": "❤️ Emojis",
    "fr": "❤️ Émoji",
    "zh": "❤️ 表情符号",
    "ar": "❤️ رموز تعبيرية",
}
l_itm_delete = {
    "ru": "❌ Удалить",
    "en": "❌ Delete",
    "es": "❌ Eliminar",
    "fr": "❌ Supprimer",
    "zh": "❌ 删除",
    "ar": "❌ حذف",
}
l_itm_thumb = {
    "ru": "🖼️ Обложка",
    "en": "🖼️ Cover",
    "es": "🖼️ Portada",
    "fr": "🖼️ Couverture",
    "zh": "🖼️ 封面",
    "ar": "🖼️ غلاف",
}
l_itm_shift = {
    "ru": "🔛 Сдвиг",
    "en": "🔛 Shift",
    "es": "🔛 Desplazamiento",
    "fr": "🔛 Décalage",
    "zh": "🔛 移动",
    "ar": "🔛 تغيير",
}
l_itm_back = {
    "ru": "🔙 Назад",
    "en": "🔙 Back",
    "es": "🔙 Atrás",
    "fr": "🔙 Retour",
    "zh": "🔙 返回",
    "ar": "🔙 العودة",
}
l_pack_warn = {
    "ru": "👩🏽‍💻 <b>@username набора</b> не может начинаться с цифр/подчеркиваний, содержать не латинские символы и несколько подчеркиваний подряд",
    "en": "👩🏽‍💻 <b>@username set</b> cannot start with numbers/underscores, contain non-Latin characters, or have multiple consecutive underscores.",
    "es": "👩🏽‍💻 <b>@username debe comenzar</b> no puede comenzar con números/bajos, contener caracteres no latinos y varios bajos consecutivos",
    "fr": "👩🏽‍💻 <b>@username doit commencer par des lettres, ne peut pas contenir de caractères non latins et plusieurs soulignements consécutifs</b>",
    "zh": "👩🏽‍💻 <b>@username 的用户名</b> 不能以数字/下划线开头，不能包含非拉丁字符和多个连续的下划线",
    "ar": "👩🏽‍💻 <b>@username مجموعة</b> لا يمكن أن تبدأ بأرقام/شرطات سفلية، تحتوي على رموز غير لاتينية أو عدة شرطات سفلية متتالية",
}
l_pack_exist = {
    "ru": "👩🏽‍💻 {0} уже существует, выбери другой @username-набора",
    "en": "👩🏽‍💻 {0} already exists, please choose another @username-set",
    "es": "👩🏽‍💻 {0} ya existe, elige otro @username-conjunto",
    "fr": "👩🏽‍💻 {0} existe déjà, choisissez un autre @username-ensemble",
    "zh": "👩🏽‍💻 {0} 已经存在，请选择另一个 @username-集合",
    "ar": "👩🏽‍💻 {0} موجود بالفعل، اختر مجموعة @username أخرى",
}
l_pack_error = {
    "ru": "👩🏽‍💻 <b>Ошибка</b> создания набора: повтори попытку позже или загрузи другой media-файл",
    "en": "👩🏽‍💻 <b>Error</b> creating the set: please try again later or upload another media file",
    "es": "👩🏽‍💻 <b>Error</b> al crear el conjunto: intenta de nuevo más tarde o carga otro archivo multimedia",
    "fr": "👩🏽‍💻 <b>Erreur</b> de création du jeu : réessayez plus tard ou téléchargez un autre fichier media",
    "zh": "👩🏽‍💻 <b>创建集合时出错</b>：请稍后重试或上传其他媒体文件",
    "ar": "👩🏽‍💻 <b>خطأ</b> في إنشاء المجموعة: حاول مرة أخرى لاحقًا أو قم بتحميل ملف وسائط آخر",
}
l_pack_full = {
    "ru": "👩🏽‍💻 {0}-набор уже заполнен. Выбери из набора существующий <b>{1}</b> для редактирования/удаления",
    "en": "👩🏽‍💻 The {0} set is already filled. Choose an existing <b>{1}</b> from the set for editing/deleting.",
    "es": "👩🏽‍💻 El conjunto {0} ya está lleno. Elige de la colección el existente <b>{1}</b> para editar/eliminar.",
    "fr": "👩🏽‍💻 L'ensemble {0} est déjà rempli. Choisissez un <b>{1}</b> existant dans l'ensemble pour modifier/supprimer.",
    "zh": "👩🏽‍💻 {0} 套件已填充。选择现有的 <b>{1}</b> 进行编辑/删除。",
    "ar": "👩🏽‍💻 {0} - تم ملء المجموعة بالفعل. اختر من المجموعة <b>{1}</b> الموجودة للتعديل/الحذف",
}
l_pack_full2 = {
    "ru": "👩🏽‍💻 Набор уже заполнен ({1}/{2}). Выбери из набора существующий {3} для редактирования/удаления",
    "en": "👩🏽‍💻 The set is already filled ({1}/{2}). Choose an existing {3} from the set for editing/deleting.",
    "es": "👩🏽‍💻 El conjunto ya está completo ({1}/{2}). Elige un {3} existente del conjunto para editar/eliminar.",
    "fr": "👩🏽‍💻 L'ensemble est déjà rempli ({1}/{2}). Choisissez un {3} existant dans l'ensemble pour modifier/supprimer.",
    "zh": "👩🏽‍💻 套件已满 ({1}/{2})。请选择现有的 {3} 进行编辑/删除。",
    "ar": "👩🏽‍💻 تم ملء المجموعة بالفعل ({1}/{2}). اختر من المجموعة {3} الموجودة للتعديل/الحذف",
}
l_pack_delete = {
    "ru": "👩🏽‍💻 <b>Удалить</b> набор: {0}",
    "en": "👩🏽‍💻 <b>Delete</b> set: {0}",
    "es": "👩🏽‍💻 <b>Eliminar</b> conjunto: {0}",
    "fr": "👩🏽‍💻 <b>Supprimer</b> l'ensemble : {0}",
    "zh": "👩🏽‍💻 <b>删除</b> 套件: {0}",
    "ar": "👩🏽‍💻 <b>حذف</b> المجموعة: {0}",
}
l_item_thumb = {
    "ru": "✏️ 3. <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> режим обложки для загруженного файла\n\n(<i>жми «➡️️/Next», чтобы перейти к следующему шагу</i>)",
    "en": "✏️ 3. <b>Click</b> on ✅/☑️ to <b>Enable/Disable</b> cover mode for the uploaded file\n\n(<i>click \"➡️️/Next\" to proceed to the next step</i>)",
    "es": "✏️ 3. <b>Haz clic</b> en ✅/☑️, para <b>Activar/Desactivar</b> el modo de portada para el archivo cargado\n\n(<i>haz clic en «➡️️/Siguiente», para pasar al siguiente paso</i>)",
    "fr": "✏️ 3. <b>Clique</b> sur ✅/☑️ pour <b>Activer/Désactiver</b> le mode couverture pour le fichier téléchargé\n\n(<i>clique sur «➡️️/Suivant» pour passer à l'étape suivante</i>)",
    "zh": "✏️ 3. <b>点击</b> ✅/☑️，以 <b>开启/关闭</b> 上传文件的封面模式\n\n(<i>点击“➡️️/下一步”，以进入下一步</i>)",
    "ar": "✏️ 3. <b>اضغط</b> على ✅/☑️، لتفعيل <b>تشغيل/إيقاف</b> وضع الغلاف للملف المحمّل\n\n(<i>اضغط \"➡️️/التالي\" للانتقال إلى الخطوة التالية</i>)",
}
l_choose_from_pack = {
    "ru": "👩🏽‍💻 Выбрать из набора",
    "en": "👩🏽‍💻 Choose from the set",
    "es": "👩🏽‍💻 Elegir de la colección",
    "fr": "👩🏽‍💻 Choisir dans l'ensemble",
    "zh": "👩🏽‍💻 从集合中选择",
    "ar": "👩🏽‍💻 اختر من المجموعة",
}
l_item_unawailable = {
    "ru": "👩🏽‍💻 Преобразование недоступно",
    "en": "👩🏽‍💻 Conversion unavailable",
    "es": "👩🏽‍💻 La conversión no está disponible",
    "fr": "👩🏽‍💻 La conversion n'est pas disponible",
    "zh": "👩🏽‍💻 转换不可用",
    "ar": "👩🏽‍💻 التحويل غير متاح",
}
l_item_notfound = {
    "ru": "👩🏽‍💻 Стикер/эмоджи не найден в {0}",
    "en": "👩🏽‍💻 Sticker/emoji not found in {0}",
    "es": "👩🏽‍💻 Sticker/emoji no encontrado en {0}",
    "fr": "👩🏽‍💻 Autocollant/émoticône non trouvé dans {0}",
    "zh": "👩🏽‍💻 在 {0} 中未找到贴纸/表情符号",
    "ar": "👩🏽‍💻 الملصق/الإيموجي غير موجود في {0}",
}
l_item_incorrect = {
    "ru": "👩🏽‍💻 <b>Тип</b> загружаемого <b>{0}-{1}</b> не соответствует типу набора <b>{2}</b>",
    "en": "👩🏽‍💻 <b>The type</b> of the uploaded <b>{0}-{1}</b> does not match the set type <b>{2}</b>",
    "es": "👩🏽‍💻 <b>Tipo</b> de archivo cargado <b>{0}-{1}</b> no coincide con el tipo de conjunto <b>{2}</b>",
    "fr": "👩🏽‍💻 <b>Type</b> du fichier téléchargé <b>{0}-{1}</b> ne correspond pas au type de l'ensemble <b>{2}</b>",
    "zh": "👩🏽‍💻 <b>类型</b> 上传的 <b>{0}-{1}</b> 不符合集合的类型 <b>{2}</b>",
    "ar": "👩🏽‍💻 <b>النوع</b> من <b>{0}-{1}</b> الذي تم تحميله لا يتوافق مع نوع المجموعة <b>{2}</b>",
}
l_pack_title_edit = {
    "ru": "🏔️ <b>Введи</b> новое название для [<b>{0}</b>]-набора (до 64 символов), отображаемого в заголовке\n\n👩🏽‍💻 <b>Текущее название</b>: {1}\n(<i>отправь <code>0</code>, чтобы очистить название</i>)",
    "en": "🏔️ <b>Enter</b> a new name for the [<b>{0}</b>] set (up to 64 characters) displayed in the title\n\n👩🏽‍💻 <b>Current name</b>: {1}\n(<i>send <code>0</code> to clear the name</i>)",
    "es": "🏔️ <b>Introduce</b> un nuevo nombre para el conjunto [<b>{0}</b>] (hasta 64 caracteres), que se mostrará en el encabezado\n\n👩🏽‍💻 <b>Nombre actual</b>: {1}\n(<i>envía <code>0</code> para borrar el nombre</i>)",
    "fr": "🏔️ <b>Entrez</b> un nouveau nom pour le [<b>{0}</b>]-ensemble (jusqu'à 64 caractères), affiché dans le titre\n\n👩🏽‍💻 <b>Nom actuel</b> : {1}\n(<i>envoyez <code>0</code> pour effacer le nom</i>)",
    "zh": "🏔️ <b>输入</b> [<b>{0}</b>] 集合的新名称（最多 64 个字符），将在标题中显示\n\n👩🏽‍💻 <b>当前名称</b>: {1}\n(<i>发送 <code>0</code> 以清除名称</i>)",
    "ar": "🏔️ <b>أدخل</b> اسمًا جديدًا لمجموعة [<b>{0}</b>] (حتى 64 حرفًا) يظهر في العنوان\n\n👩🏽‍💻 <b>الاسم الحالي</b>: {1}\n(<i>أرسل <code>0</code> لمسح الاسم</i>)",
}
l_item_words_edit = {
    "ru": "💬 <b>Укажи</b> ключевые слова (до 64 символов), которые будут ассоциированы с загруженным <b>{0}</b>\n\n👩🏽‍💻 <b>Текущие слова</b>: {1}\n(<i>отправь <code>0</code>, чтобы очистить ключевые слова</i>)",
    "en": "💬 <b>Specify</b> the keywords (up to 64 characters) that will be associated with the uploaded <b>{0}</b>\n\n👩🏽‍💻 <b>Current words</b>: {1}\n(<i>send <code>0</code> to clear the keywords</i>)",
    "es": "💬 <b>Indica</b> las palabras clave (hasta 64 caracteres) que se asociarán con el <b>{0}</b> cargado\n\n👩🏽‍💻 <b>Palabras actuales</b>: {1}\n(<i>envía <code>0</code> para limpiar las palabras clave</i>)",
    "fr": "💬 <b>Indique</b> les mots-clés (jusqu'à 64 caractères) qui seront associés au <b>{0}</b> téléchargé\n\n👩🏽‍💻 <b>Mots actuels</b> : {1}\n(<i>envoyer <code>0</code> pour effacer les mots-clés</i>)",
    "zh": "💬 <b>请指定</b> 关键字（最多 64 个字符），这些关键字将与上传的 <b>{0}</b> 相关联\n\n👩🏽‍💻 <b>当前关键字</b>: {1}  \n(<i>发送 <code>0</code> 以清除关键字</i>)",
    "ar": "💬 <b>حدد</b> الكلمات الرئيسية (حتى 64 حرفًا) التي ستُرتبط بـ <b>{0}</b> المحملة\n\n👩🏽‍💻 <b>الكلمات الحالية</b>: {1}\n(<i>أرسل <code>0</code> لمسح الكلمات الرئيسية</i>)",
}
l_item_emoji_edit = {
    "ru": "❤️ <b>Укажи</b> эмоджи (до 20), которые будут ассоциированы с загруженным <b>{0}</b>\n\n👩🏽‍💻 <b>Текущие эмоджи</b>: {1}\n(<i>отправь <code>0</code>, чтобы очистить эмоджи</i>)",
    "en": "❤️ <b>Specify</b> emojis (up to 20) that will be associated with the uploaded <b>{0}</b>\n\n👩🏽‍💻 <b>Current emojis</b>: {1}\n(<i>send <code>0</code> to clear emojis</i>)",
    "es": "❤️ <b>Indica</b> los emojis (hasta 20) que estarán asociados con el <b>{0}</b> cargado\n\n👩🏽‍💻 <b>Emojis actuales</b>: {1}\n(<i>envía <code>0</code> para limpiar los emojis</i>)",
    "fr": "❤️ <b>Indique</b> les émojis (jusqu'à 20) qui seront associés au <b>{0}</b> téléchargé\n\n👩🏽‍💻 <b>Émojis actuels</b> : {1}\n(<i>envoie <code>0</code> pour effacer les émojis</i>)",
    "zh": "❤️ <b>请指定</b> 与上传的 <b>{0}</b> 相关联的表情符号（最多 20 个）\n\n👩🏽‍💻 <b>当前表情符号</b>: {1}\n(<i>发送 <code>0</code> 以清除表情符号</i>)",
    "ar": "❤️ <b>حدد</b> الرموز التعبيرية (حتى 20) التي ستُرتبط بـ <b>{0}</b> المحمّل\n\n👩🏽‍💻 <b>الرموز التعبيرية الحالية</b>: {1}\n(<i>أرسل <code>0</code> لمسح الرموز التعبيرية</i>)",
}
l_item_delete_edit = {
    "ru": "❌ <b>Удалить</b> выбранный <b>{0}</b> из набора [{1}]",
    "en": "❌ <b>Remove</b> selected <b>{0}</b> from the set [{1}]",
    "es": "❌ <b>Eliminar</b> el seleccionado <b>{0}</b> del conjunto [{1}]",
    "fr": "❌ <b>Supprimer</b> le <b>{0}</b> sélectionné du jeu [{1}]",
    "zh": "❌ <b>删除</b> 选定的 <b>{0}</b> 从集合 [{1}] 中",
    "ar": "❌ <b>حذف</b> العنصر المحدد <b>{0}</b> من المجموعة [{1}]",
}
l_item_thumb_edit = {
    "ru": "🖼️ <b>Установить</b> выбранный <b>{0}</b> в качестве обложки [{1}]-набора",
    "en": "🖼️ <b>Set</b> the selected <b>{0}</b> as the cover of the [{1}]-set",
    "es": "🖼️ <b>Establecer</b> el <b>{0}</b> seleccionado como portada del conjunto [{1}]",
    "fr": "🖼️ <b>Définir</b> le <b>{0}</b> sélectionné comme couverture du jeu [{1}]",
    "zh": "🖼️ <b>设置</b> 选定的 <b>{0}</b> 作为封面 [{1}]-套件",
    "ar": "🖼️ <b>تعيين</b> {0} المحدد كغلاف لمجموعة [{1}]",
}
l_item_shift_edit = {
    "ru": "🔛 <b>Жми</b> на ⬅️/➡️, чтобы сдвинуть <b>влево/вправо</b> выбранный <b>{0}</b> в наборе [{1}]\n\n<blockquote>позиция обновится в течение часа</blockquote>",
    "en": "🔛 <b>Click</b> on ⬅️/➡️ to move the selected <b>{0}</b> in the set [{1}] <b>left/right</b>\n\n<blockquote>the position will be updated within an hour</blockquote>",
    "es": "🔛 <b>Haz clic</b> en ⬅️/➡️ para mover <b>a la izquierda/a la derecha</b> el <b>{0}</b> seleccionado en el conjunto [{1}]\n\n<blockquote>la posición se actualizará en una hora</blockquote>",
    "fr": "🔛 <b>Clique</b> sur ⬅️/➡️ pour déplacer <b>à gauche/à droite</b> le <b>{0}</b> sélectionné dans l'ensemble [{1}]\n\n<blockquote>la position sera mise à jour dans l'heure</blockquote>",
    "zh": "🔛 <b>点击</b> ⬅️/➡️，以在集合 [{1}] 中将选定的 <b>{0}</b> 向 <b>左/右</b> 移动\n\n<blockquote>位置将在一小时内更新</blockquote>",
    "ar": "🔛 <b>اضغط</b> على ⬅️/➡️، لتحريك <b>يسارًا/يمينًا</b> {0} المحدد في المجموعة [{1}]\n\n<blockquote>سيتم تحديث الموقع خلال ساعة</blockquote>",
}
l_pack_title_done = {
    "ru": "🏔️ <b>Название</b>: <b>{0}</b> установлено",
    "en": "🏔️ <b>Name</b>: <b>{0}</b> set",
    "es": "🏔️ <b>Nombre</b>: <b>{0}</b> establecido",
    "fr": "🏔️ <b>Nom</b>: <b>{0}</b> installé",
    "zh": "🏔️ <b>名称</b>: <b>{0}</b> 已安装",
    "ar": "🏔️ <b>الاسم</b>: <b>{0}</b> تم تعيينه",
}
l_item_words_done = {
    "ru": "💬 <b>Ключевые слова</b>: [<b>{0}</b>] установлены",
    "en": "💬 <b>Keywords</b>: [<b>{0}</b>] set",
    "es": "💬 <b>Palabras clave</b>: [<b>{0}</b>] establecidas",
    "fr": "💬 <b>Mots-clés</b>: [<b>{0}</b>] définis",
    "zh": "💬 <b>关键词</b>: [<b>{0}</b>] 已设置",
    "ar": "💬 <b>الكلمات الرئيسية</b>: [<b>{0}</b>] تم تعيينها",
}
l_item_emoji_done = {
    "ru": "❤️ <b>Эмоджи</b>: <b>{0}</b> установлены",
    "en": "❤️ <b>Emoji</b>: <b>{0}</b> installed",
    "es": "❤️ <b>Emoji</b>: <b>{0}</b> instalados",
    "fr": "❤️ <b>Émoji</b>: <b>{0}</b> installés",
    "zh": "❤️ <b>表情符号</b>: <b>{0}</b> 已安装",
    "ar": "❤️ <b>الإيموجي</b>: <b>{0}</b> تم تثبيتها",
}
l_item_delete_done = {
    "ru": "❌ <b>{0}</b> удален",
    "en": "❌ <b>{0}</b> has been removed",
    "es": "❌ <b>{0}</b> eliminado",
    "fr": "❌ <b>{0}</b> supprimé",
    "zh": "❌ <b>{0}</b> 已删除",
    "ar": "❌ <b>{0}</b> تم حذفه",
}
l_item_thumb_done = {
    "ru": "🖼️ <b>{0}</b> установлен в качестве обложки",
    "en": "🖼️ <b>{0}</b> is set as the cover",
    "es": "🖼️ <b>{0}</b> se ha establecido como portada",
    "fr": "🖼️ <b>{0}</b> est défini comme couverture",
    "zh": "🖼️ <b>{0}</b> 被设置为封面",
    "ar": "🖼️ <b>{0}</b> تم تعيينه كغلاف",
}
l_item_shift_done = {
    "ru": "🔛 <b>{0}</b> сдвинут",
    "en": "🔛 <b>{0}</b> shifted",
    "es": "🔛 <b>{0}</b> desplazado",
    "fr": "🔛 <b>{0}</b> déplacé",
    "zh": "🔛 <b>{0}</b> 已移动",
    "ar": "🔛 <b>{0}</b> تم نقله",
}
l_item_need_animated = {
    "ru": "👩🏽‍💻 <b>Необходимо</b> загрузить .tgs-файл для <b>animated</b>-набора",
    "en": "👩🏽‍💻 <b>It is necessary</b> to upload a .tgs file for the <b>animated</b> set",
    "es": "👩🏽‍💻 <b>Es necesario</b> cargar un archivo .tgs para el <b>conjunto animado</b>",
    "fr": "👩🏽‍💻 <b>Il est nécessaire</b> de télécharger un fichier .tgs pour le <b>jeu d'animations</b>",
    "zh": "👩🏽‍💻 <b>需要</b> 上传 .tgs 文件以获取 <b>动画</b> 套件",
    "ar": "👩🏽‍💻 <b>يجب</b> تحميل ملف .tgs لمجموعة <b>متحركة</b>",
}
l_pack_title_error = {
    "ru": "🏔️ <b>Ошибка</b> установки названия",
    "en": "🏔️ <b>Error</b> setting the title",
    "es": "🏔️ <b>Error</b> al establecer el nombre",
    "fr": "🏔️ <b>Erreur</b> d'installation du nom",
    "zh": "🏔️ <b>安装名称时出错</b>",
    "ar": "🏔️ <b>خطأ</b> في تعيين الاسم",
}
l_item_words_error = {
    "ru": "💬 <b>Ошибка</b> установки ключевых слов",
    "en": "💬 <b>Error</b> installing keywords",
    "es": "💬 <b>Error</b> de instalación de palabras clave",
    "fr": "💬 <b>Erreur</b> d'installation des mots-clés",
    "zh": "💬 <b>关键字</b> 安装错误",
    "ar": "💬 <b>خطأ</b> في تثبيت الكلمات الرئيسية",
}
l_item_emoji_error = {
    "ru": "❤️ <b>Ошибка</b> установки эмоджи",
    "en": "❤️ <b>Error</b> installing emoji",
    "es": "❤️ <b>Error</b> de instalación de emoji",
    "fr": "❤️ <b>Erreur</b> d'installation des émojis",
    "zh": "❤️ <b>安装表情符号时出错</b>",
    "ar": "❤️ <b>خطأ</b> في تثبيت الرموز التعبيرية",
}
l_item_delete_error = {
    "ru": "❌ <b>Ошибка</b> удаления",
    "en": "❌ <b>Error</b> deleting",
    "es": "❌ <b>Error</b> al eliminar",
    "fr": "❌ <b>Erreur</b> de suppression",
    "zh": "❌ <b>删除错误</b>",
    "ar": "❌ <b>خطأ</b> في الحذف",
}
l_item_thumb_error = {
    "ru": "🖼️ <b>Ошибка</b> установки обложки",
    "en": "🖼️ <b>Error</b> installing cover",
    "es": "🖼️ <b>Error</b> al instalar la portada",
    "fr": "🖼️ <b>Erreur</b> d'installation de la couverture",
    "zh": "🖼️ <b>封面</b> 安装错误",
    "ar": "🖼️ <b>خطأ</b> في تثبيت الغلاف",
}
l_item_shift_error = {
    "ru": "🔛 <b>Ошибка</b> установки сдвига",
    "en": "🔛 <b>Shift installation error</b>",
    "es": "🔛 <b>Error</b> de instalación del desplazamiento",
    "fr": "🔛 <b>Erreur</b> d'installation du décalage",
    "zh": "🔛 <b>安装偏移错误</b>",
    "ar": "🔛 <b>خطأ</b> في تثبيت الإزاحة",
}
l_item_restart = {
    "ru": "(удали и сразу добавь набор снова для ускорения изменений)",
    "en": "(Remove and immediately add the set again to speed up changes)",
    "es": "(Elimina y vuelve a agregar el conjunto de inmediato para acelerar los cambios)",
    "fr": "(Supprime et ajoute immédiatement le jeu à nouveau pour accélérer les changements)",
    "zh": "(删除并立即重新添加集合以加快更改)",
    "ar": "(قم بإزالة المجموعة وأعد إضافتها مرة أخرى لتسريع التغييرات)",
}
l_item_shift_thumb = {
    "ru": "🖼️ Используй [🔛 Cдвиг] на первую позицию для видео-обложки",
    "en": "🖼️ Use [🔛 Shift] to move to the first position for the video cover",
    "es": "🖼️ Usa [🔛 Desplazamiento] en la primera posición para la miniatura del video",
    "fr": "🖼️ Utilisez [🔛 Déplacer] à la première position pour la vidéo de couverture",
    "zh": "🖼️ 使用 [🔛 移动] 到视频封面的第一位置",
    "ar": "🖼️ استخدم [🔛 نقل] إلى الموضع الأول لصورة الفيديو",
}
l_item_rbg_only_photo = {
    "ru": "🙌🏽 Удаление фона доступно только для фото",
    "en": "🙌🏽 Background removal is available only for photos",
    "es": "🙌🏽 La eliminación de fondo está disponible solo para fotos",
    "fr": "🙌🏽 La suppression de l'arrière-plan n'est disponible que pour les photos",
    "zh": "🙌🏽 背景删除仅适用于照片",
    "ar": "🙌🏽 إزالة الخلفية متاحة فقط للصور",
}
l_pack_item_add = {
    "ru": "👩🏽‍💻 <b>Отправь</b> sticker/emoji или photo/video/gif для добавления в <b>{0}</b>: <a href='{1}'>{2}</a>\n\n<blockquote>жми ⚫️/🙌🏽/🔄, чтобы закруглить/удалить фон фото/конвертировать фото в видео</blockquote>",
    "en": "👩🏽‍💻 <b>Send</b> a sticker/emoji or photo/video/gif to add to <b>{0}</b>: <a href='{1}'>{2}</a>\n\n<blockquote>press ⚫️/🙌🏽/🔄 to round off/remove the background of the photo/convert the photo to video</blockquote>",
    "es": "👩🏽‍💻 <b>Envía</b> un sticker/emoji o una foto/video/gif para agregar a <b>{0}</b>: <a href='{1}'>{2}</a>\n\n<blockquote>presiona ⚫️/🙌🏽/🔄 para recortar/eliminar el fondo de la foto/convertir la foto en video</blockquote>",
    "fr": "👩🏽‍💻 <b>Envoie</b> un sticker/emoji ou une photo/vidéo/gif pour ajouter à <b>{0}</b>: <a href='{1}'>{2}</a>\n\n<blockquote>appuie sur ⚫️/🙌🏽/🔄 pour arrondir/supprimer l'arrière-plan de la photo/convertir la photo en vidéo</blockquote>",
    "zh": "👩🏽‍💻 <b>发送</b> sticker/emoji 或 photo/video/gif 以添加到 <b>{0}</b>: <a href='{1}'>{2}</a>\n\n<blockquote>点击 ⚫️/🙌🏽/🔄，以裁剪/删除照片背景/将照片转换为视频</blockquote>",
    "ar": "👩🏽‍💻 <b>أرسل</b> ملصق/رمز تعبيري أو صورة/فيديو/GIF لإضافته إلى <b>{0}</b>: <a href='{1}'>{2}</a>\n\n<blockquote>اضغط ⚫️/🙌🏽/🔄 لتدوير/حذف خلفية الصورة/تحويل الصورة إلى فيديو</blockquote>",
}
l_pack_sub_for_many_media = {
    "ru": "👩🏽‍💻 <b>Необходимо</b> оформить подписку для загрузки нескольких медиа-файлов за раз",
    "en": "👩🏽‍💻 <b>You need</b> to subscribe to download multiple media files at once",
    "es": "👩🏽‍💻 <b>Es necesario</b> suscribirse para descargar varios archivos multimedia a la vez",
    "fr": "👩🏽‍💻 <b>Il est nécessaire</b> de s'abonner pour télécharger plusieurs fichiers multimédias à la fois",
    "zh": "👩🏽‍💻 <b>需要</b> 订阅以一次性下载多个媒体文件",
    "ar": "👩🏽‍💻 <b>يجب</b> الاشتراك لتحميل عدة ملفات وسائط في وقت واحد",
}
l_pack_success_need_wait = {
    "ru": "👩🏽‍💻 <b>Добавление:</b> успешно! Переходи к настройкам элемента или добавь еще\n\n📍 <b>Изменения</b> в наборе применятся в течение получаса",
    "en": "👩🏽‍💻 <b>Added:</b> successfully! Go to the element settings or add more\n\n📍 <b>Changes</b> in the set will take effect within half an hour",
    "es": "👩🏽‍💻 <b>Adición:</b> ¡exitoso! Ve a la configuración del elemento o añade más\n\n📍 <b>Los cambios</b> en el conjunto se aplicarán en media hora",
    "fr": "👩🏽‍💻 <b>Ajout :</b> réussi ! Passe aux paramètres de l'élément ou ajoute-en un autre\n\n📍 <b>Les modifications</b> dans l'ensemble seront appliquées dans les trente minutes",
    "zh": "👩🏽‍💻 <b>添加：</b>成功！请转到元素设置或再添加一个\n\n📍 <b>更改</b>将在半小时内应用于集合",
    "ar": "👩🏽‍💻 <b>الإضافة:</b> تمت بنجاح! انتقل إلى إعدادات العنصر أو أضف المزيد\n\n📍 <b>التغييرات</b> في المجموعة ستطبق خلال نصف ساعة",
}
l_pack_replace_success = {
    "ru": "👩🏽‍💻 <b>Замена:</b> успешно\n\n📍 <b>Изменения</b> в наборе применятся в течение получаса",
    "en": "👩🏽‍💻 <b>Replacement:</b> successful\n\n📍 <b>Changes</b> in the set will be applied within half an hour",
    "es": "👩🏽‍💻 <b>Reemplazo:</b> exitoso\n\n📍 <b>Cambios</b> en el conjunto se aplicarán en media hora",
    "fr": "👩🏽‍💻 <b>Remplacement :</b> réussi\n\n📍 <b>Les modifications</b> dans l'ensemble seront appliquées dans les trente minutes",
    "zh": "👩🏽‍💻 <b>替换：</b> 成功\n\n📍 <b>更改</b> 将在半小时内应用于集合",
    "ar": "👩🏽‍💻 <b>التغيير:</b> تم بنجاح\n\n📍 <b>التغييرات</b> في المجموعة ستطبق خلال نصف ساعة",
}
l_pack_item_add2 = {
    "ru": "👩🏽‍💻 <b>Отправь</b> sticker/emoji или photo/video/gif для замены элемента в <b>{0}</b>: <a href='{1}'>{2}</a>\n\n<blockquote>жми ⚫️/🙌🏽/🔄, чтобы закруглить/удалить фон фото/конвертировать фото в видео</blockquote>",
    "en": "👩🏽‍💻 <b>Send</b> a sticker/emoji or photo/video/gif to replace the element in <b>{0}</b>: <a href='{1}'>{2}</a>\n\n<blockquote>press ⚫️/🙌🏽/🔄 to round off/remove the background of the photo/convert the photo to video</blockquote>",
    "es": "👩🏽‍💻 <b>Envía</b> un sticker/emoji o una foto/video/gif para reemplazar el elemento en <b>{0}</b>: <a href='{1}'>{2}</a>\n\n<blockquote>presiona ⚫️/🙌🏽/🔄 para redondear/eliminar el fondo de la foto/convertir la foto en video</blockquote>",
    "fr": "👩🏽‍💻 <b>Envoyer</b> un sticker/emoji ou une photo/vidéo/gif pour remplacer l'élément dans <b>{0}</b>: <a href='{1}'>{2}</a>\n\n<blockquote>appuie sur ⚫️/🙌🏽/🔄 pour arrondir/supprimer l'arrière-plan de la photo/convertir la photo en vidéo</blockquote>",
    "zh": "👩🏽‍💻 <b>发送</b> sticker/emoji 或 photo/video/gif 来替换 <b>{0}</b> 中的元素: <a href='{1}'>{2}</a>\n\n<blockquote>点击 ⚫️/🙌🏽/🔄，以裁剪/删除照片背景/将照片转换为视频</blockquote>",
    "ar": "👩🏽‍💻 <b>أرسل</b> ملصق/رمز تعبيري أو صورة/فيديو/GIF لاستبدال العنصر في <b>{0}</b>: <a href='{1}'>{2}</a>\n\n<blockquote>اضغط ⚫️/🙌🏽/🔄 لتدوير/حذف خلفية الصورة/تحويل الصورة إلى فيديو</blockquote>",
}
# endregion


# region FereyCodexBot
l_codex_btn1 = {
    "ru": "👩🏽‍💻 Кодекс",
    "en": "👩🏽‍💻 Code",
    "es": "👩🏽‍💻 Código",
    "fr": "👩🏽‍💻 Code",
    "zh": "👩🏽‍💻 代码",
    "ar": "👩🏽‍💻 المدونة",
}
l_codex_btn2 = {
    "ru": "💨 Подписка",
    "en": "💨 Subscription",
    "es": "💨 Suscripción",
    "fr": "💨 Abonnement",
    "zh": "💨 订阅",
    "ar": "💨 الاشتراك",
}
l_codex_welcome = {
    "ru": "🌱 <b>{0}</b>, добро пожаловать в [<b>Кодекс {1}</b>] - <i>@tg-приложение</i> быстрого погружения в новые @tg-инструменты #нейро-маркетинга и блокчейна:\n\n▪️<b>экспресс</b>-интенсив 4 мин\n▪️@tg-<b>приложения</b>\n▪️<b>нейро</b>-инструменты\n▪️<b>веб3</b>-интеграции",
    "en": "🌱 <b>{0}</b>, welcome to [<b>Code {1}</b>] - <i>@tg-application</i> for a quick dive into new @tg-tools of #neuro-marketing and blockchain:\n\n▪️<b>express</b>-intensive 4 min\n▪️@tg-<b>applications</b>\n▪️<b>neuro</b>-tools\n▪️<b>web3</b>-integrations",
    "es": "🌱 <b>{0}</b>, bienvenido a [<b>Código {1}</b>] - <i>aplicación @tg</i> para una rápida inmersión en nuevas herramientas @tg de #neuro-marketing y blockchain:\n\n▪️<b>intensivo</b> exprés 4 min\n▪️@tg-<b>aplicaciones</b>\n▪️<b>neuro</b>-herramientas\n▪️<b>integraciones</b> web3",
    "fr": "🌱 <b>{0}</b>, bienvenue dans [<b>Code {1}</b>] - <i>@tg-application</i> pour une immersion rapide dans les nouveaux @tg-outils #neuro-marketing et blockchain :\n\n▪️<b>intensif</b> express 4 min\n▪️@tg-<b>applications</b>\n▪️<b>neuro</b>-outils\n▪️<b>web3</b>-intégrations",
    "zh": "🌱 <b>{0}</b>，欢迎来到 [<b>代码 {1}</b>] - <i>@tg-应用程序</i> 快速了解新的 @tg-工具 #神经营销 和区块链：\n\n▪️<b>快速</b>强化 4 分钟\n▪️@tg-<b>应用程序</b>\n▪️<b>神经</b>工具\n▪️<b>Web3</b> 集成",
    "ar": "🌱 <b>{0}</b>، مرحبًا بك في [<b>مدونة {1}</b>] - <i>@tg-تطبيق</i> للغوص السريع في أدوات @tg الجديدة #التسويق_العصبي و blockchain:\n\n▪️<b>تدريب</b> مكثف 4 دقائق\n▪️@tg-<b>تطبيقات</b>\n▪️<b>أدوات</b> عصبية\n▪️<b>تكاملات</b> ويب3",
}
l_codex_warm1 = {
    "ru": "👩🏽‍💻 <b>Кодекс {0}</b> - это программа практического обзора новых <code>@tg</code>-инструментов #нейро-маркетинга и блокчейна:\n\n<blockquote>за несколько минут познакомишься с новым @tg-функционалом, чтобы сэкономить несколько часов</blockquote>\n<blockquote>увидишь связки нейросетей и @tg-приложений, чтобы снизить затраты на подрядчиков</blockquote>\n<blockquote>узнаешь новые способы генерации/администрирования/поиска @tg-контента, чтобы обогнать конкурентов</blockquote>\n<blockquote>сможешь в один клик интегрировать web3-инструменты геймификации в канал/группу/приложение</blockquote>\n\n🌱 После изучения <b>кодекса</b>, у тебя появится возможность подробнее разобрать @tg-функционал на <i>экспертном</i> уровне в нашем <u>реалити-фесте</u>, ссылка на который будет в конце кодекса\n\n🍃 <b>Жми [★ Кодекс: взнос], чтобы открыть доступ к кодексу</b>\n\n©️ данный текст написан нейросетью",
    "en": "👩🏽‍💻 <b>Code {0}</b> is a practical overview program of new <code>@tg</code> tools in #neuro-marketing and blockchain:\n\n<blockquote>in just a few minutes, you'll get acquainted with the new @tg functionality to save several hours</blockquote>\n<blockquote>you'll see the connections between neural networks and @tg applications to reduce contractor costs</blockquote>\n<blockquote>you'll learn new ways to generate/administer/search @tg content to outpace competitors</blockquote>\n<blockquote>you'll be able to integrate web3 gamification tools into your channel/group/app with one click</blockquote>\n\n🌱 After studying the <b>code</b>, you'll have the opportunity to delve deeper into @tg functionality at an <i>expert</i> level in our <u>reality fest</u>, the link to which will be at the end of the code\n\n🍃 <b>Click [★ Code: contribution] to gain access to the code</b>\n\n©️ this text was written by a neural network",
    "es": "👩🏽‍💻 <b>Código {0}</b> es un programa de revisión práctica de nuevas <code>@tg</code>-herramientas de #neuro-marketing y blockchain:\n\n<blockquote>en unos minutos te familiarizarás con la nueva funcionalidad de @tg para ahorrar varias horas</blockquote>\n<blockquote>verás combinaciones de redes neuronales y aplicaciones de @tg para reducir costos en contratistas</blockquote>\n<blockquote>aprenderás nuevas formas de generar/administrar/buscar contenido de @tg para superar a la competencia</blockquote>\n<blockquote>podrás integrar herramientas de gamificación web3 en un canal/grupo/aplicación con un solo clic</blockquote>\n\n🌱 Después de estudiar <b>el código</b>, tendrás la oportunidad de profundizar en la funcionalidad de @tg a un nivel <i>experto</i> en nuestro <u>reality fest</u>, cuyo enlace estará al final del código\n\n🍃 <b>Haz clic en [★ Código: contribución] para acceder al código</b>\n\n©️ este texto fue escrito por una red neuronal",
    "fr": "👩🏽‍💻 <b>Code {0}</b> - c'est un programme de revue pratique des nouveaux <code>@tg</code>-outils #neuro-marketing et blockchain :\n\n<blockquote>en quelques minutes, tu découvriras la nouvelle fonctionnalité @tg pour économiser plusieurs heures</blockquote>\n<blockquote>tu verras des liaisons entre les réseaux neuronaux et les applications @tg pour réduire les coûts des sous-traitants</blockquote>\n<blockquote>tu apprendras de nouvelles méthodes de génération/administration/recherche de contenu @tg pour devancer tes concurrents</blockquote>\n<blockquote>tu pourras intégrer en un clic des outils web3 de gamification dans le canal/groupe/application</blockquote>\n\n🌱 Après avoir étudié <b>le code</b>, tu auras la possibilité d'explorer plus en détail la fonctionnalité @tg à un niveau <i>expert</i> lors de notre <u>réalité-festival</u>, dont le lien sera à la fin du code\n\n🍃 <b>Clique [★ Code : contribution] pour accéder au code</b>\n\n©️ ce texte a été écrit par une intelligence artificielle",
    "zh": "👩🏽‍💻 <b>法典 {0}</b> 是一个关于新 <code>@tg</code> 工具的实用概述程序，涉及 #神经营销 和区块链：\n\n<blockquote>几分钟内你将了解新的 @tg 功能，以节省几个小时</blockquote>\n<blockquote>你将看到神经网络与 @tg 应用程序的结合，以降低承包商的成本</blockquote>\n<blockquote>你将学习新的生成/管理/搜索 @tg 内容的方法，以超越竞争对手</blockquote>\n<blockquote>你将能够一键将 web3 游戏化工具集成到频道/群组/应用程序中</blockquote>\n\n🌱 在学习 <b>法典</b> 后，你将有机会在我们的 <u>现实节</u> 上以 <i>专家</i> 级别更详细地探讨 @tg 功能，链接将在法典末尾提供\n\n🍃 <b>点击 [★ 法典：捐款] 以获取法典的访问权限</b>\n\n©️ 本文本由神经网络撰写",
    "ar": "👩🏽‍💻 <b>مدونة {0}</b> هي برنامج لمراجعة عملية للأدوات الجديدة <code>@tg</code> في #التسويق_العصبي و البلوكشين:\n\n<blockquote>في بضع دقائق ستتعرف على الوظائف الجديدة لـ @tg، لتوفير بضع ساعات</blockquote>\n<blockquote>سترى روابط الشبكات العصبية وتطبيقات @tg، لتقليل التكاليف على المتعاقدين</blockquote>\n<blockquote>ستتعلم طرق جديدة لتوليد/إدارة/البحث عن محتوى @tg، لتتفوق على المنافسين</blockquote>\n<blockquote>ستتمكن من دمج أدوات web3 للألعاب في القناة/المجموعة/التطبيق بنقرة واحدة</blockquote>\n\n🌱 بعد دراسة <b>المدونة</b>، سيكون لديك الفرصة للتعمق في وظائف @tg على مستوى <i>خبير</i> في <u>مهرجان الواقع</u> الخاص بنا، الرابط سيكون في نهاية المدونة\n\n🍃 <b>اضغط [★ المدونة: المساهمة] لفتح الوصول إلى المدونة</b>\n\n©️ تم كتابة هذا النص بواسطة شبكة عصبية",
}
l_codex_warm2 = {
    "ru": "👩🏽‍💻 <b>Содержание Кодекса {0}:</b>\n\n<b>Акт #1</b>: <code>мастер генераций</code>\n<blockquote>• нейро-сообщения\n• нейро-цепочки\n• нейро-поиск\n• нейро-ответ\n• нейро-диалог</blockquote>\n\n<b>Акт #2</b>: <code>мастер администрирования</code>\n<blockquote>• монетизация\n• авто-бан\n• авто-вход\n• авто-постинг\n• авто-подкаст\n• авто-ответ</blockquote>\n\n<b>Акт #3</b>: <code>мастер поиска</code>\n<blockquote>• поиск категорий\n• пассивный поиск\n• поиск в маркетплейсах\n• поиск креативов\n• нейро поиск\n• активный поиск</blockquote>\n\n<b>Акт #4</b>: <code>мастер блокчейна</code>\n<blockquote>• мастер смарт-контрактов\n• мастер NFT\n• мастер токеномики</blockquote>\n\n<b>Акт #5</b>: <code>заключение</code>\n\n🌱 После изучения <b>кодекса</b>, у тебя появится возможность стать резидентом <u>закрытого канала</u> и получить доступ к обновляемой рабочей книге со всеми @tg-инструментами\n\n🍃 <b>Жми [★ Кодекс: взнос], чтобы открыть доступ к кодексу</b>",
    "en": "👩🏽‍💻 <b>Contents of the Code {0}:</b>\n\n<b>Act #1</b>: <code>master of generations</code>\n<blockquote>• neuro-blocks\n• neuro-chains\n• neuro-posting\n• neuro-response\n• neuro-dialogue</blockquote>\n\n<b>Act #2</b>: <code>master of administration</code>\n<blockquote>• auto-ban\n• auto-decor\n• auto-login\n• auto-posting\n• auto-podcast\n• auto-response</blockquote>\n\n<b>Act #3</b>: <code>master of search</code>\n<blockquote>• premium search\n• passive search\n• built-in search\n• creative search\n• neuro search\n• like search\n• geo search</blockquote>\n\n<b>Act #4</b>: <code>master of blockchain</code>\n<blockquote>• master of smart contracts\n• master of NFTs\n• master of tokenomics</blockquote>\n\n<b>Act #5</b>: <code>conclusion</code>\n\n🌱 After studying the <b>code</b>, you will have the opportunity to become a resident of the <u>closed channel</u> and gain access to an updated workbook with all @tg-tools\n\n🍃 <b>Click [★ Code: contribution] to gain access to the code</b>",
    "es": "👩🏽‍💻 <b>Contenido del Código {0}:</b>\n\n<b>Acto #1</b>: <code>maestro de generaciones</code>\n<blockquote>• neuro-bloques\n• neuro-cadenas\n• neuro-publicación\n• neuro-respuesta\n• neuro-diálogo</blockquote>\n\n<b>Acto #2</b>: <code>maestro de administración</code>\n<blockquote>• auto-banco\n• auto-decoración\n• auto-ingreso\n• auto-publicación\n• auto-podcast\n• auto-respuesta</blockquote>\n\n<b>Acto #3</b>: <code>maestro de búsqueda</code>\n<blockquote>• búsqueda premium\n• búsqueda pasiva\n• búsqueda integrada\n• búsqueda de creativos\n• búsqueda neuro\n• búsqueda de likes\n• búsqueda geográfica</blockquote>\n\n<b>Acto #4</b>: <code>maestro de blockchain</code>\n<blockquote>• maestro de contratos inteligentes\n• maestro de NFT\n• maestro de tokenómica</blockquote>\n\n<b>Acto #5</b>: <code>conclusión</code>\n\n🌱 Después de estudiar <b>el código</b>, tendrás la oportunidad de convertirte en residente de <u>un canal cerrado</u> y obtener acceso a un libro de trabajo actualizado con todas las herramientas @tg\n\n🍃 <b>Presiona [★ Código: contribución] para abrir el acceso al código</b>",
    "fr": "👩🏽‍💻 <b>Contenu du Code {0} :</b>\n\n<b>Acte #1</b> : <code>maître des générations</code>\n<blockquote>• neuro-blocs\n• neuro-chaînes\n• neuro-pub\n• neuro-réponse\n• neuro-dialogue</blockquote>\n\n<b>Acte #2</b> : <code>maître de l'administration</code>\n<blockquote>• auto-banque\n• auto-décor\n• auto-connexion\n• auto-pub\n• auto-podcast\n• auto-réponse</blockquote>\n\n<b>Acte #3</b> : <code>maître de la recherche</code>\n<blockquote>• recherche premium\n• recherche passive\n• recherche intégrée\n• recherche de créations\n• recherche neuro\n• recherche like\n• recherche géo</blockquote>\n\n<b>Acte #4</b> : <code>maître de la blockchain</code>\n<blockquote>• maître des smart contracts\n• maître des NFT\n• maître de la tokenomique</blockquote>\n\n<b>Acte #5</b> : <code>conclusion</code>\n\n🌱 Après avoir étudié le <b>code</b>, tu auras la possibilité de devenir résident d'un <u>canal privé</u> et d'accéder à un livre de travail mis à jour avec tous les outils @tg\n\n🍃 <b>Clique [★ Code : contribution] pour ouvrir l'accès au code</b>",
    "zh": "👩🏽‍💻 <b>《{0}》的内容：</b>\n\n<b>行为 #1</b>: <code>生成大师</code>\n<blockquote>• 神经块\n• 神经链\n• 神经发布\n• 神经回复\n• 神经对话</blockquote>\n\n<b>行为 #2</b>: <code>管理大师</code>\n<blockquote>• 自动封禁\n• 自动装饰\n• 自动登录\n• 自动发布\n• 自动播客\n• 自动回复</blockquote>\n\n<b>行为 #3</b>: <code>搜索大师</code>\n<blockquote>• 高级搜索\n• 被动搜索\n• 内置搜索\n• 创意搜索\n• 神经搜索\n• 点赞搜索\n• 地理搜索</blockquote>\n\n<b>行为 #4</b>: <code>区块链大师</code>\n<blockquote>• 智能合约大师\n• NFT大师\n• 代币经济大师</blockquote>\n\n<b>行为 #5</b>: <code>结论</code>\n\n🌱 学习<b>《代码》</b>后，你将有机会成为<u>封闭频道</u>的居民，并获得访问所有@tg工具的更新工作簿的权限\n\n🍃 <b>点击 [★ 代码：捐款] 以打开对代码的访问</b>",
    "ar": "👩🏽‍💻 <b>محتوى المدونة {0}:</b>\n\n<b>الفعل #1</b>: <code>ماستر التوليد</code>\n<blockquote>• كتل عصبية\n• سلاسل عصبية\n• نشر عصبي\n• رد عصبي\n• حوار عصبي</blockquote>\n\n<b>الفعل #2</b>: <code>ماستر الإدارة</code>\n<blockquote>• حظر تلقائي\n• ديكور تلقائي\n• دخول تلقائي\n• نشر تلقائي\n• بودكاست تلقائي\n• رد تلقائي</blockquote>\n\n<b>الفعل #3</b>: <code>ماستر البحث</code>\n<blockquote>• بحث متميز\n• بحث سلبي\n• بحث مدمج\n• بحث إبداعات\n• بحث عصبي\n• بحث إعجاب\n• بحث جغرافي</blockquote>\n\n<b>الفعل #4</b>: <code>ماستر البلوكشين</code>\n<blockquote>• ماستر العقود الذكية\n• ماستر NFT\n• ماستر توكنوميكس</blockquote>\n\n<b>الفعل #5</b>: <code>خاتمة</code>\n\n🌱 بعد دراسة <b>المدونة</b>، سيكون لديك الفرصة لتصبح مقيمًا في <u>قناة مغلقة</u> والحصول على وصول إلى دفتر العمل المتجدد مع جميع أدوات @tg\n\n🍃 <b>اضغط [★ المدونة: المساهمة] لفتح الوصول إلى المدونة</b>",
}
l_codex_warm3 = {
    "ru": "👩🏽‍💻 <b>Все</b> @tg-инструменты <b>Кодекса {0}</b> поддерживаются официальными сервисами <b>Ferey</b>-проекта:\n\n<blockquote>• Bot\n• Channel\n• Group\n• User\n• Post\n• Media\n• AI\n• Find\n• Tools\n• Tonest\n• и другие •</blockquote>\n\n🌱 После изучения <b>кодекса</b>, у тебя появится возможность узнать как работать с каждым из <u>сервисов</u>, ссылки на которые найдешь внутри кодекса\n\n🍃 <b>Жми [★ Кодекс: взнос], чтобы открыть доступ к кодексу</b>",
    "en": "👩🏽‍💻 <b>All</b> @tg-tools of the <b>Code {0}</b> are supported by the official services of the <b>Ferey</b> project:\n\n<blockquote>• Bot\n• Channel\n• Group\n• User\n• Post\n• Media\n• AI\n• Find\n• Tools\n• Tonest\n• and others •</blockquote>\n\n🌱 After studying the <b>code</b>, you will have the opportunity to learn how to work with each of the <u>services</u>, links to which you will find inside the code\n\n🍃 <b>Click [★ Code: contribution] to gain access to the code</b>",
    "es": "👩🏽‍💻 <b>Todos</b> @tg-herramientas <b>Código {0}</b> son compatibles con los servicios oficiales del proyecto <b>Ferey</b>:\n\n<blockquote>• Bot\n• Canal\n• Grupo\n• Usuario\n• Publicación\n• Medios\n• IA\n• Buscar\n• Herramientas\n• Tonest\n• y otros •</blockquote>\n\n🌱 Después de estudiar el <b>código</b>, tendrás la oportunidad de aprender a trabajar con cada uno de los <u>servicios</u>, cuyos enlaces encontrarás dentro del código\n\n🍃 <b>Haz clic en [★ Código: contribución] para abrir el acceso al código</b>",
    "fr": "👩🏽‍💻 <b>Tous</b> les outils @tg du <b>Code {0}</b> sont pris en charge par les services officiels du projet <b>Ferey</b> :\n\n<blockquote>• Bot\n• Canal\n• Groupe\n• Utilisateur\n• Publication\n• Média\n• IA\n• Trouver\n• Outils\n• Tonest\n• et d'autres •</blockquote>\n\n🌱 Après avoir étudié le <b>code</b>, tu auras la possibilité d'apprendre à travailler avec chacun des <u>services</u>, dont les liens se trouvent à l'intérieur du code\n\n🍃 <b>Clique sur [★ Code : contribution] pour accéder au code</b>",
    "zh": "👩🏽‍💻 <b>所有</b> @tg-工具 <b>代码 {0}</b> 都由官方服务 <b>Ferey</b> 项目支持：\n\n<blockquote>• 机器人\n• 频道\n• 群组\n• 用户\n• 帖子\n• 媒体\n• 人工智能\n• 查找\n• 工具\n• Tonest\n• 其他 •</blockquote>\n\n🌱 学习 <b>代码</b> 后，你将有机会了解如何使用每个 <u>服务</u>，链接可以在代码中找到\n\n🍃 <b>点击 [★ 代码：捐款] 以打开访问代码的权限</b>",
    "ar": "👩🏽‍💻 <b>جميع</b> أدوات @tg-كودكس {0} مدعومة من قبل الخدمات الرسمية لمشروع <b>Ferey</b>:\n\n<blockquote>• بوت\n• قناة\n• مجموعة\n• مستخدم\n• منشور\n• وسائط\n• ذكاء اصطناعي\n• بحث\n• أدوات\n• تونست\n• وغيرها •</blockquote>\n\n🌱 بعد دراسة <b>الكودكس</b>، سيكون لديك الفرصة لمعرفة كيفية العمل مع كل من <u>الخدمات</u>، الروابط التي ستجدها داخل الكودكس\n\n🍃 <b>اضغط [★ كودكس: مساهمة] لفتح الوصول إلى الكودكس</b>",
}
l_codex_warm4 = {
    "ru": "👩🏽‍💻 <b>Приобретай</b> доступ к Кодексу {0} или поддержи <i>проект</i> донатом",
    "en": "👩🏽‍💻 <b>Get</b> access to the Code {0} or support the <i>project</i> with a donation",
    "es": "👩🏽‍💻 <b>Adquiere</b> acceso al Código {0} o apoya <i>el proyecto</i> con una donación",
    "fr": "👩🏽‍💻 <b>Achetez</b> l'accès au Code {0} ou soutenez le <i>projet</i> par un don",
    "zh": "👩🏽‍💻 <b>获取</b> {0} 的代码访问权限或通过捐赠支持 <i>项目</i>",
    "ar": "👩🏽‍💻 <b>احصل على</b> وصول إلى المدونة {0} أو دعم <i>المشروع</i> بالتبرع",
}
l_codex_pay_text = {
    "ru": "★ Кодекс: взнос",
    "en": "★ Code: contribution",
    "es": "★ Código: contribución",
    "fr": "★ Code: contribution",
    "zh": "★ 代码：捐款",
    "ar": "★ المدونة: المساهمة",
}
l_codex_pay_check = {
    "ru": "👩🏽‍💻 Проверка взноса",
    "en": "👩🏽‍💻 Contribution check",
    "es": "👩🏽‍💻 Verificación de la contribución",
    "fr": "👩🏽‍💻 Vérification de la contribution",
    "zh": "👩🏽‍💻 检查捐款",
    "ar": "👩🏽‍💻 التحقق من المساهمة",
}
l_codex_transcribation_btn = {
    "ru": "💨 Конспект",
    "en": "💨 Summary",
    "es": "💨 Resumen",
    "fr": "💨 Résumé",
    "zh": "💨 摘要",
    "ar": "💨 ملخص",
}
l_codex_caption_0 = {
    "ru": "👩🏽‍💻 <b>Акт #1</b>: <code>введение</code>\n\n00:03 - актуальность\n00:05 - цель\n00:07 - задачи\n\n<blockquote>Жми на • 2 • страницу, чтобы перейти к следующему акту</blockquote>",
    "en": "👩🏽‍💻 <b>Act #1</b>: <code>introduction</code>\n\n00:03 - relevance  \n00:05 - goal  \n00:07 - tasks  \n\n<blockquote>Click on • 2 • page to go to the next act</blockquote>",
    "es": "👩🏽‍💻 <b>Acto #1</b>: <code>introducción</code>\n\n00:03 - relevancia\n00:05 - objetivo\n00:07 - tareas\n\n<blockquote>Haz clic en • 2 • página para pasar al siguiente acto</blockquote>",
    "fr": "👩🏽‍💻 <b>Acte #1</b>: <code>introduction</code>\n\n00:03 - pertinence\n00:05 - objectif\n00:07 - tâches\n\n<blockquote>Appuie sur • 2 • page pour passer à l'acte suivant</blockquote>",
    "zh": "👩🏽‍💻 <b>行动 #1</b>: <code>引言</code>\n\n00:03 - 相关性\n00:05 - 目标\n00:07 - 任务\n\n<blockquote>点击 • 2 • 页，跳转到下一个行动</blockquote>",
    "ar": "👩🏽‍💻 <b>الفعل #1</b>: <code>مقدمة</code>\n\n00:03 - الأهمية\n00:05 - الهدف\n00:07 - المهام\n\n<blockquote>اضغط على • 2 • للانتقال إلى الفعل التالي</blockquote>",
}
l_codex_caption_1 = {
    "ru": "👩🏽‍💻 <b>Акт #1</b>: <code>мастер генераций</code>\n\n00:10 нейро-сообщения\n00:20 нейро-приложения\n00:30 нейро-диалог\n00:40 нейро-поиск\n00:50 нейро-анализ\n\n<blockquote><b>Используемые</b> в видео <u>@tg</u>-приложения:</blockquote>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>\n<a href='https://t.me/FereyGroupBot?start=codex'>@FereyGroupBot</a>\n<a href='https://t.me/FereyChannelBot?start=codex'>@FereyChannelBot</a>\n<a href='https://t.me/FereyUserBot?start=codex'>@FereyUserBot</a>\n<a href='https://t.me/FereyAIBot?start=codex'>@FereyAIBot</a>",
    "en": "👩🏽‍💻 <b>Act #1</b>: <code>master of generations</code>\n\n00:10 neuro-messages\n00:20 neuro-apps\n00:30 neuro-dialog\n00:40 neuro-search\n00:50 neuro-analysis\n\n<blockquote><b>Applications used</b> in the video <u>@tg</u>-apps:</blockquote>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>\n<a href='https://t.me/FereyGroupBot?start=codex'>@FereyGroupBot</a>\n<a href='https://t.me/FereyChannelBot?start=codex'>@FereyChannelBot</a>\n<a href='https://t.me/FereyUserBot?start=codex'>@FereyUserBot</a>\n<a href='https://t.me/FereyAIBot?start=codex'>@FereyAIBot</a>",
    "es": "👩🏽‍💻 <b>Acto #1</b>: <code>maestro de generaciones</code>\n\n00:10 neuro-mensajes\n00:20 neuro-aplicaciones\n00:30 neuro-diálogo\n00:40 neuro-búsqueda\n00:50 neuro-análisis\n\n<blockquote><b>Aplicaciones usadas</b> en el video <u>@tg</u>-aplicaciones:</blockquote>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>\n<a href='https://t.me/FereyGroupBot?start=codex'>@FereyGroupBot</a>\n<a href='https://t.me/FereyChannelBot?start=codex'>@FereyChannelBot</a>\n<a href='https://t.me/FereyUserBot?start=codex'>@FereyUserBot</a>\n<a href='https://t.me/FereyAIBot?start=codex'>@FereyAIBot</a>",
    "fr": "👩🏽‍💻 <b>Acte #1</b>: <code>maître des générations</code>\n\n00:10 neuro-messages\n00:20 neuro-applications\n00:30 neuro-dialogue\n00:40 neuro-recherche\n00:50 neuro-analyse\n\n<blockquote><b>Applications utilisées</b> dans la vidéo <u>@tg</u>-applications :</blockquote>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>\n<a href='https://t.me/FereyGroupBot?start=codex'>@FereyGroupBot</a>\n<a href='https://t.me/FereyChannelBot?start=codex'>@FereyChannelBot</a>\n<a href='https://t.me/FereyUserBot?start=codex'>@FereyUserBot</a>\n<a href='https://t.me/FereyAIBot?start=codex'>@FereyAIBot</a>",
    "zh": "👩🏽‍💻 <b>行动 #1</b>: <code>生成大师</code>\n\n00:10 神经消息\n00:20 神经应用\n00:30 神经对话\n00:40 神经搜索\n00:50 神经分析\n\n<blockquote><b>视频中使用的</b> @tg 应用：</blockquote>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>\n<a href='https://t.me/FereyGroupBot?start=codex'>@FereyGroupBot</a>\n<a href='https://t.me/FereyChannelBot?start=codex'>@FereyChannelBot</a>\n<a href='https://t.me/FereyUserBot?start=codex'>@FereyUserBot</a>\n<a href='https://t.me/FereyAIBot?start=codex'>@FereyAIBot</a>",
    "ar": "👩🏽‍💻 <b>الفصل #1</b>: <code>خبير التوليد</code>\n\n00:10 رسائل عصبية\n00:20 تطبيقات عصبية\n00:30 حوار عصبي\n00:40 بحث عصبي\n00:50 تحليل عصبي\n\n<blockquote><b>التطبيقات المستخدمة</b> في الفيديو <u>@tg</u>-تطبيقات:</blockquote>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>\n<a href='https://t.me/FereyGroupBot?start=codex'>@FereyGroupBot</a>\n<a href='https://t.me/FereyChannelBot?start=codex'>@FereyChannelBot</a>\n<a href='https://t.me/FereyUserBot?start=codex'>@FereyUserBot</a>\n<a href='https://t.me/FereyAIBot?start=codex'>@FereyAIBot</a>",
}
l_codex_caption_2 = {
    "ru": "👩🏽‍💻 <b>Акт #2</b>: <code>мастер автоматизации</code>\n\n00:10 монетизация\n00:20 модерация\n00:25 постинг\n00:35 подкасты\n00:45 геймификация\n\n<blockquote><b>Используемые</b> в видео <u>@tg</u>-приложения:</blockquote>\n<a href='https://t.me/FereyChannelBot?start=codex'>@FereyChannelBot</a>\n<a href='https://t.me/FereyGroupBot?start=codex'>@FereyGroupBot</a>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>\n<a href='https://t.me/FereyPostBot?start=codex'>@FereyPostBot</a>\n<a href='https://t.me/FereyUserBot?start=codex'>@FereyUserBot</a>",
    "en": "👩🏽‍💻 <b>Act #2</b>: <code>automation master</code>\n\n00:10 monetization\n00:20 moderation\n00:25 posting\n00:35 podcasts\n00:45 gamification\n\n<blockquote><b>Applications used</b> in the video <u>@tg</u>-apps:</blockquote>\n<a href='https://t.me/FereyChannelBot?start=codex'>@FereyChannelBot</a>\n<a href='https://t.me/FereyGroupBot?start=codex'>@FereyGroupBot</a>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>\n<a href='https://t.me/FereyPostBot?start=codex'>@FereyPostBot</a>\n<a href='https://t.me/FereyUserBot?start=codex'>@FereyUserBot</a>",
    "es": "👩🏽‍💻 <b>Acto #2</b>: <code>maestro de automatización</code>\n\n00:10 monetización\n00:20 moderación\n00:25 publicación\n00:35 pódcast\n00:45 gamificación\n\n<blockquote><b>Aplicaciones utilizadas</b> en el video <u>@tg</u>-aplicaciones:</blockquote>\n<a href='https://t.me/FereyChannelBot?start=codex'>@FereyChannelBot</a>\n<a href='https://t.me/FereyGroupBot?start=codex'>@FereyGroupBot</a>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>\n<a href='https://t.me/FereyPostBot?start=codex'>@FereyPostBot</a>\n<a href='https://t.me/FereyUserBot?start=codex'>@FereyUserBot</a>",
    "fr": "👩🏽‍💻 <b>Acte #2</b>: <code>maître de l'automatisation</code>\n\n00:10 monétisation\n00:20 modération\n00:25 publication\n00:35 podcasts\n00:45 gamification\n\n<blockquote><b>Applications utilisées</b> dans la vidéo <u>@tg</u>-applications :</blockquote>\n<a href='https://t.me/FereyChannelBot?start=codex'>@FereyChannelBot</a>\n<a href='https://t.me/FereyGroupBot?start=codex'>@FereyGroupBot</a>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>\n<a href='https://t.me/FereyPostBot?start=codex'>@FereyPostBot</a>\n<a href='https://t.me/FereyUserBot?start=codex'>@FereyUserBot</a>",
    "zh": "👩🏽‍💻 <b>行动 #2</b>: <code>自动化大师</code>\n\n00:10 货币化\n00:20 审核\n00:25 发布\n00:35 播客\n00:45 游戏化\n\n<blockquote><b>视频中使用的</b> @tg 应用：</blockquote>\n<a href='https://t.me/FereyChannelBot?start=codex'>@FereyChannelBot</a>\n<a href='https://t.me/FereyGroupBot?start=codex'>@FereyGroupBot</a>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>\n<a href='https://t.me/FereyPostBot?start=codex'>@FereyPostBot</a>\n<a href='https://t.me/FereyUserBot?start=codex'>@FereyUserBot</a>",
    "ar": "👩🏽‍💻 <b>الفصل #2</b>: <code>خبير الأتمتة</code>\n\n00:10 تحقيق الدخل\n00:20 الإشراف\n00:25 النشر\n00:35 البودكاست\n00:45 الألعاب\n\n<blockquote><b>التطبيقات المستخدمة</b> في الفيديو <u>@tg</u>-تطبيقات:</blockquote>\n<a href='https://t.me/FereyChannelBot?start=codex'>@FereyChannelBot</a>\n<a href='https://t.me/FereyGroupBot?start=codex'>@FereyGroupBot</a>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>\n<a href='https://t.me/FereyPostBot?start=codex'>@FereyPostBot</a>\n<a href='https://t.me/FereyUserBot?start=codex'>@FereyUserBot</a>",
}
l_codex_caption_3 = {
    "ru": "👩🏽‍💻 <b>Акт #3</b>: <code>мастер поиска</code>\n\n00:10 категории\n00:15 маркетплейсы\n00:30 мониторинг\n00:35 геймификация\n00:40 анализ\n\n<blockquote><b>Используемые</b> в видео <u>@tg</u>-приложения:</blockquote>\n<a href='https://t.me/FereyFindBot?start=codex'>@FereyFindBot</a>\n<a href='https://t.me/FereyMediaBot?start=codex'>@FereyMediaBot</a>\n<a href='https://t.me/FereyUserBot?start=codex'>@FereyUserBot</a>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>\n<a href='https://t.me/FereyAIBot?start=codex'>@FereyAIBot</a>",
    "en": "👩🏽‍💻 <b>Act #3</b>: <code>search master</code>\n\n00:10 categories\n00:15 marketplaces\n00:30 monitoring\n00:35 gamification\n00:40 analysis\n\n<blockquote><b>Applications used</b> in the video <u>@tg</u>-apps:</blockquote>\n<a href='https://t.me/FereyFindBot?start=codex'>@FereyFindBot</a>\n<a href='https://t.me/FereyMediaBot?start=codex'>@FereyMediaBot</a>\n<a href='https://t.me/FereyUserBot?start=codex'>@FereyUserBot</a>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>\n<a href='https://t.me/FereyAIBot?start=codex'>@FereyAIBot</a>",
    "es": "👩🏽‍💻 <b>Acto #3</b>: <code>maestro de búsqueda</code>\n\n00:10 categorías\n00:15 marketplaces\n00:30 monitorización\n00:35 gamificación\n00:40 análisis\n\n<blockquote><b>Aplicaciones utilizadas</b> en el video <u>@tg</u>-aplicaciones:</blockquote>\n<a href='https://t.me/FereyFindBot?start=codex'>@FereyFindBot</a>\n<a href='https://t.me/FereyMediaBot?start=codex'>@FereyMediaBot</a>\n<a href='https://t.me/FereyUserBot?start=codex'>@FereyUserBot</a>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>\n<a href='https://t.me/FereyAIBot?start=codex'>@FereyAIBot</a>",
    "fr": "👩🏽‍💻 <b>Acte #3</b>: <code>maître de recherche</code>\n\n00:10 catégories\n00:15 marketplaces\n00:30 surveillance\n00:35 gamification\n00:40 analyse\n\n<blockquote><b>Applications utilisées</b> dans la vidéo <u>@tg</u>-applications :</blockquote>\n<a href='https://t.me/FereyFindBot?start=codex'>@FereyFindBot</a>\n<a href='https://t.me/FereyMediaBot?start=codex'>@FereyMediaBot</a>\n<a href='https://t.me/FereyUserBot?start=codex'>@FereyUserBot</a>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>\n<a href='https://t.me/FereyAIBot?start=codex'>@FereyAIBot</a>",
    "zh": "👩🏽‍💻 <b>行动 #3</b>: <code>搜索大师</code>\n\n00:10 分类\n00:15 市场\n00:30 监测\n00:35 游戏化\n00:40 分析\n\n<blockquote><b>视频中使用的</b> @tg 应用：</blockquote>\n<a href='https://t.me/FereyFindBot?start=codex'>@FereyFindBot</a>\n<a href='https://t.me/FereyMediaBot?start=codex'>@FereyMediaBot</a>\n<a href='https://t.me/FereyUserBot?start=codex'>@FereyUserBot</a>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>\n<a href='https://t.me/FereyAIBot?start=codex'>@FereyAIBot</a>",
    "ar": "👩🏽‍💻 <b>الفعل #3</b>: <code>خبير البحث</code>\n\n00:10 الفئات\n00:15 الأسواق\n00:30 الرصد\n00:35 الألعاب\n00:40 التحليل\n\n<blockquote><b>التطبيقات المستخدمة</b> في الفيديو <u>@tg</u>-تطبيقات:</blockquote>\n<a href='https://t.me/FereyFindBot?start=codex'>@FereyFindBot</a>\n<a href='https://t.me/FereyMediaBot?start=codex'>@FereyMediaBot</a>\n<a href='https://t.me/FereyUserBot?start=codex'>@FereyUserBot</a>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>\n<a href='https://t.me/FereyAIBot?start=codex'>@FereyAIBot</a>",
}
l_codex_caption_4 = {
    "ru": "👩🏽‍💻 <b>Акт #4</b>: <code>мастер блокчейна</code>\n\n00:10 смарт-контракты\n00:20 NFT сообщества\n00:30 TON-аккаунт\n00:35 коллекции\n00:40 токеномика\n\n<blockquote><b>Используемые</b> в видео <u>@tg</u>-приложения:</blockquote>\n<a href='https://t.me/FereyTONestBot?start=codex'>@FereyTONestBot</a>\n<a href='https://t.me/FereyChannelBot?start=codex'>@FereyChannelBot</a>\n<a href='https://t.me/FereyGroupBot?start=codex'>@FereyGroupBot</a>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>",
    "en": "👩🏽‍💻 <b>Act #4</b>: <code>blockchain master</code>\n\n00:10 smart contracts\n00:20 NFT communities\n00:30 TON account\n00:35 collections\n00:40 tokenomics\n\n<blockquote><b>Applications used</b> in the video <u>@tg</u>-apps:</blockquote>\n<a href='https://t.me/FereyTONestBot?start=codex'>@FereyTONestBot</a>\n<a href='https://t.me/FereyChannelBot?start=codex'>@FereyChannelBot</a>\n<a href='https://t.me/FereyGroupBot?start=codex'>@FereyGroupBot</a>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>",
    "es": "👩🏽‍💻 <b>Acto #4</b>: <code>maestro de blockchain</code>\n\n00:10 contratos inteligentes\n00:20 comunidades NFT\n00:30 cuenta TON\n00:35 colecciones\n00:40 tokenómica\n\n<blockquote><b>Aplicaciones utilizadas</b> en el video <u>@tg</u>-aplicaciones:</blockquote>\n<a href='https://t.me/FereyTONestBot?start=codex'>@FereyTONestBot</a>\n<a href='https://t.me/FereyChannelBot?start=codex'>@FereyChannelBot</a>\n<a href='https://t.me/FereyGroupBot?start=codex'>@FereyGroupBot</a>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>",
    "fr": "👩🏽‍💻 <b>Acte #4</b>: <code>maître de la blockchain</code>\n\n00:10 contrats intelligents\n00:20 communautés NFT\n00:30 compte TON\n00:35 collections\n00:40 tokenomics\n\n<blockquote><b>Applications utilisées</b> dans la vidéo <u>@tg</u>-applications :</blockquote>\n<a href='https://t.me/FereyTONestBot?start=codex'>@FereyTONestBot</a>\n<a href='https://t.me/FereyChannelBot?start=codex'>@FereyChannelBot</a>\n<a href='https://t.me/FereyGroupBot?start=codex'>@FereyGroupBot</a>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>",
    "zh": "👩🏽‍💻 <b>行动 #4</b>: <code>区块链大师</code>\n\n00:10 智能合约\n00:20 NFT 社区\n00:30 TON 账户\n00:35 收藏\n00:40 代币经济学\n\n<blockquote><b>视频中使用的</b> @tg 应用：</blockquote>\n<a href='https://t.me/FereyTONestBot?start=codex'>@FereyTONestBot</a>\n<a href='https://t.me/FereyChannelBot?start=codex'>@FereyChannelBot</a>\n<a href='https://t.me/FereyGroupBot?start=codex'>@FereyGroupBot</a>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>",
    "ar": "👩🏽‍💻 <b>الفعل #4</b>: <code>خبير البلوكتشين</code>\n\n00:10 العقود الذكية\n00:20 مجتمعات NFT\n00:30 حساب TON\n00:35 المجموعات\n00:40 اقتصاديات التوكن\n\n<blockquote><b>التطبيقات المستخدمة</b> في الفيديو <u>@tg</u>-تطبيقات:</blockquote>\n<a href='https://t.me/FereyTONestBot?start=codex'>@FereyTONestBot</a>\n<a href='https://t.me/FereyChannelBot?start=codex'>@FereyChannelBot</a>\n<a href='https://t.me/FereyGroupBot?start=codex'>@FereyGroupBot</a>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>",
}
l_codex_caption_5 = {
    "ru": "👩🏽‍💻 <b>Акт #5</b>: <code>заключение</code>\n\n00:05 - результаты\n00:10 - вывод\n\n<blockquote><b>Рассмотрены</b> <u>@tg</u>-приложения #нейро-генерации/администрирования/поиска/блокчейн интеграции</blockquote>\n\n🌱 <b>Переходи</b> к <a href='{0}'>реалити-фесту</a>, чтобы подробно в режиме <b>реального времени</b> собрать все @tg-инструменты для развития своего продукта\n\n🍃 <b>Становись</b> резидентом <a href='{1}'>закрытого канала</a>, чтобы приобрести <b>рабочую книгу</b> с актуальными знаниями и в числе первых получать инструкции нового @tg-функционала",
    "en": "👩🏽‍💻 <b>Act #5</b>: <code>conclusion</code>\n\n00:05 - results\n00:10 - summary\n\n<blockquote><b>Reviewed</b> <u>@tg</u>-applications #neuro-generation/administration/search/blockchain integration</blockquote>\n\n🌱 <b>Join</b> the <a href='{0}'>reality fest</a> to collect in detail, in <b>real time</b>, all @tg-tools for developing your product\n\n🍃 <b>Become</b> a resident of the <a href='{1}'>closed channel</a> to get a <b>workbook</b> with up-to-date knowledge and be among the first to receive instructions on new @tg features",
    "es": "👩🏽‍💻 <b>Acto #5</b>: <code>conclusión</code>\n\n00:05 - resultados\n00:10 - resumen\n\n<blockquote><b>Revisadas</b> aplicaciones <u>@tg</u> #neuro-generación/administración/búsqueda/integración blockchain</blockquote>\n\n🌱 <b>Pasa</b> al <a href='{0}'>festival de realidad</a> para recopilar en detalle, en <b>tiempo real</b>, todas las herramientas @tg para desarrollar tu producto\n\n🍃 <b>Conviértete</b> en residente del <a href='{1}'>canal cerrado</a> para obtener un <b>cuaderno de trabajo</b> con conocimientos actualizados y ser de los primeros en recibir instrucciones sobre las nuevas funciones de @tg",
    "fr": "👩🏽‍💻 <b>Acte #5</b>: <code>conclusion</code>\n\n00:05 - résultats\n00:10 - synthèse\n\n<blockquote><b>Examinées</b> applications <u>@tg</u> #neuro-génération/administration/recherche/intégration blockchain</blockquote>\n\n🌱 <b>Rejoins</b> le <a href='{0}'>festival de la réalité</a> pour rassembler en détail, en <b>temps réel</b>, tous les outils @tg pour développer ton produit\n\n🍃 <b>Deviens</b> résident du <a href='{1}'>canal privé</a> pour obtenir un <b>carnet de travail</b> avec des connaissances à jour et être parmi les premiers à recevoir les instructions sur les nouvelles fonctionnalités @tg",
    "zh": "👩🏽‍💻 <b>行动 #5</b>: <code>结论</code>\n\n00:05 - 结果\n00:10 - 总结\n\n<blockquote><b>已审阅</b> <u>@tg</u> 应用 #神经生成/管理/搜索/区块链 集成</blockquote>\n\n🌱 <b>前往</b> <a href='{0}'>现实节</a>，以在<b>实时</b>中详细收集所有用于发展您产品的 @tg 工具\n\n🍃 <b>成为</b> <a href='{1}'>封闭频道</a> 的成员，以获取一本包含最新知识的 <b>工作手册</b>，并成为第一批收到新 @tg 功能说明的人",
    "ar": "👩🏽‍💻 <b>الحدث #5</b>: <code>الاستنتاج</code>\n\n00:05 - النتائج\n00:10 - الخلاصة\n\n<blockquote><b>تمت مراجعة</b> تطبيقات <u>@tg</u> #التوليد_العصبي/الإدارة/البحث/تكامل_البلوكشين</blockquote>\n\n🌱 <b>انتقل</b> إلى <a href='{0}'>مهرجان الواقع</a> لجمع جميع أدوات @tg لتطوير منتجك بالتفصيل وفي <b>الوقت الحقيقي</b>\n\n🍃 <b>كن</b> مقيمًا في <a href='{1}'>القناة المغلقة</a> للحصول على <b>كتاب عمل</b> بالمعرفة المحدثة ولكي تكون من أوائل من يتلقون تعليمات الوظائف الجديدة لـ @tg",
}
l_fest_pay_btn = {
    "ru": "ᯅ Реалити: фест",
    "en": "ᯅ Reality: fest",
    "es": "ᯅ Realidad: fest",
    "fr": "ᯅ Réalité : fest",
    "zh": "ᯅ 现实：节日",
    "ar": "ᯅ الواقع: مهرجان",
}
l_league_btn = {
    "ru": "🌿 Лига",
    "en": "🌿 League",
    "es": "🌿 Liga",
    "fr": "🌿 Ligue",
    "zh": "🌿 联盟",
    "ar": "🌿 الدوري",
}

l_codex_fest_before = {
    "ru": "👩🏽‍💻 <b>Перед</b> прохождением Реалити-феста необходимо сначала изучить [Кодекс 1.0]",
    "en": "👩🏽‍💻 <b>Before</b> participating in the Reality Fest you must first study [Codex 1.0]",
    "es": "👩🏽‍💻 <b>Antes</b> de participar en el Reality Fest debes primero estudiar [Códice 1.0]",
    "fr": "👩🏽‍💻 <b>Avant</b> de participer au Reality Fest, vous devez d'abord étudier [Codex 1.0]",
    "zh": "👩🏽‍💻 <b>在</b>参加现实节之前，必须先学习[法典 1.0]",
    "ar": "👩🏽‍💻 <b>قبل</b> المشاركة في مهرجان الواقع، يجب عليك أولاً دراسة [كودكس 1.0]",
}
l_codex_fest_doc = {
    "ru": "👩🏽‍💻 <b>Реалити-фест</b> - это программа полного погружения в экосистему и использования всех проектов под свои задачи персонально\n\nᯅ <b>Скачивай</b> pdf-чек-лист по созданию @tg-приложений и открывай реалити-фест по кнопке ниже",
    "en": "👩🏽‍💻 <b>Reality Fest</b> - is a full-immersion program into the ecosystem and the use of all projects for your personal tasks\n\nᯅ <b>Download</b> the pdf checklist for creating @tg-apps and open the Reality Fest via the button below",
    "es": "👩🏽‍💻 <b>Reality Fest</b> - es un programa de inmersión total en el ecosistema y el uso de todos los proyectos para tus tareas personales\n\nᯅ <b>Descarga</b> la lista de verificación en pdf para crear @tg-apps y abre el Reality Fest con el botón de abajo",
    "fr": "👩🏽‍💻 <b>Reality Fest</b> - c'est un programme d'immersion totale dans l'écosystème et l'utilisation de tous les projets pour vos tâches personnelles\n\nᯅ <b>Télécharge</b> la checklist pdf pour créer des @tg-apps et ouvre le Reality Fest via le bouton ci-dessous",
    "zh": "👩🏽‍💻 <b>现实节</b> - 这是一个完整沉浸式的项目，用于深入生态系统并将所有项目用于你的个人任务\n\nᯅ <b>下载</b> 用于创建 @tg-apps 的 pdf 清单，并通过下面的按钮打开现实节",
    "ar": "👩🏽‍💻 <b>مهرجان الواقع</b> - برنامج غمر كامل في النظام البيئي واستخدام جميع المشاريع لمهامك الشخصية\n\nᯅ <b>حمّل</b> قائمة التحقق بصيغة pdf لإنشاء @tg-apps وافتح مهرجان الواقع عبر الزر أدناه",
}
# endregion


# region FereySupportBot
l_support_btn1 = {
    "ru": "👩🏽‍💻 Проекты",
    "en": "👩🏽‍💻 Projects",
    "es": "👩🏽‍💻 Proyectos",
    "fr": "👩🏽‍💻 Projets",
    "zh": "👩🏽‍💻 项目",
    "ar": "👩🏽‍💻 المشاريع",
}
l_support_btn2 = {
    "ru": "💨 Подписка",
    "en": "💨 Subscription",
    "es": "💨 Suscripción",
    "fr": "💨 Abonnement",
    "zh": "💨 订阅",
    "ar": "💨 الاشتراك",
}
l_support_welcome = {
    "ru": "🌱 <b>{0}</b>, добро пожаловать в <i>@tg-приложение</i>: служба <b>заботы</b> Ferey-экосистемы:\n\n<blockquote>▪️<b>задавай</b> вопросы\n▪️<b>присылай</b> любые медиа-файлы</blockquote>",
    "en": "🌱 <b>{0}</b>, welcome to <i>@tg-app</i>: the <b>care</b> service of the Ferey ecosystem:\n\n<blockquote>▪️<b>ask</b> questions\n▪️<b>send</b> any media files</blockquote>",
    "es": "🌱 <b>{0}</b>, bienvenido a <i>@tg-aplicación</i>: el servicio de <b>cuidado</b> del ecosistema Ferey:\n\n<blockquote>▪️<b>haz</b> preguntas\n▪️<b>envía</b> cualquier archivo multimedia</blockquote>",
    "fr": "🌱 <b>{0}</b>, bienvenue dans <i>@tg-application</i> : le service de <b>soins</b> de l'écosystème Ferey :\n\n<blockquote>▪️<b>pose</b> des questions\n▪️<b>envoie</b> tous les fichiers multimédias</blockquote>",
    "zh": "🌱 <b>{0}</b>, 欢迎来到 <i>@tg-应用</i>：Ferey生态系统的<b>关怀</b>服务：\n\n<blockquote>▪️<b>提问</b>\n▪️<b>发送</b>任何媒体文件</blockquote>",
    "ar": "🌱 <b>{0}</b>, مرحبًا بك في <i>@tg-التطبيق</i>: خدمة <b>الرعاية</b> لنظام Ferey البيئي:\n\n<blockquote>▪️<b>اطرح</b> الأسئلة\n▪️<b>أرسل</b> أي ملفات وسائط</blockquote>",
}
l_subscribe_support = {
    "ru": "👩🏽‍💻 <b>Оформи</b> ежемесячную подписку:\n\n¹ [<b>Все приложения</b> и проекты (-<u>22</u>%)]",
    "en": "👩🏽‍💻 <b>Subscribe</b> to a monthly plan:\n\n¹ [<b>All apps</b> and projects (-<u>22</u>%)]",
    "es": "👩🏽‍💻 <b>Suscríbete</b> a una suscripción mensual:\n\n¹ [<b>Todas las aplicaciones</b> y proyectos (-<u>22</u>%)]",
    "fr": "👩🏽‍💻 <b>Abonnez-vous</b> à un abonnement mensuel :\n\n¹ [<b>Toutes les applications</b> et projets (-<u>22</u>%)]",
    "zh": "👩🏽‍💻 <b>订阅</b> 每月订阅：\n\n¹ [<b>所有应用程序</b> 和项目 (-<u>22</u>%)]",
    "ar": "👩🏽‍💻 <b>اشترك</b> في الاشتراك الشهري:\n\n¹ [<b>جميع التطبيقات</b> والمشاريع (-<u>22</u>%)]",
}
# endregion


# region FereyFestBot
l_fest_btn1 = {
    "ru": "👩🏽‍💻 Реалити",
    "en": "👩🏽‍💻 Reality",
    "es": "👩🏽‍💻 Realidad",
    "fr": "👩🏽‍💻 Réalité",
    "zh": "👩🏽‍💻 现实",
    "ar": "👩🏽‍💻 واقع",
}
l_fest_btn2 = {
    "ru": "💨 Подписка",
    "en": "💨 Subscription",
    "es": "💨 Suscripción",
    "fr": "💨 Abonnement",
    "zh": "💨 订阅",
    "ar": "💨 الاشتراك",
}
l_fest_welcome = {
    "ru": "🌱 <b>{0}</b>, добро пожаловать в <i>@tg-приложение</i> службу <b>заботы</b> Ferey-проекта:\n\n▪️<b>задавай</b> вопросы\n▪️<b>присылай</b> любые медиа-файлы",
    "en": "🌱 <b>{0}</b>, welcome to the <i>@tg-app</i> service of <b>care</b> for the Ferey project:\n\n▪️<b>ask</b> questions\n▪️<b>send</b> any media files",
    "es": "🌱 <b>{0}</b>, bienvenido a la <i>aplicación @tg</i> del servicio de <b>cuidado</b> del proyecto Ferey:\n\n▪️<b>haz</b> preguntas\n▪️<b>envía</b> cualquier archivo multimedia",
    "fr": "🌱 <b>{0}</b>, bienvenue dans le service <b>soins</b> du projet Ferey de l<i>@tg-application</i> :\n\n▪️<b>pose</b> des questions\n▪️<b>envoie</b> tous les fichiers multimédias",
    "zh": "🌱 <b>{0}</b>，欢迎来到 <i>@tg-应用程序</i> Ferey项目的 <b>关怀</b> 服务：\n\n▪️<b>提问</b>\n▪️<b>发送</b> 任何媒体文件",
    "ar": "🌱 <b>{0}</b>, مرحبًا بك في <i>@tg-التطبيق</i> خدمة <b>الرعاية</b> لمشروع Ferey:\n\n▪️<b>اطرح</b> الأسئلة\n▪️<b>أرسل</b> أي ملفات وسائط",
}
l_subscribe_fest = {
    "ru": "👩🏽‍💻 <b>Оформи</b> ежемесячную подписку:\n\n¹ [<b>Все приложения</b> и проекты (-<u>22</u>%)]",
    "en": "👩🏽‍💻 <b>Subscribe</b> to a monthly plan:\n\n¹ [<b>All apps</b> and projects (-<u>22</u>%)]",
    "es": "👩🏽‍💻 <b>Suscríbete</b> a la suscripción mensual:\n\n¹ [<b>Todas las aplicaciones</b> y proyectos (-<u>22</u>%)]",
    "fr": "👩🏽‍💻 <b>Abonnez-vous</b> à un abonnement mensuel :\n\n¹ [<b>Toutes les applications</b> et projets (-<u>22</u>%)]",
    "zh": "👩🏽‍💻 <b>订阅</b> 每月订阅：\n\n¹ [<b>所有应用程序</b> 和项目 (-<u>22</u>%)]",
    "ar": "👩🏽‍💻 <b>اشترك</b> في الاشتراك الشهري:\n\n¹ [<b>جميع التطبيقات</b> والمشاريع (-<u>22</u>%)]",
}
# endregion

